(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    109257,       3276]
NotebookOptionsPosition[     98184,       2889]
NotebookOutlinePosition[     98541,       2905]
CellTagsIndexPosition[     98498,       2902]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
MDA-Chapter 3: Design of Mechanisms - 3.3 Crank-Rocker Mechanisms\
\>", "Subtitle"],

Cell["\<\
created 2009, Prof. Oskar Wallrapp, FK06, Munich University of Applied \
Sciences
updated 17.11.2009 - Animation\
\>", "Text",
 CellChangeTimes->{{3.4674673047927027`*^9, 3.467467366088581*^9}}],

Cell[CellGroupData[{

Cell["crank-rocker mechanismus: Basic functions", "Subsection"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
 Evaluatable->False,
 ImageSize->{263, 223},
 ImageMargins->{{110, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Clear[par,\[CurlyPhi],\[Psi],\[Psi]1,\[Psi]2,\[CurlyPhi]0,\[Psi]0,a,b,c,d];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
X = d - a Cos[\[CurlyPhi]];
Y = a Sin[\[CurlyPhi]];
\[Sigma] = ArcTan[X,Y];
\[CapitalDelta] = Sqrt[X^2 + Y^2];
\[Lambda] = Simplify[ArcCos[(\[CapitalDelta]^2 + b^2 - c^2) / (2 b \
\[CapitalDelta])] ];
f\[Psi] = \[Pi] - (\[Sigma] + \[Lambda])
f\[Psi]2 = \[Pi] - (\[Sigma] - \[Lambda])\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{"\[Pi]", "-", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["b", "2"], "-", 
     SuperscriptBox["c", "2"], "+", 
     SuperscriptBox["d", "2"], "-", 
     RowBox[{"2", " ", "a", " ", "d", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}], 
    RowBox[{"2", " ", "b", " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["d", "2"], "-", 
       RowBox[{"2", " ", "a", " ", "d", " ", 
        RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}]]}]], "]"}], "-", 
  RowBox[{"ArcTan", "[", 
   RowBox[{
    RowBox[{"d", "-", 
     RowBox[{"a", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}], ",", 
    RowBox[{"a", " ", 
     RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}]}], "]"}]}]], "Output",
 CellChangeTimes->{3.467460273239066*^9}],

Cell[BoxData[
 RowBox[{"\[Pi]", "+", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["b", "2"], "-", 
     SuperscriptBox["c", "2"], "+", 
     SuperscriptBox["d", "2"], "-", 
     RowBox[{"2", " ", "a", " ", "d", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}], 
    RowBox[{"2", " ", "b", " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["d", "2"], "-", 
       RowBox[{"2", " ", "a", " ", "d", " ", 
        RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}]]}]], "]"}], "-", 
  RowBox[{"ArcTan", "[", 
   RowBox[{
    RowBox[{"d", "-", 
     RowBox[{"a", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}], ",", 
    RowBox[{"a", " ", 
     RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}]}], "]"}]}]], "Output",
 CellChangeTimes->{3.4674602732902184`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[CurlyPhi]i", "=", 
   RowBox[{"Pi", "+", 
    RowBox[{"ArcCos", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"d", "^", "2"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"c", "-", "a"}], ")"}], "^", "2"}], "-", 
        RowBox[{"b", "^", "2"}]}], ")"}], " ", "/", " ", 
      RowBox[{"(", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"c", "-", "a"}], ")"}], " ", "d"}], ")"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CurlyPhi]a", "=", 
   RowBox[{"ArcCos", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"d", "^", "2"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"c", "+", "a"}], ")"}], "^", "2"}], "-", 
       RowBox[{"b", "^", "2"}]}], ")"}], " ", "/", " ", 
     RowBox[{"(", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"c", "+", "a"}], ")"}], " ", "d"}], ")"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"f\[CurlyPhi]0", "=", 
  RowBox[{
  "\[CurlyPhi]i", "-", "\[CurlyPhi]a"}]}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{"\[Pi]", "+", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["b", "2"]}], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "c"}], ")"}], "2"], "+", 
     SuperscriptBox["d", "2"]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "+", "c"}], ")"}], " ", "d"}]], "]"}], "-", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["b", "2"]}], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], "2"], "+", 
     SuperscriptBox["d", "2"]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"a", "+", "c"}], ")"}], " ", "d"}]], "]"}]}]], "Output",
 CellChangeTimes->{3.467460273362843*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Psi]i", "=", 
   RowBox[{"Pi", "-", 
    RowBox[{"ArcCos", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"d", "^", "2"}], "+", 
        RowBox[{"b", "^", "2"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"c", "-", "a"}], ")"}], "^", "2"}]}], ")"}], " ", "/", " ", 
      
      RowBox[{"(", 
       RowBox[{"2", " ", "b", " ", "d"}], ")"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Psi]a", "=", 
   RowBox[{"Pi", "-", 
    RowBox[{"ArcCos", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"d", "^", "2"}], "+", 
        RowBox[{"b", "^", "2"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"c", "+", "a"}], ")"}], "^", "2"}]}], ")"}], " ", "/", " ", 
      
      RowBox[{"(", 
       RowBox[{"2", " ", "b", " ", "d"}], ")"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"f\[Psi]0", "=", 
  RowBox[{"\[Psi]i", "-", "\[Psi]a"}]}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"ArcCos", "[", 
    FractionBox[
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "c"}], ")"}], "2"], "+", 
      SuperscriptBox["d", "2"]}], 
     RowBox[{"2", " ", "b", " ", "d"}]], "]"}]}], "+", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{
     SuperscriptBox["b", "2"], "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], "2"], "+", 
     SuperscriptBox["d", "2"]}], 
    RowBox[{"2", " ", "b", " ", "d"}]], "]"}]}]], "Output",
 CellChangeTimes->{3.467460273443438*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Mu]min1", "=", 
  RowBox[{"ArcCos", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "^", "2"}], "+", 
      RowBox[{"b", "^", "2"}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"d", "-", "a"}], ")"}], "^", "2"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", "b", " ", "c"}], ")"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"ArcCos", "[", 
  FractionBox[
   RowBox[{
    SuperscriptBox["b", "2"], "+", 
    SuperscriptBox["c", "2"], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "+", "d"}], ")"}], "2"]}], 
   RowBox[{"2", " ", "b", " ", "c"}]], "]"}]], "Output",
 CellChangeTimes->{3.467460273518963*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Mu]min2", "=", 
  RowBox[{"Pi", "-", 
   RowBox[{"ArcCos", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"c", "^", "2"}], "+", 
       RowBox[{"b", "^", "2"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"d", "+", "a"}], ")"}], "^", "2"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"2", " ", "b", " ", "c"}], ")"}]}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"\[Pi]", "-", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{
     SuperscriptBox["b", "2"], "+", 
     SuperscriptBox["c", "2"], "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "+", "d"}], ")"}], "2"]}], 
    RowBox[{"2", " ", "b", " ", "c"}]], "]"}]}]], "Output",
 CellChangeTimes->{3.4674602735884037`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grashof", "=", 
  RowBox[{
   RowBox[{"Min", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}], "+", 
   RowBox[{"Max", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Max", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}], "+", 
  RowBox[{"Min", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}]}]], "Output",
 CellChangeTimes->{3.4674602736733713`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.3.1\tFind mechanism for toggle points and crank angle phi0", "Section",
 CellChangeTimes->{{3.469252180223134*^9, 3.4692521815181637`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "par", ",", "\[CurlyPhi]", ",", "\[Psi]", ",", "\[Psi]1", ",", "\[Psi]2", 
    ",", "\[CurlyPhi]0", ",", "\[Psi]0", ",", "a", ",", "b", ",", "c", ",", 
    "d"}], "]"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
 "Requirements: given is ",
 StyleBox["\[CurlyPhi]0 -> 180 Degree, \[Psi]0 -> 60 Degree, d -> 100 mm, \
\[Mu]min -> 40 Degree ",
  Background->RGBColor[1, 0.5, 0]]
}], "Subsubsection",
 CellChangeTimes->{3.467460317396632*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"par", "=", 
  RowBox[{"{", 
   RowBox[{"d", "\[Rule]", "100"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"d", "\[Rule]", "100"}], "}"}]], "Output",
 CellChangeTimes->{{3.467460265995544*^9, 3.467460276903472*^9}}]
}, Open  ]],

Cell["Setup 3 Eqs for 3 unknowns a, b, c.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f\[CurlyPhi]0", "/.", "par"}]], "Input"],

Cell[BoxData[
 RowBox[{"\[Pi]", "+", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{"10000", "-", 
     SuperscriptBox["b", "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "c"}], ")"}], "2"]}], 
    RowBox[{"200", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "+", "c"}], ")"}]}]], "]"}], "-", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{"10000", "-", 
     SuperscriptBox["b", "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], "2"]}], 
    RowBox[{"200", " ", 
     RowBox[{"(", 
      RowBox[{"a", "+", "c"}], ")"}]}]], "]"}]}]], "Output",
 CellChangeTimes->{{3.467460266070447*^9, 3.467460276983424*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f\[Psi]0", "/.", "par"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"ArcCos", "[", 
    FractionBox[
     RowBox[{"10000", "+", 
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "c"}], ")"}], "2"]}], 
     RowBox[{"200", " ", "b"}]], "]"}]}], "+", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{"10000", "+", 
     SuperscriptBox["b", "2"], "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], "2"]}], 
    RowBox[{"200", " ", "b"}]], "]"}]}]], "Output",
 CellChangeTimes->{{3.467460266140049*^9, 3.467460277081677*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Mu]min1", "/.", "par"}]], "Input"],

Cell[BoxData[
 RowBox[{"ArcCos", "[", 
  FractionBox[
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"100", "-", "a"}], ")"}], "2"]}], "+", 
    SuperscriptBox["b", "2"], "+", 
    SuperscriptBox["c", "2"]}], 
   RowBox[{"2", " ", "b", " ", "c"}]], "]"}]], "Output",
 CellChangeTimes->{{3.4674602662078543`*^9, 3.4674602771616793`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"erg1", "=", 
  RowBox[{"FindRoot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"f\[CurlyPhi]0", "/.", "par"}], ")"}], "\[Equal]", 
       RowBox[{"180", " ", "Degree"}]}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"f\[Psi]0", "/.", "par"}], ")"}], "\[Equal]", 
       RowBox[{"60", " ", "Degree"}]}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]min1", "/.", "par"}], ")"}], "\[Equal]", 
       RowBox[{"40", "Degree"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "30"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"b", ",", "60"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"c", ",", "80"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "\[Rule]", "43.740825790083804`"}], ",", 
   RowBox[{"b", "\[Rule]", "87.48165158016762`"}], ",", 
   RowBox[{"c", "\[Rule]", "65.2703644666139`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.467460266703761*^9, 3.467460277404264*^9}}]
}, Open  ]],

Cell[TextData[StyleBox["This is  a realistic solution!",
 FontSize->16,
 Background->RGBColor[0, 1, 0]]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["further evaluations", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"f\[CurlyPhi]0", "/", "Degree"}], "/.", "par"}], "/.", "erg1"}],
     "//", "N"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"f\[Psi]0", "/", "Degree"}], "/.", "par"}], "/.", "erg1"}], "//",
     "N"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Mu]min1", "/", "Degree"}], "/.", "par"}], "/.", "erg1"}], "//",
     "N"}]}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "179.99999999999997`", ",", "59.999999999999986`", ",", 
   "39.999999999999986`"}], "}"}]], "Output",
 CellChangeTimes->{{3.467460267084689*^9, 3.4674602776406193`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[CurlyPhi]", "=", 
   RowBox[{"phiG", " ", "\[Degree]"}]}], ";"}], "\n", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["f\[Psi]", "\[Degree]"], "/.", "\[InvisibleSpace]", "par"}], 
    "/.", "\[InvisibleSpace]", "erg1"}], ",", 
   RowBox[{"{", 
    RowBox[{"phiG", ",", 
     RowBox[{"-", "40"}], ",", "440"}], "}"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<phi(Degree)\>\"", ",", "None"}], "}"}]}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<psi (Degree)\>\""}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "40"}], ",", "440"}], "}"}], ",", "Automatic"}], 
     "}"}]}]}], "]"}], "\n", 
 RowBox[{
  RowBox[{"Clear", "[", "\[CurlyPhi]", "]"}], ";"}]}], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV2Qk0VV0UB3AapEGJQhShQkSJkOhvyhxSpvtMbzA+M3nvqajwISQR0iBl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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"phi(Degree)\"", TraditionalForm], None},
  AxesOrigin->{0, 110.},
  GridLines->Automatic,
  PlotLabel->FormBox["\"psi (Degree)\"", TraditionalForm],
  PlotRange->{{-40, 440}, {109.25425361673172`, 169.2542428101317}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.467460268140147*^9, 3.4674602780526047`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Psi]a", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Pi", "-", 
       RowBox[{"ArcCos", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"d", "^", "2"}], "+", 
           RowBox[{"b", "^", "2"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"c", "+", "a"}], ")"}], "^", "2"}]}], ")"}], " ", "/", 
         " ", 
         RowBox[{"(", 
          RowBox[{"2", " ", "b", " ", "d"}], ")"}]}], "]"}]}], ")"}], "/", 
     "Degree"}], "/.", "par"}], "/.", "erg1"}]}]], "Input"],

Cell[BoxData["109.25424338167699`"], "Output",
 CellChangeTimes->{{3.467460268765991*^9, 3.4674602782558107`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grashof", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Min", "[", 
      RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}], "+", 
     RowBox[{"Max", "[", 
      RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}]}], "/.", "par"}], "/.",
    "erg1"}]}]], "Input"],

Cell[BoxData["143.74082579008382`"], "Output",
 CellChangeTimes->{{3.467460269083377*^9, 3.4674602783357286`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"c", "+", "b"}], "/.", "par"}], "/.", "erg1"}]], "Input"],

Cell[BoxData["152.75201604678153`"], "Output",
 CellChangeTimes->{{3.467460269288694*^9, 3.4674602784196*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Mu]min1", "/", "Degree"}], "/.", "par"}], "/.", 
  "erg1"}]], "Input",
 CellChangeTimes->{{3.4674602537000237`*^9, 3.467460286684474*^9}}],

Cell[BoxData["39.999999999999986`"], "Output",
 CellChangeTimes->{{3.4674602699088697`*^9, 3.467460287438274*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Mu]min2", "/", "Degree"}], "/.", "par"}], "/.", 
  "erg1"}]], "Input",
 CellChangeTimes->{3.467460364124563*^9}],

Cell[BoxData["39.99999999999993`"], "Output",
 CellChangeTimes->{3.467460364790698*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.3.2\tDead point construction via ALT", "Section"],

Cell[CellGroupData[{

Cell["\<\
1. Find the length  a, b, c for given toggle parameters  \[CurlyPhi]0, \
\[Psi]0 and \[Mu]min -> max (VDI 2130)
use Table 3-1 and Table 3-3
Note: for \[CurlyPhi]0 = 180 Degrees there we can not find a value for \
\[Beta] !! We select  \[Beta] = 40 Degree!\
\>", "Subsection",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "par", ",", "\[CurlyPhi]", ",", "\[Psi]", ",", "\[Psi]1", ",", "phi0", ",",
     "psi0", ",", "par", ",", "a", ",", "b", ",", "c", ",", "d"}], "]"}], 
  ";"}]], "Input"],

Cell[CellGroupData[{

Cell["\<\
par = {phi0->180 Degree, psi0->60 Degree, auxbeta->40 Degree, d->100}\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"phi0", "\[Rule]", 
    RowBox[{"180", " ", "\[Degree]"}]}], ",", 
   RowBox[{"psi0", "\[Rule]", 
    RowBox[{"60", " ", "\[Degree]"}]}], ",", 
   RowBox[{"auxbeta", "\[Rule]", 
    RowBox[{"40", " ", "\[Degree]"}]}], ",", 
   RowBox[{"d", "\[Rule]", "100"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4674604162860823`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["gamma = 1/2 (phi0 - psi0)", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"phi0", "-", "psi0"}], "2"]], "Output",
 CellChangeTimes->{3.467460416384987*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["rA  = (d Sin[psi0/2]) / (2 Sin[gamma])", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", "d", " ", 
  RowBox[{"Csc", "[", 
   FractionBox[
    RowBox[{"phi0", "-", "psi0"}], "2"], "]"}], " ", 
  RowBox[{"Sin", "[", 
   FractionBox["psi0", "2"], "]"}]}]], "Output",
 CellChangeTimes->{3.4674604164627533`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["rB  = rA / Cos[gamma]", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", "d", " ", 
  RowBox[{"Csc", "[", 
   FractionBox[
    RowBox[{"phi0", "-", "psi0"}], "2"], "]"}], " ", 
  RowBox[{"Sec", "[", 
   FractionBox[
    RowBox[{"phi0", "-", "psi0"}], "2"], "]"}], " ", 
  RowBox[{"Sin", "[", 
   FractionBox["psi0", "2"], "]"}]}]], "Output",
 CellChangeTimes->{3.4674604165457773`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["theta = 180 Degree - auxbeta - phi0/2", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "auxbeta"}], "+", 
  RowBox[{"180", " ", "\[Degree]"}], "-", 
  FractionBox["phi0", "2"]}]], "Output",
 CellChangeTimes->{3.4674604166121264`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["a = 2 rA Cos[theta]", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "d"}], " ", 
  RowBox[{"Cos", "[", 
   RowBox[{"auxbeta", "+", 
    FractionBox["phi0", "2"]}], "]"}], " ", 
  RowBox[{"Csc", "[", 
   FractionBox[
    RowBox[{"phi0", "-", "psi0"}], "2"], "]"}], " ", 
  RowBox[{"Sin", "[", 
   FractionBox["psi0", "2"], "]"}]}]], "Output",
 CellChangeTimes->{3.4674604166791897`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["c = 2 rB Cos[theta - gamma] - a", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"auxbeta", "+", 
     FractionBox["phi0", "2"]}], "]"}], " ", 
   RowBox[{"Csc", "[", 
    FractionBox[
     RowBox[{"phi0", "-", "psi0"}], "2"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    FractionBox["psi0", "2"], "]"}]}], "-", 
  RowBox[{"d", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"auxbeta", "+", 
     FractionBox["phi0", "2"], "+", 
     FractionBox[
      RowBox[{"phi0", "-", "psi0"}], "2"]}], "]"}], " ", 
   RowBox[{"Csc", "[", 
    FractionBox[
     RowBox[{"phi0", "-", "psi0"}], "2"], "]"}], " ", 
   RowBox[{"Sec", "[", 
    FractionBox[
     RowBox[{"phi0", "-", "psi0"}], "2"], "]"}], " ", 
   RowBox[{"Sin", "[", 
    FractionBox["psi0", "2"], "]"}]}]}]], "Output",
 CellChangeTimes->{3.467460416765403*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["e  = (a+c) Cos[auxbeta]", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "d"}], " ", 
  RowBox[{"Cos", "[", "auxbeta", "]"}], " ", 
  RowBox[{"Cos", "[", 
   RowBox[{"auxbeta", "+", 
    FractionBox["phi0", "2"], "+", 
    FractionBox[
     RowBox[{"phi0", "-", "psi0"}], "2"]}], "]"}], " ", 
  RowBox[{"Csc", "[", 
   FractionBox[
    RowBox[{"phi0", "-", "psi0"}], "2"], "]"}], " ", 
  RowBox[{"Sec", "[", 
   FractionBox[
    RowBox[{"phi0", "-", "psi0"}], "2"], "]"}], " ", 
  RowBox[{"Sin", "[", 
   FractionBox["psi0", "2"], "]"}]}]], "Output",
 CellChangeTimes->{3.467460416828971*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["b  = Sqrt[d^2 + (a+c)^2 - 2 d e]", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{"\[Sqrt]", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["d", "2"], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["d", "2"], " ", 
     RowBox[{"Cos", "[", "auxbeta", "]"}], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"auxbeta", "+", 
       FractionBox["phi0", "2"], "+", 
       FractionBox[
        RowBox[{"phi0", "-", "psi0"}], "2"]}], "]"}], " ", 
     RowBox[{"Csc", "[", 
      FractionBox[
       RowBox[{"phi0", "-", "psi0"}], "2"], "]"}], " ", 
     RowBox[{"Sec", "[", 
      FractionBox[
       RowBox[{"phi0", "-", "psi0"}], "2"], "]"}], " ", 
     RowBox[{"Sin", "[", 
      FractionBox["psi0", "2"], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["d", "2"], " ", 
     SuperscriptBox[
      RowBox[{"Cos", "[", 
       RowBox[{"auxbeta", "+", 
        FractionBox["phi0", "2"], "+", 
        FractionBox[
         RowBox[{"phi0", "-", "psi0"}], "2"]}], "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"Csc", "[", 
       FractionBox[
        RowBox[{"phi0", "-", "psi0"}], "2"], "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"Sec", "[", 
       FractionBox[
        RowBox[{"phi0", "-", "psi0"}], "2"], "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"Sin", "[", 
       FractionBox["psi0", "2"], "]"}], "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.467460416899111*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
a = a/.par//N  
b = b/.par//N
c = c/.par//N
par\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData["37.11135994842796`"], "Output",
 CellChangeTimes->{3.467460416982705*^9}],

Cell[BoxData["74.2227198968559`"], "Output",
 CellChangeTimes->{3.4674604170202217`*^9}],

Cell[BoxData["76.60444431189781`"], "Output",
 CellChangeTimes->{3.46746041707495*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"phi0", "\[Rule]", 
    RowBox[{"180", " ", "\[Degree]"}]}], ",", 
   RowBox[{"psi0", "\[Rule]", 
    RowBox[{"60", " ", "\[Degree]"}]}], ",", 
   RowBox[{"auxbeta", "\[Rule]", 
    RowBox[{"40", " ", "\[Degree]"}]}], ",", 
   RowBox[{"d", "\[Rule]", "100"}]}], "}"}]], "Output",
 CellChangeTimes->{3.467460417125306*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["further evaluations", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f\[CurlyPhi]0", "/", "Degree"}], "/.", "par"}], "//", 
  "N"}]], "Input"],

Cell[BoxData["180.`"], "Output",
 CellChangeTimes->{3.467460417323894*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f\[Psi]0", "/", "Degree"}], "/.", "par"}], "//", "N"}]], "Input"],

Cell[BoxData["59.99999999999999`"], "Output",
 CellChangeTimes->{3.467460417408169*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Mu]min1", "/", "Degree"}], "/.", "par"}], "//", "N"}]], "Input"],

Cell[BoxData["49.254243381676964`"], "Output",
 CellChangeTimes->{3.467460417491395*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f\[Psi]", "/.", "par"}], "/.", 
   RowBox[{"\[CurlyPhi]", "\[Rule]", "Pi"}]}], "//", "N"}]], "Input"],

Cell[BoxData["2.704529654803`"], "Output",
 CellChangeTimes->{3.467460417586523*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[CurlyPhi]", "=", 
   RowBox[{"phiG", " ", "\[Degree]"}]}], ";"}], "\n", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    FractionBox["f\[Psi]", "\[Degree]"], "/.", "\[InvisibleSpace]", "par"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"phiG", ",", 
     RowBox[{"-", "40"}], ",", "400"}], "}"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<phi(Degree)\>\"", ",", "None"}], "}"}]}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<psi (Degree)\>\""}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "40"}], ",", "400"}], "}"}], ",", "Automatic"}], 
     "}"}]}]}], "]"}], "\n", 
 RowBox[{
  RowBox[{"Clear", "[", "\[CurlyPhi]", "]"}], ";"}]}], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwd2Qk0lN8bB3BkyVKIJGmjlCVbZcn2ZcYu0v6O3VhnBkUxCpUo7UlRKKVN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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"phi(Degree)\"", TraditionalForm], None},
  AxesOrigin->{0, 100.},
  GridLines->Automatic,
  PlotLabel->FormBox["\"psi (Degree)\"", TraditionalForm],
  PlotRange->{{-40, 400}, {100.0000000000006, 159.99999727739944`}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.4674604177929296`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Psi]a", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"Pi", "-", 
      RowBox[{"ArcCos", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"d", "^", "2"}], "+", 
          RowBox[{"b", "^", "2"}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"c", "+", "a"}], ")"}], "^", "2"}]}], ")"}], " ", "/", 
        " ", 
        RowBox[{"(", 
         RowBox[{"2", " ", "b", " ", "d"}], ")"}]}], "]"}]}], ")"}], "/", 
    "Degree"}], "/.", "par"}]}]], "Input"],

Cell[BoxData["99.99999999999999`"], "Output",
 CellChangeTimes->{3.467460417887218*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grashof", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Min", "[", 
     RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}], "+", 
    RowBox[{"Max", "[", 
     RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}]}], "/.", 
   "par"}]}]], "Input"],

Cell[BoxData["137.11135994842795`"], "Output",
 CellChangeTimes->{3.467460417965316*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"c", "+", "b"}], "/.", "par"}]], "Input"],

Cell[BoxData["150.82716420875371`"], "Output",
 CellChangeTimes->{3.467460418039886*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Mu]min1", "/", "Degree"}], "/.", "par"}], "/.", 
  "erg1"}]], "Input",
 CellChangeTimes->{{3.4674602537000237`*^9, 3.467460286684474*^9}}],

Cell[BoxData["49.254243381676964`"], "Output",
 CellChangeTimes->{{3.4674602699088697`*^9, 3.467460287438274*^9}, 
   3.467460418124577*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Mu]min2", "/", "Degree"}], "/.", "par"}], "/.", 
  "erg1"}]], "Input",
 CellChangeTimes->{3.467460364124563*^9}],

Cell[BoxData["49.25424338167699`"], "Output",
 CellChangeTimes->{3.467460364790698*^9, 3.467460418190403*^9}]
}, Open  ]],

Cell[TextData[StyleBox["A special solution line for \[Psi]0 = 180 \[Degree] \
is given in Table 3-3",
 FontSize->16,
 Background->RGBColor[1, 0, 1]]], "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.3.3\tFind mechanism for list of fct values", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "par", ",", "\[CurlyPhi]", ",", "\[Psi]", ",", "\[Psi]1", ",", "\[Psi]2", 
    ",", "\[CurlyPhi]0", ",", "\[Psi]0", ",", "a", ",", "b", ",", "c", ",", 
    "d"}], "]"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell["\<\
Requirements of crank-rocker mechanism  (A)
R5, .. R8 and  R9 :  a =  50  for internal paramters a, b, c, d  in mm  a\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData["f\[Psi]"], "Input"],

Cell[BoxData[
 RowBox[{"\[Pi]", "-", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["b", "2"], "-", 
     SuperscriptBox["c", "2"], "+", 
     SuperscriptBox["d", "2"], "-", 
     RowBox[{"2", " ", "a", " ", "d", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}], 
    RowBox[{"2", " ", "b", " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["d", "2"], "-", 
       RowBox[{"2", " ", "a", " ", "d", " ", 
        RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}]]}]], "]"}], "-", 
  RowBox[{"ArcTan", "[", 
   RowBox[{
    RowBox[{"d", "-", 
     RowBox[{"a", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}], ",", 
    RowBox[{"a", " ", 
     RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}]}], "]"}]}]], "Output",
 CellChangeTimes->{3.4674604455299683`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"par", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"d", "\[Rule]", "100"}], ",", " ", 
    RowBox[{"a", " ", "\[Rule]", " ", "40"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"d", "\[Rule]", "100"}], ",", 
   RowBox[{"a", "\[Rule]", "40"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4674604458088017`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"R6", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"81.5", " ", "Degree"}], "  ", "\[Equal]", " ", "f\[Psi]"}], "/.",
     
    RowBox[{"\[CurlyPhi]", "\[Rule]", "\[CurlyPhi]1"}]}], "/.", 
   "par"}]}], "\[IndentingNewLine]", 
 RowBox[{"R7", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"86.5", " ", "Degree"}], "  ", "\[Equal]", " ", "f\[Psi]"}], "/.",
     
    RowBox[{"\[CurlyPhi]", "\[Rule]", 
     RowBox[{"\[CurlyPhi]1", "+", 
      RowBox[{"20", " ", "Degree"}]}]}]}], "/.", 
   "par"}]}], "\[IndentingNewLine]", 
 RowBox[{"R8", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"96.5", " ", "Degree"}], "  ", "\[Equal]", " ", "f\[Psi]"}], "/.",
     
    RowBox[{"\[CurlyPhi]", "\[Rule]", 
     RowBox[{"\[CurlyPhi]1", "+", 
      RowBox[{"60", " ", "Degree"}]}]}]}], "/.", 
   "par"}]}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{"1.4224433403753787`", "\[Equal]", 
  RowBox[{"\[Pi]", "-", 
   RowBox[{"ArcCos", "[", 
    FractionBox[
     RowBox[{"11600", "+", 
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"], "-", 
      RowBox[{"8000", " ", 
       RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}], 
     RowBox[{"2", " ", "b", " ", 
      SqrtBox[
       RowBox[{"11600", "-", 
        RowBox[{"8000", " ", 
         RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}]]}]], "]"}], "-", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{"100", "-", 
      RowBox[{"40", " ", 
       RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}], ",", 
     RowBox[{"40", " ", 
      RowBox[{"Sin", "[", "\[CurlyPhi]1", "]"}]}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.467460445897399*^9}],

Cell[BoxData[
 RowBox[{"1.509709802975095`", "\[Equal]", 
  RowBox[{"\[Pi]", "-", 
   RowBox[{"ArcCos", "[", 
    FractionBox[
     RowBox[{"11600", "+", 
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"], "-", 
      RowBox[{"8000", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"20", " ", "\[Degree]"}], "+", "\[CurlyPhi]1"}], "]"}]}]}], 
     RowBox[{"2", " ", "b", " ", 
      SqrtBox[
       RowBox[{"11600", "-", 
        RowBox[{"8000", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{
           RowBox[{"20", " ", "\[Degree]"}], "+", "\[CurlyPhi]1"}], 
          "]"}]}]}]]}]], "]"}], "-", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{"100", "-", 
      RowBox[{"40", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"20", " ", "\[Degree]"}], "+", "\[CurlyPhi]1"}], "]"}]}]}], 
     ",", 
     RowBox[{"40", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{
        RowBox[{"20", " ", "\[Degree]"}], "+", "\[CurlyPhi]1"}], "]"}]}]}], 
    "]"}]}]}]], "Output",
 CellChangeTimes->{3.4674604459052877`*^9}],

Cell[BoxData[
 RowBox[{"1.684242728174528`", "\[Equal]", 
  RowBox[{"\[Pi]", "-", 
   RowBox[{"ArcCos", "[", 
    FractionBox[
     RowBox[{"11600", "+", 
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"], "-", 
      RowBox[{"8000", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"30", " ", "\[Degree]"}], "-", "\[CurlyPhi]1"}], "]"}]}]}], 
     RowBox[{"2", " ", "b", " ", 
      SqrtBox[
       RowBox[{"11600", "-", 
        RowBox[{"8000", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           RowBox[{"30", " ", "\[Degree]"}], "-", "\[CurlyPhi]1"}], 
          "]"}]}]}]]}]], "]"}], "-", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{"100", "-", 
      RowBox[{"40", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"30", " ", "\[Degree]"}], "-", "\[CurlyPhi]1"}], "]"}]}]}], 
     ",", 
     RowBox[{"40", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"30", " ", "\[Degree]"}], "-", "\[CurlyPhi]1"}], "]"}]}]}], 
    "]"}]}]}]], "Output",
 CellChangeTimes->{3.467460445910234*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"erg3", "=", 
  RowBox[{"FindRoot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"R6", ",", "R7", ",", "R8"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[CurlyPhi]1", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"b", ",", "100"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"c", ",", "50"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FindRoot", "::", "\<\"cvmit\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Failed to converge to the requested accuracy or precision \
within \\!\\(100\\) iterations. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/FindRoot\\\", ButtonNote -> \
\\\"FindRoot::cvmit\\\"]\\)\"\>"}]], "Message",
 CellChangeTimes->{3.467460446054661*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[CurlyPhi]1", "\[Rule]", "2.21290274617881`"}], ",", 
   RowBox[{"b", "\[Rule]", "1266.4854474614242`"}], ",", 
   RowBox[{"c", "\[Rule]", "1258.5439255063643`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.467460446065995*^9}]
}, Open  ]],

Cell[TextData[StyleBox["No realistic solution is found ",
 FontSize->16,
 Background->RGBColor[1, 0, 1]]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Use the crossed Crank-Rocker (A):
Requirements of crank-rocker mechanism  R5, .. R8 and  R9 :  a =  50  for \
internal paramters a, b, c, d  in mm  a\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData["f\[Psi]2"], "Input"],

Cell[BoxData[
 RowBox[{"\[Pi]", "+", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["b", "2"], "-", 
     SuperscriptBox["c", "2"], "+", 
     SuperscriptBox["d", "2"], "-", 
     RowBox[{"2", " ", "a", " ", "d", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}], 
    RowBox[{"2", " ", "b", " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["d", "2"], "-", 
       RowBox[{"2", " ", "a", " ", "d", " ", 
        RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}]]}]], "]"}], "-", 
  RowBox[{"ArcTan", "[", 
   RowBox[{
    RowBox[{"d", "-", 
     RowBox[{"a", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}], ",", 
    RowBox[{"a", " ", 
     RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}]}], "]"}]}]], "Output",
 CellChangeTimes->{3.467460474215259*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"par", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"d", "\[Rule]", "100"}], ",", " ", 
    RowBox[{"a", " ", "\[Rule]", " ", "40"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"d", "\[Rule]", "100"}], ",", 
   RowBox[{"a", "\[Rule]", "40"}]}], "}"}]], "Output",
 CellChangeTimes->{3.467460474471793*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"R6", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"81.5", " ", "Degree"}], "  ", "\[Equal]", " ", "f\[Psi]2"}], "/.",
     
    RowBox[{"\[CurlyPhi]", "\[Rule]", "\[CurlyPhi]1"}]}], "/.", 
   "par"}]}], "\[IndentingNewLine]", 
 RowBox[{"R7", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"86.5", " ", "Degree"}], "  ", "\[Equal]", " ", "f\[Psi]2"}], "/.",
     
    RowBox[{"\[CurlyPhi]", "\[Rule]", 
     RowBox[{"\[CurlyPhi]1", "+", 
      RowBox[{"20", " ", "Degree"}]}]}]}], "/.", 
   "par"}]}], "\[IndentingNewLine]", 
 RowBox[{"R8", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"96.5", " ", "Degree"}], "  ", "\[Equal]", " ", "f\[Psi]2"}], "/.",
     
    RowBox[{"\[CurlyPhi]", "\[Rule]", 
     RowBox[{"\[CurlyPhi]1", "+", 
      RowBox[{"60", " ", "Degree"}]}]}]}], "/.", 
   "par"}]}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{"1.4224433403753787`", "\[Equal]", 
  RowBox[{"\[Pi]", "+", 
   RowBox[{"ArcCos", "[", 
    FractionBox[
     RowBox[{"11600", "+", 
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"], "-", 
      RowBox[{"8000", " ", 
       RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}], 
     RowBox[{"2", " ", "b", " ", 
      SqrtBox[
       RowBox[{"11600", "-", 
        RowBox[{"8000", " ", 
         RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}]]}]], "]"}], "-", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{"100", "-", 
      RowBox[{"40", " ", 
       RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}], ",", 
     RowBox[{"40", " ", 
      RowBox[{"Sin", "[", "\[CurlyPhi]1", "]"}]}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.467460474556406*^9}],

Cell[BoxData[
 RowBox[{"1.509709802975095`", "\[Equal]", 
  RowBox[{"\[Pi]", "+", 
   RowBox[{"ArcCos", "[", 
    FractionBox[
     RowBox[{"11600", "+", 
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"], "-", 
      RowBox[{"8000", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"20", " ", "\[Degree]"}], "+", "\[CurlyPhi]1"}], "]"}]}]}], 
     RowBox[{"2", " ", "b", " ", 
      SqrtBox[
       RowBox[{"11600", "-", 
        RowBox[{"8000", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{
           RowBox[{"20", " ", "\[Degree]"}], "+", "\[CurlyPhi]1"}], 
          "]"}]}]}]]}]], "]"}], "-", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{"100", "-", 
      RowBox[{"40", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"20", " ", "\[Degree]"}], "+", "\[CurlyPhi]1"}], "]"}]}]}], 
     ",", 
     RowBox[{"40", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{
        RowBox[{"20", " ", "\[Degree]"}], "+", "\[CurlyPhi]1"}], "]"}]}]}], 
    "]"}]}]}]], "Output",
 CellChangeTimes->{3.467460474616329*^9}],

Cell[BoxData[
 RowBox[{"1.684242728174528`", "\[Equal]", 
  RowBox[{"\[Pi]", "+", 
   RowBox[{"ArcCos", "[", 
    FractionBox[
     RowBox[{"11600", "+", 
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"], "-", 
      RowBox[{"8000", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"30", " ", "\[Degree]"}], "-", "\[CurlyPhi]1"}], "]"}]}]}], 
     RowBox[{"2", " ", "b", " ", 
      SqrtBox[
       RowBox[{"11600", "-", 
        RowBox[{"8000", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           RowBox[{"30", " ", "\[Degree]"}], "-", "\[CurlyPhi]1"}], 
          "]"}]}]}]]}]], "]"}], "-", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{"100", "-", 
      RowBox[{"40", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"30", " ", "\[Degree]"}], "-", "\[CurlyPhi]1"}], "]"}]}]}], 
     ",", 
     RowBox[{"40", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"30", " ", "\[Degree]"}], "-", "\[CurlyPhi]1"}], "]"}]}]}], 
    "]"}]}]}]], "Output",
 CellChangeTimes->{3.467460474694005*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"erg3", "=", 
  RowBox[{"Chop", "[", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"R6", ",", "R7", ",", "R8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[CurlyPhi]1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"b", ",", "200"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"c", ",", "100"}], "}"}]}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FindRoot", "::", "\<\"lstol\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"The line search decreased the step size to within \
tolerance specified by AccuracyGoal and PrecisionGoal but was unable to find \
a sufficient decrease in the merit function.  You may need more than \
\\!\\(MachinePrecision\\) digits of working precision to meet these \
tolerances. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/FindRoot\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message",
 CellChangeTimes->{3.467460474892603*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[CurlyPhi]1", "\[Rule]", "3.2463785629971134`"}], ",", 
   RowBox[{"b", "\[Rule]", 
    RowBox[{"-", "172.5960407997807`"}]}], ",", 
   RowBox[{"c", "\[Rule]", 
    RowBox[{"-", "329.4716998129767`"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.4674604749446487`*^9}]
}, Open  ]],

Cell[TextData[StyleBox["No realistic solution is found ",
 FontSize->16,
 Background->RGBColor[1, 0, 1]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f\[Psi]2", "/.", "par"}], "/.", 
   RowBox[{"\[CurlyPhi]", "\[Rule]", "\[CurlyPhi]1"}]}], "/.", 
  "erg3"}]], "Input"],

Cell[BoxData[
 RowBox[{"3.171514699509875`", "\[InvisibleSpace]", "+", 
  RowBox[{"0.6609424097963116`", " ", "\[ImaginaryI]"}]}]], "Output",
 CellChangeTimes->{3.46746047506835*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Use other requirements - Model (C) for internal paramters a, b, c, d  in mm  \
\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData["f\[Psi]"], "Input"],

Cell[BoxData[
 RowBox[{"\[Pi]", "-", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["b", "2"], "-", 
     SuperscriptBox["c", "2"], "+", 
     SuperscriptBox["d", "2"], "-", 
     RowBox[{"2", " ", "a", " ", "d", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}], 
    RowBox[{"2", " ", "b", " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["d", "2"], "-", 
       RowBox[{"2", " ", "a", " ", "d", " ", 
        RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}]]}]], "]"}], "-", 
  RowBox[{"ArcTan", "[", 
   RowBox[{
    RowBox[{"d", "-", 
     RowBox[{"a", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}], ",", 
    RowBox[{"a", " ", 
     RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}]}], "]"}]}]], "Output",
 CellChangeTimes->{3.467460493604062*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"par", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"d", "\[Rule]", "100"}], ",", " ", 
    RowBox[{"a", " ", "\[Rule]", " ", "40"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"d", "\[Rule]", "100"}], ",", 
   RowBox[{"a", "\[Rule]", "40"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4674604939358463`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"R6", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"78", " ", "Degree"}], "  ", "\[Equal]", " ", "f\[Psi]"}], "/.", 
    
    RowBox[{"\[CurlyPhi]", "\[Rule]", "\[CurlyPhi]1"}]}], "/.", 
   "par"}]}], "\[IndentingNewLine]", 
 RowBox[{"R7", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"88", " ", "Degree"}], "  ", "\[Equal]", " ", "f\[Psi]"}], "/.", 
    
    RowBox[{"\[CurlyPhi]", "\[Rule]", 
     RowBox[{"\[CurlyPhi]1", "+", 
      RowBox[{"20", " ", "Degree"}]}]}]}], "/.", 
   "par"}]}], "\[IndentingNewLine]", 
 RowBox[{"R8", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"110", " ", "Degree"}], "  ", "\[Equal]", " ", "f\[Psi]"}], "/.",
     
    RowBox[{"\[CurlyPhi]", "\[Rule]", 
     RowBox[{"\[CurlyPhi]1", "+", 
      RowBox[{"60", " ", "Degree"}]}]}]}], "/.", 
   "par"}]}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"78", " ", "\[Degree]"}], "\[Equal]", 
  RowBox[{"\[Pi]", "-", 
   RowBox[{"ArcCos", "[", 
    FractionBox[
     RowBox[{"11600", "+", 
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"], "-", 
      RowBox[{"8000", " ", 
       RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}], 
     RowBox[{"2", " ", "b", " ", 
      SqrtBox[
       RowBox[{"11600", "-", 
        RowBox[{"8000", " ", 
         RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}]]}]], "]"}], "-", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{"100", "-", 
      RowBox[{"40", " ", 
       RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}], ",", 
     RowBox[{"40", " ", 
      RowBox[{"Sin", "[", "\[CurlyPhi]1", "]"}]}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.467460494023468*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"88", " ", "\[Degree]"}], "\[Equal]", 
  RowBox[{"\[Pi]", "-", 
   RowBox[{"ArcCos", "[", 
    FractionBox[
     RowBox[{"11600", "+", 
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"], "-", 
      RowBox[{"8000", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"20", " ", "\[Degree]"}], "+", "\[CurlyPhi]1"}], "]"}]}]}], 
     RowBox[{"2", " ", "b", " ", 
      SqrtBox[
       RowBox[{"11600", "-", 
        RowBox[{"8000", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{
           RowBox[{"20", " ", "\[Degree]"}], "+", "\[CurlyPhi]1"}], 
          "]"}]}]}]]}]], "]"}], "-", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{"100", "-", 
      RowBox[{"40", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"20", " ", "\[Degree]"}], "+", "\[CurlyPhi]1"}], "]"}]}]}], 
     ",", 
     RowBox[{"40", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{
        RowBox[{"20", " ", "\[Degree]"}], "+", "\[CurlyPhi]1"}], "]"}]}]}], 
    "]"}]}]}]], "Output",
 CellChangeTimes->{3.467460494030415*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"110", " ", "\[Degree]"}], "\[Equal]", 
  RowBox[{"\[Pi]", "-", 
   RowBox[{"ArcCos", "[", 
    FractionBox[
     RowBox[{"11600", "+", 
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"], "-", 
      RowBox[{"8000", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"30", " ", "\[Degree]"}], "-", "\[CurlyPhi]1"}], "]"}]}]}], 
     RowBox[{"2", " ", "b", " ", 
      SqrtBox[
       RowBox[{"11600", "-", 
        RowBox[{"8000", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           RowBox[{"30", " ", "\[Degree]"}], "-", "\[CurlyPhi]1"}], 
          "]"}]}]}]]}]], "]"}], "-", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{"100", "-", 
      RowBox[{"40", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"30", " ", "\[Degree]"}], "-", "\[CurlyPhi]1"}], "]"}]}]}], 
     ",", 
     RowBox[{"40", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"30", " ", "\[Degree]"}], "-", "\[CurlyPhi]1"}], "]"}]}]}], 
    "]"}]}]}]], "Output",
 CellChangeTimes->{3.467460494035266*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"erg4", "=", 
  RowBox[{"FindRoot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"R6", ",", "R7", ",", "R8"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[CurlyPhi]1", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"b", ",", "70"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"c", ",", "100"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[CurlyPhi]1", "\[Rule]", "1.1152976610661691`"}], ",", 
   RowBox[{"b", "\[Rule]", "72.52396784014827`"}], ",", 
   RowBox[{"c", "\[Rule]", "103.58087460041978`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4674604941057863`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CurlyPhi]1", "/", "Degree"}], " ", "/.", "erg4", " "}]], "Input"],

Cell[BoxData["63.901848879903646`"], "Output",
 CellChangeTimes->{3.4674604941996593`*^9}]
}, Open  ]],

Cell["scaled parameters :  d = 34 mm for 100", "Text",
 CellChangeTimes->{{3.4674605868937407`*^9, 3.467460630556748*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"a", "*", "0.34"}], "/.", "par"}]], "Input",
 CellChangeTimes->{{3.467460601323325*^9, 3.467460601590904*^9}, {
  3.467460647928306*^9, 3.467460665624999*^9}}],

Cell[BoxData["13.600000000000001`"], "Output",
 CellChangeTimes->{{3.467460650354958*^9, 3.4674606661672583`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"b", "*", "0.34"}], "/.", "par"}], "/.", "erg4"}]], "Input",
 CellChangeTimes->{{3.467460684758419*^9, 3.467460709213151*^9}}],

Cell[BoxData["24.658149065650413`"], "Output",
 CellChangeTimes->{{3.467460684967638*^9, 3.46746070968034*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"c", "*", "0.34"}], "/.", "par"}], "/.", "erg4"}]], "Input",
 CellChangeTimes->{3.467460716199284*^9}],

Cell[BoxData["35.21749736414272`"], "Output",
 CellChangeTimes->{3.467460716479473*^9}]
}, Open  ]],

Cell[TextData[StyleBox["A realistic solution is found",
 FontSize->16,
 Background->RGBColor[1, 1, 0]]], "Text"],

Cell[CellGroupData[{

Cell["further results", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f\[Psi]", "/", "Degree"}], "/.", "par"}], "/.", 
    RowBox[{"\[CurlyPhi]", "\[Rule]", "\[CurlyPhi]1"}]}], "/.", "erg4"}], "//",
   "N"}]], "Input"],

Cell[BoxData["77.99999999999999`"], "Output",
 CellChangeTimes->{3.4674604943040752`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f\[Psi]", "/", "Degree"}], "/.", "par"}], "/.", 
    RowBox[{"\[CurlyPhi]", "\[Rule]", 
     RowBox[{"\[CurlyPhi]1", "+", 
      RowBox[{"60", " ", "Degree"}]}]}]}], "/.", "erg4"}], "//", 
  "N"}]], "Input"],

Cell[BoxData["110.`"], "Output",
 CellChangeTimes->{3.4674604944179583`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[CurlyPhi]", "=", 
   RowBox[{"phiG", " ", "\[Degree]"}]}], ";"}], "\n", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["f\[Psi]", "\[Degree]"], "/.", "\[InvisibleSpace]", "erg4"}],
     "/.", "\[InvisibleSpace]", "par"}], ",", 
   RowBox[{"{", 
    RowBox[{"phiG", ",", "0", ",", "180"}], "}"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<phi(Degree)\>\"", ",", "None"}], "}"}]}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<psi (Degree)\>\""}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "180"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "180"}], "}"}]}], "}"}]}]}], "]"}], "\n", 
 RowBox[{
  RowBox[{"Clear", "[", "\[CurlyPhi]", "]"}], ";"}]}], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1ndcje0fB/CKFE3SoKFNe5x2p86nOkKL+zS1lzSMhtKgKBX1oDxFooGK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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"phi(Degree)\"", TraditionalForm], None},
  AxesOrigin->{0, 0},
  GridLines->Automatic,
  PlotLabel->FormBox["\"psi (Degree)\"", TraditionalForm],
  PlotRange->{{0, 180}, {0, 180}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.467460494600683*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f\[CurlyPhi]0", "/", "Degree"}], "/.", "par"}], "/.", 
  "erg4"}]], "Input"],

Cell[BoxData["198.31974913641838`"], "Output",
 CellChangeTimes->{3.467460494700459*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f\[Psi]0", "/", "Degree"}], "/.", "par"}], "/.", 
  "erg4"}]], "Input"],

Cell[BoxData["72.32387258603147`"], "Output",
 CellChangeTimes->{3.467460494901243*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Mu]min1", "/", "Degree"}], "/.", "par"}], "/.", "erg4"}], "//",
   "N"}]], "Input"],

Cell[BoxData["34.4535600733094`"], "Output",
 CellChangeTimes->{3.467460494995892*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Mu]min2", "/", "Degree"}], "/.", "par"}], "/.", "erg4"}], "//",
   "N"}]], "Input"],

Cell[BoxData["76.09196874541497`"], "Output",
 CellChangeTimes->{3.4674604950964823`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grashof", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Min", "[", 
      RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}], "+", 
     RowBox[{"Max", "[", 
      RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}]}], "/.", "par"}], "/.",
    "erg4"}]}]], "Input"],

Cell[BoxData["143.58087460041978`"], "Output",
 CellChangeTimes->{3.46746049518476*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"c", "+", "b"}], "/.", "par"}], "/.", "erg4"}]], "Input"],

Cell[BoxData["176.10484244056806`"], "Output",
 CellChangeTimes->{3.467460495278083*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Use requirements R6 .. R8 and a new R9 as mymin = 50 Degree: (D) for internal \
paramters a, b, c, d   \
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"par", "=", 
  RowBox[{"{", 
   RowBox[{"d", "\[Rule]", "100"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"d", "\[Rule]", "100"}], "}"}]], "Output",
 CellChangeTimes->{3.4674610088733788`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"R6", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"78", " ", "Degree"}], "  ", "\[Equal]", " ", "f\[Psi]"}], "/.", 
    
    RowBox[{"\[CurlyPhi]", "\[Rule]", "\[CurlyPhi]1"}]}], "/.", 
   "par"}]}], "\[IndentingNewLine]", 
 RowBox[{"R7", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"88", " ", "Degree"}], "  ", "\[Equal]", " ", "f\[Psi]"}], "/.", 
    
    RowBox[{"\[CurlyPhi]", "\[Rule]", 
     RowBox[{"\[CurlyPhi]1", "+", 
      RowBox[{"20", " ", "Degree"}]}]}]}], "/.", 
   "par"}]}], "\[IndentingNewLine]", 
 RowBox[{"R8", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"110", " ", "Degree"}], "  ", "\[Equal]", " ", "f\[Psi]"}], "/.",
     
    RowBox[{"\[CurlyPhi]", "\[Rule]", 
     RowBox[{"\[CurlyPhi]1", "+", 
      RowBox[{"60", " ", "Degree"}]}]}]}], "/.", 
   "par"}]}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"78", " ", "\[Degree]"}], "\[Equal]", 
  RowBox[{"\[Pi]", "-", 
   RowBox[{"ArcCos", "[", 
    FractionBox[
     RowBox[{"10000", "+", 
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"], "-", 
      RowBox[{"200", " ", "a", " ", 
       RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}], 
     RowBox[{"2", " ", "b", " ", 
      SqrtBox[
       RowBox[{"10000", "+", 
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"200", " ", "a", " ", 
         RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}]]}]], "]"}], "-", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{"100", "-", 
      RowBox[{"a", " ", 
       RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}], ",", 
     RowBox[{"a", " ", 
      RowBox[{"Sin", "[", "\[CurlyPhi]1", "]"}]}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.467461009160252*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"88", " ", "\[Degree]"}], "\[Equal]", 
  RowBox[{"\[Pi]", "-", 
   RowBox[{"ArcCos", "[", 
    FractionBox[
     RowBox[{"10000", "+", 
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"], "-", 
      RowBox[{"200", " ", "a", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"20", " ", "\[Degree]"}], "+", "\[CurlyPhi]1"}], "]"}]}]}], 
     RowBox[{"2", " ", "b", " ", 
      SqrtBox[
       RowBox[{"10000", "+", 
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"200", " ", "a", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{
           RowBox[{"20", " ", "\[Degree]"}], "+", "\[CurlyPhi]1"}], 
          "]"}]}]}]]}]], "]"}], "-", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{"100", "-", 
      RowBox[{"a", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"20", " ", "\[Degree]"}], "+", "\[CurlyPhi]1"}], "]"}]}]}], 
     ",", 
     RowBox[{"a", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{
        RowBox[{"20", " ", "\[Degree]"}], "+", "\[CurlyPhi]1"}], "]"}]}]}], 
    "]"}]}]}]], "Output",
 CellChangeTimes->{3.467461009169791*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"110", " ", "\[Degree]"}], "\[Equal]", 
  RowBox[{"\[Pi]", "-", 
   RowBox[{"ArcCos", "[", 
    FractionBox[
     RowBox[{"10000", "+", 
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"], "-", 
      RowBox[{"200", " ", "a", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"30", " ", "\[Degree]"}], "-", "\[CurlyPhi]1"}], "]"}]}]}], 
     RowBox[{"2", " ", "b", " ", 
      SqrtBox[
       RowBox[{"10000", "+", 
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"200", " ", "a", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           RowBox[{"30", " ", "\[Degree]"}], "-", "\[CurlyPhi]1"}], 
          "]"}]}]}]]}]], "]"}], "-", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{"100", "-", 
      RowBox[{"a", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"30", " ", "\[Degree]"}], "-", "\[CurlyPhi]1"}], "]"}]}]}], 
     ",", 
     RowBox[{"a", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"30", " ", "\[Degree]"}], "-", "\[CurlyPhi]1"}], "]"}]}]}], 
    "]"}]}]}]], "Output",
 CellChangeTimes->{3.467461009174844*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"R9", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"50", "Degree"}], " ", "\[Equal]", " ", "\[Mu]min1"}], "/.", 
   "par"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"50", " ", "\[Degree]"}], "\[Equal]", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"100", "-", "a"}], ")"}], "2"]}], "+", 
     SuperscriptBox["b", "2"], "+", 
     SuperscriptBox["c", "2"]}], 
    RowBox[{"2", " ", "b", " ", "c"}]], "]"}]}]], "Output",
 CellChangeTimes->{3.467461009241335*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"erg5", "=", 
  RowBox[{"FindRoot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"R6", ",", "R7", ",", "R8", ",", "R9"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[CurlyPhi]1", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"b", ",", "70"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"c", ",", "100"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "40"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[CurlyPhi]1", "\[Rule]", "1.02902954823823`"}], ",", 
   RowBox[{"b", "\[Rule]", "33.14965855843466`"}], ",", 
   RowBox[{"c", "\[Rule]", "98.75758629612622`"}], ",", 
   RowBox[{"a", "\[Rule]", "18.493742999516478`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.467461009338789*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CurlyPhi]1", "/", "Degree"}], " ", "/.", "erg5", " "}]], "Input"],

Cell[BoxData["58.95905010830433`"], "Output",
 CellChangeTimes->{3.467461009406302*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["further results", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"f\[Psi]", "/", "Degree"}], "/.", "par"}], "/.", 
      RowBox[{"\[CurlyPhi]", "\[Rule]", "\[CurlyPhi]1"}]}], "/.", "erg5"}], "//",
     "N"}], ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"f\[Psi]", "/", "Degree"}], "/.", "par"}], "/.", 
      RowBox[{"\[CurlyPhi]", "\[Rule]", 
       RowBox[{"\[CurlyPhi]1", "+", 
        RowBox[{"60", " ", "Degree"}]}]}]}], "/.", "erg5"}], "//", "N"}]}], 
  "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"78.00000000000001`", ",", "110.00000000000001`"}], "}"}]], "Output",\

 CellChangeTimes->{3.4674610095028687`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f\[CurlyPhi]0", "/", "Degree"}], "/.", "par"}], "/.", 
  "erg5"}]], "Input"],

Cell[BoxData["182.07567702280576`"], "Output",
 CellChangeTimes->{3.4674610096040907`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f\[Psi]0", "/", "Degree"}], "/.", "par"}], "/.", 
  "erg5"}]], "Input"],

Cell[BoxData["68.16676503939809`"], "Output",
 CellChangeTimes->{3.467461009692835*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Mu]min1", "/", "Degree"}], "/.", "par"}], "/.", "erg5"}], "//",
   "N"}]], "Input"],

Cell[BoxData["50.`"], "Output",
 CellChangeTimes->{3.467461009776513*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grashof", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Min", "[", 
      RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}], "+", 
     RowBox[{"Max", "[", 
      RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}]}], "/.", "par"}], "/.",
    "erg5"}]}]], "Input"],

Cell[BoxData["118.49374299951648`"], "Output",
 CellChangeTimes->{3.4674610098595247`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"c", "+", "b"}], "/.", "par"}], "/.", "erg5"}]], "Input"],

Cell[BoxData["131.90724485456087`"], "Output",
 CellChangeTimes->{3.467461009940403*^9}]
}, Open  ]],

Cell[TextData[StyleBox["Another realistic solution is found !!!",
 FontSize->16,
 Background->RGBColor[1, 1, 0]]], "Text",
 CellChangeTimes->{{3.467461052354156*^9, 3.467461059571116*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{970, 982},
WindowMargins->{{132, Automatic}, {Automatic, 0}},
Magnification->1,
FrontEndVersion->"6.0 for Mac OS X PowerPC (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 93, 2, 46, "Subtitle"],
Cell[686, 27, 204, 5, 41, "Text"],
Cell[CellGroupData[{
Cell[915, 36, 63, 0, 34, "Subsection"],
Cell[981, 38, 5285, 89, 231, "Graphics",
 Evaluatable->False],
Cell[6269, 129, 132, 3, 27, "Input"],
Cell[CellGroupData[{
Cell[6426, 136, 340, 10, 105, "Input"],
Cell[6769, 148, 873, 25, 59, "Output"],
Cell[7645, 175, 875, 25, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8557, 205, 1126, 36, 73, "Input"],
Cell[9686, 243, 825, 28, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10548, 276, 1032, 34, 73, "Input"],
Cell[11583, 312, 666, 22, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12286, 339, 374, 12, 27, "Input"],
Cell[12663, 353, 345, 11, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13045, 369, 409, 13, 27, "Input"],
Cell[13457, 384, 359, 11, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13853, 400, 230, 6, 27, "Input"],
Cell[14086, 408, 242, 6, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14377, 420, 147, 1, 67, "Section"],
Cell[14527, 423, 250, 6, 27, "Input"],
Cell[CellGroupData[{
Cell[14802, 433, 242, 6, 25, "Subsubsection"],
Cell[CellGroupData[{
Cell[15069, 443, 106, 3, 27, "Input"],
Cell[15178, 448, 147, 3, 27, "Output"]
}, Open  ]],
Cell[15340, 454, 51, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[15416, 458, 64, 1, 27, "Input"],
Cell[15483, 461, 743, 24, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16263, 490, 59, 1, 27, "Input"],
Cell[16325, 493, 627, 20, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16989, 518, 60, 1, 27, "Input"],
Cell[17052, 521, 375, 11, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17464, 537, 755, 23, 27, "Input"],
Cell[18222, 562, 290, 6, 27, "Output"]
}, Open  ]],
Cell[18527, 571, 113, 2, 30, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18677, 578, 44, 0, 25, "Subsubsection"],
Cell[CellGroupData[{
Cell[18746, 582, 469, 17, 27, "Input"],
Cell[19218, 601, 212, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19467, 611, 913, 26, 100, "Input"],
Cell[20383, 639, 13604, 229, 227, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34024, 873, 591, 19, 27, "Input"],
Cell[34618, 894, 114, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34769, 900, 298, 9, 27, "Input"],
Cell[35070, 911, 114, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35221, 917, 103, 3, 27, "Input"],
Cell[35327, 922, 110, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35474, 928, 187, 5, 27, "Input"],
Cell[35664, 935, 114, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35815, 941, 161, 5, 27, "Input"],
Cell[35979, 948, 87, 1, 27, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[36127, 956, 57, 0, 67, "Section"],
Cell[CellGroupData[{
Cell[36209, 960, 317, 7, 65, "Subsection"],
Cell[36529, 969, 233, 6, 27, "Input"],
Cell[CellGroupData[{
Cell[36787, 979, 126, 3, 27, "Input"],
Cell[36916, 984, 374, 10, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37327, 999, 74, 1, 27, "Input"],
Cell[37404, 1002, 119, 3, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37560, 1010, 87, 1, 27, "Input"],
Cell[37650, 1013, 273, 8, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37960, 1026, 70, 1, 27, "Input"],
Cell[38033, 1029, 366, 11, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38436, 1045, 86, 1, 27, "Input"],
Cell[38525, 1048, 185, 5, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38747, 1058, 68, 1, 27, "Input"],
Cell[38818, 1061, 356, 11, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39211, 1077, 80, 1, 27, "Input"],
Cell[39294, 1080, 805, 25, 82, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40136, 1110, 72, 1, 27, "Input"],
Cell[40211, 1113, 558, 17, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40806, 1135, 81, 1, 27, "Input"],
Cell[40890, 1138, 1342, 40, 96, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42269, 1183, 104, 6, 66, "Input"],
Cell[42376, 1191, 87, 1, 27, "Output"],
Cell[42466, 1194, 88, 1, 27, "Output"],
Cell[42557, 1197, 86, 1, 27, "Output"],
Cell[42646, 1200, 372, 10, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43055, 1215, 44, 0, 25, "Subsubsection"],
Cell[CellGroupData[{
Cell[43124, 1219, 120, 4, 27, "Input"],
Cell[43247, 1225, 74, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43358, 1231, 112, 3, 27, "Input"],
Cell[43473, 1236, 87, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43597, 1242, 113, 3, 27, "Input"],
Cell[43713, 1247, 88, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43838, 1253, 148, 4, 27, "Input"],
Cell[43989, 1259, 84, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44110, 1265, 861, 25, 100, "Input"],
Cell[44974, 1292, 11246, 191, 227, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56257, 1488, 547, 18, 27, "Input"],
Cell[56807, 1508, 87, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56931, 1514, 265, 8, 27, "Input"],
Cell[57199, 1524, 88, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57324, 1530, 75, 2, 27, "Input"],
Cell[57402, 1534, 88, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57527, 1540, 187, 5, 27, "Input"],
Cell[57717, 1547, 140, 2, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57894, 1554, 161, 5, 27, "Input"],
Cell[58058, 1561, 109, 1, 27, "Output"]
}, Open  ]],
Cell[58182, 1565, 158, 3, 30, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[58401, 1575, 63, 0, 67, "Section"],
Cell[58467, 1577, 250, 6, 27, "Input"],
Cell[CellGroupData[{
Cell[58742, 1587, 150, 3, 39, "Subsubsection"],
Cell[CellGroupData[{
Cell[58917, 1594, 33, 0, 27, "Input"],
Cell[58953, 1596, 875, 25, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[59865, 1626, 178, 5, 27, "Input"],
Cell[60046, 1633, 180, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[60263, 1643, 880, 28, 73, "Input"],
Cell[61146, 1673, 790, 22, 53, "Output"],
Cell[61939, 1697, 1087, 33, 53, "Output"],
Cell[63029, 1732, 1085, 33, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[64151, 1770, 362, 11, 27, "Input"],
Cell[64516, 1783, 435, 9, 20, "Message"],
Cell[64954, 1794, 278, 6, 27, "Output"]
}, Open  ]],
Cell[65247, 1803, 114, 2, 30, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[65398, 1810, 182, 4, 39, "Subsubsection"],
Cell[CellGroupData[{
Cell[65605, 1818, 34, 0, 27, "Input"],
Cell[65642, 1820, 873, 25, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[66552, 1850, 178, 5, 27, "Input"],
Cell[66733, 1857, 178, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[66948, 1867, 883, 28, 73, "Input"],
Cell[67834, 1897, 790, 22, 53, "Output"],
Cell[68627, 1921, 1085, 33, 53, "Output"],
Cell[69715, 1956, 1085, 33, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[70837, 1994, 404, 12, 27, "Input"],
Cell[71244, 2008, 627, 12, 62, "Message"],
Cell[71874, 2022, 320, 8, 27, "Output"]
}, Open  ]],
Cell[72209, 2033, 114, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[72348, 2039, 165, 5, 27, "Input"],
Cell[72516, 2046, 182, 3, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[72747, 2055, 109, 3, 34, "Subsection"],
Cell[CellGroupData[{
Cell[72881, 2062, 33, 0, 27, "Input"],
Cell[72917, 2064, 873, 25, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[73827, 2094, 178, 5, 27, "Input"],
Cell[74008, 2101, 180, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[74225, 2111, 875, 28, 73, "Input"],
Cell[75103, 2141, 804, 23, 53, "Output"],
Cell[75910, 2166, 1100, 34, 53, "Output"],
Cell[77013, 2202, 1101, 34, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[78151, 2241, 362, 11, 27, "Input"],
Cell[78516, 2254, 281, 6, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[78834, 2265, 102, 2, 27, "Input"],
Cell[78939, 2269, 90, 1, 27, "Output"]
}, Open  ]],
Cell[79044, 2273, 122, 1, 26, "Text"],
Cell[CellGroupData[{
Cell[79191, 2278, 193, 4, 27, "Input"],
Cell[79387, 2284, 114, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[79538, 2290, 172, 4, 27, "Input"],
Cell[79713, 2296, 111, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[79861, 2302, 148, 4, 27, "Input"],
Cell[80012, 2308, 87, 1, 27, "Output"]
}, Open  ]],
Cell[80114, 2312, 112, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[80251, 2318, 40, 0, 25, "Subsubsection"],
Cell[CellGroupData[{
Cell[80316, 2322, 222, 7, 27, "Input"],
Cell[80541, 2331, 89, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[80667, 2337, 281, 9, 27, "Input"],
Cell[80951, 2348, 76, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[81064, 2354, 909, 25, 100, "Input"],
Cell[81976, 2381, 5709, 100, 218, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[87722, 2486, 123, 4, 27, "Input"],
Cell[87848, 2492, 88, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[87973, 2498, 118, 4, 27, "Input"],
Cell[88094, 2504, 87, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[88218, 2510, 145, 5, 27, "Input"],
Cell[88366, 2517, 86, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[88489, 2523, 145, 5, 27, "Input"],
Cell[88637, 2530, 89, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[88763, 2536, 298, 9, 27, "Input"],
Cell[89064, 2547, 87, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[89188, 2553, 103, 3, 27, "Input"],
Cell[89294, 2558, 88, 1, 27, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[89443, 2566, 133, 3, 34, "Subsection"],
Cell[CellGroupData[{
Cell[89601, 2573, 106, 3, 27, "Input"],
Cell[89710, 2578, 125, 3, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[89872, 2586, 875, 28, 73, "Input"],
Cell[90750, 2616, 898, 25, 59, "Output"],
Cell[91651, 2643, 1194, 36, 59, "Output"],
Cell[92848, 2681, 1195, 36, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[94080, 2722, 160, 5, 27, "Input"],
Cell[94243, 2729, 418, 13, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[94698, 2747, 435, 13, 27, "Input"],
Cell[95136, 2762, 334, 7, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[95507, 2774, 102, 2, 27, "Input"],
Cell[95612, 2778, 87, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[95736, 2784, 40, 0, 25, "Subsubsection"],
Cell[CellGroupData[{
Cell[95801, 2788, 556, 18, 27, "Input"],
Cell[96360, 2808, 154, 4, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[96551, 2817, 123, 4, 27, "Input"],
Cell[96677, 2823, 90, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[96804, 2829, 118, 4, 27, "Input"],
Cell[96925, 2835, 87, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[97049, 2841, 145, 5, 27, "Input"],
Cell[97197, 2848, 73, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[97307, 2854, 298, 9, 27, "Input"],
Cell[97608, 2865, 90, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[97735, 2871, 103, 3, 27, "Input"],
Cell[97841, 2876, 88, 1, 27, "Output"]
}, Open  ]],
Cell[97944, 2880, 188, 3, 30, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
