(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     64169,       2489]
NotebookOptionsPosition[     60319,       2354]
NotebookOutlinePosition[     60731,       2372]
CellTagsIndexPosition[     60688,       2369]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
MDA-Chapter 3: Design of Mechanisms - 3.4 Paths of Crank-Rocker Mechanisms\
\>", "Subtitle"],

Cell["\<\
created 2009, Prof. Oskar Wallrapp, FK06, Munich University of Applied \
Sciences
updated 17.11.2009 - Animation\
\>", "Text",
 CellChangeTimes->{{3.4674673047927027`*^9, 3.467467366088581*^9}}],

Cell[CellGroupData[{

Cell["crank-rocker mechanismus: Basic functions", "Subsection"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
 Evaluatable->False,
 ImageSize->{263, 223},
 ImageMargins->{{110, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Clear[par,\[CurlyPhi],\[Psi],\[Psi]1,\[Psi]2,\[CurlyPhi]0,\[Psi]0,a,b,c,d];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
X = d - a Cos[\[CurlyPhi]];
Y = a Sin[\[CurlyPhi]];
\[Sigma] = ArcTan[X,Y];
\[CapitalDelta] = Sqrt[X^2 + Y^2];
\[Lambda] = Simplify[ArcCos[(\[CapitalDelta]^2 + b^2 - c^2) / (2 b \
\[CapitalDelta])] ];
f\[Psi] = \[Pi] - (\[Sigma] + \[Lambda])
f\[Psi]2 = \[Pi] - (\[Sigma] - \[Lambda])\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{"\[Pi]", "-", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["b", "2"], "-", 
     SuperscriptBox["c", "2"], "+", 
     SuperscriptBox["d", "2"], "-", 
     RowBox[{"2", " ", "a", " ", "d", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}], 
    RowBox[{"2", " ", "b", " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["d", "2"], "-", 
       RowBox[{"2", " ", "a", " ", "d", " ", 
        RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}]]}]], "]"}], "-", 
  RowBox[{"ArcTan", "[", 
   RowBox[{
    RowBox[{"d", "-", 
     RowBox[{"a", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}], ",", 
    RowBox[{"a", " ", 
     RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}]}], "]"}]}]], "Output"],

Cell[BoxData[
 RowBox[{"\[Pi]", "+", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["b", "2"], "-", 
     SuperscriptBox["c", "2"], "+", 
     SuperscriptBox["d", "2"], "-", 
     RowBox[{"2", " ", "a", " ", "d", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}], 
    RowBox[{"2", " ", "b", " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["d", "2"], "-", 
       RowBox[{"2", " ", "a", " ", "d", " ", 
        RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}]]}]], "]"}], "-", 
  RowBox[{"ArcTan", "[", 
   RowBox[{
    RowBox[{"d", "-", 
     RowBox[{"a", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}], ",", 
    RowBox[{"a", " ", 
     RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}]}], "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[CurlyPhi]i", "=", 
   RowBox[{"Pi", "+", 
    RowBox[{"ArcCos", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"d", "^", "2"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"c", "-", "a"}], ")"}], "^", "2"}], "-", 
        RowBox[{"b", "^", "2"}]}], ")"}], " ", "/", " ", 
      RowBox[{"(", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"c", "-", "a"}], ")"}], " ", "d"}], ")"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CurlyPhi]a", "=", 
   RowBox[{"ArcCos", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"d", "^", "2"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"c", "+", "a"}], ")"}], "^", "2"}], "-", 
       RowBox[{"b", "^", "2"}]}], ")"}], " ", "/", " ", 
     RowBox[{"(", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"c", "+", "a"}], ")"}], " ", "d"}], ")"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"f\[CurlyPhi]0", "=", 
  RowBox[{
  "\[CurlyPhi]i", "-", "\[CurlyPhi]a"}]}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{"\[Pi]", "+", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["b", "2"]}], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "c"}], ")"}], "2"], "+", 
     SuperscriptBox["d", "2"]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "+", "c"}], ")"}], " ", "d"}]], "]"}], "-", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["b", "2"]}], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], "2"], "+", 
     SuperscriptBox["d", "2"]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"a", "+", "c"}], ")"}], " ", "d"}]], "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Psi]i", "=", 
   RowBox[{"Pi", "-", 
    RowBox[{"ArcCos", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"d", "^", "2"}], "+", 
        RowBox[{"b", "^", "2"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"c", "-", "a"}], ")"}], "^", "2"}]}], ")"}], " ", "/", " ", 
      
      RowBox[{"(", 
       RowBox[{"2", " ", "b", " ", "d"}], ")"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Psi]a", "=", 
   RowBox[{"Pi", "-", 
    RowBox[{"ArcCos", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"d", "^", "2"}], "+", 
        RowBox[{"b", "^", "2"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"c", "+", "a"}], ")"}], "^", "2"}]}], ")"}], " ", "/", " ", 
      
      RowBox[{"(", 
       RowBox[{"2", " ", "b", " ", "d"}], ")"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"f\[Psi]0", "=", 
  RowBox[{"\[Psi]i", "-", "\[Psi]a"}]}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"ArcCos", "[", 
    FractionBox[
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "c"}], ")"}], "2"], "+", 
      SuperscriptBox["d", "2"]}], 
     RowBox[{"2", " ", "b", " ", "d"}]], "]"}]}], "+", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{
     SuperscriptBox["b", "2"], "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], "2"], "+", 
     SuperscriptBox["d", "2"]}], 
    RowBox[{"2", " ", "b", " ", "d"}]], "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Mu]min1", "=", 
  RowBox[{"ArcCos", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "^", "2"}], "+", 
      RowBox[{"b", "^", "2"}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"d", "-", "a"}], ")"}], "^", "2"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", "b", " ", "c"}], ")"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"ArcCos", "[", 
  FractionBox[
   RowBox[{
    SuperscriptBox["b", "2"], "+", 
    SuperscriptBox["c", "2"], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "+", "d"}], ")"}], "2"]}], 
   RowBox[{"2", " ", "b", " ", "c"}]], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Mu]min2", "=", 
  RowBox[{"Pi", "-", 
   RowBox[{"ArcCos", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"c", "^", "2"}], "+", 
       RowBox[{"b", "^", "2"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"d", "+", "a"}], ")"}], "^", "2"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"2", " ", "b", " ", "c"}], ")"}]}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"\[Pi]", "-", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{
     SuperscriptBox["b", "2"], "+", 
     SuperscriptBox["c", "2"], "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "+", "d"}], ")"}], "2"]}], 
    RowBox[{"2", " ", "b", " ", "c"}]], "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grashof", "=", 
  RowBox[{
   RowBox[{"Min", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}], "+", 
   RowBox[{"Max", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Max", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}], "+", 
  RowBox[{"Min", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f\[Delta]", "=", 
  RowBox[{"ArcTan", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"d", "+", 
      RowBox[{"b", " ", 
       RowBox[{"Cos", "[", "\[Psi]", "]"}]}], "-", 
      RowBox[{"a", " ", 
       RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}], ")"}], ",", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", " ", 
       RowBox[{"Sin", "[", "\[Psi]", "]"}]}], "-", 
      RowBox[{"a", " ", 
       RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}]}], " ", ")"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"ArcTan", "[", 
  RowBox[{
   RowBox[{"d", "-", 
    RowBox[{"a", " ", 
     RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}], "+", 
    RowBox[{"b", " ", 
     RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "a"}], " ", 
     RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}], "+", 
    RowBox[{"b", " ", 
     RowBox[{"Sin", "[", "\[Psi]", "]"}]}]}]}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"xK", " ", "=", " ", 
  RowBox[{"A0x", " ", "+", " ", 
   RowBox[{"a", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"\[CurlyPhi]", "+", "\[Gamma]0"}], "]"}]}], "+", 
   RowBox[{"k", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "+", "\[Delta]", "+", "\[Gamma]0"}], 
     "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"yK", " ", "=", " ", 
  RowBox[{"A0y", " ", "+", " ", 
   RowBox[{"a", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"\[CurlyPhi]", "+", "\[Gamma]0"}], "]"}]}], "+", 
   RowBox[{"k", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"\[Kappa]", "+", "\[Delta]", "+", "\[Gamma]0"}], 
     "]"}]}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"A0x", "+", 
  RowBox[{"k", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Gamma]0", "+", "\[Delta]", "+", "\[Kappa]"}], "]"}]}], "+", 
  RowBox[{"a", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Gamma]0", "+", "\[CurlyPhi]"}], "]"}]}]}]], "Output"],

Cell[BoxData[
 RowBox[{"A0y", "+", 
  RowBox[{"k", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"\[Gamma]0", "+", "\[Delta]", "+", "\[Kappa]"}], "]"}]}], "+", 
  RowBox[{"a", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"\[Gamma]0", "+", "\[CurlyPhi]"}], "]"}]}]}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.3.1\tFind mechanism for path of a coupler point K", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "par", ",", "\[CurlyPhi]", ",", "\[Psi]", ",", "\[Psi]1", ",", "\[Psi]2", 
    ",", "\[CurlyPhi]0", ",", "\[Psi]0", ",", "a", ",", "b", ",", "c", ",", 
    "d", ",", "k", ",", "\[Kappa]"}], "]"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell["\<\
Requirements of crank-rocker mechanism  are 5 points of K and par\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{"xK", "\[IndentingNewLine]", "yK"}], "Input"],

Cell[BoxData[
 RowBox[{"A0x", "+", 
  RowBox[{"k", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Gamma]0", "+", "\[Delta]", "+", "\[Kappa]"}], "]"}]}], "+", 
  RowBox[{"a", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Gamma]0", "+", "\[CurlyPhi]"}], "]"}]}]}]], "Output"],

Cell[BoxData[
 RowBox[{"A0y", "+", 
  RowBox[{"k", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"\[Gamma]0", "+", "\[Delta]", "+", "\[Kappa]"}], "]"}]}], "+", 
  RowBox[{"a", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"\[Gamma]0", "+", "\[CurlyPhi]"}], "]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"par", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"a", "\[Rule]", "26"}], ",", 
    RowBox[{"d", "\[Rule]", "20"}], ",", 
    RowBox[{"\[Kappa]", "->", "0"}], ",", 
    RowBox[{"k", "\[Rule]", "32"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "\[Rule]", "26"}], ",", 
   RowBox[{"d", "\[Rule]", "20"}], ",", 
   RowBox[{"\[Kappa]", "\[Rule]", "0"}], ",", 
   RowBox[{"k", "\[Rule]", "32"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"R2", "=", 
   RowBox[{"62", "  ", "\[Equal]", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"xK", "/.", 
         RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
        RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", "par"}], "/.", 
      RowBox[{"\[CurlyPhi]", "->", "\[CurlyPhi]1"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"R3", "=", 
   RowBox[{"22", "  ", "\[Equal]", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"yK", "/.", 
         RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
        RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", "par"}], "/.", 
      RowBox[{"\[CurlyPhi]", "->", "\[CurlyPhi]1"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"R4", "=", 
   RowBox[{"39", "  ", "\[Equal]", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"xK", "/.", 
         RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
        RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", "par"}], "/.", 
      RowBox[{"\[CurlyPhi]", "->", "\[CurlyPhi]2"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"R5", "=", 
   RowBox[{"22", "  ", "\[Equal]", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"yK", "/.", 
         RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
        RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", "par"}], "/.", 
      RowBox[{"\[CurlyPhi]", "->", "\[CurlyPhi]2"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"R6", "=", 
   RowBox[{"30", "  ", "\[Equal]", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"xK", "/.", 
         RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
        RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", "par"}], "/.", 
      RowBox[{"\[CurlyPhi]", "->", "\[CurlyPhi]3"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"R7", "=", 
   RowBox[{"22", "  ", "\[Equal]", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"yK", "/.", 
         RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
        RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", "par"}], "/.", 
      RowBox[{"\[CurlyPhi]", "->", "\[CurlyPhi]3"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"R8", "=", 
   RowBox[{"14", "  ", "\[Equal]", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"xK", "/.", 
         RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
        RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", "par"}], "/.", 
      RowBox[{"\[CurlyPhi]", "->", "\[CurlyPhi]4"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"R9", "=", 
   RowBox[{"57", "  ", "\[Equal]", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"yK", "/.", 
         RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
        RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", "par"}], "/.", 
      RowBox[{"\[CurlyPhi]", "->", "\[CurlyPhi]4"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"R10", "=", 
   RowBox[{"57", "  ", "\[Equal]", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"xK", "/.", 
         RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
        RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", "par"}], "/.", 
      RowBox[{"\[CurlyPhi]", "->", "\[CurlyPhi]5"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"R11", "=", 
   RowBox[{"55", "  ", "\[Equal]", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"yK", "/.", 
         RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
        RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", "par"}], "/.", 
      RowBox[{"\[CurlyPhi]", "->", "\[CurlyPhi]5"}]}], "]"}]}]}], 
  ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"parinit", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"A0x", "\[Rule]", "13"}], ",", 
    RowBox[{"A0y", "\[Rule]", "33"}], ",", 
    RowBox[{"\[Gamma]0", "\[Rule]", 
     RowBox[{
      RowBox[{"-", "60"}], " ", "Degree"}]}], ",", 
    RowBox[{"b", "\[Rule]", "29"}], ",", 
    RowBox[{"c", "\[Rule]", "9"}], ",", 
    RowBox[{"\[CurlyPhi]1", "\[Rule]", 
     RowBox[{"79", " ", "Degree"}]}], ",", 
    RowBox[{"\[CurlyPhi]2", "\[Rule]", 
     RowBox[{"106", " ", "Degree"}]}], ",", 
    RowBox[{"\[CurlyPhi]3", "\[Rule]", 
     RowBox[{"110", " ", "Degree"}]}], ",", 
    RowBox[{"\[CurlyPhi]4", "\[Rule]", 
     RowBox[{"80", " ", "Degree"}]}], ",", 
    RowBox[{"\[CurlyPhi]5", "\[Rule]", 
     RowBox[{"50", " ", "Degree"}]}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A0x", "\[Rule]", "13"}], ",", 
   RowBox[{"A0y", "\[Rule]", "33"}], ",", 
   RowBox[{"\[Gamma]0", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "60"}], " ", "\[Degree]"}]}], ",", 
   RowBox[{"b", "\[Rule]", "29"}], ",", 
   RowBox[{"c", "\[Rule]", "9"}], ",", 
   RowBox[{"\[CurlyPhi]1", "\[Rule]", 
    RowBox[{"79", " ", "\[Degree]"}]}], ",", 
   RowBox[{"\[CurlyPhi]2", "\[Rule]", 
    RowBox[{"106", " ", "\[Degree]"}]}], ",", 
   RowBox[{"\[CurlyPhi]3", "\[Rule]", 
    RowBox[{"110", " ", "\[Degree]"}]}], ",", 
   RowBox[{"\[CurlyPhi]4", "\[Rule]", 
    RowBox[{"80", " ", "\[Degree]"}]}], ",", 
   RowBox[{"\[CurlyPhi]5", "\[Rule]", 
    RowBox[{"50", " ", "\[Degree]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xKpar", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"xK", "/.", "\[InvisibleSpace]", 
       RowBox[{"\[Delta]", "\[Rule]", "f\[Delta]"}]}], "/.", 
      "\[InvisibleSpace]", 
      RowBox[{"\[Psi]", "\[Rule]", "f\[Psi]"}]}], "/.", "\[InvisibleSpace]", 
     "par"}], "/.", "\[InvisibleSpace]", "parinit"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"yKpar", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"yK", "/.", "\[InvisibleSpace]", 
       RowBox[{"\[Delta]", "\[Rule]", "f\[Delta]"}]}], "/.", 
      "\[InvisibleSpace]", 
      RowBox[{"\[Psi]", "\[Rule]", "f\[Psi]"}]}], "/.", "\[InvisibleSpace]", 
     "par"}], "/.", "\[InvisibleSpace]", "parinit"}]}], ";"}], "\n", 
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"xKpar", ",", "yKpar"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[CurlyPhi]", ",", 
     RowBox[{"50", " ", "\[Degree]"}], ",", 
     RowBox[{"110", " ", "\[Degree]"}]}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "80"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "60"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Path of K - init param\>\""}]}], 
  "]"}]}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.0125 0 0.0103006 [
[.125 -0.0125 -6 -9 ]
[.125 -0.0125 6 0 ]
[.25 -0.0125 -6 -9 ]
[.25 -0.0125 6 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.625 -0.0125 -6 -9 ]
[.625 -0.0125 6 0 ]
[.75 -0.0125 -6 -9 ]
[.75 -0.0125 6 0 ]
[.875 -0.0125 -6 -9 ]
[.875 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .10301 -12 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -12 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -12 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -12 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -68.0625 0 ]
[.5 .63053 68.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .61803 L
s
.125 0 m
.125 .61803 L
s
.25 0 m
.25 .61803 L
s
.375 0 m
.375 .61803 L
s
.5 0 m
.5 .61803 L
s
.625 0 m
.625 .61803 L
s
.75 0 m
.75 .61803 L
s
.875 0 m
.875 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.125 0 m
.125 .00625 L
s
[(10)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(20)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(30)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(40)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(50)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(60)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(70)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(80)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10301 m
.00625 .10301 L
s
[(10)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(20)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(30)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(40)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(50)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(60)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -129.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Path) show
93.000 13.000 moveto
(of) show
111.000 13.000 moveto
(K) show
123.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(init) show
165.000 13.000 moveto
(param) show
195.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.84411 .43443 m
.85949 .40758 L
.86943 .38601 L
.87613 .3678 L
.8802 .35382 L
.88319 .34031 L
.88431 .33361 L
.88509 .32769 L
.88561 .32252 L
.88579 .32016 L
.88593 .318 L
.88604 .31572 L
.88609 .31453 L
.88613 .31327 L
.88614 .31265 L
.88615 .31197 L
.88616 .31134 L
.88617 .31076 L
.88618 .30966 L
.88618 .30906 L
.88617 .30852 L
.88616 .3075 L
.88615 .30656 L
.88613 .30554 L
.88609 .30446 L
.886 .3023 L
.88589 .30038 L
.88561 .29678 L
.88526 .29352 L
.88424 .28669 L
.88353 .28307 L
.88279 .27988 L
.87962 .26945 L
.87749 .26415 L
.8753 .25954 L
.86545 .24453 L
.85963 .23823 L
.85309 .23248 L
.84033 .22405 L
.83334 .22053 L
.82558 .21729 L
.81794 .21466 L
.80939 .21224 L
.7928 .20878 L
.78419 .20749 L
.77482 .20638 L
.76587 .20557 L
.75727 .20498 L
.75229 .20471 L
.7475 .2045 L
Mistroke
.74272 .20432 L
.73834 .2042 L
.7335 .20409 L
.731 .20404 L
.72828 .204 L
.72573 .20397 L
.72337 .20395 L
.7211 .20394 L
.71996 .20394 L
.71935 .20393 L
.7187 .20393 L
.71801 .20393 L
.71737 .20393 L
.71668 .20393 L
.71628 .20393 L
.71592 .20393 L
.71525 .20393 L
.71464 .20393 L
.71397 .20393 L
.71326 .20393 L
.71203 .20394 L
.71087 .20394 L
.70825 .20395 L
.70536 .20398 L
.70272 .204 L
.69673 .20408 L
.68584 .20427 L
.67368 .20454 L
.64853 .20525 L
.62256 .20607 L
.59561 .20694 L
.56423 .20791 L
.53048 .20889 L
.48888 .21005 L
.46461 .21078 L
.43876 .21167 L
.40952 .21291 L
.36653 .21548 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{250, 154.438},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztnTFv1DAUgNMkd1C19K7HXQtiKQsLEpXYWMoGEwvsSKcKqR1QUene/8EM
KxM/A4k/AX+iS4jt1E58z3acpBe/3Dupie/Ffve9l2c7jp303fLq7NPn5dX5
6fLo7eXyy9n56dejNxeXuSjZiqLoJv/7dhSxdJYni81Nln+i6AXbJUyUslTM
UlOWGrFUImX7QD4lq5tPyWb857kwKz4lLVOgxEQAHwMFY75NyzKpZVVsyC30
jyri4pCpyL6zSJXzgf9PNKaq5aE9f+2iiM9p8OB5CIshX+6y7chyPj10NTgv
M2cRAPeuPe0LxYMrlhXYhLAiNuT29Xhq0eVrCleYOE3x8WaDqucdc0oWmdEn
LmdNAP1pa8LmIcs7lVg23524tkGRqcRo77cpkNWqtYHfumoduumNY3kUuh6Y
yZT9usHSk99Ydo/Z7o9CEwKN8LCF7GAN+qZ10K+9ZQctytbVNxB0Hm6PEAEj
9jWh94FOEU7ow0anCCd0Qg8UHVPl5ONZ7upUoqcyOzr/6zcQ2DfDWDEhK4dl
Jc/5m2mabZKbeA223VdCbBt0BtVtFMTtFLp+AnufTOh9oFOEEzqhB4pOlZPQ
h41OEb4W9B2206Y4U7zmiCn+uiukBja6cg6wL5imlyz1nKWKobZ7rh4+pqLe
37KnWWW1gj3zmG05w66fk3aclnUaEgvJ2SYQODQH2A7a2q4rwB7AMvbzgPGG
aK+diVqU5mlOSN0KtOYxAfIhMce4PginOXwRXKx6OpRGLDSW/BhYZ4O5SmwC
HIivy6u7CjmYL0B0JYMWqw0OPZBx0Eb4Ojj061ueIaMHEuGofS3o4IEH0tUC
DnOQj3Y8rZ3AFkGGZsVZ/sX0lLp49m3BtuUZdtvDBEN1V/d3Myjsqc2qYw51
d4S+AegU4YSOEZ0G5XeNjvi2E2J0urG6PvQ53+rX4NcWeu1B/+Cucf0t6mNC
eb0WqlUTzjn3nzx6VbvBvj1h21lJlUGBSRxGYIg3L0Cn0lpb1Rz+beVGYW0H
M4ao7rh0MOELzeirlzCE1MZ1Nbvda68JvdEjBfIhuVasq4/Q+0YPZDRUHxix
rwm9D3SKcEIfNjpF+FrQsU1oOcwZ2Gykw1rEs8ptLIOXF5Qf1udhYHufI+KT
vgOgp8O0cjiPAVGXRugbgE4RTujDRqcIJ3RCDxQdU+WkgTf20clmWescTXPT
VgbhmsUprOCv2Osz8eKbrYSawVa16J849F1CfRCCH4D29+LQicybVm1Vj7CO
WeqezMdlo6pMFMnEworivfo8Sx4ppQO3AHnJys9sS0WJhBA85ZIKUDy9Lc0p
7V+J/WvAYGt01n1NBTfZEP5QnN+H1eirqpx8tbKKHxvr4qpJMLshOvUipb3N
1apWQPQGjzdzbVJh4oGUypBq6+GqbNviI7uxiY8vS5lroXbpTl4bD4GjnbjO
EZkrNzdt63NqRyZcUqlWLV5iaoqgSJsD+WJTWa1VVSmt3YztWdjObptOmsn4
qMqg9SmGpuoZkPWjOHYibTPWNm6CeiWCsceYAwrMVRikqf6Tl2jrPwo//n8=
\
\>"],
 ImageRangeCache->{{{73.5625, 272.562}, {226.625, 104.125}} -> {-45.8955, \
56.0307, 0.38935, 0.472485}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"erg1", "=", 
  RowBox[{"FindRoot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "R2", ",", "R3", ",", "R4", ",", "R5", ",", "R6", ",", "R7", ",", "R8", 
      ",", "R9", ",", "R10", ",", "R11"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"A0x", ",", "13"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"A0y", ",", "33"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Gamma]0", ",", 
        RowBox[{
         RowBox[{"-", "60"}], " ", "Degree"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"b", ",", "29"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"c", ",", "9"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[CurlyPhi]1", ",", 
        RowBox[{"79", " ", "Degree"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[CurlyPhi]2", ",", 
        RowBox[{"106", " ", "Degree"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[CurlyPhi]3", ",", 
        RowBox[{"110", " ", "Degree"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[CurlyPhi]4", ",", 
        RowBox[{"80", " ", "Degree"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[CurlyPhi]5", ",", 
        RowBox[{"50", " ", "Degree"}]}], "}"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FindRoot", "::", "\<\"lstol\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"The line search decreased the step size to within \
tolerance specified by AccuracyGoal and PrecisionGoal but was unable to find \
a sufficient decrease in the merit function.  You may need more than \
\\!\\(MachinePrecision\\) digits of working precision to meet these \
tolerances. \\!\\(\\*ButtonBox[\\\"Mehr\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A0x", "\[Rule]", "13.679480557657607`"}], ",", 
   RowBox[{"A0y", "\[Rule]", "37.95670881359349`"}], ",", 
   RowBox[{"\[Gamma]0", "\[Rule]", 
    RowBox[{"-", "0.29959933038325653`"}]}], ",", 
   RowBox[{"b", "\[Rule]", "11.9464447260867`"}], ",", 
   RowBox[{"c", "\[Rule]", "9.8478850941716`"}], ",", 
   RowBox[{"\[CurlyPhi]1", "\[Rule]", "0.4995331870265596`"}], ",", 
   RowBox[{"\[CurlyPhi]2", "\[Rule]", "0.8884032738482893`"}], ",", 
   RowBox[{"\[CurlyPhi]3", "\[Rule]", "0.8982441965202608`"}], ",", 
   RowBox[{"\[CurlyPhi]4", "\[Rule]", "0.5266282422105724`"}], ",", 
   RowBox[{"\[CurlyPhi]5", "\[Rule]", 
    RowBox[{"-", "0.01866112713889356`"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["par"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "\[Rule]", "26"}], ",", 
   RowBox[{"d", "\[Rule]", "20"}], ",", 
   RowBox[{"\[Kappa]", "\[Rule]", "0"}], ",", 
   RowBox[{"k", "\[Rule]", "32"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xKpar", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"xK", "/.", "\[InvisibleSpace]", 
       RowBox[{"\[Delta]", "\[Rule]", "f\[Delta]"}]}], "/.", 
      "\[InvisibleSpace]", 
      RowBox[{"\[Psi]", "\[Rule]", "f\[Psi]"}]}], "/.", "\[InvisibleSpace]", 
     "erg1"}], "/.", "\[InvisibleSpace]", "par"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"yKpar", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"yK", "/.", "\[InvisibleSpace]", 
       RowBox[{"\[Delta]", "\[Rule]", "f\[Delta]"}]}], "/.", 
      "\[InvisibleSpace]", 
      RowBox[{"\[Psi]", "\[Rule]", "f\[Psi]"}]}], "/.", "\[InvisibleSpace]", 
     "erg1"}], "/.", "\[InvisibleSpace]", "par"}]}], ";"}], "\n", 
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"xKpar", ",", "yKpar"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[CurlyPhi]", ",", 
     RowBox[{"0", " ", "\[Degree]"}], ",", 
     RowBox[{"50", " ", "\[Degree]"}]}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "80"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "10"}], ",", "60"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Path of K\>\""}]}], "]"}]}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.0125 0.0882906 0.00882906 [
[.125 .07579 -6 -9 ]
[.125 .07579 6 0 ]
[.25 .07579 -6 -9 ]
[.25 .07579 6 0 ]
[.375 .07579 -6 -9 ]
[.375 .07579 6 0 ]
[.5 .07579 -6 -9 ]
[.5 .07579 6 0 ]
[.625 .07579 -6 -9 ]
[.625 .07579 6 0 ]
[.75 .07579 -6 -9 ]
[.75 .07579 6 0 ]
[.875 .07579 -6 -9 ]
[.875 .07579 6 0 ]
[1 .07579 -6 -9 ]
[1 .07579 6 0 ]
[-0.0125 0 -18 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .17658 -12 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -12 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .35316 -12 -4.5 ]
[-0.0125 .35316 0 4.5 ]
[-0.0125 .44145 -12 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -12 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -29 0 ]
[.5 .63053 29 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .61803 L
s
.125 0 m
.125 .61803 L
s
.25 0 m
.25 .61803 L
s
.375 0 m
.375 .61803 L
s
.5 0 m
.5 .61803 L
s
.625 0 m
.625 .61803 L
s
.75 0 m
.75 .61803 L
s
.875 0 m
.875 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
s
0 .08829 m
1 .08829 L
s
0 .17658 m
1 .17658 L
s
0 .26487 m
1 .26487 L
s
0 .35316 m
1 .35316 L
s
0 .44145 m
1 .44145 L
s
0 .52974 m
1 .52974 L
s
0 .61803 m
1 .61803 L
s
0 g
.125 .08829 m
.125 .09454 L
s
[(10)] .125 .07579 0 1 Mshowa
.25 .08829 m
.25 .09454 L
s
[(20)] .25 .07579 0 1 Mshowa
.375 .08829 m
.375 .09454 L
s
[(30)] .375 .07579 0 1 Mshowa
.5 .08829 m
.5 .09454 L
s
[(40)] .5 .07579 0 1 Mshowa
.625 .08829 m
.625 .09454 L
s
[(50)] .625 .07579 0 1 Mshowa
.75 .08829 m
.75 .09454 L
s
[(60)] .75 .07579 0 1 Mshowa
.875 .08829 m
.875 .09454 L
s
[(70)] .875 .07579 0 1 Mshowa
1 .08829 m
1 .09454 L
s
[(80)] 1 .07579 0 1 Mshowa
.125 Mabswid
.025 .08829 m
.025 .09204 L
s
.05 .08829 m
.05 .09204 L
s
.075 .08829 m
.075 .09204 L
s
.1 .08829 m
.1 .09204 L
s
.15 .08829 m
.15 .09204 L
s
.175 .08829 m
.175 .09204 L
s
.2 .08829 m
.2 .09204 L
s
.225 .08829 m
.225 .09204 L
s
.275 .08829 m
.275 .09204 L
s
.3 .08829 m
.3 .09204 L
s
.325 .08829 m
.325 .09204 L
s
.35 .08829 m
.35 .09204 L
s
.4 .08829 m
.4 .09204 L
s
.425 .08829 m
.425 .09204 L
s
.45 .08829 m
.45 .09204 L
s
.475 .08829 m
.475 .09204 L
s
.525 .08829 m
.525 .09204 L
s
.55 .08829 m
.55 .09204 L
s
.575 .08829 m
.575 .09204 L
s
.6 .08829 m
.6 .09204 L
s
.65 .08829 m
.65 .09204 L
s
.675 .08829 m
.675 .09204 L
s
.7 .08829 m
.7 .09204 L
s
.725 .08829 m
.725 .09204 L
s
.775 .08829 m
.775 .09204 L
s
.8 .08829 m
.8 .09204 L
s
.825 .08829 m
.825 .09204 L
s
.85 .08829 m
.85 .09204 L
s
.9 .08829 m
.9 .09204 L
s
.925 .08829 m
.925 .09204 L
s
.95 .08829 m
.95 .09204 L
s
.975 .08829 m
.975 .09204 L
s
.25 Mabswid
0 .08829 m
1 .08829 L
s
0 0 m
.00625 0 L
s
[(-10)] -0.0125 0 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(10)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(20)] -0.0125 .26487 1 0 Mshowa
0 .35316 m
.00625 .35316 L
s
[(30)] -0.0125 .35316 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(40)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(50)] -0.0125 .52974 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(60)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01766 m
.00375 .01766 L
s
0 .03532 m
.00375 .03532 L
s
0 .05297 m
.00375 .05297 L
s
0 .07063 m
.00375 .07063 L
s
0 .10595 m
.00375 .10595 L
s
0 .12361 m
.00375 .12361 L
s
0 .14126 m
.00375 .14126 L
s
0 .15892 m
.00375 .15892 L
s
0 .19424 m
.00375 .19424 L
s
0 .2119 m
.00375 .2119 L
s
0 .22956 m
.00375 .22956 L
s
0 .24721 m
.00375 .24721 L
s
0 .28253 m
.00375 .28253 L
s
0 .30019 m
.00375 .30019 L
s
0 .31785 m
.00375 .31785 L
s
0 .3355 m
.00375 .3355 L
s
0 .37082 m
.00375 .37082 L
s
0 .38848 m
.00375 .38848 L
s
0 .40614 m
.00375 .40614 L
s
0 .42379 m
.00375 .42379 L
s
0 .45911 m
.00375 .45911 L
s
0 .47677 m
.00375 .47677 L
s
0 .49443 m
.00375 .49443 L
s
0 .51209 m
.00375 .51209 L
s
0 .5474 m
.00375 .5474 L
s
0 .56506 m
.00375 .56506 L
s
0 .58272 m
.00375 .58272 L
s
0 .60038 m
.00375 .60038 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Path) show
93.000 13.000 moveto
(of) show
111.000 13.000 moveto
(K) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.39535 .07977 m
.39728 .07972 L
.39903 .07969 L
.40091 .07966 L
.40294 .07963 L
.40482 .07961 L
.40656 .0796 L
.40821 .0796 L
.40997 .0796 L
.41185 .0796 L
.41386 .07962 L
.41576 .07964 L
.4175 .07966 L
.42172 .07974 L
.42572 .07985 L
.43347 .08014 L
.4406 .0805 L
.45645 .08164 L
.47234 .08327 L
.48628 .08509 L
.51578 .09023 L
.53975 .09577 L
.56332 .10254 L
.60277 .11727 L
.63274 .13209 L
.65518 .14612 L
.67335 .16035 L
.68625 .17314 L
.69134 .17929 L
.69589 .1857 L
.69911 .1911 L
.70189 .19681 L
.70383 .20198 L
.70462 .20472 L
.7052 .20724 L
.70562 .20961 L
.70577 .21079 L
.7059 .21206 L
.70598 .21314 L
.70601 .21374 L
.70603 .21402 L
.70603 .21428 L
.70604 .21452 L
.70605 .21478 L
.70605 .21505 L
.70605 .21533 L
.70605 .21557 L
.70605 .21583 L
.70605 .21608 L
.70604 .2163 L
Mistroke
.70604 .21659 L
.70603 .21687 L
.70601 .21737 L
.70597 .21791 L
.70593 .2185 L
.70583 .21954 L
.70572 .22049 L
.70535 .22264 L
.70483 .22485 L
.70425 .22679 L
.70351 .22881 L
.70187 .23235 L
.69949 .23628 L
.69676 .23982 L
.69033 .24612 L
.6817 .25222 L
.67161 .2575 L
.66014 .26205 L
.64585 .26633 L
.62976 .2699 L
.62057 .2715 L
.60961 .27308 L
.59889 .27434 L
.58632 .27553 L
.57283 .27653 L
.55913 .27729 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztXc1ymzAQlg00duwkzY+duH/jvkx7ao+9ezKdSQ5t0jTHdPIyPfbSB+y4
0UK0gBcDlpAEbA4Ey9Lu9612pUXI8Gl1f/X12+r++nK1/Hi3ur26vvy5/HBz
91QUDIQYLIUQf5dCnq+fTpMD/L2Xh+RDcj6W/wJZJ5Rnw/Vz5aP4+334F6hi
+WkIxzBdps4P4w9QJZKlQXUBocLy7+nwOK6NICSqvlVlj0bK3hiWt9cnltCl
QyTRJW5UDwaKb9ReYueKxLsWAW6xrRm6C+js4c6gX8gjFOGUFzdM8pe5PId0
Ih5Sn78X0GnnZc1RPtV8Xta8mnzxIjOZpdRUA/mi2D6LLfKVwGyTs8TmVI6W
NCPbncJxRKjKtKWagh1FlFNZrOpkd1UaKGdwrGVLDW1x9muqU3fAHmsOKxs1
H2RFnTevKdeOSxnqKQjYV1BQy9h14c6UsqFq+ZgP2aTXN1LlbU0uck3Keies
JrA6Mxh+gjKpUcrm+tGh0fk1ouQsVyZKOJ5Vsu+M0BRsqb+oDriZ0QscAlx3
G8zZ7rp1h/jSsMp3JBKm68+J+uVdapv7jhPOumqWUlphoUwi8hridAvsUpjL
oV81kwqmsyzO+FsJHXp2IsW9bC+JA3mcSnFhe0lArEdNRFEaMMTuQB7GVWiY
KYsUtRPDki0GNCxJgoojw5ItkoBIgaH6oEESjcwFYHWwzr6GFMf2P1HmGbWX
BF6PRBpSHJNARw00pDgmsVAkcvmbTvA1HsmvU5YxDdhGVqdtFOtp6EbmrpMT
OUSf/KWWlDx1ccq+eP/ywhB0K9bPlkWKxLyiFA9J7BF6T9tLB1OJ/P2AFkXH
mCBxbIiEgz6hNjBQV9g16VA7jFzthpgQenUujdqzeWdK6D3sBXO8ahREmTXm
UPOPlJRKI+Wnz/LYnr1u6DSod0rU22WU8HFnGA4PqHdC1DPgPu53izVE1u60
jHMWktBZf3E8LWNGgXrHRD2m44IOtTqss07WYTrWBgDuE6bTCTrWIuZYaeOJ
0hc6HUtjOkanE5ky3lo1sBTgqicmioSBxSoYufF3a04vxppcjxMF20m9ueyG
jgDzG1jl3mmt5reUBGdf5FmyQhPHeHZ7W9KU3I9HlTVjv41bTsDNwH2bUSll
J14DN9NgN6OBO4OecoRhebrO+JYZyY4X56dKm87M481Eagqwg4GWobcZOns4
Q2fonkLn4GTo3YbOHm4Fuk9baAzQ8fRiqyG2U5qR28UC4yxhiSW1N73iw536
YZx+OXzHRiue6Bg6Q/cZOgcnQ+82dPZwhs7QPYXOwWkFOj7MwP3WDAN0/N1I
YJwqbqqp9eDnEV152/pCO+2T/x2h6CTLaitE7eRG/a5wqPi2eJTiCY6h9wA6
ezhDZ+ieQufgZOjdhs4ebgV6x25M9uuucj92CtRlCUUbiybQvntX2dRDo8Ju
svTkJ2g8wemLZegM3WvoHJwMvdvQ2cMZOkP3FDoHpxXovPgR9o8tkK21PAD/
D9NaswYLy5tRj0WuoA33B6CDwvfJm8jhnHiD+YMiGmbJ4Vuk4CkRe6oevpwc
y8Tzywji96V/jz/8IqgU2LuAYUHtuF/pDqXemF6wF+amGGagqFHyCtDuBgvL
ZL3bFKZgiwmahgXd/yNtILpzcEsKug6IwxETvy0jvKmDCiIKM/V8rO29/qBQ
URGH3E7VWZm7QxkRYmLwHz/KH0o=\
\>"],
 ImageRangeCache->{{{73.5625, 302.938}, {581.375, 440.062}} -> {-36.5113, \
233.305, 0.314991, 0.445958}}]
}, Open  ]],

Cell[TextData[StyleBox["No realistic solution is found ",
 FontSize->16,
 Background->RGBColor[1, 0, 1]]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Now we use the optimisation method", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"xCGi", "=", 
  RowBox[{"{", 
   RowBox[{"62", ",", "39", ",", "30", ",", "14", ",", "57"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"yCGi", " ", "=", 
  RowBox[{"{", 
   RowBox[{"22", ",", "22", ",", "22", ",", "57", ",", "55"}], 
   "}"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"62", ",", "39", ",", "30", ",", "14", ",", "57"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"22", ",", "22", ",", "22", ",", "57", ",", "55"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CurlyPhi]i", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
   "\[CurlyPhi]1", ",", "\[CurlyPhi]2", ",", "\[CurlyPhi]3", ",", 
    "\[CurlyPhi]4", ",", "\[CurlyPhi]5"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "\[CurlyPhi]1", ",", "\[CurlyPhi]2", ",", "\[CurlyPhi]3", ",", 
   "\[CurlyPhi]4", ",", "\[CurlyPhi]5"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"xK", "/.", 
      RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
     RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", 
    RowBox[{"\[CurlyPhi]", "->", 
     RowBox[{"\[CurlyPhi]i", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}]}], "]"}], "-", 
  RowBox[{"xCGi", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "62"}], "+", "A0x", "+", 
  RowBox[{"a", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Gamma]0", "+", "\[CurlyPhi]1"}], "]"}]}], "+", 
  RowBox[{"k", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Gamma]0", "+", "\[Kappa]", "+", 
     RowBox[{"ArcTan", "[", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", 
         RowBox[{"Sin", "[", "\[CurlyPhi]1", "]"}]}], "+", 
        RowBox[{"b", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           RowBox[{"ArcCos", "[", 
            FractionBox[
             RowBox[{
              SuperscriptBox["a", "2"], "+", 
              SuperscriptBox["b", "2"], "-", 
              SuperscriptBox["c", "2"], "+", 
              SuperscriptBox["d", "2"], "-", 
              RowBox[{"2", " ", "a", " ", "d", " ", 
               RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}], 
             RowBox[{"2", " ", "b", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["a", "2"], "+", 
                SuperscriptBox["d", "2"], "-", 
                RowBox[{"2", " ", "a", " ", "d", " ", 
                 RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}]]}]], "]"}], 
           "+", 
           RowBox[{"ArcTan", "[", 
            RowBox[{
             RowBox[{"d", "-", 
              RowBox[{"a", " ", 
               RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}], ",", 
             RowBox[{"a", " ", 
              RowBox[{"Sin", "[", "\[CurlyPhi]1", "]"}]}]}], "]"}]}], 
          "]"}]}]}], 
       RowBox[{"d", "-", 
        RowBox[{"a", " ", 
         RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}], "-", 
        RowBox[{"b", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{
           RowBox[{"ArcCos", "[", 
            FractionBox[
             RowBox[{
              SuperscriptBox["a", "2"], "+", 
              SuperscriptBox["b", "2"], "-", 
              SuperscriptBox["c", "2"], "+", 
              SuperscriptBox["d", "2"], "-", 
              RowBox[{"2", " ", "a", " ", "d", " ", 
               RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}], 
             RowBox[{"2", " ", "b", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["a", "2"], "+", 
                SuperscriptBox["d", "2"], "-", 
                RowBox[{"2", " ", "a", " ", "d", " ", 
                 RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}]]}]], "]"}], 
           "+", 
           RowBox[{"ArcTan", "[", 
            RowBox[{
             RowBox[{"d", "-", 
              RowBox[{"a", " ", 
               RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}], ",", 
             RowBox[{"a", " ", 
              RowBox[{"Sin", "[", "\[CurlyPhi]1", "]"}]}]}], "]"}]}], 
          "]"}]}]}]], "]"}]}], "]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"yK", "/.", 
      RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
     RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", 
    RowBox[{"\[CurlyPhi]", "->", 
     RowBox[{"\[CurlyPhi]i", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}]}], "]"}], "-", 
  RowBox[{"yCGi", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "22"}], "+", "A0y", "+", 
  RowBox[{"a", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"\[Gamma]0", "+", "\[CurlyPhi]1"}], "]"}]}], "+", 
  RowBox[{"k", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"\[Gamma]0", "+", "\[Kappa]", "+", 
     RowBox[{"ArcTan", "[", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", 
         RowBox[{"Sin", "[", "\[CurlyPhi]1", "]"}]}], "+", 
        RowBox[{"b", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           RowBox[{"ArcCos", "[", 
            FractionBox[
             RowBox[{
              SuperscriptBox["a", "2"], "+", 
              SuperscriptBox["b", "2"], "-", 
              SuperscriptBox["c", "2"], "+", 
              SuperscriptBox["d", "2"], "-", 
              RowBox[{"2", " ", "a", " ", "d", " ", 
               RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}], 
             RowBox[{"2", " ", "b", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["a", "2"], "+", 
                SuperscriptBox["d", "2"], "-", 
                RowBox[{"2", " ", "a", " ", "d", " ", 
                 RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}]]}]], "]"}], 
           "+", 
           RowBox[{"ArcTan", "[", 
            RowBox[{
             RowBox[{"d", "-", 
              RowBox[{"a", " ", 
               RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}], ",", 
             RowBox[{"a", " ", 
              RowBox[{"Sin", "[", "\[CurlyPhi]1", "]"}]}]}], "]"}]}], 
          "]"}]}]}], 
       RowBox[{"d", "-", 
        RowBox[{"a", " ", 
         RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}], "-", 
        RowBox[{"b", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{
           RowBox[{"ArcCos", "[", 
            FractionBox[
             RowBox[{
              SuperscriptBox["a", "2"], "+", 
              SuperscriptBox["b", "2"], "-", 
              SuperscriptBox["c", "2"], "+", 
              SuperscriptBox["d", "2"], "-", 
              RowBox[{"2", " ", "a", " ", "d", " ", 
               RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}], 
             RowBox[{"2", " ", "b", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["a", "2"], "+", 
                SuperscriptBox["d", "2"], "-", 
                RowBox[{"2", " ", "a", " ", "d", " ", 
                 RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}]]}]], "]"}], 
           "+", 
           RowBox[{"ArcTan", "[", 
            RowBox[{
             RowBox[{"d", "-", 
              RowBox[{"a", " ", 
               RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}], ",", 
             RowBox[{"a", " ", 
              RowBox[{"Sin", "[", "\[CurlyPhi]1", "]"}]}]}], "]"}]}], 
          "]"}]}]}]], "]"}]}], "]"}]}]}]], "Output"]
}, Open  ]],

Cell["we have 14 parameters:", "Text"],

Cell[CellGroupData[{

Cell[BoxData["par"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "\[Rule]", "26"}], ",", 
   RowBox[{"d", "\[Rule]", "20"}], ",", 
   RowBox[{"\[Kappa]", "\[Rule]", "0"}], ",", 
   RowBox[{"k", "\[Rule]", "32"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["parinit"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A0x", "\[Rule]", "13"}], ",", 
   RowBox[{"A0y", "\[Rule]", "33"}], ",", 
   RowBox[{"\[Gamma]0", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "60"}], " ", "\[Degree]"}]}], ",", 
   RowBox[{"b", "\[Rule]", "29"}], ",", 
   RowBox[{"c", "\[Rule]", "9"}], ",", 
   RowBox[{"\[CurlyPhi]1", "\[Rule]", 
    RowBox[{"79", " ", "\[Degree]"}]}], ",", 
   RowBox[{"\[CurlyPhi]2", "\[Rule]", 
    RowBox[{"106", " ", "\[Degree]"}]}], ",", 
   RowBox[{"\[CurlyPhi]3", "\[Rule]", 
    RowBox[{"110", " ", "\[Degree]"}]}], ",", 
   RowBox[{"\[CurlyPhi]4", "\[Rule]", 
    RowBox[{"80", " ", "\[Degree]"}]}], ",", 
   RowBox[{"\[CurlyPhi]5", "\[Rule]", 
    RowBox[{"50", " ", "\[Degree]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ferror", "=", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Simplify", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"xK", "/.", 
              RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
             RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", 
            RowBox[{"\[CurlyPhi]", "->", 
             RowBox[{"\[CurlyPhi]i", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}]}], "]"}], "-", 
          RowBox[{"xCGi", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ")"}], "^", "2"}], "+", 
       "\[IndentingNewLine]", "                  ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Simplify", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"yK", "/.", 
              RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
             RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", 
            RowBox[{"\[CurlyPhi]", "->", 
             RowBox[{"\[CurlyPhi]i", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}]}], "]"}], "-", 
          RowBox[{"yCGi", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ")"}], "^", "2"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "3"}], "}"}]}], "]"}], "//", "N"}]}], 
  ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"erg2", " ", "=", " ", 
  RowBox[{"NMinimize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"ferror", ",", 
      RowBox[{"10", "\[LessEqual]", "A0x", "\[LessEqual]", "15"}], ",", 
      RowBox[{"30", "\[LessEqual]", "A0y", "\[LessEqual]", "35"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "70"}], " ", "Degree"}], "\[LessEqual]", "\[Gamma]0", 
       "\[LessEqual]", 
       RowBox[{
        RowBox[{"-", "50"}], " ", "Degree"}]}], ",", 
      RowBox[{"25", "\[LessEqual]", "a", "\[LessEqual]", "30"}], ",", 
      RowBox[{"25", "\[LessEqual]", "b", "\[LessEqual]", "35"}], ",", 
      RowBox[{"5", "\[LessEqual]", "c", "\[LessEqual]", "12"}], ",", 
      RowBox[{"18", "\[LessEqual]", "d", "\[LessEqual]", "25"}], ",", 
      RowBox[{"30", "\[LessEqual]", "k", "\[LessEqual]", "50"}], ",", 
      RowBox[{
       RowBox[{"-", "0.1"}], "\[LessEqual]", "\[Kappa]", "\[LessEqual]", 
       "0.1"}], ",", 
      RowBox[{"0", "\[LessEqual]", "\[CurlyPhi]1", "\[LessEqual]", "2"}], ",",
       
      RowBox[{"0", "\[LessEqual]", "\[CurlyPhi]2", "\[LessEqual]", "2"}], ",",
       
      RowBox[{"0", "\[LessEqual]", "\[CurlyPhi]3", "\[LessEqual]", "2"}], ",",
       
      RowBox[{"0", "\[LessEqual]", "\[CurlyPhi]4", "\[LessEqual]", "2"}], ",",
       
      RowBox[{"0", "\[LessEqual]", "\[CurlyPhi]5", "\[LessEqual]", "2"}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "A0x", ",", "A0y", ",", "\[Gamma]0", ",", "a", ",", "b", ",", "c", ",", 
      "d", ",", "k", ",", "\[Kappa]", ",", "\[CurlyPhi]1", ",", 
      "\[CurlyPhi]2", ",", "\[CurlyPhi]3", ",", "\[CurlyPhi]4", ",", 
      "\[CurlyPhi]5"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NMinimize", "::", "\<\"nrnum\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"The function value \\!\\(\\(\\(9388.74646668146`\
\[InvisibleSpace]\\)\\) + \\(\\(15394.529827434802`\\\\ \
\[ImaginaryI]\\)\\)\\) is not a real number at \\!\\({a, A0x, A0y, b, c, d, \
k, \[Gamma]0, \[Kappa], \[CurlyPhi]1, \\(\\(\[LeftSkeleton] 4 \
\[RightSkeleton]\\)\\)}\\) = \\!\\({25.159268184920627`, 13.201041034552215`, \
33.621512576758`, 30.808841755627377`, 11.518060209029588`, \\(\\(\
\[LeftSkeleton] 19 \[RightSkeleton]\\)\\), \\(\\(\[LeftSkeleton] 18 \
\[RightSkeleton]\\)\\), \\(\\(-1.204647256690294`\\)\\), \
0.04046073333134717`, 0.8504681440981766`, \\(\\(\[LeftSkeleton] 4 \
\[RightSkeleton]\\)\\)}\\). \\!\\(\\*ButtonBox[\\\"Mehr\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::nrnum\\\"]\\)\"\>"}]], "Message"]
}, Open  ]],

Cell["\<\
Also this solution fail. reason is that the proposed path is not possible \
with this desired lengths of bars ! \
\>", "Text",
 CellChangeTimes->{{3.469249717879786*^9, 3.469249844129066*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{967, 928},
WindowMargins->{{Automatic, 102}, {29, Automatic}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
Magnification->1,
FrontEndVersion->"6.0 for Mac OS X PowerPC (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 102, 2, 46, "Subtitle"],
Cell[695, 27, 204, 5, 41, "Text"],
Cell[CellGroupData[{
Cell[924, 36, 63, 0, 34, "Subsection"],
Cell[990, 38, 5285, 89, 231, "Graphics",
 Evaluatable->False],
Cell[6278, 129, 132, 3, 27, "Input"],
Cell[CellGroupData[{
Cell[6435, 136, 340, 10, 105, "Input"],
Cell[6778, 148, 831, 24, 59, "Output"],
Cell[7612, 174, 831, 24, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8480, 203, 1126, 36, 73, "Input"],
Cell[9609, 241, 783, 27, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10429, 273, 1032, 34, 73, "Input"],
Cell[11464, 309, 624, 21, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12125, 335, 374, 12, 27, "Input"],
Cell[12502, 349, 303, 10, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12842, 364, 409, 13, 27, "Input"],
Cell[13254, 379, 315, 10, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13606, 394, 230, 6, 27, "Input"],
Cell[13839, 402, 198, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14074, 412, 513, 16, 27, "Input"],
Cell[14590, 430, 424, 13, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15051, 448, 653, 18, 43, "Input"],
Cell[15707, 468, 270, 7, 27, "Output"],
Cell[15980, 477, 270, 7, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[16299, 490, 70, 0, 67, "Section"],
Cell[16372, 492, 277, 6, 27, "Input"],
Cell[CellGroupData[{
Cell[16674, 502, 98, 2, 25, "Subsubsection"],
Cell[CellGroupData[{
Cell[16797, 508, 59, 0, 43, "Input"],
Cell[16859, 510, 270, 7, 27, "Output"],
Cell[17132, 519, 270, 7, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17439, 531, 247, 7, 27, "Input"],
Cell[17689, 540, 223, 6, 27, "Output"]
}, Open  ]],
Cell[17927, 549, 4053, 120, 163, "Input"],
Cell[CellGroupData[{
Cell[22005, 673, 788, 20, 43, "Input"],
Cell[22796, 695, 750, 19, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23583, 719, 1356, 38, 73, "Input"],
Cell[24942, 759, 9044, 545, 163, 7199, 511, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34023, 1309, 1255, 36, 58, "Input"],
Cell[35281, 1347, 551, 10, 62, "Message"],
Cell[35835, 1359, 736, 14, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36608, 1378, 29, 0, 27, "Input"],
Cell[36640, 1380, 223, 6, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36900, 1391, 1357, 38, 73, "Input"],
Cell[38260, 1431, 8986, 540, 186, 6990, 504, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[47261, 1974, 114, 2, 30, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47412, 1981, 56, 0, 34, "Subsection"],
Cell[CellGroupData[{
Cell[47493, 1985, 284, 8, 43, "Input"],
Cell[47780, 1995, 108, 2, 27, "Output"],
Cell[47891, 1999, 108, 2, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48036, 2006, 211, 5, 27, "Input"],
Cell[48250, 2013, 165, 4, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48452, 2022, 404, 12, 27, "Input"],
Cell[48859, 2036, 2795, 73, 105, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[51691, 2114, 404, 12, 27, "Input"],
Cell[52098, 2128, 2795, 73, 105, "Output"]
}, Open  ]],
Cell[54908, 2204, 38, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[54971, 2208, 29, 0, 27, "Input"],
Cell[55003, 2210, 223, 6, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[55263, 2221, 33, 0, 27, "Input"],
Cell[55299, 2223, 750, 19, 27, "Output"]
}, Open  ]],
Cell[56064, 2245, 1393, 39, 58, "Input"],
Cell[CellGroupData[{
Cell[57482, 2288, 1686, 37, 58, "Input"],
Cell[59171, 2327, 891, 15, 34, "Message"]
}, Open  ]],
Cell[60077, 2345, 202, 4, 26, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
