(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    109868,       4370]
NotebookOptionsPosition[    105100,       4210]
NotebookOutlinePosition[    105455,       4226]
CellTagsIndexPosition[    105412,       4223]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
MDA-Chapter 3: Design of Mechanisms - 3.4 Paths of Crank-Rocker Mechanisms\
\>", "Subtitle"],

Cell["\<\
created 2009, Prof. Oskar Wallrapp, FK06, Munich University of Applied \
Sciences
updated 17.11.2009 - Animation\
\>", "Text",
 CellChangeTimes->{{3.4674673047927027`*^9, 3.467467366088581*^9}}],

Cell[CellGroupData[{

Cell["crank-rocker mechanismus: Basic functions", "Subsection"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
 Evaluatable->False,
 ImageSize->{263, 223},
 ImageMargins->{{110, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Clear[par,\[CurlyPhi],\[Psi],\[Psi]1,\[Psi]2,\[CurlyPhi]0,\[Psi]0,a,b,c,d];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
X = d - a Cos[\[CurlyPhi]];
Y = a Sin[\[CurlyPhi]];
\[Sigma] = ArcTan[X,Y];
\[CapitalDelta] = Sqrt[X^2 + Y^2];
\[Lambda] = Simplify[ArcCos[(\[CapitalDelta]^2 + b^2 - c^2) / (2 b \
\[CapitalDelta])] ];
f\[Psi] = \[Pi] - (\[Sigma] + \[Lambda])
f\[Psi]2 = \[Pi] - (\[Sigma] - \[Lambda])\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{"\[Pi]", "-", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["b", "2"], "-", 
     SuperscriptBox["c", "2"], "+", 
     SuperscriptBox["d", "2"], "-", 
     RowBox[{"2", " ", "a", " ", "d", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}], 
    RowBox[{"2", " ", "b", " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["d", "2"], "-", 
       RowBox[{"2", " ", "a", " ", "d", " ", 
        RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}]]}]], "]"}], "-", 
  RowBox[{"ArcTan", "[", 
   RowBox[{
    RowBox[{"d", "-", 
     RowBox[{"a", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}], ",", 
    RowBox[{"a", " ", 
     RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}]}], "]"}]}]], "Output"],

Cell[BoxData[
 RowBox[{"\[Pi]", "+", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["b", "2"], "-", 
     SuperscriptBox["c", "2"], "+", 
     SuperscriptBox["d", "2"], "-", 
     RowBox[{"2", " ", "a", " ", "d", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}], 
    RowBox[{"2", " ", "b", " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["d", "2"], "-", 
       RowBox[{"2", " ", "a", " ", "d", " ", 
        RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}]]}]], "]"}], "-", 
  RowBox[{"ArcTan", "[", 
   RowBox[{
    RowBox[{"d", "-", 
     RowBox[{"a", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}], ",", 
    RowBox[{"a", " ", 
     RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}]}], "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[CurlyPhi]i", "=", 
   RowBox[{"Pi", "+", 
    RowBox[{"ArcCos", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"d", "^", "2"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"c", "-", "a"}], ")"}], "^", "2"}], "-", 
        RowBox[{"b", "^", "2"}]}], ")"}], " ", "/", " ", 
      RowBox[{"(", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"c", "-", "a"}], ")"}], " ", "d"}], ")"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CurlyPhi]a", "=", 
   RowBox[{"ArcCos", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"d", "^", "2"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"c", "+", "a"}], ")"}], "^", "2"}], "-", 
       RowBox[{"b", "^", "2"}]}], ")"}], " ", "/", " ", 
     RowBox[{"(", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"c", "+", "a"}], ")"}], " ", "d"}], ")"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"f\[CurlyPhi]0", "=", 
  RowBox[{
  "\[CurlyPhi]i", "-", "\[CurlyPhi]a"}]}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{"\[Pi]", "+", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["b", "2"]}], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "c"}], ")"}], "2"], "+", 
     SuperscriptBox["d", "2"]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "+", "c"}], ")"}], " ", "d"}]], "]"}], "-", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["b", "2"]}], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], "2"], "+", 
     SuperscriptBox["d", "2"]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"a", "+", "c"}], ")"}], " ", "d"}]], "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Psi]i", "=", 
   RowBox[{"Pi", "-", 
    RowBox[{"ArcCos", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"d", "^", "2"}], "+", 
        RowBox[{"b", "^", "2"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"c", "-", "a"}], ")"}], "^", "2"}]}], ")"}], " ", "/", " ", 
      
      RowBox[{"(", 
       RowBox[{"2", " ", "b", " ", "d"}], ")"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Psi]a", "=", 
   RowBox[{"Pi", "-", 
    RowBox[{"ArcCos", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"d", "^", "2"}], "+", 
        RowBox[{"b", "^", "2"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"c", "+", "a"}], ")"}], "^", "2"}]}], ")"}], " ", "/", " ", 
      
      RowBox[{"(", 
       RowBox[{"2", " ", "b", " ", "d"}], ")"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"f\[Psi]0", "=", 
  RowBox[{"\[Psi]i", "-", "\[Psi]a"}]}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"ArcCos", "[", 
    FractionBox[
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "c"}], ")"}], "2"], "+", 
      SuperscriptBox["d", "2"]}], 
     RowBox[{"2", " ", "b", " ", "d"}]], "]"}]}], "+", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{
     SuperscriptBox["b", "2"], "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], "2"], "+", 
     SuperscriptBox["d", "2"]}], 
    RowBox[{"2", " ", "b", " ", "d"}]], "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Mu]min1", "=", 
  RowBox[{"ArcCos", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "^", "2"}], "+", 
      RowBox[{"b", "^", "2"}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"d", "-", "a"}], ")"}], "^", "2"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", "b", " ", "c"}], ")"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"ArcCos", "[", 
  FractionBox[
   RowBox[{
    SuperscriptBox["b", "2"], "+", 
    SuperscriptBox["c", "2"], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "+", "d"}], ")"}], "2"]}], 
   RowBox[{"2", " ", "b", " ", "c"}]], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Mu]min2", "=", 
  RowBox[{"Pi", "-", 
   RowBox[{"ArcCos", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"c", "^", "2"}], "+", 
       RowBox[{"b", "^", "2"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"d", "+", "a"}], ")"}], "^", "2"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"2", " ", "b", " ", "c"}], ")"}]}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"\[Pi]", "-", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{
     SuperscriptBox["b", "2"], "+", 
     SuperscriptBox["c", "2"], "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "+", "d"}], ")"}], "2"]}], 
    RowBox[{"2", " ", "b", " ", "c"}]], "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grashof", "=", 
  RowBox[{
   RowBox[{"Min", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}], "+", 
   RowBox[{"Max", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Max", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}], "+", 
  RowBox[{"Min", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f\[Delta]", "=", 
  RowBox[{"ArcTan", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"d", "+", 
      RowBox[{"b", " ", 
       RowBox[{"Cos", "[", "\[Psi]", "]"}]}], "-", 
      RowBox[{"a", " ", 
       RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}], ")"}], ",", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", " ", 
       RowBox[{"Sin", "[", "\[Psi]", "]"}]}], "-", 
      RowBox[{"a", " ", 
       RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}]}], " ", ")"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"ArcTan", "[", 
  RowBox[{
   RowBox[{"d", "-", 
    RowBox[{"a", " ", 
     RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}], "+", 
    RowBox[{"b", " ", 
     RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "a"}], " ", 
     RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}], "+", 
    RowBox[{"b", " ", 
     RowBox[{"Sin", "[", "\[Psi]", "]"}]}]}]}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"xK", " ", "=", " ", 
  RowBox[{"A0x", " ", "+", " ", 
   RowBox[{"a", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"\[CurlyPhi]", "+", "\[Gamma]0"}], "]"}]}], "+", 
   RowBox[{"k", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "+", "\[Delta]", "+", "\[Gamma]0"}], 
     "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"yK", " ", "=", " ", 
  RowBox[{"A0y", " ", "+", " ", 
   RowBox[{"a", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"\[CurlyPhi]", "+", "\[Gamma]0"}], "]"}]}], "+", 
   RowBox[{"k", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"\[Kappa]", "+", "\[Delta]", "+", "\[Gamma]0"}], 
     "]"}]}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"A0x", "+", 
  RowBox[{"k", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Gamma]0", "+", "\[Delta]", "+", "\[Kappa]"}], "]"}]}], "+", 
  RowBox[{"a", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Gamma]0", "+", "\[CurlyPhi]"}], "]"}]}]}]], "Output"],

Cell[BoxData[
 RowBox[{"A0y", "+", 
  RowBox[{"k", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"\[Gamma]0", "+", "\[Delta]", "+", "\[Kappa]"}], "]"}]}], "+", 
  RowBox[{"a", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"\[Gamma]0", "+", "\[CurlyPhi]"}], "]"}]}]}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.4.1\tFind mechanism for path of a coupler point K", "Section",
 CellChangeTimes->{3.4674628228694677`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "par", ",", "\[CurlyPhi]", ",", "\[Psi]", ",", "\[Psi]1", ",", "\[Psi]2", 
    ",", "\[CurlyPhi]0", ",", "\[Psi]0", ",", "a", ",", "b", ",", "c", ",", 
    "d", ",", "k", ",", "\[Kappa]"}], "]"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell["Initialisation model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{"xK", "\[IndentingNewLine]", "yK"}], "Input"],

Cell[BoxData[
 RowBox[{"A0x", "+", 
  RowBox[{"k", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Gamma]0", "+", "\[Delta]", "+", "\[Kappa]"}], "]"}]}], "+", 
  RowBox[{"a", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Gamma]0", "+", "\[CurlyPhi]"}], "]"}]}]}]], "Output"],

Cell[BoxData[
 RowBox[{"A0y", "+", 
  RowBox[{"k", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"\[Gamma]0", "+", "\[Delta]", "+", "\[Kappa]"}], "]"}]}], "+", 
  RowBox[{"a", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"\[Gamma]0", "+", "\[CurlyPhi]"}], "]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"parinit", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"A0x", "\[Rule]", "0"}], ",", 
    RowBox[{"A0y", "\[Rule]", "0"}], ",", 
    RowBox[{"\[Gamma]0", "\[Rule]", 
     RowBox[{"0", " ", "Degree"}]}], ",", 
    RowBox[{"a", "\[Rule]", "30"}], ",", 
    RowBox[{"b", "\[Rule]", "50"}], ",", 
    RowBox[{"c", "\[Rule]", "50"}], ",", 
    RowBox[{"d", "\[Rule]", "60"}], ",", 
    RowBox[{"\[Kappa]", "\[Rule]", 
     RowBox[{"0", " ", "Degree"}]}], ",", 
    RowBox[{"k", "\[Rule]", "100"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A0x", "\[Rule]", "0"}], ",", 
   RowBox[{"A0y", "\[Rule]", "0"}], ",", 
   RowBox[{"\[Gamma]0", "\[Rule]", "0"}], ",", 
   RowBox[{"a", "\[Rule]", "30"}], ",", 
   RowBox[{"b", "\[Rule]", "50"}], ",", 
   RowBox[{"c", "\[Rule]", "50"}], ",", 
   RowBox[{"d", "\[Rule]", "60"}], ",", 
   RowBox[{"\[Kappa]", "\[Rule]", "0"}], ",", 
   RowBox[{"k", "\[Rule]", "100"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xKpar", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"xK", "/.", "\[InvisibleSpace]", 
      RowBox[{"\[Delta]", "\[Rule]", "f\[Delta]"}]}], "/.", 
     "\[InvisibleSpace]", 
     RowBox[{"\[Psi]", "\[Rule]", "f\[Psi]"}]}], "/.", "\[InvisibleSpace]", 
    "parinit"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"yKpar", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"yK", "/.", "\[InvisibleSpace]", 
      RowBox[{"\[Delta]", "\[Rule]", "f\[Delta]"}]}], "/.", 
     "\[InvisibleSpace]", 
     RowBox[{"\[Psi]", "\[Rule]", "f\[Psi]"}]}], "/.", "\[InvisibleSpace]", 
    "parinit"}]}], ";"}], "\n", 
 RowBox[{"plo1", "=", 
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"xKpar", ",", "yKpar"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[CurlyPhi]", ",", "0", ",", 
      RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "120"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", "100"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<Path of K - init param\>\""}]}], 
   "]"}]}]}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .66667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00833333 -0.166667 0.00833333 [
[.16667 -0.0125 -6 -9 ]
[.16667 -0.0125 6 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -9 -9 ]
[.83333 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[-0.0125 .08333 -12 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .16667 -12 -4.5 ]
[-0.0125 .16667 0 4.5 ]
[-0.0125 .25 -12 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .33333 -12 -4.5 ]
[-0.0125 .33333 0 4.5 ]
[-0.0125 .41667 -12 -4.5 ]
[-0.0125 .41667 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .58333 -12 -4.5 ]
[-0.0125 .58333 0 4.5 ]
[-0.0125 .66667 -18 -4.5 ]
[-0.0125 .66667 0 4.5 ]
[.5 .67917 -68.0625 0 ]
[.5 .67917 68.0625 12 ]
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .66667 L
s
.16667 0 m
.16667 .66667 L
s
.33333 0 m
.33333 .66667 L
s
.5 0 m
.5 .66667 L
s
.66667 0 m
.66667 .66667 L
s
.83333 0 m
.83333 .66667 L
s
1 0 m
1 .66667 L
s
0 0 m
1 0 L
s
0 .08333 m
1 .08333 L
s
0 .16667 m
1 .16667 L
s
0 .25 m
1 .25 L
s
0 .33333 m
1 .33333 L
s
0 .41667 m
1 .41667 L
s
0 .5 m
1 .5 L
s
0 .58333 m
1 .58333 L
s
0 .66667 m
1 .66667 L
s
0 g
.16667 0 m
.16667 .00625 L
s
[(20)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(40)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(60)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(80)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(100)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(120)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08333 m
.00625 .08333 L
s
[(30)] -0.0125 .08333 1 0 Mshowa
0 .16667 m
.00625 .16667 L
s
[(40)] -0.0125 .16667 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(50)] -0.0125 .25 1 0 Mshowa
0 .33333 m
.00625 .33333 L
s
[(60)] -0.0125 .33333 1 0 Mshowa
0 .41667 m
.00625 .41667 L
s
[(70)] -0.0125 .41667 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(80)] -0.0125 .5 1 0 Mshowa
0 .58333 m
.00625 .58333 L
s
[(90)] -0.0125 .58333 1 0 Mshowa
0 .66667 m
.00625 .66667 L
s
[(100)] -0.0125 .66667 1 0 Mshowa
.125 Mabswid
0 .01667 m
.00375 .01667 L
s
0 .03333 m
.00375 .03333 L
s
0 .05 m
.00375 .05 L
s
0 .06667 m
.00375 .06667 L
s
0 .1 m
.00375 .1 L
s
0 .11667 m
.00375 .11667 L
s
0 .13333 m
.00375 .13333 L
s
0 .15 m
.00375 .15 L
s
0 .18333 m
.00375 .18333 L
s
0 .2 m
.00375 .2 L
s
0 .21667 m
.00375 .21667 L
s
0 .23333 m
.00375 .23333 L
s
0 .26667 m
.00375 .26667 L
s
0 .28333 m
.00375 .28333 L
s
0 .3 m
.00375 .3 L
s
0 .31667 m
.00375 .31667 L
s
0 .35 m
.00375 .35 L
s
0 .36667 m
.00375 .36667 L
s
0 .38333 m
.00375 .38333 L
s
0 .4 m
.00375 .4 L
s
0 .43333 m
.00375 .43333 L
s
0 .45 m
.00375 .45 L
s
0 .46667 m
.00375 .46667 L
s
0 .48333 m
.00375 .48333 L
s
0 .51667 m
.00375 .51667 L
s
0 .53333 m
.00375 .53333 L
s
0 .55 m
.00375 .55 L
s
0 .56667 m
.00375 .56667 L
s
0 .6 m
.00375 .6 L
s
0 .61667 m
.00375 .61667 L
s
0 .63333 m
.00375 .63333 L
s
0 .65 m
.00375 .65 L
s
.25 Mabswid
0 0 m
0 .66667 L
s
gsave
.5 .67917 -129.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Path) show
93.000 13.000 moveto
(of) show
111.000 13.000 moveto
(K) show
123.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(init) show
165.000 13.000 moveto
(param) show
195.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
.5 Mabswid
.5 .62828 m
.50617 .62825 L
.51177 .62818 L
.51824 .62803 L
.52434 .62784 L
.53517 .62735 L
.54687 .62662 L
.55966 .62559 L
.57309 .62423 L
.59676 .62115 L
.62048 .61716 L
.64193 .61274 L
.68741 .60063 L
.72832 .58616 L
.76052 .57186 L
.79176 .55475 L
.81488 .53912 L
.83196 .52491 L
.84374 .51272 L
.85312 .50004 L
.85676 .49346 L
.85928 .48752 L
.86086 .48238 L
.86147 .47955 L
.86169 .4783 L
.86188 .47695 L
.86196 .47623 L
.86203 .47556 L
.86212 .47426 L
.86218 .47309 L
.8622 .47185 L
.86218 .47054 L
.86212 .46932 L
.86207 .46863 L
.86202 .468 L
.86186 .46658 L
.86152 .46444 L
.8611 .46248 L
.85981 .45811 L
.85811 .45398 L
.85585 .44968 L
.84975 .44101 L
.8413 .43197 L
.82197 .41609 L
.77192 .38331 L
.71711 .34833 L
.66418 .311 L
.61213 .26963 L
.5688 .23311 L
.54951 .21792 L
Mistroke
.53999 .21127 L
.53029 .20541 L
.52118 .20105 L
.51697 .19949 L
.51315 .19834 L
.50932 .19747 L
.50732 .19713 L
.50631 .19699 L
.50522 .19686 L
.50426 .19676 L
.50339 .19669 L
.50251 .19664 L
.50168 .1966 L
.50071 .19658 L
.49982 .19658 L
.49884 .19659 L
.49781 .19662 L
.49689 .19667 L
.49589 .19675 L
.49388 .19696 L
.49201 .19723 L
.49027 .19755 L
.48632 .19848 L
.48206 .19982 L
.4741 .20316 L
.46667 .20713 L
.42884 .23506 L
.38546 .27164 L
.33224 .31367 L
.27696 .35225 L
.22445 .38558 L
.19754 .40268 L
.17571 .41781 L
.16619 .42531 L
.15704 .43358 L
.14981 .44155 L
.14437 .44932 L
.14223 .45327 L
.14036 .45765 L
.13955 .46006 L
.13886 .46266 L
.1384 .46491 L
.1382 .4662 L
.13804 .46741 L
.13792 .46869 L
.13787 .46942 L
.13784 .4701 L
.1378 .47135 L
.1378 .47199 L
.13781 .47269 L
Mistroke
.13786 .47391 L
.13795 .47524 L
.13807 .4765 L
.13822 .47767 L
.13871 .48049 L
.13947 .48363 L
.14149 .48953 L
.14439 .49571 L
.14798 .50176 L
.1571 .51369 L
.17078 .52741 L
.1906 .54313 L
.2421 .57313 L
.27601 .58787 L
.31935 .60268 L
.36073 .61333 L
.40157 .6209 L
.42515 .62404 L
.43782 .62536 L
.4514 .6265 L
.46333 .62727 L
.47015 .62761 L
.47656 .62787 L
.48244 .62805 L
.48783 .62817 L
.49376 .62825 L
.5 .62828 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{155.562, 103.688},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztXM1u1DAQTjfJ7rZld0t/hIQEaitRuJQjjwBcOPAIpSDaAwKVIo498hB9
2GXtZG3H+40zjp1NtmolmnQ8Hs+Mx54fO3y6uL369uPi9vry4vjDzcWvq+vL
38fvf94sQOlWkiT3i3/fjxPxPl+8lr/u54ufJHklHrkApeJtIN52xVtKwTIn
bARg+i1XrQMw7qhg6Uw+MgGZL3+WPVbBkokkr4DLprJLaraVg7jwV4bY9u8y
AiMTqAQ4D6YwLJ6v+YTG4pk7SDbQRG+Ul/Kplpp7U8t6ldoQU0sdiskcCDvi
mToQ2tFT5il1gV9sJE1MQ1NLapQFB+6TweFBCZHi6lIay6DOmuCSiKHBoRqe
mBWin3YNacNBS39huZwnQNpBtdVyTciZjSmdWX2H1GjIOS4ccuXxTDz+iuaJ
AYDWGBuGtZ2tbfyuYN3JXUQrcIqfKtidgu0BGMIL6fvI0iNLD58lHUxZeUm/
2GzgelFc27EUE8wpEmBezsUfQad0gLsKSgQomyYyns+Dbjl+GKa2Ieu6hzti
D1lChaceTmaRXLhWTn8XvKu608Plve3iFINX3Imd+SYb5Vg20Rm6s+8eruiQ
vXAqfo9EV9S6RkZ0VUNbimpVbdNumdwFfVOAh6x6F+B1HC6gqloG8NAYOwCv
3zGcrIcZlaxqa65aI0jWYjyNqr1IHi5e+8nRuaAj347EW8mToC3+emv4utpD
hZDp5xoxKtbnAK+RsaO1FlVK7agmoFXX2WNJZB2C+u1Gub3Hy5UwA/ikT16n
L6i6JMJlTpRk9hq/S/bb5E7DhBIR3lRJYZrb3Rq4KnEh3syi10BRIX5xpnqQ
O7Bs9WSpRd82tfCEwhDvZt9ix8UW240U2JHc0YKsrD60T9TJUutc5FyfAD+l
vdip7bHi7uooxkRbHTeZsG7BeK4qGOw2lm1b8YL8D1cidO4/ZvZdyUv9d4yR
6oHiKa4Q6NSVS89zJw4ZilSARW/I7OvJup4dFKpxGUYn4VwD9GTYOqZvyLD/
OjHtGq3ZGgvHkRjKtrki2JWfIBG8fU1jZ0G6KilKMeKyEcYE7CorTpYOgev5
CGAHhhOKUdFdRmhxylYcD9ckSd5XeuKGYyGRadwgKCTODYn6PbO1wCQhMHty
7LatMWZv4MRu4WAtRs4XI0veHBa5GVvP2I60FfRijTWVpVwgqy7pM4DNDDdV
eyOYVBXyvVzFdKssSxrTQ8YTRHsyjg/osxSsuMGr2iNbQ5gz3TYj7qPzBG1u
5UytOyTlsFb+kAVkLn90SIprVZ5ZFrLKkARR18UzZg/TFnWi5lVHiJPb0hUo
thAxb4Toq/TcikycEkvz46kXgo58e6feXtpuK6OoEFskaWQGoWaq0TfzPct5
bVekJRq3Dk0e5nd5XJyZLM6JgGCmZF3jIQUKWJbUyHM+47JUfdrT0oUJKeBz
aiFv/p2/HrIkVY7srK/Xl8K/Fe3hJbJIQq1cBwyn+y8yIdu2uN2/iKcc/5Tm
CH2v9hXgnRQk9hRNiZ5V9SgZGarNKFWwvApTIXXhq/YVSsGi6SHkn6PqMNuK
UKqYKPgxe2oGi5hJiWM8ixDKMDNmRZw7Ba6vydGaGmMyR778sVCLwYY2uCqS
61u42sqy8XSpWvKcUtw7v272VW1a4UmfWKMg31vDVRhxN1mHl6SwqY8uDWQW
qzHVKVcj/T1qoOpqLBMnG871ybBM3FOT1jteSm1FyNIOAd6A6mvtqvrN2jcH
bhQ1TaRs5AfMFgzVj4it6gygnhdte0o2crXpa0LW/xZiSX4ICNBLGHJT/co6
2foPMkqBCQ==\
\>"],
 ImageRangeCache->{{{0, 154.562}, {102.688, 0}} -> {-23.8403, 9.35489, \
1.01608, 1.01608}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[CurlyPhi]", "=", 
   RowBox[{"phiG", "*", "Degree"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"xKpar", ",", "yKpar"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"phiG", ",", "0", ",", "360"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "360"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "120"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<Path of K - init param\>\""}]}], 
   "]"}], ";", 
  RowBox[{"Clear", "[", "\[CurlyPhi]", "]"}], ";"}]}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.89806e-17 0.00277778 0 0.00277778 [
[.13889 -0.0125 -6 -9 ]
[.13889 -0.0125 6 0 ]
[.27778 -0.0125 -9 -9 ]
[.27778 -0.0125 9 0 ]
[.41667 -0.0125 -9 -9 ]
[.41667 -0.0125 9 0 ]
[.55556 -0.0125 -9 -9 ]
[.55556 -0.0125 9 0 ]
[.69444 -0.0125 -9 -9 ]
[.69444 -0.0125 9 0 ]
[.83333 -0.0125 -9 -9 ]
[.83333 -0.0125 9 0 ]
[.97222 -0.0125 -9 -9 ]
[.97222 -0.0125 9 0 ]
[-0.0125 .05556 -12 -4.5 ]
[-0.0125 .05556 0 4.5 ]
[-0.0125 .11111 -12 -4.5 ]
[-0.0125 .11111 0 4.5 ]
[-0.0125 .16667 -12 -4.5 ]
[-0.0125 .16667 0 4.5 ]
[-0.0125 .22222 -12 -4.5 ]
[-0.0125 .22222 0 4.5 ]
[-0.0125 .27778 -18 -4.5 ]
[-0.0125 .27778 0 4.5 ]
[-0.0125 .33333 -18 -4.5 ]
[-0.0125 .33333 0 4.5 ]
[.5 .34583 -68.0625 0 ]
[.5 .34583 68.0625 12 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .33333 L
s
.13889 0 m
.13889 .33333 L
s
.27778 0 m
.27778 .33333 L
s
.41667 0 m
.41667 .33333 L
s
.55556 0 m
.55556 .33333 L
s
.69444 0 m
.69444 .33333 L
s
.83333 0 m
.83333 .33333 L
s
.97222 0 m
.97222 .33333 L
s
0 0 m
1 0 L
s
0 .05556 m
1 .05556 L
s
0 .11111 m
1 .11111 L
s
0 .16667 m
1 .16667 L
s
0 .22222 m
1 .22222 L
s
0 .27778 m
1 .27778 L
s
0 .33333 m
1 .33333 L
s
0 g
.13889 0 m
.13889 .00625 L
s
[(50)] .13889 -0.0125 0 1 Mshowa
.27778 0 m
.27778 .00625 L
s
[(100)] .27778 -0.0125 0 1 Mshowa
.41667 0 m
.41667 .00625 L
s
[(150)] .41667 -0.0125 0 1 Mshowa
.55556 0 m
.55556 .00625 L
s
[(200)] .55556 -0.0125 0 1 Mshowa
.69444 0 m
.69444 .00625 L
s
[(250)] .69444 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(300)] .83333 -0.0125 0 1 Mshowa
.97222 0 m
.97222 .00625 L
s
[(350)] .97222 -0.0125 0 1 Mshowa
.125 Mabswid
.02778 0 m
.02778 .00375 L
s
.05556 0 m
.05556 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.11111 0 m
.11111 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.19444 0 m
.19444 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.25 0 m
.25 .00375 L
s
.30556 0 m
.30556 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.36111 0 m
.36111 .00375 L
s
.38889 0 m
.38889 .00375 L
s
.44444 0 m
.44444 .00375 L
s
.47222 0 m
.47222 .00375 L
s
.5 0 m
.5 .00375 L
s
.52778 0 m
.52778 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.61111 0 m
.61111 .00375 L
s
.63889 0 m
.63889 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75 0 m
.75 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.80556 0 m
.80556 .00375 L
s
.86111 0 m
.86111 .00375 L
s
.88889 0 m
.88889 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .05556 m
.00625 .05556 L
s
[(20)] -0.0125 .05556 1 0 Mshowa
0 .11111 m
.00625 .11111 L
s
[(40)] -0.0125 .11111 1 0 Mshowa
0 .16667 m
.00625 .16667 L
s
[(60)] -0.0125 .16667 1 0 Mshowa
0 .22222 m
.00625 .22222 L
s
[(80)] -0.0125 .22222 1 0 Mshowa
0 .27778 m
.00625 .27778 L
s
[(100)] -0.0125 .27778 1 0 Mshowa
0 .33333 m
.00625 .33333 L
s
[(120)] -0.0125 .33333 1 0 Mshowa
.125 Mabswid
0 .01389 m
.00375 .01389 L
s
0 .02778 m
.00375 .02778 L
s
0 .04167 m
.00375 .04167 L
s
0 .06944 m
.00375 .06944 L
s
0 .08333 m
.00375 .08333 L
s
0 .09722 m
.00375 .09722 L
s
0 .125 m
.00375 .125 L
s
0 .13889 m
.00375 .13889 L
s
0 .15278 m
.00375 .15278 L
s
0 .18056 m
.00375 .18056 L
s
0 .19444 m
.00375 .19444 L
s
0 .20833 m
.00375 .20833 L
s
0 .23611 m
.00375 .23611 L
s
0 .25 m
.00375 .25 L
s
0 .26389 m
.00375 .26389 L
s
0 .29167 m
.00375 .29167 L
s
0 .30556 m
.00375 .30556 L
s
0 .31944 m
.00375 .31944 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
gsave
.5 .34583 -129.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Path) show
93.000 13.000 moveto
(of) show
111.000 13.000 moveto
(K) show
123.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(init) show
165.000 13.000 moveto
(param) show
195.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
.5 Mabswid
0 .16667 m
.01975 .19892 L
.04057 .22914 L
.06168 .25331 L
.07365 .26383 L
.08481 .27163 L
.09583 .27759 L
.10625 .28177 L
.1156 .28445 L
.12088 .28555 L
.12575 .28633 L
.13064 .28689 L
.13339 .28711 L
.13469 .28719 L
.1359 .28725 L
.13713 .28731 L
.13823 .28734 L
.13947 .28737 L
.14078 .28739 L
.14192 .2874 L
.14317 .28739 L
.14434 .28738 L
.14541 .28736 L
.14667 .28732 L
.14801 .28727 L
.15043 .28714 L
.15332 .28694 L
.15594 .28671 L
.16166 .28606 L
.16707 .28527 L
.17721 .28337 L
.18797 .28081 L
.20732 .27507 L
.24695 .26007 L
.28917 .24161 L
.32979 .22351 L
.37299 .20561 L
.41459 .19065 L
.45461 .17856 L
.49719 .16738 L
.53819 .15675 L
.58176 .14388 L
.62375 .12899 L
.66413 .11245 L
.7071 .0934 L
.74847 .07518 L
.78825 .05975 L
.80867 .05342 L
.82006 .05057 L
.83061 .04845 L
Mistroke
.83619 .04757 L
.84125 .04692 L
.84687 .04638 L
.84835 .04627 L
.84995 .04617 L
.85145 .04609 L
.85284 .04603 L
.85408 .04599 L
.8554 .04596 L
.85615 .04595 L
.85686 .04594 L
.8582 .04593 L
.85888 .04594 L
.8596 .04594 L
.8609 .04597 L
.86163 .04599 L
.8623 .04601 L
.86384 .04607 L
.86639 .04621 L
.86871 .04639 L
.87127 .04664 L
.87395 .04696 L
.87922 .0478 L
.884 .04879 L
.89472 .0519 L
.90466 .05597 L
.91402 .06099 L
.92426 .0679 L
.93508 .07695 L
.95446 .09787 L
.9943 .15719 L
1 .16667 L
Mfstroke
0 .26498 m
.00123 .26497 L
.00236 .26495 L
.00365 .2649 L
.00488 .26483 L
.00706 .26467 L
.00942 .26443 L
.01203 .26409 L
.01479 .26363 L
.01975 .26261 L
.02966 .2598 L
.04057 .25577 L
.08481 .23526 L
.12711 .21785 L
.16782 .20522 L
.21111 .19412 L
.2528 .18352 L
.2929 .17226 L
.33558 .15893 L
.37667 .14555 L
.39764 .13901 L
.42033 .13259 L
.44038 .1278 L
.45177 .12556 L
.4624 .12384 L
.4725 .12257 L
.47817 .12203 L
.48333 .12163 L
.48597 .12147 L
.48877 .12133 L
.49024 .12127 L
.49185 .12121 L
.49333 .12117 L
.49469 .12114 L
.49599 .12111 L
.49736 .12109 L
.49874 .12108 L
.49952 .12108 L
.50024 .12108 L
.50156 .12109 L
.50276 .1211 L
.50414 .12111 L
.50545 .12114 L
.50796 .12121 L
.51031 .12129 L
.51566 .12157 L
.52087 .12194 L
.52647 .12246 L
.53659 .1237 L
.54584 .12514 L
Mistroke
.56582 .12917 L
.58759 .13473 L
.63032 .1478 L
.67146 .1612 L
.71518 .17463 L
.7573 .18616 L
.79784 .19634 L
.84095 .20768 L
.88246 .22137 L
.92239 .23864 L
.94463 .24925 L
.95434 .25363 L
.96489 .25789 L
.97427 .26102 L
.97839 .26215 L
.98293 .2632 L
.9872 .26397 L
.99121 .2645 L
.99342 .26471 L
.99544 .26485 L
.99651 .26491 L
.99766 .26495 L
.99888 .26498 L
1 .26498 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{532, 177.125},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 531}, {176.125, 0}} -> {-50.5209, -11.9849, 0.831587, \
0.831587}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CurlyPhi]init", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[CurlyPhi]1", "\[Rule]", 
     RowBox[{"0", " ", "Degree"}]}], ",", 
    RowBox[{"\[CurlyPhi]2", "\[Rule]", 
     RowBox[{"90", " ", "Degree"}]}], ",", 
    RowBox[{"\[CurlyPhi]3", "\[Rule]", 
     RowBox[{"150", " ", "Degree"}]}], ",", 
    RowBox[{"\[CurlyPhi]4", "\[Rule]", 
     RowBox[{"210", " ", "Degree"}]}], ",", 
    RowBox[{"\[CurlyPhi]5", "\[Rule]", 
     RowBox[{"270", " ", "Degree"}]}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[CurlyPhi]1", "\[Rule]", "0"}], ",", 
   RowBox[{"\[CurlyPhi]2", "\[Rule]", 
    RowBox[{"90", " ", "\[Degree]"}]}], ",", 
   RowBox[{"\[CurlyPhi]3", "\[Rule]", 
    RowBox[{"150", " ", "\[Degree]"}]}], ",", 
   RowBox[{"\[CurlyPhi]4", "\[Rule]", 
    RowBox[{"210", " ", "\[Degree]"}]}], ",", 
   RowBox[{"\[CurlyPhi]5", "\[Rule]", 
    RowBox[{"270", " ", "\[Degree]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"\[CurlyPhi]initpar", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"0", " ", "\[Degree]"}], ",", 
    RowBox[{"90", " ", "\[Degree]"}], ",", 
    RowBox[{"160", " ", "\[Degree]"}], ",", 
    RowBox[{"250", " ", "\[Degree]"}], ",", 
    RowBox[{"300", " ", "\[Degree]"}]}], "}"}]}], "\n", 
 RowBox[{"xyKtab", "=", 
  RowBox[{"N", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"xKpar", "/.", "\[InvisibleSpace]", 
        RowBox[{"\[CurlyPhi]", "\[Rule]", 
         RowBox[{
         "\[CurlyPhi]initpar", "\[LeftDoubleBracket]", "i", 
          "\[RightDoubleBracket]"}]}]}], ",", 
       RowBox[{"yKpar", "/.", "\[InvisibleSpace]", 
        RowBox[{"\[CurlyPhi]", "\[Rule]", 
         RowBox[{
         "\[CurlyPhi]initpar", "\[LeftDoubleBracket]", "i", 
          "\[RightDoubleBracket]"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}]}], "\n", 
 RowBox[{"plo2", "=", 
  RowBox[{"ListPlot", "[", "xyKtab", "]"}]}], "\n", 
 RowBox[{"Show", "[", 
  RowBox[{"plo1", ",", "plo2"}], 
  "]"}], "\n", "\[CurlyPhi]initpar", "\n", "parinit"}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"90", " ", "\[Degree]"}], ",", 
   RowBox[{"160", " ", "\[Degree]"}], ",", 
   RowBox[{"250", " ", "\[Degree]"}], ",", 
   RowBox[{"300", " ", "\[Degree]"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"60.`", ",", "95.39392014169457`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"93.166247903554`", ",", "66.332495807108`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"65.31742619928156`", ",", "45.70373665014629`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"35.67063596465018`", ",", "60.63670117728224`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"17.279981273412346`", ",", "73.9932429347437`"}], "}"}]}], 
  "}"}]], "Output"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.193056 0.0125501 -0.526667 0.0118455 [
[.18345 .05311 -6 -9 ]
[.18345 .05311 6 0 ]
[.30895 .05311 -6 -9 ]
[.30895 .05311 6 0 ]
[.43445 .05311 -6 -9 ]
[.43445 .05311 6 0 ]
[.55995 .05311 -6 -9 ]
[.55995 .05311 6 0 ]
[.68545 .05311 -6 -9 ]
[.68545 .05311 6 0 ]
[.81095 .05311 -6 -9 ]
[.81095 .05311 6 0 ]
[.93645 .05311 -6 -9 ]
[.93645 .05311 6 0 ]
[.04545 .18406 -12 -4.5 ]
[.04545 .18406 0 4.5 ]
[.04545 .30252 -12 -4.5 ]
[.04545 .30252 0 4.5 ]
[.04545 .42097 -12 -4.5 ]
[.04545 .42097 0 4.5 ]
[.04545 .53943 -12 -4.5 ]
[.04545 .53943 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18345 .06561 m
.18345 .07186 L
s
[(30)] .18345 .05311 0 1 Mshowa
.30895 .06561 m
.30895 .07186 L
s
[(40)] .30895 .05311 0 1 Mshowa
.43445 .06561 m
.43445 .07186 L
s
[(50)] .43445 .05311 0 1 Mshowa
.55995 .06561 m
.55995 .07186 L
s
[(60)] .55995 .05311 0 1 Mshowa
.68545 .06561 m
.68545 .07186 L
s
[(70)] .68545 .05311 0 1 Mshowa
.81095 .06561 m
.81095 .07186 L
s
[(80)] .81095 .05311 0 1 Mshowa
.93645 .06561 m
.93645 .07186 L
s
[(90)] .93645 .05311 0 1 Mshowa
.125 Mabswid
.08305 .06561 m
.08305 .06936 L
s
.10815 .06561 m
.10815 .06936 L
s
.13325 .06561 m
.13325 .06936 L
s
.15835 .06561 m
.15835 .06936 L
s
.20855 .06561 m
.20855 .06936 L
s
.23365 .06561 m
.23365 .06936 L
s
.25875 .06561 m
.25875 .06936 L
s
.28385 .06561 m
.28385 .06936 L
s
.33405 .06561 m
.33405 .06936 L
s
.35915 .06561 m
.35915 .06936 L
s
.38425 .06561 m
.38425 .06936 L
s
.40935 .06561 m
.40935 .06936 L
s
.45955 .06561 m
.45955 .06936 L
s
.48465 .06561 m
.48465 .06936 L
s
.50975 .06561 m
.50975 .06936 L
s
.53485 .06561 m
.53485 .06936 L
s
.58505 .06561 m
.58505 .06936 L
s
.61015 .06561 m
.61015 .06936 L
s
.63525 .06561 m
.63525 .06936 L
s
.66035 .06561 m
.66035 .06936 L
s
.71055 .06561 m
.71055 .06936 L
s
.73565 .06561 m
.73565 .06936 L
s
.76075 .06561 m
.76075 .06936 L
s
.78585 .06561 m
.78585 .06936 L
s
.83605 .06561 m
.83605 .06936 L
s
.86115 .06561 m
.86115 .06936 L
s
.88625 .06561 m
.88625 .06936 L
s
.91135 .06561 m
.91135 .06936 L
s
.03285 .06561 m
.03285 .06936 L
s
.00775 .06561 m
.00775 .06936 L
s
.96155 .06561 m
.96155 .06936 L
s
.98665 .06561 m
.98665 .06936 L
s
.25 Mabswid
0 .06561 m
1 .06561 L
s
.05795 .18406 m
.0642 .18406 L
s
[(60)] .04545 .18406 1 0 Mshowa
.05795 .30252 m
.0642 .30252 L
s
[(70)] .04545 .30252 1 0 Mshowa
.05795 .42097 m
.0642 .42097 L
s
[(80)] .04545 .42097 1 0 Mshowa
.05795 .53943 m
.0642 .53943 L
s
[(90)] .04545 .53943 1 0 Mshowa
.125 Mabswid
.05795 .0893 m
.0617 .0893 L
s
.05795 .11299 m
.0617 .11299 L
s
.05795 .13668 m
.0617 .13668 L
s
.05795 .16037 m
.0617 .16037 L
s
.05795 .20775 m
.0617 .20775 L
s
.05795 .23144 m
.0617 .23144 L
s
.05795 .25513 m
.0617 .25513 L
s
.05795 .27882 m
.0617 .27882 L
s
.05795 .32621 m
.0617 .32621 L
s
.05795 .3499 m
.0617 .3499 L
s
.05795 .37359 m
.0617 .37359 L
s
.05795 .39728 m
.0617 .39728 L
s
.05795 .44466 m
.0617 .44466 L
s
.05795 .46835 m
.0617 .46835 L
s
.05795 .49204 m
.0617 .49204 L
s
.05795 .51573 m
.0617 .51573 L
s
.05795 .04192 m
.0617 .04192 L
s
.05795 .01822 m
.0617 .01822 L
s
.05795 .56312 m
.0617 .56312 L
s
.05795 .58681 m
.0617 .58681 L
s
.05795 .6105 m
.0617 .6105 L
s
.25 Mabswid
.05795 0 m
.05795 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.55995 .60332 Mdot
.97619 .25907 Mdot
.62668 .01472 Mdot
.25461 .1916 Mdot
.02381 .34982 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{86, 53.125},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzdVl9LwzAQT5um+qCg4geo+BkEP4C4Cfq69zKE7WEoc9+/Nsk1y6WXS2xh
wgrdhfvzu7+59aM9bD537WG7bpvFvv3ebNc/zevXvmfJQgix6t+nRuhz1x/h
Z9X1Ty+05FYTqSWVPpVGxxw7sNCvZGSGoTBCaXQMbAePxQj0LHNAEsoJpGXf
GKJ8nMEAfNRINpwdQhWKJYEIZ+GFPrILM3Kl8FQhDRYhElBEW9wz4aok6tQ0
k0HmZMp1LZbunSbeANShx0TVuLSrZLWZiOXRGE811wRI6oo0YyzwlFFeyVyg
RBHoeRMxpZkm7zIPI1wV8VbVNFsRMFHfJ8h7FEo3WrNU5oZ3EaxcvCQrrBJu
VHo/+0v12JdlPOCFFV1q8k42NW08S5dLhKoc4LAdY6ZgmWEe/a95s9S7lYyn
ayL4Z9AKb3lm0BKJqqxgS1fNoK5/btgLoVR4TqjvgFQbo3cjoxxUB0B3dHNh
tLIt8Wp2fcegIOZ9zZo05bouiQ1xHrctw5z+Tk1W7z93RLLQk/dl7FN6hHrS
KcdRefN01k16JHgPnjqKtPgFP6vRaA==\
\>"],
 ImageRangeCache->{{{0, 85}, {52.125, 0}} -> {6.28823, 38.4785, 1.05964, \
1.12267}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .66667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00833333 -0.166667 0.00833333 [
[.16667 -0.0125 -6 -9 ]
[.16667 -0.0125 6 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -9 -9 ]
[.83333 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[-0.0125 .08333 -12 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .16667 -12 -4.5 ]
[-0.0125 .16667 0 4.5 ]
[-0.0125 .25 -12 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .33333 -12 -4.5 ]
[-0.0125 .33333 0 4.5 ]
[-0.0125 .41667 -12 -4.5 ]
[-0.0125 .41667 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .58333 -12 -4.5 ]
[-0.0125 .58333 0 4.5 ]
[-0.0125 .66667 -18 -4.5 ]
[-0.0125 .66667 0 4.5 ]
[.5 .67917 -68.0625 0 ]
[.5 .67917 68.0625 12 ]
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .66667 L
s
.16667 0 m
.16667 .66667 L
s
.33333 0 m
.33333 .66667 L
s
.5 0 m
.5 .66667 L
s
.66667 0 m
.66667 .66667 L
s
.83333 0 m
.83333 .66667 L
s
1 0 m
1 .66667 L
s
0 0 m
1 0 L
s
0 .08333 m
1 .08333 L
s
0 .16667 m
1 .16667 L
s
0 .25 m
1 .25 L
s
0 .33333 m
1 .33333 L
s
0 .41667 m
1 .41667 L
s
0 .5 m
1 .5 L
s
0 .58333 m
1 .58333 L
s
0 .66667 m
1 .66667 L
s
0 g
.16667 0 m
.16667 .00625 L
s
[(20)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(40)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(60)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(80)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(100)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(120)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08333 m
.00625 .08333 L
s
[(30)] -0.0125 .08333 1 0 Mshowa
0 .16667 m
.00625 .16667 L
s
[(40)] -0.0125 .16667 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(50)] -0.0125 .25 1 0 Mshowa
0 .33333 m
.00625 .33333 L
s
[(60)] -0.0125 .33333 1 0 Mshowa
0 .41667 m
.00625 .41667 L
s
[(70)] -0.0125 .41667 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(80)] -0.0125 .5 1 0 Mshowa
0 .58333 m
.00625 .58333 L
s
[(90)] -0.0125 .58333 1 0 Mshowa
0 .66667 m
.00625 .66667 L
s
[(100)] -0.0125 .66667 1 0 Mshowa
.125 Mabswid
0 .01667 m
.00375 .01667 L
s
0 .03333 m
.00375 .03333 L
s
0 .05 m
.00375 .05 L
s
0 .06667 m
.00375 .06667 L
s
0 .1 m
.00375 .1 L
s
0 .11667 m
.00375 .11667 L
s
0 .13333 m
.00375 .13333 L
s
0 .15 m
.00375 .15 L
s
0 .18333 m
.00375 .18333 L
s
0 .2 m
.00375 .2 L
s
0 .21667 m
.00375 .21667 L
s
0 .23333 m
.00375 .23333 L
s
0 .26667 m
.00375 .26667 L
s
0 .28333 m
.00375 .28333 L
s
0 .3 m
.00375 .3 L
s
0 .31667 m
.00375 .31667 L
s
0 .35 m
.00375 .35 L
s
0 .36667 m
.00375 .36667 L
s
0 .38333 m
.00375 .38333 L
s
0 .4 m
.00375 .4 L
s
0 .43333 m
.00375 .43333 L
s
0 .45 m
.00375 .45 L
s
0 .46667 m
.00375 .46667 L
s
0 .48333 m
.00375 .48333 L
s
0 .51667 m
.00375 .51667 L
s
0 .53333 m
.00375 .53333 L
s
0 .55 m
.00375 .55 L
s
0 .56667 m
.00375 .56667 L
s
0 .6 m
.00375 .6 L
s
0 .61667 m
.00375 .61667 L
s
0 .63333 m
.00375 .63333 L
s
0 .65 m
.00375 .65 L
s
.25 Mabswid
0 0 m
0 .66667 L
s
gsave
.5 .67917 -129.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Path) show
93.000 13.000 moveto
(of) show
111.000 13.000 moveto
(K) show
123.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(init) show
165.000 13.000 moveto
(param) show
195.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
.5 Mabswid
.5 .62828 m
.50617 .62825 L
.51177 .62818 L
.51824 .62803 L
.52434 .62784 L
.53517 .62735 L
.54687 .62662 L
.55966 .62559 L
.57309 .62423 L
.59676 .62115 L
.62048 .61716 L
.64193 .61274 L
.68741 .60063 L
.72832 .58616 L
.76052 .57186 L
.79176 .55475 L
.81488 .53912 L
.83196 .52491 L
.84374 .51272 L
.85312 .50004 L
.85676 .49346 L
.85928 .48752 L
.86086 .48238 L
.86147 .47955 L
.86169 .4783 L
.86188 .47695 L
.86196 .47623 L
.86203 .47556 L
.86212 .47426 L
.86218 .47309 L
.8622 .47185 L
.86218 .47054 L
.86212 .46932 L
.86207 .46863 L
.86202 .468 L
.86186 .46658 L
.86152 .46444 L
.8611 .46248 L
.85981 .45811 L
.85811 .45398 L
.85585 .44968 L
.84975 .44101 L
.8413 .43197 L
.82197 .41609 L
.77192 .38331 L
.71711 .34833 L
.66418 .311 L
.61213 .26963 L
.5688 .23311 L
.54951 .21792 L
Mistroke
.53999 .21127 L
.53029 .20541 L
.52118 .20105 L
.51697 .19949 L
.51315 .19834 L
.50932 .19747 L
.50732 .19713 L
.50631 .19699 L
.50522 .19686 L
.50426 .19676 L
.50339 .19669 L
.50251 .19664 L
.50168 .1966 L
.50071 .19658 L
.49982 .19658 L
.49884 .19659 L
.49781 .19662 L
.49689 .19667 L
.49589 .19675 L
.49388 .19696 L
.49201 .19723 L
.49027 .19755 L
.48632 .19848 L
.48206 .19982 L
.4741 .20316 L
.46667 .20713 L
.42884 .23506 L
.38546 .27164 L
.33224 .31367 L
.27696 .35225 L
.22445 .38558 L
.19754 .40268 L
.17571 .41781 L
.16619 .42531 L
.15704 .43358 L
.14981 .44155 L
.14437 .44932 L
.14223 .45327 L
.14036 .45765 L
.13955 .46006 L
.13886 .46266 L
.1384 .46491 L
.1382 .4662 L
.13804 .46741 L
.13792 .46869 L
.13787 .46942 L
.13784 .4701 L
.1378 .47135 L
.1378 .47199 L
.13781 .47269 L
Mistroke
.13786 .47391 L
.13795 .47524 L
.13807 .4765 L
.13822 .47767 L
.13871 .48049 L
.13947 .48363 L
.14149 .48953 L
.14439 .49571 L
.14798 .50176 L
.1571 .51369 L
.17078 .52741 L
.1906 .54313 L
.2421 .57313 L
.27601 .58787 L
.31935 .60268 L
.36073 .61333 L
.40157 .6209 L
.42515 .62404 L
.43782 .62536 L
.4514 .6265 L
.46333 .62727 L
.47015 .62761 L
.47656 .62787 L
.48244 .62805 L
.48783 .62817 L
.49376 .62825 L
.5 .62828 L
Mfstroke
.008 w
.5 .62828 Mdot
.77639 .3861 Mdot
.54431 .2142 Mdot
.29726 .33864 Mdot
.144 .44994 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{557, 371.125},
 ImageMargins->{{44, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 556}, {370.125, 0}} -> {-7.91176, 16.36, 0.237741, \
0.237741}}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"90", " ", "\[Degree]"}], ",", 
   RowBox[{"160", " ", "\[Degree]"}], ",", 
   RowBox[{"250", " ", "\[Degree]"}], ",", 
   RowBox[{"300", " ", "\[Degree]"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A0x", "\[Rule]", "0"}], ",", 
   RowBox[{"A0y", "\[Rule]", "0"}], ",", 
   RowBox[{"\[Gamma]0", "\[Rule]", "0"}], ",", 
   RowBox[{"a", "\[Rule]", "30"}], ",", 
   RowBox[{"b", "\[Rule]", "50"}], ",", 
   RowBox[{"c", "\[Rule]", "50"}], ",", 
   RowBox[{"d", "\[Rule]", "60"}], ",", 
   RowBox[{"\[Kappa]", "\[Rule]", "0"}], ",", 
   RowBox[{"k", "\[Rule]", "100"}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["14 Requirements in xK and yK", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Gamma]0", "=", "0"}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"R2", "=", 
   RowBox[{"120", "  ", "\[Equal]", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"xK", "/.", 
        RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
       RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", 
      RowBox[{"\[CurlyPhi]", "->", "\[CurlyPhi]1"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"R3", "=", 
   RowBox[{"80", "     ", "\[Equal]", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"yK", "/.", 
        RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
       RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", 
      RowBox[{"\[CurlyPhi]", "->", "\[CurlyPhi]1"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"R4", "=", 
   RowBox[{"100", "  ", "\[Equal]", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"xK", "/.", 
        RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
       RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", 
      RowBox[{"\[CurlyPhi]", "->", "\[CurlyPhi]2"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"R5", "=", 
   RowBox[{"60", "    ", "\[Equal]", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"yK", "/.", 
        RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
       RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", 
      RowBox[{"\[CurlyPhi]", "->", "\[CurlyPhi]2"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"R6", "=", 
   RowBox[{"80", "  ", "\[Equal]", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"xK", "/.", 
        RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
       RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", 
      RowBox[{"\[CurlyPhi]", "->", "\[CurlyPhi]3"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"R7", "=", 
   RowBox[{"60", "  ", "\[Equal]", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"yK", "/.", 
        RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
       RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", 
      RowBox[{"\[CurlyPhi]", "->", "\[CurlyPhi]3"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"R8", "=", 
   RowBox[{"60", "  ", "\[Equal]", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"xK", "/.", 
        RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
       RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", 
      RowBox[{"\[CurlyPhi]", "->", "\[CurlyPhi]4"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"R9", "=", 
   RowBox[{"60", "  ", "\[Equal]", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"yK", "/.", 
        RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
       RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", 
      RowBox[{"\[CurlyPhi]", "->", "\[CurlyPhi]4"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"R10", "=", 
   RowBox[{"40", "  ", "\[Equal]", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"xK", "/.", 
        RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
       RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", 
      RowBox[{"\[CurlyPhi]", "->", "\[CurlyPhi]5"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"R11", "=", 
   RowBox[{"60", "  ", "\[Equal]", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"yK", "/.", 
        RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
       RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", 
      RowBox[{"\[CurlyPhi]", "->", "\[CurlyPhi]5"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"R12", "=", 
   RowBox[{"20", "  ", "\[Equal]", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"xK", "/.", 
        RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
       RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", 
      RowBox[{"\[CurlyPhi]", "->", "\[CurlyPhi]6"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"R13", "=", 
   RowBox[{"60", "  ", "\[Equal]", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"yK", "/.", 
        RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
       RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", 
      RowBox[{"\[CurlyPhi]", "->", "\[CurlyPhi]6"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"R14", "=", 
   RowBox[{"0", "      ", "\[Equal]", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"xK", "/.", 
        RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
       RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", 
      RowBox[{"\[CurlyPhi]", "->", "\[CurlyPhi]7"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"R15", "=", 
   RowBox[{"80", "  ", "\[Equal]", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"yK", "/.", 
        RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
       RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", 
      RowBox[{"\[CurlyPhi]", "->", "\[CurlyPhi]7"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"R16", "=", 
   RowBox[{"60", "      ", "\[Equal]", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"xK", "/.", 
        RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
       RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", 
      RowBox[{"\[CurlyPhi]", "->", "\[CurlyPhi]8"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"R17", "=", 
   RowBox[{"90", "  ", "\[Equal]", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"yK", "/.", 
        RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
       RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", 
      RowBox[{"\[CurlyPhi]", "->", "\[CurlyPhi]8"}]}], "]"}]}]}], 
  ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData["R17"], "Input"],

Cell[BoxData[
 RowBox[{"90", "\[Equal]", 
  RowBox[{"A0y", "+", 
   RowBox[{"a", " ", 
    RowBox[{"Sin", "[", "\[CurlyPhi]8", "]"}]}], "+", 
   RowBox[{"k", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"\[Kappa]", "+", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{"d", "-", 
         RowBox[{"a", " ", 
          RowBox[{"Cos", "[", "\[CurlyPhi]8", "]"}]}], "-", 
         RowBox[{"b", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"ArcCos", "[", 
             FractionBox[
              RowBox[{
               SuperscriptBox["a", "2"], "+", 
               SuperscriptBox["b", "2"], "-", 
               SuperscriptBox["c", "2"], "+", 
               SuperscriptBox["d", "2"], "-", 
               RowBox[{"2", " ", "a", " ", "d", " ", 
                RowBox[{"Cos", "[", "\[CurlyPhi]8", "]"}]}]}], 
              RowBox[{"2", " ", "b", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["a", "2"], "+", 
                 SuperscriptBox["d", "2"], "-", 
                 RowBox[{"2", " ", "a", " ", "d", " ", 
                  RowBox[{"Cos", "[", "\[CurlyPhi]8", "]"}]}]}]]}]], "]"}], 
            "+", 
            RowBox[{"ArcTan", "[", 
             RowBox[{
              RowBox[{"d", "-", 
               RowBox[{"a", " ", 
                RowBox[{"Cos", "[", "\[CurlyPhi]8", "]"}]}]}], ",", 
              RowBox[{"a", " ", 
               RowBox[{"Sin", "[", "\[CurlyPhi]8", "]"}]}]}], "]"}]}], 
           "]"}]}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "a"}], " ", 
          RowBox[{"Sin", "[", "\[CurlyPhi]8", "]"}]}], "+", 
         RowBox[{"b", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"ArcCos", "[", 
             FractionBox[
              RowBox[{
               SuperscriptBox["a", "2"], "+", 
               SuperscriptBox["b", "2"], "-", 
               SuperscriptBox["c", "2"], "+", 
               SuperscriptBox["d", "2"], "-", 
               RowBox[{"2", " ", "a", " ", "d", " ", 
                RowBox[{"Cos", "[", "\[CurlyPhi]8", "]"}]}]}], 
              RowBox[{"2", " ", "b", " ", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["a", "2"], "+", 
                 SuperscriptBox["d", "2"], "-", 
                 RowBox[{"2", " ", "a", " ", "d", " ", 
                  RowBox[{"Cos", "[", "\[CurlyPhi]8", "]"}]}]}]]}]], "]"}], 
            "+", 
            RowBox[{"ArcTan", "[", 
             RowBox[{
              RowBox[{"d", "-", 
               RowBox[{"a", " ", 
                RowBox[{"Cos", "[", "\[CurlyPhi]8", "]"}]}]}], ",", 
              RowBox[{"a", " ", 
               RowBox[{"Sin", "[", "\[CurlyPhi]8", "]"}]}]}], "]"}]}], 
           "]"}]}]}]}], "]"}]}], "]"}]}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"erg1", "=", 
  RowBox[{"FindRoot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "R2", ",", "R3", ",", "R4", ",", "R5", ",", "R6", ",", "R7", ",", "R8", 
      ",", "R9", ",", "R10", ",", "R11", ",", "R12", ",", "R13", ",", "R14", 
      ",", "R15", ",", "R16", ",", "R17"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"A0x", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"A0y", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"a", ",", "30"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"b", ",", "50"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"c", ",", "50"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"d", ",", "60"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Kappa]", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "100"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[CurlyPhi]1", ",", 
        RowBox[{"90", " ", "Degree"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[CurlyPhi]2", ",", 
        RowBox[{"110", " ", "Degree"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[CurlyPhi]3", ",", 
        RowBox[{"130", " ", "Degree"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[CurlyPhi]4", ",", 
        RowBox[{"180", " ", "Degree"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[CurlyPhi]5", ",", 
        RowBox[{"200", " ", "Degree"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[CurlyPhi]6", ",", 
        RowBox[{"220", "  ", "Degree"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[CurlyPhi]7", ",", 
        RowBox[{"270", " ", "Degree"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[CurlyPhi]8", ",", 
        RowBox[{"360", " ", "Degree"}]}], "}"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FindRoot", "::", "\<\"cvmit\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Failed to converge to the requested accuracy or precision \
within \\!\\(100\\) iterations. \\!\\(\\*ButtonBox[\\\"Mehr\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"FindRoot::cvmit\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A0x", "\[Rule]", 
    RowBox[{"-", "249.99717285927943`"}]}], ",", 
   RowBox[{"A0y", "\[Rule]", 
    RowBox[{"-", "268.70273732253935`"}]}], ",", 
   RowBox[{"a", "\[Rule]", "28.38891520943183`"}], ",", 
   RowBox[{"b", "\[Rule]", "28.771591152368423`"}], ",", 
   RowBox[{"c", "\[Rule]", "11.724084435472696`"}], ",", 
   RowBox[{"d", "\[Rule]", "11.96229187850677`"}], ",", 
   RowBox[{"\[Kappa]", "\[Rule]", "0.7091818686439222`"}], ",", 
   RowBox[{"k", "\[Rule]", "453.0234589015766`"}], ",", 
   RowBox[{"\[CurlyPhi]1", "\[Rule]", "0.7408989448218143`"}], ",", 
   RowBox[{"\[CurlyPhi]2", "\[Rule]", "1.668220938808899`"}], ",", 
   RowBox[{"\[CurlyPhi]3", "\[Rule]", "2.093646468000932`"}], ",", 
   RowBox[{"\[CurlyPhi]4", "\[Rule]", "2.7625160946878684`"}], ",", 
   RowBox[{"\[CurlyPhi]5", "\[Rule]", "2.9059616869628564`"}], ",", 
   RowBox[{"\[CurlyPhi]6", "\[Rule]", "2.997060258740033`"}], ",", 
   RowBox[{"\[CurlyPhi]7", "\[Rule]", "3.1138784822404304`"}], ",", 
   RowBox[{"\[CurlyPhi]8", "\[Rule]", "6.649549054700596`"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xKpar", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"xK", "/.", "\[InvisibleSpace]", 
      RowBox[{"\[Delta]", "\[Rule]", "f\[Delta]"}]}], "/.", 
     "\[InvisibleSpace]", 
     RowBox[{"\[Psi]", "\[Rule]", "f\[Psi]"}]}], "/.", "\[InvisibleSpace]", 
    "erg1"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"yKpar", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"yK", "/.", "\[InvisibleSpace]", 
      RowBox[{"\[Delta]", "\[Rule]", "f\[Delta]"}]}], "/.", 
     "\[InvisibleSpace]", 
     RowBox[{"\[Psi]", "\[Rule]", "f\[Psi]"}]}], "/.", "\[InvisibleSpace]", 
    "erg1"}]}], ";"}], "\n", 
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"xKpar", ",", "yKpar"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[CurlyPhi]", ",", "0", ",", 
     RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "100"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "120"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Path of K\>\""}]}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ParametricPlot", "::", "\<\"pptr\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"\\!\\({xKpar, yKpar}\\) does not evaluate to a pair of \
real numbers at \\!\\(\[CurlyPhi]\\) = \\!\\(2.617993877991494`*^-7\\). \
\\!\\(\\*ButtonBox[\\\"Mehr\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, \
ButtonData:>\\\"ParametricPlot::pptr\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ParametricPlot", "::", "\<\"pptr\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"\\!\\({xKpar, yKpar}\\) does not evaluate to a pair of \
real numbers at \\!\\(\[CurlyPhi]\\) = \\!\\(0.12408141638188183`\\). \
\\!\\(\\*ButtonBox[\\\"Mehr\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, \
ButtonData:>\\\"ParametricPlot::pptr\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ParametricPlot", "::", "\<\"pptr\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"\\!\\({xKpar, yKpar}\\) does not evaluate to a pair of \
real numbers at \\!\\(\[CurlyPhi]\\) = \\!\\(0.1865103330665333`\\). \
\\!\\(\\*ButtonBox[\\\"Mehr\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, \
ButtonData:>\\\"ParametricPlot::pptr\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"stop\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Further output of \\!\\(ParametricPlot :: \\\"pptr\\\"\\) \
will be suppressed during this calculation. \\!\\(\\*ButtonBox[\\\"Mehr\
\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.01 0 0.00515028 [
[.2 -0.0125 -6 -9 ]
[.2 -0.0125 6 0 ]
[.4 -0.0125 -6 -9 ]
[.4 -0.0125 6 0 ]
[.6 -0.0125 -6 -9 ]
[.6 -0.0125 6 0 ]
[.8 -0.0125 -6 -9 ]
[.8 -0.0125 6 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[-0.0125 .10301 -12 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -12 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -12 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -18 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -29 0 ]
[.5 .63053 29 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .61803 L
s
.2 0 m
.2 .61803 L
s
.4 0 m
.4 .61803 L
s
.6 0 m
.6 .61803 L
s
.8 0 m
.8 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.2 0 m
.2 .00625 L
s
[(20)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(40)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(60)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(80)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(100)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10301 m
.00625 .10301 L
s
[(20)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(40)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(60)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(80)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(100)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(120)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02575 m
.00375 .02575 L
s
0 .0515 m
.00375 .0515 L
s
0 .07725 m
.00375 .07725 L
s
0 .12876 m
.00375 .12876 L
s
0 .15451 m
.00375 .15451 L
s
0 .18026 m
.00375 .18026 L
s
0 .23176 m
.00375 .23176 L
s
0 .25751 m
.00375 .25751 L
s
0 .28327 m
.00375 .28327 L
s
0 .33477 m
.00375 .33477 L
s
0 .36052 m
.00375 .36052 L
s
0 .38627 m
.00375 .38627 L
s
0 .43777 m
.00375 .43777 L
s
0 .46353 m
.00375 .46353 L
s
0 .48928 m
.00375 .48928 L
s
0 .54078 m
.00375 .54078 L
s
0 .56653 m
.00375 .56653 L
s
0 .59228 m
.00375 .59228 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Path) show
93.000 13.000 moveto
(of) show
111.000 13.000 moveto
(K) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.19967 .61803 m
.8583 .3851 L
.90817 .36536 L
.92323 .35905 L
.93155 .35506 L
.93406 .35356 L
.93493 .35293 L
.93554 .35239 L
.93582 .35208 L
.93602 .35182 L
.93618 .35155 L
.93624 .3514 L
.93628 .35127 L
.93632 .35105 L
.93631 .35085 L
.93626 .35064 L
.93615 .35044 L
.93599 .35024 L
.9358 .35007 L
.93554 .34988 L
.93524 .34971 L
.9346 .34943 L
.93375 .34914 L
.93263 .34886 L
.93126 .34858 L
.92832 .34813 L
.92512 .34776 L
.92179 .34743 L
.91308 .34671 L
.89376 .34513 L
.87006 .3427 L
.84112 .33871 L
.81187 .33342 L
.77962 .326 L
.71586 .30613 L
.65758 .28212 L
.6318 .27068 L
.61701 .2645 L
.6027 .2592 L
.58772 .25476 L
.57865 .25277 L
.57443 .25203 L
.56977 .25137 L
.5671 .25105 L
.56462 .25081 L
.56204 .2506 L
.55961 .25045 L
.55822 .25038 L
.55669 .25031 L
.55511 .25027 L
Mistroke
.55343 .25024 L
.55192 .25022 L
.55027 .25022 L
.54724 .25027 L
.54409 .25038 L
.54226 .25048 L
.54055 .25058 L
.53375 .25115 L
.5271 .25194 L
.5195 .25311 L
.50268 .2565 L
.48435 .26122 L
.42783 .2798 L
.22691 .35903 L
Mfstroke
.22691 .35903 m
0 .44094 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-11.6555, -9.63372, 0.412368, \
0.800671}}]
}, Open  ]],

Cell[TextData[StyleBox["No realistic solution is found ",
 FontSize->16,
 Background->RGBColor[1, 0, 1]]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Now we use the optimisation method", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"xCGi", "=", 
  RowBox[{"{", 
   RowBox[{
   "120", ",", "100", ",", "80", ",", "60", ",", "40", ",", "20", ",", "80", 
    ",", "60"}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"yCGi", " ", "=", 
  RowBox[{"{", 
   RowBox[{
   "80", ",", "60", ",", "60", ",", "60", ",", "60", ",", "60", ",", "80", 
    ",", "90"}], "}"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "120", ",", "100", ",", "80", ",", "60", ",", "40", ",", "20", ",", "80", 
   ",", "60"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "80", ",", "60", ",", "60", ",", "60", ",", "60", ",", "60", ",", "80", ",",
    "90"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CurlyPhi]i", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
   "\[CurlyPhi]1", ",", "\[CurlyPhi]2", ",", "\[CurlyPhi]3", ",", 
    "\[CurlyPhi]4", ",", "\[CurlyPhi]5", ",", "\[CurlyPhi]6", ",", 
    "\[CurlyPhi]7", ",", "\[CurlyPhi]8"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "\[CurlyPhi]1", ",", "\[CurlyPhi]2", ",", "\[CurlyPhi]3", ",", 
   "\[CurlyPhi]4", ",", "\[CurlyPhi]5", ",", "\[CurlyPhi]6", ",", 
   "\[CurlyPhi]7", ",", "\[CurlyPhi]8"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"xK", "/.", 
      RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
     RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", 
    RowBox[{"\[CurlyPhi]", "->", 
     RowBox[{"\[CurlyPhi]i", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}]}], "]"}], "-", 
  RowBox[{"xCGi", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "120"}], "+", "A0x", "+", 
  RowBox[{"a", " ", 
   RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}], "+", 
  RowBox[{"k", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Kappa]", "+", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"d", "-", 
        RowBox[{"a", " ", 
         RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}], "-", 
        RowBox[{"b", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{
           RowBox[{"ArcCos", "[", 
            FractionBox[
             RowBox[{
              SuperscriptBox["a", "2"], "+", 
              SuperscriptBox["b", "2"], "-", 
              SuperscriptBox["c", "2"], "+", 
              SuperscriptBox["d", "2"], "-", 
              RowBox[{"2", " ", "a", " ", "d", " ", 
               RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}], 
             RowBox[{"2", " ", "b", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["a", "2"], "+", 
                SuperscriptBox["d", "2"], "-", 
                RowBox[{"2", " ", "a", " ", "d", " ", 
                 RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}]]}]], "]"}], 
           "+", 
           RowBox[{"ArcTan", "[", 
            RowBox[{
             RowBox[{"d", "-", 
              RowBox[{"a", " ", 
               RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}], ",", 
             RowBox[{"a", " ", 
              RowBox[{"Sin", "[", "\[CurlyPhi]1", "]"}]}]}], "]"}]}], 
          "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", 
         RowBox[{"Sin", "[", "\[CurlyPhi]1", "]"}]}], "+", 
        RowBox[{"b", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           RowBox[{"ArcCos", "[", 
            FractionBox[
             RowBox[{
              SuperscriptBox["a", "2"], "+", 
              SuperscriptBox["b", "2"], "-", 
              SuperscriptBox["c", "2"], "+", 
              SuperscriptBox["d", "2"], "-", 
              RowBox[{"2", " ", "a", " ", "d", " ", 
               RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}], 
             RowBox[{"2", " ", "b", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["a", "2"], "+", 
                SuperscriptBox["d", "2"], "-", 
                RowBox[{"2", " ", "a", " ", "d", " ", 
                 RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}]]}]], "]"}], 
           "+", 
           RowBox[{"ArcTan", "[", 
            RowBox[{
             RowBox[{"d", "-", 
              RowBox[{"a", " ", 
               RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}], ",", 
             RowBox[{"a", " ", 
              RowBox[{"Sin", "[", "\[CurlyPhi]1", "]"}]}]}], "]"}]}], 
          "]"}]}]}]}], "]"}]}], "]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"yK", "/.", 
      RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
     RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", 
    RowBox[{"\[CurlyPhi]", "->", 
     RowBox[{"\[CurlyPhi]i", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}]}], "]"}], "-", 
  RowBox[{"yCGi", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "80"}], "+", "A0y", "+", 
  RowBox[{"a", " ", 
   RowBox[{"Sin", "[", "\[CurlyPhi]1", "]"}]}], "+", 
  RowBox[{"k", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"\[Kappa]", "+", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"d", "-", 
        RowBox[{"a", " ", 
         RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}], "-", 
        RowBox[{"b", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{
           RowBox[{"ArcCos", "[", 
            FractionBox[
             RowBox[{
              SuperscriptBox["a", "2"], "+", 
              SuperscriptBox["b", "2"], "-", 
              SuperscriptBox["c", "2"], "+", 
              SuperscriptBox["d", "2"], "-", 
              RowBox[{"2", " ", "a", " ", "d", " ", 
               RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}], 
             RowBox[{"2", " ", "b", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["a", "2"], "+", 
                SuperscriptBox["d", "2"], "-", 
                RowBox[{"2", " ", "a", " ", "d", " ", 
                 RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}]]}]], "]"}], 
           "+", 
           RowBox[{"ArcTan", "[", 
            RowBox[{
             RowBox[{"d", "-", 
              RowBox[{"a", " ", 
               RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}], ",", 
             RowBox[{"a", " ", 
              RowBox[{"Sin", "[", "\[CurlyPhi]1", "]"}]}]}], "]"}]}], 
          "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", 
         RowBox[{"Sin", "[", "\[CurlyPhi]1", "]"}]}], "+", 
        RowBox[{"b", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           RowBox[{"ArcCos", "[", 
            FractionBox[
             RowBox[{
              SuperscriptBox["a", "2"], "+", 
              SuperscriptBox["b", "2"], "-", 
              SuperscriptBox["c", "2"], "+", 
              SuperscriptBox["d", "2"], "-", 
              RowBox[{"2", " ", "a", " ", "d", " ", 
               RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}], 
             RowBox[{"2", " ", "b", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["a", "2"], "+", 
                SuperscriptBox["d", "2"], "-", 
                RowBox[{"2", " ", "a", " ", "d", " ", 
                 RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}]]}]], "]"}], 
           "+", 
           RowBox[{"ArcTan", "[", 
            RowBox[{
             RowBox[{"d", "-", 
              RowBox[{"a", " ", 
               RowBox[{"Cos", "[", "\[CurlyPhi]1", "]"}]}]}], ",", 
             RowBox[{"a", " ", 
              RowBox[{"Sin", "[", "\[CurlyPhi]1", "]"}]}]}], "]"}]}], 
          "]"}]}]}]}], "]"}]}], "]"}]}]}]], "Output"]
}, Open  ]],

Cell["we have 8 sets of points for 16 parameters:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ferror", "=", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Simplify", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"xK", "/.", 
              RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
             RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", 
            RowBox[{"\[CurlyPhi]", "->", 
             RowBox[{"\[CurlyPhi]i", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}]}], "]"}], "-", 
          RowBox[{"xCGi", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ")"}], "^", "2"}], "+", 
       "\[IndentingNewLine]", "                  ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Simplify", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"yK", "/.", 
              RowBox[{"\[Delta]", "->", "f\[Delta]"}]}], "/.", 
             RowBox[{"\[Psi]", "->", "f\[Psi]"}]}], "/.", 
            RowBox[{"\[CurlyPhi]", "->", 
             RowBox[{"\[CurlyPhi]i", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}]}], "]"}], "-", 
          RowBox[{"yCGi", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ")"}], "^", "2"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "8"}], "}"}]}], "]"}], "//", "N"}]}], 
  ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"erg2", " ", "=", " ", 
  RowBox[{"NMinimize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"ferror", ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"-", "10"}], "\[LessEqual]", "A0x", "\[LessEqual]", "10"}], 
      ",", 
      RowBox[{
       RowBox[{"-", "10"}], "\[LessEqual]", "A0y", "\[LessEqual]", "10"}], 
      ",", 
      RowBox[{"20", "\[LessEqual]", "a", "\[LessEqual]", "40"}], ",", 
      RowBox[{"60", "\[LessEqual]", "b", "\[LessEqual]", "100"}], ",", 
      RowBox[{"60", "\[LessEqual]", "c", "\[LessEqual]", "100"}], ",", 
      RowBox[{"40", "\[LessEqual]", "d", "\[LessEqual]", "100"}], ",", 
      RowBox[{"100", "\[LessEqual]", "k", "\[LessEqual]", "200"}], ",", 
      RowBox[{
       RowBox[{"-", "1"}], "\[LessEqual]", "\[Kappa]", "\[LessEqual]", "1"}], 
      ",", 
      RowBox[{"0", "\[LessEqual]", "\[CurlyPhi]1", "\[LessEqual]", "2"}], ",",
       
      RowBox[{"0", "\[LessEqual]", "\[CurlyPhi]2", "\[LessEqual]", "2"}], ",",
       
      RowBox[{"0", "\[LessEqual]", "\[CurlyPhi]3", "\[LessEqual]", "2"}], ",",
       
      RowBox[{"1", "\[LessEqual]", "\[CurlyPhi]4", "\[LessEqual]", "4"}], ",",
       
      RowBox[{"2", "\[LessEqual]", "\[CurlyPhi]5", "\[LessEqual]", "5"}], ",",
       
      RowBox[{"3", "\[LessEqual]", "\[CurlyPhi]6", "\[LessEqual]", "6"}], ",",
       
      RowBox[{"3", "\[LessEqual]", "\[CurlyPhi]7", "\[LessEqual]", "6"}], ",",
       
      RowBox[{"3", "\[LessEqual]", "\[CurlyPhi]8", "\[LessEqual]", "7"}]}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
     "A0x", ",", "A0y", ",", "a", ",", "b", ",", "c", ",", "d", ",", "k", ",",
       "\[Kappa]", ",", "\[CurlyPhi]1", ",", "\[CurlyPhi]2", ",", 
      "\[CurlyPhi]3", ",", "\[CurlyPhi]4", ",", "\[CurlyPhi]5", ",", 
      "\[CurlyPhi]6", ",", "\[CurlyPhi]7", ",", "\[CurlyPhi]8"}], "}"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NMinimize", "::", "\<\"nrnum\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"The function value \\!\\(\\(\\(140901.95837146306`\
\[InvisibleSpace]\\)\\) - \\(\\(50061.54673744169`\\\\ \[ImaginaryI]\\)\\)\\) \
is not a real number at \\!\\({a, A0x, A0y, b, c, d, k, \[Kappa], \
\[CurlyPhi]1, \[CurlyPhi]2, \\(\\(\[LeftSkeleton] 6 \
\[RightSkeleton]\\)\\)}\\) = \\!\\({37.18069831861328`, 9.812644782123119`, \
4.788619917461451`, 66.03526533309986`, 82.0134789735369`, \\(\\(\
\[LeftSkeleton] 18 \[RightSkeleton]\\)\\), \\(\\(\[LeftSkeleton] 19 \
\[RightSkeleton]\\)\\), \\(\\(-0.8222456711517978`\\)\\), \
0.11564485740631837`, 0.3792450847012598`, \\(\\(\[LeftSkeleton] 6 \
\[RightSkeleton]\\)\\)}\\). \\!\\(\\*ButtonBox[\\\"Mehr\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::nrnum\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NMinimize", "::", "\<\"nrnum\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"The function value \\!\\(\\(\\(140901.95837146306`\
\[InvisibleSpace]\\)\\) - \\(\\(50061.54673744169`\\\\ \[ImaginaryI]\\)\\)\\) \
is not a real number at \\!\\({a, A0x, A0y, b, c, d, k, \[Kappa], \
\[CurlyPhi]1, \[CurlyPhi]2, \\(\\(\[LeftSkeleton] 6 \
\[RightSkeleton]\\)\\)}\\) = \\!\\({37.18069831861328`, 9.812644782123119`, \
4.788619917461451`, 66.03526533309986`, 82.0134789735369`, \\(\\(\
\[LeftSkeleton] 18 \[RightSkeleton]\\)\\), \\(\\(\[LeftSkeleton] 19 \
\[RightSkeleton]\\)\\), \\(\\(-0.8222456711517978`\\)\\), \
0.11564485740631837`, 0.3792450847012598`, \\(\\(\[LeftSkeleton] 6 \
\[RightSkeleton]\\)\\)}\\). \\!\\(\\*ButtonBox[\\\"Mehr\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::nrnum\\\"]\\)\"\>"}]], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"erg3", "=", 
  RowBox[{"FindMinimum", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "R2", ",", "R3", ",", "R4", ",", "R5", ",", "R6", ",", "R7", ",", "R8", 
      ",", "R9", ",", "R10", ",", "R11", ",", "R12", ",", "R13", ",", "R14", 
      ",", "R15", ",", "R16", ",", "R17"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"A0x", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"A0y", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"a", ",", "30"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"b", ",", "50"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"c", ",", "50"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"d", ",", "60"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Kappa]", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "100"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[CurlyPhi]1", ",", 
        RowBox[{"90", " ", "Degree"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[CurlyPhi]2", ",", 
        RowBox[{"110", " ", "Degree"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[CurlyPhi]3", ",", 
        RowBox[{"130", " ", "Degree"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[CurlyPhi]4", ",", 
        RowBox[{"180", " ", "Degree"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[CurlyPhi]5", ",", 
        RowBox[{"200", " ", "Degree"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[CurlyPhi]6", ",", 
        RowBox[{"220", "  ", "Degree"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[CurlyPhi]7", ",", 
        RowBox[{"270", " ", "Degree"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[CurlyPhi]8", ",", 
        RowBox[{"360", " ", "Degree"}]}], "}"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FindMinimum", "::", "\<\"nnum\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"The function value \\!\\({False, False, False, False, \
False, False, True, False, False, False, \\(\\(\[LeftSkeleton] 6 \
\[RightSkeleton]\\)\\)}\\) is not a number at \\!\\({A0x, A0y, a, b, c, d, \
\[Kappa], k, \[CurlyPhi]1, \[CurlyPhi]2, \\(\\(\[LeftSkeleton] 6 \
\[RightSkeleton]\\)\\)}\\) = \\!\\({0.`, 0.`, 30.`, 50.`, 50.`, 60.`, 0.`, \
100.`, 1.5707963267948966`, 1.9198621771937625`, \\(\\(\[LeftSkeleton] 6 \
\[RightSkeleton]\\)\\)}\\). \\!\\(\\*ButtonBox[\\\"Mehr\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::nnum\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FindMinimum", "::", "\<\"nnum\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"The function value \\!\\({False, False, False, False, \
False, False, True, False, False, False, \\(\\(\[LeftSkeleton] 6 \
\[RightSkeleton]\\)\\)}\\) is not a number at \\!\\({A0x, A0y, a, b, c, d, \
\[Kappa], k, \[CurlyPhi]1, \[CurlyPhi]2, \\(\\(\[LeftSkeleton] 6 \
\[RightSkeleton]\\)\\)}\\) = \\!\\({0.`, 0.`, 30.`, 50.`, 50.`, 60.`, 0.`, \
100.`, 1.5707963267948966`, 1.9198621771937625`, \\(\\(\[LeftSkeleton] 6 \
\[RightSkeleton]\\)\\)}\\). \\!\\(\\*ButtonBox[\\\"Mehr\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::nnum\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{"FindMinimum", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "R2", ",", "R3", ",", "R4", ",", "R5", ",", "R6", ",", "R7", ",", "R8", 
     ",", "R9", ",", "R10", ",", "R11", ",", "R12", ",", "R13", ",", "R14", 
     ",", "R15", ",", "R16", ",", "R17"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"A0x", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"A0y", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "30"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"b", ",", "50"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"c", ",", "50"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"d", ",", "60"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Kappa]", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "100"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[CurlyPhi]1", ",", 
       RowBox[{"90", " ", "\[Degree]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[CurlyPhi]2", ",", 
       RowBox[{"110", " ", "\[Degree]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[CurlyPhi]3", ",", 
       RowBox[{"130", " ", "\[Degree]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[CurlyPhi]4", ",", 
       RowBox[{"180", " ", "\[Degree]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[CurlyPhi]5", ",", 
       RowBox[{"200", " ", "\[Degree]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[CurlyPhi]6", ",", 
       RowBox[{"220", " ", "\[Degree]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[CurlyPhi]7", ",", 
       RowBox[{"270", " ", "\[Degree]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[CurlyPhi]8", ",", 
       RowBox[{"360", " ", "\[Degree]"}]}], "}"}]}], "}"}]}], "]"}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{957, 855},
WindowMargins->{{4, Automatic}, {Automatic, 0}},
Magnification->1,
FrontEndVersion->"6.0 for Mac OS X PowerPC (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 102, 2, 46, "Subtitle"],
Cell[695, 27, 204, 5, 41, "Text"],
Cell[CellGroupData[{
Cell[924, 36, 63, 0, 34, "Subsection"],
Cell[990, 38, 5285, 89, 231, "Graphics",
 Evaluatable->False],
Cell[6278, 129, 132, 3, 27, "Input"],
Cell[CellGroupData[{
Cell[6435, 136, 340, 10, 105, "Input"],
Cell[6778, 148, 831, 24, 59, "Output"],
Cell[7612, 174, 831, 24, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8480, 203, 1126, 36, 73, "Input"],
Cell[9609, 241, 783, 27, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10429, 273, 1032, 34, 73, "Input"],
Cell[11464, 309, 624, 21, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12125, 335, 374, 12, 27, "Input"],
Cell[12502, 349, 303, 10, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12842, 364, 409, 13, 27, "Input"],
Cell[13254, 379, 315, 10, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13606, 394, 230, 6, 27, "Input"],
Cell[13839, 402, 198, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14074, 412, 513, 16, 27, "Input"],
Cell[14590, 430, 424, 13, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15051, 448, 653, 18, 43, "Input"],
Cell[15707, 468, 270, 7, 27, "Output"],
Cell[15980, 477, 270, 7, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[16299, 490, 114, 1, 67, "Section"],
Cell[16416, 493, 277, 6, 27, "Input"],
Cell[CellGroupData[{
Cell[16718, 503, 45, 0, 25, "Subsubsection"],
Cell[CellGroupData[{
Cell[16788, 507, 59, 0, 43, "Input"],
Cell[16850, 509, 270, 7, 27, "Output"],
Cell[17123, 518, 270, 7, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17430, 530, 548, 14, 27, "Input"],
Cell[17981, 546, 438, 11, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18456, 562, 1309, 37, 73, "Input"],
Cell[19768, 601, 9884, 571, 112, 7792, 533, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29689, 1177, 806, 22, 73, "Input"],
Cell[30498, 1201, 12247, 612, 186, 8176, 542, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42782, 1818, 512, 13, 27, "Input"],
Cell[43297, 1833, 447, 11, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43781, 1849, 1173, 31, 103, "Input"],
Cell[44957, 1882, 238, 6, 27, "Output"],
Cell[45198, 1890, 503, 13, 27, "Output"],
Cell[CellGroupData[{
Cell[45726, 1907, 4653, 297, 62, 3835, 280, "GraphicsData", "PostScript", \
"Graphics"],
Cell[50382, 2206, 12812, 623, 380, 7886, 539, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[63209, 2832, 238, 6, 27, "Output"],
Cell[63450, 2840, 438, 11, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[63937, 2857, 53, 0, 25, "Subsubsection"],
Cell[CellGroupData[{
Cell[64015, 2861, 57, 1, 27, "Input"],
Cell[64075, 2864, 28, 0, 27, "Output"]
}, Open  ]],
Cell[64118, 2867, 5959, 176, 253, "Input"],
Cell[CellGroupData[{
Cell[70102, 3047, 29, 0, 27, "Input"],
Cell[70134, 3049, 2818, 72, 127, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[72989, 3126, 1810, 50, 58, "Input"],
Cell[74802, 3178, 359, 7, 20, "Message"],
Cell[75164, 3187, 1116, 21, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[76317, 3213, 1185, 34, 73, "Input"],
Cell[77505, 3249, 408, 8, 20, "Message"],
Cell[77916, 3259, 406, 8, 20, "Message"],
Cell[78325, 3269, 405, 8, 20, "Message"],
Cell[78733, 3279, 367, 7, 20, "Message"],
Cell[79103, 3288, 7861, 422, 186, 5420, 378, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[86979, 3713, 114, 2, 30, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[87130, 3720, 56, 0, 34, "Subsection"],
Cell[CellGroupData[{
Cell[87211, 3724, 362, 10, 43, "Input"],
Cell[87576, 3736, 150, 4, 27, "Output"],
Cell[87729, 3742, 148, 4, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[87914, 3751, 279, 6, 27, "Input"],
Cell[88196, 3759, 232, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[88465, 3769, 404, 12, 27, "Input"],
Cell[88872, 3783, 2747, 72, 127, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[91656, 3860, 404, 12, 27, "Input"],
Cell[92063, 3874, 2746, 72, 127, "Output"]
}, Open  ]],
Cell[94824, 3949, 59, 0, 26, "Text"],
Cell[94886, 3951, 1393, 39, 58, "Input"],
Cell[CellGroupData[{
Cell[96304, 3994, 1902, 42, 73, "Input"],
Cell[98209, 4038, 893, 15, 34, "Message"],
Cell[99105, 4055, 893, 15, 34, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[100035, 4075, 1813, 50, 58, "Input"],
Cell[101851, 4127, 714, 12, 48, "Message"],
Cell[102568, 4141, 714, 12, 48, "Message"],
Cell[103285, 4155, 1763, 49, 58, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
