(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    983132,      17468]
NotebookOptionsPosition[    977475,      17289]
NotebookOutlinePosition[    977832,      17305]
CellTagsIndexPosition[    977789,      17302]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
MDA-Chapter 3: Design of Mechanisms - 3.4 Paths of Crank-Rocker Mechanisms\
\>", "Subtitle",
 CellChangeTimes->{3.467467260282127*^9, 3.467467419351796*^9}],

Cell["\<\
created 2009, Prof. Oskar Wallrapp, FK06, Munich University of Applied \
Sciences
updated 17.11.2009 - Animation\
\>", "Text",
 CellChangeTimes->{{3.4674673047927027`*^9, 3.467467366088581*^9}}],

Cell[CellGroupData[{

Cell["crank-rocker mechanismus: Basic functions", "Subsection"],

Cell["\<\
Clear[par,\[CurlyPhi],\[Psi],\[Psi]1,\[Psi]2,\[CurlyPhi]0,\[Psi]0,a,b,c,d];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
\[Sigma] = ArcTan[a Sin[\[CurlyPhi]]/(d-a Cos[\[CurlyPhi]])]
\[CapitalDelta] = Simplify[Sqrt[(a Sin[\[CurlyPhi]])^2 + (d-a \
Cos[\[CurlyPhi]])^2]]
\[Lambda] = Simplify[ArcCos[(\[CapitalDelta]^2 + b^2 - c^2) / (2 b \
\[CapitalDelta])] ]
f\[Psi] = \[Pi] - (\[Sigma] + \[Lambda])
f\[Psi]2 = \[Pi] - (\[Sigma] - \[Lambda])\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{"ArcTan", "[", 
  FractionBox[
   RowBox[{"a", " ", 
    RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}], 
   RowBox[{"d", "-", 
    RowBox[{"a", " ", 
     RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}]], "]"}]], "Output",
 CellChangeTimes->{
  3.467463009278082*^9, 3.4674633754198017`*^9, {3.467464124876346*^9, 
   3.4674641274994183`*^9}}],

Cell[BoxData[
 SqrtBox[
  RowBox[{
   SuperscriptBox["a", "2"], "+", 
   SuperscriptBox["d", "2"], "-", 
   RowBox[{"2", " ", "a", " ", "d", " ", 
    RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}]]], "Output",
 CellChangeTimes->{
  3.467463009278082*^9, 3.4674633754198017`*^9, {3.467464124876346*^9, 
   3.467464127505618*^9}}],

Cell[BoxData[
 RowBox[{"ArcCos", "[", 
  FractionBox[
   RowBox[{
    SuperscriptBox["a", "2"], "+", 
    SuperscriptBox["b", "2"], "-", 
    SuperscriptBox["c", "2"], "+", 
    SuperscriptBox["d", "2"], "-", 
    RowBox[{"2", " ", "a", " ", "d", " ", 
     RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}], 
   RowBox[{"2", " ", "b", " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["d", "2"], "-", 
      RowBox[{"2", " ", "a", " ", "d", " ", 
       RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}]]}]], "]"}]], "Output",
 CellChangeTimes->{
  3.467463009278082*^9, 3.4674633754198017`*^9, {3.467464124876346*^9, 
   3.4674641275098963`*^9}}],

Cell[BoxData[
 RowBox[{"\[Pi]", "-", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["b", "2"], "-", 
     SuperscriptBox["c", "2"], "+", 
     SuperscriptBox["d", "2"], "-", 
     RowBox[{"2", " ", "a", " ", "d", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}], 
    RowBox[{"2", " ", "b", " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["d", "2"], "-", 
       RowBox[{"2", " ", "a", " ", "d", " ", 
        RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}]]}]], "]"}], "-", 
  RowBox[{"ArcTan", "[", 
   FractionBox[
    RowBox[{"a", " ", 
     RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}], 
    RowBox[{"d", "-", 
     RowBox[{"a", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}]], "]"}]}]], "Output",
 CellChangeTimes->{
  3.467463009278082*^9, 3.4674633754198017`*^9, {3.467464124876346*^9, 
   3.4674641275143013`*^9}}],

Cell[BoxData[
 RowBox[{"\[Pi]", "+", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["b", "2"], "-", 
     SuperscriptBox["c", "2"], "+", 
     SuperscriptBox["d", "2"], "-", 
     RowBox[{"2", " ", "a", " ", "d", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}], 
    RowBox[{"2", " ", "b", " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["d", "2"], "-", 
       RowBox[{"2", " ", "a", " ", "d", " ", 
        RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}]]}]], "]"}], "-", 
  RowBox[{"ArcTan", "[", 
   FractionBox[
    RowBox[{"a", " ", 
     RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}], 
    RowBox[{"d", "-", 
     RowBox[{"a", " ", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}]], "]"}]}]], "Output",
 CellChangeTimes->{
  3.467463009278082*^9, 3.4674633754198017`*^9, {3.467464124876346*^9, 
   3.467464127518798*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[CurlyPhi]i", "=", 
   RowBox[{"Pi", "+", 
    RowBox[{"ArcCos", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"d", "^", "2"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"c", "-", "a"}], ")"}], "^", "2"}], "-", 
        RowBox[{"b", "^", "2"}]}], ")"}], " ", "/", " ", 
      RowBox[{"(", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"c", "-", "a"}], ")"}], " ", "d"}], ")"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CurlyPhi]a", "=", 
   RowBox[{"ArcCos", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"d", "^", "2"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"c", "+", "a"}], ")"}], "^", "2"}], "-", 
       RowBox[{"b", "^", "2"}]}], ")"}], " ", "/", " ", 
     RowBox[{"(", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"c", "+", "a"}], ")"}], " ", "d"}], ")"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"f\[CurlyPhi]0", "=", 
  RowBox[{
  "\[CurlyPhi]i", "-", "\[CurlyPhi]a"}]}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{"\[Pi]", "+", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["b", "2"]}], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "c"}], ")"}], "2"], "+", 
     SuperscriptBox["d", "2"]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "+", "c"}], ")"}], " ", "d"}]], "]"}], "-", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["b", "2"]}], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], "2"], "+", 
     SuperscriptBox["d", "2"]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"a", "+", "c"}], ")"}], " ", "d"}]], "]"}]}]], "Output",
 CellChangeTimes->{3.4674630094722*^9, 3.4674633756790953`*^9, 
  3.467464127582334*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Psi]i", "=", 
   RowBox[{"Pi", "-", 
    RowBox[{"ArcCos", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"d", "^", "2"}], "+", 
        RowBox[{"b", "^", "2"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"c", "-", "a"}], ")"}], "^", "2"}]}], ")"}], " ", "/", " ", 
      
      RowBox[{"(", 
       RowBox[{"2", " ", "b", " ", "d"}], ")"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Psi]a", "=", 
   RowBox[{"Pi", "-", 
    RowBox[{"ArcCos", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"d", "^", "2"}], "+", 
        RowBox[{"b", "^", "2"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"c", "+", "a"}], ")"}], "^", "2"}]}], ")"}], " ", "/", " ", 
      
      RowBox[{"(", 
       RowBox[{"2", " ", "b", " ", "d"}], ")"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"f\[Psi]0", "=", 
  RowBox[{"\[Psi]i", "-", "\[Psi]a"}]}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"ArcCos", "[", 
    FractionBox[
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "c"}], ")"}], "2"], "+", 
      SuperscriptBox["d", "2"]}], 
     RowBox[{"2", " ", "b", " ", "d"}]], "]"}]}], "+", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{
     SuperscriptBox["b", "2"], "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], "2"], "+", 
     SuperscriptBox["d", "2"]}], 
    RowBox[{"2", " ", "b", " ", "d"}]], "]"}]}]], "Output",
 CellChangeTimes->{3.467463009560733*^9, 3.467463375746386*^9, 
  3.467464127661618*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Mu]min1", "=", 
  RowBox[{"ArcCos", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", "^", "2"}], "+", 
      RowBox[{"b", "^", "2"}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"d", "-", "a"}], ")"}], "^", "2"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", "b", " ", "c"}], ")"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"ArcCos", "[", 
  FractionBox[
   RowBox[{
    SuperscriptBox["b", "2"], "+", 
    SuperscriptBox["c", "2"], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "a"}], "+", "d"}], ")"}], "2"]}], 
   RowBox[{"2", " ", "b", " ", "c"}]], "]"}]], "Output",
 CellChangeTimes->{3.467463009638894*^9, 3.4674633758295517`*^9, 
  3.467464127728547*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Mu]min2", "=", 
  RowBox[{"Pi", "-", 
   RowBox[{"ArcCos", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"c", "^", "2"}], "+", 
       RowBox[{"b", "^", "2"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"d", "+", "a"}], ")"}], "^", "2"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"2", " ", "b", " ", "c"}], ")"}]}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"\[Pi]", "-", 
  RowBox[{"ArcCos", "[", 
   FractionBox[
    RowBox[{
     SuperscriptBox["b", "2"], "+", 
     SuperscriptBox["c", "2"], "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "+", "d"}], ")"}], "2"]}], 
    RowBox[{"2", " ", "b", " ", "c"}]], "]"}]}]], "Output",
 CellChangeTimes->{3.467463009726112*^9, 3.467463375912642*^9, 
  3.467464127799902*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grashof", "=", 
  RowBox[{
   RowBox[{"Min", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}], "+", 
   RowBox[{"Max", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Max", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}], "+", 
  RowBox[{"Min", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}]}]], "Output",
 CellChangeTimes->{3.4674630097965317`*^9, 3.467463375988099*^9, 
  3.467464128159204*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f\[Delta]", "=", 
  RowBox[{"ArcTan", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"d", "+", 
      RowBox[{"b", " ", 
       RowBox[{"Cos", "[", "\[Psi]", "]"}]}], "-", 
      RowBox[{"a", " ", 
       RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}]}], ")"}], ",", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", " ", 
       RowBox[{"Sin", "[", "\[Psi]", "]"}]}], "-", 
      RowBox[{"a", " ", 
       RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}]}], " ", ")"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"ArcTan", "[", 
  RowBox[{
   RowBox[{"d", "-", 
    RowBox[{"a", " ", 
     RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}]}], "+", 
    RowBox[{"b", " ", 
     RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "a"}], " ", 
     RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}], "+", 
    RowBox[{"b", " ", 
     RowBox[{"Sin", "[", "\[Psi]", "]"}]}]}]}], "]"}]], "Output",
 CellChangeTimes->{3.467463009949726*^9, 3.467463376073021*^9, 
  3.4674641282442617`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"xK", " ", "=", " ", 
  RowBox[{"A0x", " ", "+", " ", 
   RowBox[{"a", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"\[CurlyPhi]", "+", "\[Gamma]0"}], "]"}]}], "+", 
   RowBox[{"k", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Kappa]", "+", "\[Delta]", "+", "\[Gamma]0"}], 
     "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"yK", " ", "=", " ", 
  RowBox[{"A0y", " ", "+", " ", 
   RowBox[{"a", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"\[CurlyPhi]", "+", "\[Gamma]0"}], "]"}]}], "+", 
   RowBox[{"k", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"\[Kappa]", "+", "\[Delta]", "+", "\[Gamma]0"}], 
     "]"}]}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"A0x", "+", 
  RowBox[{"k", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Gamma]0", "+", "\[Delta]", "+", "\[Kappa]"}], "]"}]}], "+", 
  RowBox[{"a", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Gamma]0", "+", "\[CurlyPhi]"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.467463010104824*^9, 3.467463376154687*^9, 
  3.467464128326655*^9}],

Cell[BoxData[
 RowBox[{"A0y", "+", 
  RowBox[{"k", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"\[Gamma]0", "+", "\[Delta]", "+", "\[Kappa]"}], "]"}]}], "+", 
  RowBox[{"a", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"\[Gamma]0", "+", "\[CurlyPhi]"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.467463010104824*^9, 3.467463376154687*^9, 
  3.46746412853579*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3.4.2\tCalculate the path of a coupler point K with Robert-solutions\
\>", "Section",
 CellChangeTimes->{{3.4198523331725683`*^9, 3.419852336349229*^9}, {
  3.46746290017601*^9, 3.4674629009342947`*^9}, {3.467467054450403*^9, 
  3.467467067761745*^9}}],

Cell[CellGroupData[{

Cell["\<\
par set 1  :  A0-A-B-B0 with point C
herein \[Psi]->f\[Psi]\
\>", "Subsection",
 CellChangeTimes->{{3.4674670800350113`*^9, 3.467467118051469*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"par", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"A0x", "\[Rule]", "22"}], ",", 
    RowBox[{"A0y", "\[Rule]", "59"}], ",", 
    RowBox[{"\[Gamma]0", "\[Rule]", 
     RowBox[{
      RowBox[{"-", "57"}], " ", "\[Degree]"}]}], ",", 
    RowBox[{"a", "\[Rule]", "47"}], ",", 
    RowBox[{"b", "\[Rule]", "52"}], ",", 
    RowBox[{"c", "\[Rule]", "17"}], ",", 
    RowBox[{"d", "\[Rule]", "35.5"}], ",", 
    RowBox[{"\[Kappa]", "->", "0"}], ",", 
    RowBox[{"k", "\[Rule]", "58.5"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.419852365989037*^9, 3.4198524491248837`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A0x", "\[Rule]", "22"}], ",", 
   RowBox[{"A0y", "\[Rule]", "59"}], ",", 
   RowBox[{"\[Gamma]0", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "57"}], " ", "\[Degree]"}]}], ",", 
   RowBox[{"a", "\[Rule]", "47"}], ",", 
   RowBox[{"b", "\[Rule]", "52"}], ",", 
   RowBox[{"c", "\[Rule]", "17"}], ",", 
   RowBox[{"d", "\[Rule]", "35.5`"}], ",", 
   RowBox[{"\[Kappa]", "\[Rule]", "0"}], ",", 
   RowBox[{"k", "\[Rule]", "58.5`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.467463015712232*^9, 3.467463462624421*^9, 
  3.467464134737348*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xKpar", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"xK", "/.", "\[InvisibleSpace]", 
      RowBox[{"\[Delta]", "\[Rule]", "f\[Delta]"}]}], "/.", 
     "\[InvisibleSpace]", 
     RowBox[{"\[Psi]", "\[Rule]", "f\[Psi]"}]}], "/.", "\[InvisibleSpace]", 
    "par"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"yKpar", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"yK", "/.", "\[InvisibleSpace]", 
      RowBox[{"\[Delta]", "\[Rule]", "f\[Delta]"}]}], "/.", 
     "\[InvisibleSpace]", 
     RowBox[{"\[Psi]", "\[Rule]", "f\[Psi]"}]}], "/.", "\[InvisibleSpace]", 
    "par"}]}], ";"}], "\n", 
 RowBox[{"plo1", "=", 
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"xKpar", ",", "yKpar"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[CurlyPhi]", ",", 
      RowBox[{"48", " ", "Degree"}], ",", " ", 
      RowBox[{"115", " ", "Degree"}]}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "130"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "120"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<Path of K - par set 1\>\""}]}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.4198524708446827`*^9, 3.4198524779235077`*^9}, {
  3.467464047041479*^9, 3.4674640521243553`*^9}, {3.4674642536629133`*^9, 
  3.4674642632030478`*^9}, {3.467464914161706*^9, 3.467465017426586*^9}, {
  3.4674658100908947`*^9, 3.4674658320468817`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmgk0lG0Ux1sU2iRECi2SyhYt9q5mGGbDzNhmmMlSyRaVSPYt2yBpkVaJ
kr5KlohkCQlllyVSsiXao+K7c07ndH5n3ud9n+c+9/7v//Z9jCNOGw7Mmzdv
Af75LvgbHGqEEyMvhgNLm+KnbpgDDs0XuHf77wJrsz87TW0/OPReXv53VRqw
JJhF/vOawOGLTkbioDcwp1qnzNa1AFfqzaYxKX9gPswWPRBSCVyG0D/184rA
JMzkG6TpATdncnrISB4YZ47nxD6dBO79BL/Q6DfAOJ3QI7mTBtz8VR6n1FYB
I6jKTOiKFXBL+zJaI2yB4XZ692YjYeA2RvDThq8Dw5i1t+VNLXDHT99gcGTA
cs7VSdh3BfDktPMXbdQCy7BJ/ROzi4G3XvVL4KgIWAYsaFOd1wq8TdLxLira
YHl0i9TbJhXgKdc1twd9BEun6+ZXGS+Ap5WzsWxxIlgSaTqmibeARzr3bG1/
JlgusdrpY2UPPLOxtEWzymC50PLD1NavwKPu/pV31hUs/nI2cq/xgGdR2F9T
9gEsPqcEXLiaAzw7G0bt13qwaE1yNVL/DrzDewJ9MrrB4tpli6Xv44HnLpm/
dHswWKRRC54v8Aeex7jn2LoZsDgrLBLergs876hGF08qWERf/HyyFr/n5907
LVcCFl5q2kZzhcCL1EpWjpMGi71CPWd6Q4GX9rlu34+bYN7oGPHN5jbw0sUy
JgtTwLwqyi3dYiPwLqu06Uimgnlxgc454xbgXbV3OZHUDeZZ2nIQ/gB4GWes
oy2ywDyk9nO0ZSLwcthNpJ4tYL7zd7FoFRt4d42vf7mrA+bbm+Luj+F+clW5
hZGuYL7xv9vPWxSBd+/bk9vgDOYr+d7elWTgPbRv+0hjA/1T5cvtD4WBV5T1
pe9mN9CzZi6U7nsDvMfOMw2r9gP9qjtNLj0XeMXyjtM1q4B+bmiJO/Ui8Eri
XcyOLAR65DcrqcPfgFdm8mEv/TvQnU8aNeyfBV6l6fDVQXugb1w7nqe8C/lt
+kw4FeiyUupenhiPqqOiPfOdgb5qte8N+yDgVacocb/tAfoCjVfzlMKAV1P0
SSv3ItAGq5QigvH+669U//aqAdotxqn5sxLAeykmJj/vPdCujMOB5gnkYG9l
ZjLQzseN8fdaAK/BJvrIS3ugnX5bfnrICXiN3zw7uFpAc+vUqrwQDrwmqzeR
j92A5nxr6MtOA+TCk9+ZKkCzP6X4ah7u99XRQ1pKdKDRdeSfs+qB97qd+Z++
F9A053+YXo3xat5as+PYBqBtX9inwd+EHBhza40J0BSXiRssw/xskVui934L
0FarL+YSvIDXSrbV3R8N1Jmn66aYy4DXblvla54K1OrpJZdyPyOfzaySqwfq
U/aRAcfTyI2LEttqgVpUEVbXyABeh56F+w1FoOZcj3twEPOvc7HVngtrgJp8
w9x3xWPkXYFZhBVAjVPf0/1KDNlZ24fiA9SISr6eGOZ3Z4mf6FUWUE9M7z81
VQK8LluW1R86UB2yOjt/iiIHOo0K1tvwrA9Ti5CvrVmxYBColnKL+xqOIg9E
aYr/BSox+91mfgzy3N6Ctx5ANTz+988zrI8363LajGWAqk1SKznXiMxMv2ut
C9TtM48zf/+H7Ln5ySEA6ubehRY6v5CjDksJdQBVodL0/UZt5DxFmcPaQJW4
kuOcq4dcc+1z62mgLk8pJl2cQ37T57oTfxdOuD13sA/57y2X3qVA+ZMkfuws
xqN7uZ9qFBEoP1brP8zfjLyu51/1W6B8vim87fJ65G0dVm7pQBnZdXh+TDvy
Htd7j54B5V0j22NJKvK+cyedlgClx631YS0XmcpTbHEASvvyRhXDQGRW3epV
v4HSVLjXhL8VmdOSO20BlDqXjUE7C5Adwwh74oFSKX3EYaAL+UCHis9loDx5
LX9aHeu327W1kDEfKAWJyrcD1JDdApWvbgPKfcvosCtNAm5+To4Byh1ZjcGa
HuTDHXWJhkDJGFmfq78W+RDf9ScfKJef0Ju2uSI7/+o82QaU82fzTY8K9suT
2RvnApRkH/I23w/ItlO1yvh7HEs05aOALSMSf2oDJVJv/P75L8imLXnGH4AS
rDxaZoL51204QFJfCBR/2X/CJzWQtf7jXqkHytFV8iP7sB66t+wVcjkOFI8V
pnVr85HXpO6l/ATKQbHjckVnkZc8EFc8CJT9Upc821C/38yknmhXBAp7fQFl
ZRzyKMHVA+PN0nhqVSmH3PH0jQbeB934vl49EblKpCiXARRTXthjTw/k/zZO
POsCyr5g9dStv5FDX33R1wXK7nqhhrUYvzeuB0+lNgFF45fCjOh+ZHpbZzQV
KNuVZ7ftPoEsA7QAAlAULo0//eyL+frHaL4dPr+me9L2Gx25b31JtjlQJBWu
8gZRv7quRO6b2wQUkcLhmzY5gnpYGheaCJSFoieO8/H7XXb+dX4HgPxvf1pP
I/avLvGln66ygfx1XYzEE2Wsr2MELjMPyD31rtumtZDNlGeVjgK5w2i+w6O7
yPLzS+LPAPl16cIUjgnWc3VK++VOID8vV5ufNYW8iPvxzwkg35+O06x0w/pv
FemUogE5J6X74MIs5Gt5G2ErkG9puF3nf0TeLXK7VRvIl/z3HHI4Arw264me
ljYgR+lMj1RiPrWtv7UsUQjIofS7DoYYn9bR6JSrykA+dXBy/fNVyP6Nko5d
QPbJkHcfLUe94kffvsoFMnffI15BNepd8qUXOW+BrL01qrvuHDLN/+x1PK+W
b8alcxXIomeS8kuBrPZcum+LM+plyMkVS2WBvNlz1lRXE/XUSYd00QDIq4bt
g70aUI+FLCtftoDZZ9/ggOvLUa8LWFO8nWA2+uPc/clp5AMZurnIQ/7NFmGH
UO+r5W/uWAdmvTF3wtxR/174F3aN54BZfWPM0Q8LsD9UrLewY4BZ9ujBsHmR
wHvW5jJ2MRbMXKxKbX9hP3x2qGOl7m8w4/U6Vt+IAl75TNLabx5gxjlIm3TC
fC6X6/Xa/RHMGBETfDXMvzLOX/sjpmAGQ1MMP7y/4iKx+dEPwEx+H8nDCOuv
eO8BZckCMFvz563VaRb2x9qVlxemgpnU4zjHcuwfRW1uyRorwGy53mqFCOw3
BcNg7a8Fpn9dcprc8fwPP6/bnjgIpj0kysy3V8geG0/N+oBpp0bfGhXspw9G
40Sdp8C0Vc5ab8Nr4N0fDLmd+RZM62d/NO/FeN9rlGE4LgfTkg/XxVbj/d+J
Or+5vRBM0/dw3F5dAd71GMOd5bpg6jAyq+KM+X3tp+s+0TYwZetLF/Ax/6+5
LKtJXQam1mfyLCdQv68a1NrwaWBqTnQyvI/1lD4ubv0+C0yh1qd3HP3UBVX3
MSk3MFXcF/qsGvWYz7oTW9oGpE+zbr6a2N8SHq0FxxEgjV4p+gonkcVXT2k5
AenjXpI5fxB4cS/vTWtdB1J/rOLBc1g/MXoHn5g/B1LLnluZ5CrgRSxy3LyY
CqSiWW332/OA529iZtbQBaSozbkvBiTRT2Wkfti0AEjhe409UlWBd2I2shN9
JCmEfavDEn/3LWB8c7MF0snzj0c1MJ+OyT9YRRIBkpei0LN49F+eA/e2GrwF
kk2K3E5zvA/nTRdDkhcCafujD1ERLsBzOv7b1iAASFuFZHbe1geeY82i9f+6
gaRkNeHdjnq4/5BSUCIRSOtn/df8KwWew60kFTgPpNVOk5ocPI+thGpa40kg
zff31tTEfKA+0la4wwKTribmdhe8H8q4pMUPazDpkB3tnRJC3nhh/81jYNJ6
mNCt+gz9avLZra4tYNK0VP+hEfYLE1fX+z6NYFLlIj+xzQx4IFz9WukSmPzn
mpLtgP1La/HvaaINmEQ9GtDww34nI/FnJIAGJjpSG1JMsd6lTVa3+smDye4p
1xE21vdqv6modbh+Z8OfgF14Psnugc6OODDRiJ1TULcEnviVYu+kDDBRlnDb
bYv1tVTaPdhoB5hIO6+X8UZ//6+nZXFMExj/nHros2c1cAcfrLoX4w/Gxen3
miW4wH3Xab4mYQaMixqVfp2XAu7ALOu9jRIYF8zliZ8wBG4/pfRPnj4Y5x36
cy/1PHB7PixQflYPxneNKVEvPIDbvsTPRtkZjK9o2mgFLAJurXrZW74FGIe1
LOB+U8F5ZOCD+4gUGNNFNBV9zwL3zvCDOeULYEy1eXGRMAPc25+J6wdWgDH5
9smAaRngZs089a0QAmMSTeFnXjVwb4ovVj5fA8Zw07emQhu46Zq/XO7VgbFW
RKHL0izgxtNETpxpBGPZFTsKXfOB6/a2/OeJ9UAc21rRrdoH3MOjweG9r4E4
0rrjhet24Lp+F2teeR6Iw0G+8/8kAveQSM7k7iggfmg7lvz4BnCd1avbvrOB
2J9AnLvRDFyOb+p6uaNAbN/YNSF3HLiUgYVzSvJAfDbSIl4QDFwVreW1BzcC
8VIFc4VkGHC3yx1g1QIQ0yIq5AklwN0mHH+mLxeIF0mia6STgbulh8j85QXE
c68Vx+dh/DaFuoY5tAIx+VNw5+Bl4MpWnE5W+w7E0zTmlVhr4IoqBBlnBQPx
eK75lg/V4DBE/QH+C4BoWfMTfsyCwweNO9El64BoUbEreEMYOLyX3KE+juc3
L93epaYGDgPdJc17Y4BIy9d3wLnOoffAY5vmGiCa5Q6uqVMCh9ZjLnEX5YBo
VP7J+XUiOFR4ll8Q+QRETTfX8xt0weHygGmT3R4gSpVJm2UeBYf0htk/PZ+B
KDn1727gQnC4VJwsm7sMefORnEN/weFiCsHoHO5/VdKPIy6rwSHVaKIuXAeI
Yu6h97ZOgUP8JVuolgWiqD5nS9IKcAhQv3VqrTwQ/hEsGpdXgoP1hLy03Gsg
fOzSelllAA5WjzMPK04hy8du6vgKDqzIeUc5n4AwdODI+Pyl4MCQ1SmNvgyE
99+nzuVpggON+PDe2iNAeCdbKEZaBw6EMyUNX1WA0BMmdj94IzhoLKPnXS8F
wuvCnxVh7uAgEklylvMHQmlRTxtbBByE2Ze6Kt8jb3M6NhAIDos16vWvtAPh
yRVbHe4WcFjYW9q52xYIJZHJ9n1+YD+n+SU5PgcIj21V17xXAfsfXZdqbr8B
Qr7EKO/sUbB/L/K7LMYJCHd7pnuKx8D+XXfj2ci/yJx/jSKPwX4gNzgpWhMI
Ob1uZpu/g/1b8+NzOzKBcOdtoGRdJ9i/OfvoPb0LCNnDQc7VI2D/WiqgX3UB
EDKX1QdNioJ96eyuWyb9QLh8U4N4fgDsnzycPLE9ElnJOKv8HdiXHAixjckA
QvqdJp95smBf1LDBKvcEEC7l6ZA8l4B93gUvqsYyIFys8zRZvg3sbyupjD5c
A4RzS9bo9aeB/VlFo3M3VwKBP9B7+vkjsD/TUr7s/VVkn9HKtWSwTw5bdSeM
hbzQaVRsCuz5ffrMh3QgJGy5KPl8PtjHnE3zvoLr43yFkzsywD7od8DbSh4Q
Tm+q6y/B9a4Zbz5a4vlCX5keUlsA9ocYdp9fuSMfUdk03wHsD85/mC5Wgyzm
I3t5Bdg784Z7P9wGQoil3ERvOdhzZY/8WorxC+r6F5yoDvbM0xP/AuyBEDCT
7fxeEewNiZeFNrOB4BtJKCjC+OtPimmY4fO+6p/UhfaDvV6a3ce7K4BwvGcy
tYAK9toTvhMZ+ci7FjtKCIG91tk6wlV8/ui41y0hPL9yV9s0E9nbdc52yBPs
JYiRbePngeB+qznrbh/Yr5q/9cmGOmRHZ9PCLWC/suwugaqBLGfYc3QT2K/Y
TdRqjwWC27lWva+DYC+6udHTCs93OM6j/q8ocGZn9b4twno4FLZvv30/cMZS
gyV6Md7Omcdt1NKAM0rN3z3ZgOz659fvFuCMCNXUdtkgq9Z9uiAJnKHjYdsL
nwDB6bGmkVMicAYY5JryC0BwfG2YW1gLnA5h9QvbS4Cwf7kCo3cSOBXWOxjP
8D7si0XeNtUBp3zih3kwft8+LFe/vAo4T6OSVMtTkcnpY0e1gfMknxghgfnC
6eNFy88Ap1CswKAD75+z+Oh0+Fbg5DzNJc/IAMHuYObAAyfgnP3bHXGkDQjW
XJFHXkeAk5LEuk1Zh6w+mGD0EjhnNmSSqmaQFyx0iNYCTqJx1chxCyBYZa/Z
1/IDODEJQjSxj0BgfT+TuOYYcIJWRvuWLgEC83KySP0b4ByY9n33sBsIlgpZ
7UN4PpdrWkkWVCBY/E2InH8bOM7ElxXvzyK/uXtTqAQ4+5Pib0eJIqeeywtp
AA5nk5ncDi/k5VLJc+XAsSAUZXKwXsxFbhtWzQMOfXidiBoyfVRqQnIzcGhx
7OI6IeQXT5Y5YjzIrw/+FsJ40+PvKvh3AceYXXKqVw55lYLi87fA0XUle31c
DATaVj3t+2zg6Iha/pExQV4urud0Cjh7crQukfF+qV/WlWxYDZyd41ELQrAe
qMWt9/8wgaPusV9MciEy7anc0gngKB78lr+3AwiUEDf5nbuBs2KvL2XxCBDI
ombDSmPAWTaYb9MfCgSz7/M+vKUAZ2lUk+8P1Euzt8O3fhcDR+Tl2fYO1Bez
AuKCSHfgLLRyehSG+mXmsktGkwjs307LWYq4H9P6AU9yMbB/LfjD34zxNX0c
nbbnDLB/3Kw+V0VGzmI3WkwA++uHYaGvz5HDEwaORgB74oDHB8IZZAPJAoN4
YA/y/D+wUY9IJemU3h5gD8yukipDvSLdldr53RHY/Zejmu8lI6c/OdZ4BNi9
XX87jw8gByWctuoEdqeF8pV8PWSCofS5HGA37Dm2UZQGBJOO2tOrLgK7vjVv
oCkP+cWMSeU/YL840vDufDxymU2emS6wa7KTzidrI2embAq+CuwKKXOKNMbH
xHdB4thvYBeMPirZgfpvIleSzZUGdv4Bjbhi1HuTVQ+SKtKBnTcQen4h6oOJ
cEcl4ROw73dcIkx8BYLx10dhpVPAvvPsES37OHJ9TjOfCezbui+IPS7IFQo+
WX3AzsrPIwZgvhsXVVltGwf2zex/BM8HyLcuOn/0A/aVhBMJFKwP44jjKx+4
AvvyIkUJ6STkUzx9GzqwLwVlehUGIB/zzz60GtgXvOTijPD+jV12lcT1A/sM
deqSAeqPMamdnk8CdlL1TjHf9chGapNblYCdqEdWvAnIugWNd72AHa/8WVIC
699YjVz9RQXYUQskyf4HkaUTFY5VATvC79OCJxzkVXTNf/h82MR5xVePkZfr
RrX8BHZwl2PcL6wH44UX3KrwfEG08AoCnoc4J1x2B/dzqvKEcQvqB3HmZrP3
JLD977bJTdxD/soty/oFbL/1hs6xwcifg2x2nAO2b2pATxTqCXGsVqvNG9hH
A91MgmeR3/fqiDwCtveU3HYnrDfiQPamxcLAPuKcoeQlgtx3ueUbB9ge5I37
kjcid4kIvz8ObLcyOav9McjtQfQb94F9WH3MsQnzj9i67m1NE7APZcTuv/MZ
+fXHNDNjYB+UnCGXoV4Qm7p5W6nAdjltINOI/oPY8FvcG8/rNG1ZlY79jPhy
75md8sB2dNcmDBgiv3hQnoz5y+udSrF8ilxHCbq3FthcekD2tWjkWrHcJx7A
ti/vCDw2ifz8n+pPzC/ODiHRYyMClhi8cR7YdhkLSYaC81Yzc5ctAbbtqja1
I6inxKpSd74BsK0jThSlXRcwfUE0H9isb2M9tM0CFmE4zQCb6aKRIiH4fuW4
/oWVwLacnOf98JaAv1/Zh2xxMrstS7Dfqg1KSc7ANhdSKmoTnKfKu7yyDti0
xCBJ2SABv7fYog9sqkzOe6bg+Wr/8hUDwCZnPFBgfRDsV+Nb61Jgm6kkVHzB
eiXWLG1vUwM2qRCqf+0UnFeUenIE2CZ7GzaqnxfEY+teze/AJr5Qa91vIoiX
+znfrcAmMFxbyJg/xPrXu8v8gW3UEyBzt0UQb5slSagP4OJ0Xf8lcuPcbz/M
B8OJjU55+5Bf1Y8sZgFbb3ZLiIib4D5r3KLygK0b7dFgwBXc98+GMtQnnRWx
unPWgnwwfbUd379bnuScuUKQL5bMyC/A3nlrdOVjQbwHhDMnC4Ctper4vFwQ
78H+XYmYvxp6Xart3sgjXx7loz6oVba3/kA9J35S8f56EtiqZjmum9GPEidj
ljX7AHubdRfcxfoh/rwRqhIAbMUjxjND+lgfi9n5gy+BvfH7DJuK+m28JK3m
dAawNwREHdMqRF7x++dUFrDloxQKx1DvjGWkWTcOAlvmonN99Q/k7c2uP+qB
Lb2uUU8e/azxjhUdQpeALXVjuboFEXm3+80cd2CvurMyRjJFUO8RCzZh/i0r
UtRfivVkbKe0R9IC2Et1jZbtEOgNz17iF96naNnOre7ol40PPEj9DMBeXHlF
3RH7n/HRgs10vP95L09mmQv0KHHr1LunYPe93XrNWmuBvt17XW0Fdt923Wt5
gv7RuNXnmXoc2H0517Y0czlyr83PvWlg99kqviNeoCef4579zQS74Zbsxq/Z
qJ+S0VfO7QS77qpY6WZl5INl3z+0gd2b9dWH76B+mvhcvD6ZAnadQY2Z9QI9
DjxbubcX7Nr2mD0ItUNOGfsSoQt2jdnDYv5YzyYVa95uswG7ZyH/ObsrYX/Y
tH94+j3YPX1T9WQoBFljV4CJBNiVaWU5zsN+SjJQfjz0COyKP7Yeno/5SbJx
q19wDewekV9a/cZ+QOKzNz/YBnZZoluf7JxAnm1U3bYc7OJ5NjObxLGf/TLy
XkADu9iSdt1a9JNmwq57Fg+DXczq9Zz0o8jSd3btUgO7yIb1kqcE/Vb75JEy
ALvgXdWwawz5lMXS+lGw8547b2mA+UheVH54bz7YWXuu9tbGeFFUvnulYXzW
35PeVI/3QSvXsw26AHYKMgPWFIw3rfW/UJo92MlFngoc0EUe0RKu6QY7Wc6W
4LQD6DfEjwzrzIGd5GIrAz3cL92lsOrJE7ATZs52i6Femq841G+gCrYTDfs6
e/ei3/F89eWiCtiWqOnSj9Wjn7KNeV4ZDrak1OaV97Ffsel7RvZUg80bpQMG
oxhfR+ZXifiNYHPYjaom8PuuXmFbLHrAevw7Kz0D5ytvmdqwZF+wPnr26kgv
6suJb1xKmzFYe58Kpviif/NbKaP9PhSsvZyFdzVjfvqp1GlaLgBrtx1SS24M
Ih9cMm9qB1g7vlgXL43669clseyVH1hbjBRvFdy3f8m20QxzsFYbksjkY/8L
8P36OZEJVqMvlBV8m9H/1/41HEoGq+HyHarv8f1B/b/PX9IFq6H8oSt9BORf
I/tvaILVu2sWwqamQAjekiGRZAVWb7yVir+eQo4O9JRxBKsX8x9Pi0rhfGH0
rHQrvj/7PWuTTgXOH/8p/Uy3BqtbTadivTF/QqtP5I39BKubxWY7gl8gdz/e
MhgNVtf4HWlCm4AQJrxyUUo1WF3QzJ8eiULmrZKyTgSraHe7tRlYj+HLmE+P
4HqX87Mvjz0DQgTnSMN+WbByCiO8lUD/EHHkBP3wR7Da7666OQnjExHhGdSe
DVb2BuOX1LA/R9xVffTADayY/RLzb2C/j5j+rujkDFYEsUEfe4x3ZGqiV1UZ
WG3Ypn6Civ0zqixTzWwJWCmIXFWaxH4S9er222dSYLXuY854EvqlqHeXn6RW
gpXMjSv9D12BEL3I8iXvCVitXPX+gQfmczRl8s9TFWDNDj7bLo/zTHT7Vx/S
IWD17tbte6aD81xvuaF2ObDedBVKm+L+T0+MHtErAVZnQMHInu/Is7ObXuH6
lrJ962u3AyFm/ce3X/8B64V+ZMIn9CMxzvniY/h84SZPDRmsj5ihHdskIoD1
6OnyCxaYjzHf/84J84H10Fb1vifqV6xQnr/xX2Dlxo3nyr9F3tS9frwKWBlj
Vh2liciOso1F6sBKSk7L0cD+EdtpVReYDSz+phWyPehHYocK4gLTgBWX//fn
B9Tf2G+za7q1gBXVaXqmAvt33EozD1VlYAVK8a/vqUUm1fo8jgWWq3+osvd/
yHlW+Wv2Awva/X7LzwNCvK9TZaE+sAzDlDuvYT7Eh86ffW8GLH0VjtS4M3Jc
/J2rkcDaE7bPsRr7R/w1riIF96+2WUJoDvtZfO3sTeYvYK1l+VwX+YXzs9Tm
hPqXwJL5vfJMBvqbBPlDBDMhYK1O3x7CeSWYr1NaHscAS7y/dUTKHFkn25Z1
DVgiTkNCpRHI9s+FpIuA+cO86E6zYP3VlyoBIcD8Oja+fz7md0JWFjWfAMyp
qHP7zmN8E/5zK9GrAOZ4MVnkJ/qjhLL7nJo+YA7Kqrz/hPqd0KPUbKkEzP6H
wmYjl5AHKcdxHmX2kVi1tZXIo3Yb7x4CZtdRkl9qH/Iv9fD4AmA2VYSGta8F
Al+81rspB5gNzJHIxt/IMlpn9ZYC88XQM3d11Ee+fEz4hT/AfC781FAc/Qx/
26c7TxSA+YT40TFWFXnfFVJGBDCzb8b+u7oH2TPNIVsOmJm/ptwzHiIf/TW7
A7+XQbmVsg71ku+v2/nDGpiXp6arbgu+H+4pOfACmClaOndYqLf8c+F1nZXA
TApf9LrfAPnSApJqPjATXq8Tv4TzOf/qgVKKODBPuykGN6Af4md1ue+5D8zA
c6l7Rq8hF3os1GQA8+Tb69x6nI/5JUu40VnA9FP6UrcS/R2/LOHYtXJg+hQ4
Dm3eglyt9x9TB5hef0JsTS8i17o+r3QCpgf0J/iXItefDLh+GpgHXxzI1V6K
/Nr4hkMYMF2WxZmf/IncOn9R23JgOtInN23DeZLffu3T6AlgcppPPDuC+cPv
jtm6sxaYduIXddpQ//m9zT6NGF9ri18EI5x3+W9nN73YCEyLRnd2Lt43//38
u80HgElfErKSEY78oevEqiBgUkwab9H8kD+mpGz4BEzTcGu3VtQL/oj6DFcb
mMZlMg+XeiKPPrhjZAvMfb8kakVRL/jjkmmOgcAEDZOZRvT3/E+c597DwDRw
fZgGrcgT0cqGbsDUvc74rCW4n89nSwueA3NP5zaiHeoffzIyqP8GMHct3z1E
Rj3jT9keHJQBpuY+/zUBxchfxI7NlwSm+okJZUNBvL7cuXIV800l55xNNfor
/lelQV11YG7tOzKx8q6AT+sfowBzi1igyjxNAdffFsb7UoRiG9w38pf1rfj7
Bh+lB0wVAc9ktFYDU/56lV94goCHt21WBubaV4njw3wBFz4S2gFMmX8xFKfb
Aj6s04T5uXrbfy2XBP8+9mX2yfx1wJSwmV/6S0bAflr6eJ6V4aHEm8qC87Rc
M8J8WH5va0aU4PeplX++HQHmko5/KwwdBefXNLHBfBOem36qLCmIz+5TqbeB
uUhZfthihyB+chd/sYC5wNy97ISLIN7D6RORwJjz7T8min6BP5YaLnoLGH/T
T+psuim4H0WzBWLA+Plhbf51Qf4MffJZYwqM75Kh2c87BPetyhP1AMYX4krn
K4J4DjK0CtOBMX793lKjEkG+kOLDO4Ax0viYWyQhyCeZZWvIwBiaHidvF7zv
TYOXPQMYA+bVd2oE52sbaHOnAqPv5OGAd4J8aoGOjnhgdGdoXhnEeYz/KvKx
mgQw2r6oRdo6Ib94vDq6ABgvIgvU2V+QSxv3VZwFRk22y4/TgnoppuofMgFG
1QtNQ2H0E/yC+6ubR4HxdMmGlmM4X/L/W+8zdRkYeWH6st//IV95+PHicmDc
v1y+UgL7ET/NYkn0MDByi2xt/QX7SW1Ze6UTGFmj9arZucjx4StetgIjnZB8
oRPnGb7fmeht2sC4aHN3IElboCfmPHkZYJxza/+YKagfjy8GG6qAkZTI2JuL
/Zzv+E766zQwIl68ZhYJnif7VOh9BIaH+L/A3YL6XM2x+vEYGIdXx5MbZpDF
OBXNLsA4KCvNmsb5jS8CseedgLFffnPRCPanhOkisvsYMFhr/p6WXyzQW7bn
Szdg6PWfeeqL80hCWvC3mBxg6AiP/NiD+ZdwhleUKgmM3ermTWycvxJilT+v
TAaGxilTl1fCyP7HO78lAWOzcF1WLM5fCVbf8v64AmP517UOx3CeT1h2fmjr
TbDsF6IvlcX8jXd9aRI+CZa9y8IHLqFfjndolk26DJZvJG46ncR5KZ5RIWxX
BJat8hmsUlwfr887Oi4KlrVbjj1n7EJecfFSSR1Y3l+oe1cf9Tbu/vIz3G1g
GfTGx/4u1m/swPWsqhywDDi54/aqJcjNE4Xx4mDpJ30iWx7npdgqxdANi8HS
2zzaPPId8i3zvoexYOl0L1TqrB6ya4bWx1NgSZIfIzg3oB8Y5+hMlIPliprG
Y5PYj08P+gsNj4HFRX7MdrXV6GducTmrlcAidWbazQHvKypV2uv2frA4c/CU
90WcD6LCGwzatoNF3J7MfdtPIu/fFllmBhanKre0qWN/jpKt3ndyJ1hwj9df
29iOfiqpZtfSALDYuPPhJBfzKyJQ477wJFjI27drV6C/inDfXe6oBxay4dE7
Z3CejWCT7utOgcWqmqCtgZhfEdoJWdfLwGKhhpqL/Rz6vx/5A1FKYF67tGgg
Bf1l+DHpbHc2mJeLPBxmYj2HO6/90TsI5kXzpEzfYr8JZ+4+tLEezLP6hrp/
fUPWejB98BGYR7MIU97T6C9/tOUoeIA5UWF6UR7297CQDE+NBjDXGw5dF+WL
7FPS5rUBzLVuv860xX4d5vzza3kEmG+SOXN5JdZjmOnbYI9AMJ+f8zb1JM67
YZKxskr6QJ82nNXyXyrws337ffKAPtVwaHQmH/3uH65+1hDQ+1va3mXuRx4c
S6k/CvSyhE3HmTbI+ZZrC4aBnj+SqTashXxHla6tAfRcg75CV5zvQq+C36s5
oF9qUfEyskeOFT+wuxboKeJr9isI/ntAcMvqJFGgx5p6XQnH+SX0+KtLJ/B9
ftf++bo0ITueppkbAt3r2dIOc4EftyXelYkD+oEulSVB6E9DzY110hYAnTlF
WuhIQTZcfftOMdDJUxJGMxnIu8bn1RgB3Wg41eg19ptQNdGTOi+Brl7GiOpB
fxOqoLKlOxDoSukOl0KwfkJldiqV9wJdzrt4SWo/sji/S0QX6JIG5JB9OJ+H
LtXTe/0f0JfO+7U2W3C+RYYOHxOBPv/JzZNr0f+GzKVZK5QC7ben1k0K+t+Q
Gbpp4QqgTUrFSwr0NOQH72CWP9CG8hPuN+P9h0w1fZZIBlovWfaZFPrhkE/X
tuVKA62lY/WUFOZ7yEjLCSkloL2wdSLFZyIPuWvb3gRa+eu+zZM4T4cMuo/Y
qgGtcO8hA5/dyP2dy4ieQMu92c8vVUPuu6+7RhZoGbOK3NMeyD2/ZOSXAy2N
LqHzuRC5+6GDJx9oSWdjPqagXwt5M9ASiu+LanJ0DEwXcIzlUwbQTs36dZZn
CDinTroWaEc3ZV3rXS1YT9l1oxxorga1mm80BO/3+E/PA2hcat5maRnB91ex
ddqBxrLYK99iLtjfXj9ZXE82JbZZY78LeffLdm8j0GDnxX/dioLzGRx6qA+0
3VIrzYVQj0JGpZTG1gNt+2iw14oLyBPh6rmFQNvwsGAsDPMz5GvMzncUoEl7
xmgl4/2H/N6+MPg80Jave86fwfoLmfWKCNoFtAXlBqKhjYL7sn7coQzU36xS
33ZB/i0brubfA+qn3y1iX7F/hUq92/dNDajv+Js8YhYJ8iNXahsfqB3i7uJ9
+P3QbbRZXzGg1kc5htd/FuRXwxeFJqA+HSnbeg79WOg+9ZVRa4D6SE/TKMtT
kJ8Bj7ZuAGp6rpru+1vIHiOjZ/YCNalevKkjEDlojeGgI1Aj2usWDqF+hibS
r+XoANW9wLQr8Cvyo4/3X68DKi+GnTyB+hJaZyf/9jxQmaSGN2sF9dQ3pbBD
D6i6cYbtOejHwpb9F/nqKFDVlrm/zkW/GLZ5RGwfB6gbTjLPZmM8w8AtyCcI
qCLikQGfcT4NO3lULbYUKH/0ep7UH0C+uCzEvRYon81Fk+twXgp7vKY7KB4o
baotmYJ5LexvaayaAVBqflvNRNajPm1wC6wZA0rxnZDT57B/hpNK6/SSgHK1
zEZ9DPUnPC3qtFogUA5dzD6/AfUigkndd+MdUOyixRcdQ38fEf1UtC4BKBRW
4prLmF8Rpcxiwf8nqHbGIXQR5l+kmk7UZlugKPx7f349zieRbo8Ozg4ARZz0
PkgQ/8g7me/E/IH8zVvHyB/zP0qdznXdAuQPVCeLrcuRT+h4/7gG5Pb5d3Kf
jiM/W+DmMgDkgq8pV8WxX0fbZ7L8PYHsW1OeZYTxOV1WO1dUCeQDxmqQifNB
jIL2ZF4+kFnJOdK1qAcxkdlJ/CQga0YPRKdZYb+y179W8gHMxh9KL67B/Ion
GhWt6gGzN3buqq9wPoh/Gb9gpAPMako+2Fii306wLWTeoYHZ9fRD9Ne4nh8t
sophCGYWvP65OYxX8p57xRUXwEy//t6fvei3ksermXddwEy5886nQKy3M7el
97YXg+lchdq/SYzHWb08xbYRML29lL9HAvvn+UFKxsHlYJpcpZjShH7zwnj6
s+IxMPV/48CXRb+ctrDV+VAXmJp8/Gk6Tx0I6Qdb+RQGkLrMt5dRTgHhhvro
ZLstkIprTDbUYr/OGF19U6gDSGnPbqyysABCZq3Ovst6QGJpDC/LUQLCneXP
1a61gUnmTh7TvxkIBcZ/b03yweSwQlaA/xogFL+pz7ByAhOFuqDXKp1AKH83
UxFwDowfKv5kimD+vHjayzyZBsb2lKs3luP5m3/4Gm1R+h/uTwDb
     "]]}},
  Axes->True,
  AxesOrigin->{0, 0},
  GridLines->Automatic,
  PlotLabel->FormBox["\"Path of K - par set 1\"", TraditionalForm],
  PlotRange->{{0, 130}, {0, 120}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.467463016031364*^9, {3.467463456383997*^9, 3.467463462932336*^9}, 
   3.4674640557325563`*^9, 3.467464136860861*^9, {3.4674642550128317`*^9, 
   3.467464264116076*^9}, {3.467464919937768*^9, 3.4674650180741*^9}, {
   3.467465822541086*^9, 3.467465832788904*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Animation of double-rocker mecha par 1 (\[Psi]\[Rule]f\[Psi])\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pa", "=", "par"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A0x", "\[Rule]", "22"}], ",", 
   RowBox[{"A0y", "\[Rule]", "59"}], ",", 
   RowBox[{"\[Gamma]0", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "57"}], " ", "\[Degree]"}]}], ",", 
   RowBox[{"a", "\[Rule]", "47"}], ",", 
   RowBox[{"b", "\[Rule]", "52"}], ",", 
   RowBox[{"c", "\[Rule]", "17"}], ",", 
   RowBox[{"d", "\[Rule]", "35.5`"}], ",", 
   RowBox[{"\[Kappa]", "\[Rule]", "0"}], ",", 
   RowBox[{"k", "\[Rule]", "58.5`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.467463016157563*^9, 3.467465623922567*^9, 
  3.467465843090315*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"f\[Psi]i", "=", "f\[Psi]"}], ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rA0x", "=", 
   RowBox[{"A0x", "/.", "\[InvisibleSpace]", "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rA0y", "=", 
   RowBox[{"A0y", "/.", "\[InvisibleSpace]", "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rB0x", "=", 
   RowBox[{
    RowBox[{"A0x", "+", 
     RowBox[{"d", " ", 
      RowBox[{"Cos", "[", "\[Gamma]0", "]"}]}]}], "/.", "\[InvisibleSpace]", 
    "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rB0y", "=", 
   RowBox[{
    RowBox[{"A0y", "+", 
     RowBox[{"d", " ", 
      RowBox[{"Sin", "[", "\[Gamma]0", "]"}]}]}], "/.", "\[InvisibleSpace]", 
    "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rax", "=", 
   RowBox[{
    RowBox[{"A0x", "+", 
     RowBox[{"a", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[CurlyPhi]", "+", "\[Gamma]0"}], "]"}]}]}], "/.", 
    "\[InvisibleSpace]", "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ray", "=", 
   RowBox[{
    RowBox[{"A0y", "+", 
     RowBox[{"a", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"\[CurlyPhi]", "+", "\[Gamma]0"}], "]"}]}]}], "/.", 
    "\[InvisibleSpace]", "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rbx", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"A0x", "+", 
      RowBox[{"b", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Psi]", "+", "\[Gamma]0"}], "]"}]}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"Cos", "[", "\[Gamma]0", "]"}]}]}], "/.", "\[InvisibleSpace]", 
     
     RowBox[{"\[Psi]", "\[Rule]", "f\[Psi]i"}]}], "/.", "\[InvisibleSpace]", 
    "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rby", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"A0y", "+", 
      RowBox[{"b", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"\[Psi]", "+", "\[Gamma]0"}], "]"}]}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"Sin", "[", "\[Gamma]0", "]"}]}]}], "/.", "\[InvisibleSpace]", 
     
     RowBox[{"\[Psi]", "\[Rule]", "f\[Psi]i"}]}], "/.", "\[InvisibleSpace]", 
    "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rkx", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"xK", "/.", "\[InvisibleSpace]", 
      RowBox[{"\[Delta]", "\[Rule]", "f\[Delta]"}]}], "/.", 
     "\[InvisibleSpace]", 
     RowBox[{"\[Psi]", "\[Rule]", "f\[Psi]i"}]}], "/.", "\[InvisibleSpace]", 
    "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rky", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"yK", "/.", "\[InvisibleSpace]", 
      RowBox[{"\[Delta]", "\[Rule]", "f\[Delta]"}]}], "/.", 
     "\[InvisibleSpace]", 
     RowBox[{"\[Psi]", "\[Rule]", "f\[Psi]i"}]}], "/.", "\[InvisibleSpace]", 
    "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"lmax", "=", 
   RowBox[{
    RowBox[{"Max", "[", 
     RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}], "/.", 
    "\[InvisibleSpace]", "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Plo0", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "100"}], ",", "300"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "150"}], ",", "200"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Coupling Path par set 2)\>\""}]}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{
  3.467463175087881*^9, {3.467465353479857*^9, 3.4674653629230633`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"PloMecha1", " ", "=", " ", 
       RowBox[{"Graphics", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"rA0x", ",", " ", "rA0y"}], "}"}], ",", " ", 
            RowBox[{"a", " ", "/.", " ", "pa"}]}], "]"}], ",", " ", 
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"rA0x", ",", " ", "rA0y"}], "}"}], ",", " ", 
            RowBox[{"lmax", "/", "100"}]}], "]"}], ",", " ", "\n", "       ", 
          
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"rax", ",", " ", "ray"}], "}"}], ",", " ", 
            RowBox[{"lmax", "/", "100"}]}], "]"}], ",", " ", 
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"rbx", ",", " ", "rby"}], "}"}], ",", " ", 
            RowBox[{"lmax", "/", "100"}]}], "]"}], ",", " ", 
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"rkx", ",", " ", "rky"}], "}"}], ",", " ", 
            RowBox[{"lmax", "/", "100"}]}], "]"}], ",", " ", "\n", "       ", 
          
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"rB0x", ",", " ", "rB0y"}], "}"}], ",", " ", 
            RowBox[{"lmax", "/", "100"}]}], "]"}], ",", " ", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"rA0x", ",", " ", "rA0y"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"rB0x", ",", " ", "rB0y"}], "}"}]}], "}"}], "]"}], ",", 
          " ", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"rA0x", ",", " ", "rA0y"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"rax", ",", " ", "ray"}], "}"}]}], "}"}], "]"}], ",", 
          " ", "\n", "       ", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"rB0x", ",", " ", "rB0y"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"rbx", ",", " ", "rby"}], "}"}]}], "}"}], "]"}], ",", 
          " ", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"rax", ",", " ", "ray"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"rbx", ",", " ", "rby"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"rkx", ",", " ", "rky"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"rax", ",", " ", "ray"}], "}"}]}], "}"}], "]"}], ",", 
          " ", "\n", "       ", 
          RowBox[{"Text", "[", 
           RowBox[{"A0", ",", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"rA0x", " ", "+", " ", 
               RowBox[{"lmax", "/", "30"}]}], ",", " ", 
              RowBox[{"rA0y", " ", "-", " ", 
               RowBox[{"lmax", "/", "30"}]}]}], "}"}]}], "]"}], ",", " ", 
          RowBox[{"Text", "[", 
           RowBox[{"A", ",", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"rax", " ", "+", " ", 
               RowBox[{"lmax", "/", "30"}]}], ",", " ", 
              RowBox[{"ray", " ", "+", " ", 
               RowBox[{"lmax", "/", "30"}]}]}], "}"}]}], "]"}], ",", " ", 
          "\n", "       ", 
          RowBox[{"Text", "[", 
           RowBox[{"B", ",", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"rbx", " ", "+", " ", 
               RowBox[{"lmax", "/", "30"}]}], ",", " ", 
              RowBox[{"rby", " ", "+", " ", 
               RowBox[{"lmax", "/", "30"}]}]}], "}"}]}], "]"}], ",", " ", 
          RowBox[{"Text", "[", 
           RowBox[{"K", ",", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"rkx", " ", "+", " ", 
               RowBox[{"lmax", "/", "30"}]}], ",", " ", 
              RowBox[{"rky", " ", "+", " ", 
               RowBox[{"lmax", "/", "30"}]}]}], "}"}]}], "]"}], ",", " ", 
          "\n", "       ", 
          RowBox[{"Text", "[", 
           RowBox[{"B0", ",", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"rB0x", " ", "+", " ", 
               RowBox[{"lmax", "/", "30"}]}], ",", " ", 
              RowBox[{"rB0y", " ", "-", " ", 
               RowBox[{"lmax", "/", "30"}]}]}], "}"}]}], "]"}]}], "}"}], 
        "]"}]}], ";", " ", 
      RowBox[{"Print", "[", 
       RowBox[{"Show", "[", 
        RowBox[{"Plo0", ",", " ", "plo1", ",", " ", "PloMecha1"}], "]"}], 
       "]"}]}], ",", " ", "\n", "   ", 
     RowBox[{"{", 
      RowBox[{"\[CurlyPhi]", ",", " ", 
       RowBox[{"48", "*", "Degree"}], ",", " ", 
       RowBox[{"112", "*", "Degree"}], ",", " ", 
       RowBox[{"6", "*", "Degree"}]}], "}"}]}], "]"}], ";"}], " "}]], "Input",\

 CellChangeTimes->{
  3.4674632286481457`*^9, {3.467463327555623*^9, 3.4674633466056128`*^9}, {
   3.467463780132885*^9, 3.467463817429319*^9}, {3.467465152596867*^9, 
   3.467465155832548*^9}, {3.467465661797447*^9, 3.4674657634134703`*^9}},
 FormatType->"InputForm",
 ImageRegion->{{0, 1}, {0, 1}},
 RenderingOptions->{"RenderThickness"->False}],

Cell[CellGroupData[{

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmgk0lG0Ux1sU2iRECi2SyhYt9q5mGGbDzNhmmMlSyRaVSPYt2yBpkVaJ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      "]]}}, {
    CircleBox[{22, 59}, 47], 
    CircleBox[{22, 59}, NCache[Rational[13, 25], 0.52]], 
    CircleBox[
     NCache[{22 + 47 Cos[9 Degree], 59 - 47 Sin[9 Degree]}, {
      68.42135200797148, 51.64758014310915}], NCache[Rational[13, 25], 0.52]],
     CircleBox[{83.146798276174, 60.14235690311173}, NCache[
     Rational[13, 25], 0.52]], 
    CircleBox[{119.09421122502138`, 80.8796060525298}, NCache[
     Rational[13, 25], 0.52]], 
    CircleBox[{41.33468574303346, 29.227194837937446`}, NCache[
     Rational[13, 25], 0.52]], 
    LineBox[{{22, 59}, {41.33468574303346, 29.227194837937446`}}], 
    LineBox[NCache[{{22, 59}, {
       22 + 47 Cos[9 Degree], 59 - 47 Sin[9 Degree]}}, {{22, 59}, {
       68.42135200797148, 51.64758014310915}}]], 
    LineBox[{{41.33468574303346, 29.227194837937446`}, {83.146798276174, 
     60.14235690311173}}], 
    LineBox[NCache[{{22 + 47 Cos[9 Degree], 59 - 47 Sin[9 Degree]}, {
       83.146798276174, 60.14235690311173}, {119.09421122502138`, 
       80.8796060525298}, {22 + 47 Cos[9 Degree], 59 - 47 Sin[9 Degree]}}, {{
      68.42135200797148, 51.64758014310915}, {83.146798276174, 
      60.14235690311173}, {119.09421122502138`, 80.8796060525298}, {
      68.42135200797148, 51.64758014310915}}]], 
    InsetBox["A0", 
     NCache[{Rational[356, 15], Rational[859, 15]}, {23.733333333333334`, 
      57.266666666666666`}]], 
    InsetBox["A", 
     NCache[{Rational[356, 15] + 47 Cos[9 Degree], Rational[911, 15] - 47 
       Sin[9 Degree]}, {70.15468534130481, 53.38091347644249}]], 
    InsetBox["B", {84.88013160950733, 61.87569023644507}], 
    InsetBox["K", {120.82754455835472`, 82.61293938586313}], 
    InsetBox["B0", {43.068019076366795`, 27.493861504604112`}]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 2)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{
  3.46746301746504*^9, 3.467463230869689*^9, {3.467463328583921*^9, 
   3.467463346976651*^9}, 3.4674651566757402`*^9, 3.467465366855465*^9, 
   3.4674656243916273`*^9, 3.467465688402937*^9, {3.467465722271455*^9, 
   3.467465763661873*^9}, 3.467465843594438*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmgk0lG0Ux1sU2iRECi2SyhYt9q5mGGbDzNhmmMlSyRaVSPYt2yBpkVaJ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      "]]}}, {
    CircleBox[{22, 59}, 47], 
    CircleBox[{22, 59}, NCache[Rational[13, 25], 0.52]], 
    CircleBox[
     NCache[{22 + 47 Cos[3 Degree], 59 - 47 Sin[3 Degree]}, {
      68.93558813346496, 56.54021005658164}], NCache[Rational[13, 25], 0.52]],
     CircleBox[{85.92627934286472, 55.97770474387174}, NCache[
     Rational[13, 25], 0.52]], 
    CircleBox[{127.40355494228169`, 54.60453000990349}, NCache[
     Rational[13, 25], 0.52]], 
    CircleBox[{41.33468574303346, 29.227194837937446`}, NCache[
     Rational[13, 25], 0.52]], 
    LineBox[{{22, 59}, {41.33468574303346, 29.227194837937446`}}], 
    LineBox[NCache[{{22, 59}, {
       22 + 47 Cos[3 Degree], 59 - 47 Sin[3 Degree]}}, {{22, 59}, {
       68.93558813346496, 56.54021005658164}}]], 
    LineBox[{{41.33468574303346, 29.227194837937446`}, {85.92627934286472, 
     55.97770474387174}}], 
    LineBox[NCache[{{22 + 47 Cos[3 Degree], 59 - 47 Sin[3 Degree]}, {
       85.92627934286472, 55.97770474387174}, {127.40355494228169`, 
       54.60453000990349}, {22 + 47 Cos[3 Degree], 59 - 47 Sin[3 Degree]}}, {{
      68.93558813346496, 56.54021005658164}, {85.92627934286472, 
      55.97770474387174}, {127.40355494228169`, 54.60453000990349}, {
      68.93558813346496, 56.54021005658164}}]], 
    InsetBox["A0", 
     NCache[{Rational[356, 15], Rational[859, 15]}, {23.733333333333334`, 
      57.266666666666666`}]], 
    InsetBox["A", 
     NCache[{Rational[356, 15] + 47 Cos[3 Degree], Rational[911, 15] - 47 
       Sin[3 Degree]}, {70.66892146679831, 58.27354338991498}]], 
    InsetBox["B", {87.65961267619805, 57.711038077205075`}], 
    InsetBox["K", {129.136888275615, 56.337863343236826`}], 
    InsetBox["B0", {43.068019076366795`, 27.493861504604112`}]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 2)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{
  3.46746301746504*^9, 3.467463230869689*^9, {3.467463328583921*^9, 
   3.467463346976651*^9}, 3.4674651566757402`*^9, 3.467465366855465*^9, 
   3.4674656243916273`*^9, 3.467465688402937*^9, {3.467465722271455*^9, 
   3.467465763661873*^9}, 3.4674658437482862`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmgk0lG0Ux1sU2iRECi2SyhYt9q5mGGbDzNhmmMlSyRaVSPYt2yBpkVaJ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      "]]}}, {
    CircleBox[{22, 59}, 47], 
    CircleBox[{22, 59}, NCache[Rational[13, 25], 0.52]], 
    CircleBox[
     NCache[{22 + 47 Cos[3 Degree], 59 + 47 Sin[3 Degree]}, {
      68.93558813346496, 61.45978994341836}], NCache[Rational[13, 25], 0.52]],
     CircleBox[{85.3270703134126, 56.95209519505087}, NCache[
     Rational[13, 25], 0.52]], 
    CircleBox[{125.34157092916706`, 45.948016838742014`}, NCache[
     Rational[13, 25], 0.52]], 
    CircleBox[{41.33468574303346, 29.227194837937446`}, NCache[
     Rational[13, 25], 0.52]], 
    LineBox[{{22, 59}, {41.33468574303346, 29.227194837937446`}}], 
    LineBox[NCache[{{22, 59}, {
       22 + 47 Cos[3 Degree], 59 + 47 Sin[3 Degree]}}, {{22, 59}, {
       68.93558813346496, 61.45978994341836}}]], 
    LineBox[{{41.33468574303346, 29.227194837937446`}, {85.3270703134126, 
     56.95209519505087}}], 
    LineBox[NCache[{{22 + 47 Cos[3 Degree], 59 + 47 Sin[3 Degree]}, {
       85.3270703134126, 56.95209519505087}, {125.34157092916706`, 
       45.948016838742014`}, {
       22 + 47 Cos[3 Degree], 59 + 47 Sin[3 Degree]}}, {{68.93558813346496, 
      61.45978994341836}, {85.3270703134126, 56.95209519505087}, {
      125.34157092916706`, 45.948016838742014`}, {68.93558813346496, 
      61.45978994341836}}]], 
    InsetBox["A0", 
     NCache[{Rational[356, 15], Rational[859, 15]}, {23.733333333333334`, 
      57.266666666666666`}]], 
    InsetBox["A", 
     NCache[{Rational[356, 15] + 47 Cos[3 Degree], Rational[911, 15] + 
       47 Sin[3 Degree]}, {70.66892146679831, 63.19312327675169}]], 
    InsetBox["B", {87.06040364674594, 58.68542852838421}], 
    InsetBox["K", {127.0749042625004, 47.68135017207535}], 
    InsetBox["B0", {43.068019076366795`, 27.493861504604112`}]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 2)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{
  3.46746301746504*^9, 3.467463230869689*^9, {3.467463328583921*^9, 
   3.467463346976651*^9}, 3.4674651566757402`*^9, 3.467465366855465*^9, 
   3.4674656243916273`*^9, 3.467465688402937*^9, {3.467465722271455*^9, 
   3.467465763661873*^9}, 3.467465843860736*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmgk0lG0Ux1sU2iRECi2SyhYt9q5mGGbDzNhmmMlSyRaVSPYt2yBpkVaJ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      "]]}}, {
    CircleBox[{22, 59}, 47], 
    CircleBox[{22, 59}, NCache[Rational[13, 25], 0.52]], 
    CircleBox[
     NCache[{22 + 47 Cos[9 Degree], 59 + 47 Sin[9 Degree]}, {
      68.42135200797148, 66.35241985689085}], NCache[Rational[13, 25], 0.52]],
     CircleBox[{83.8371131861058, 59.18622789053063}, NCache[
     Rational[13, 25], 0.52]], 
    CircleBox[{121.46970665037499`, 41.69228867853363}, NCache[
     Rational[13, 25], 0.52]], 
    CircleBox[{41.33468574303346, 29.227194837937446`}, NCache[
     Rational[13, 25], 0.52]], 
    LineBox[{{22, 59}, {41.33468574303346, 29.227194837937446`}}], 
    LineBox[NCache[{{22, 59}, {
       22 + 47 Cos[9 Degree], 59 + 47 Sin[9 Degree]}}, {{22, 59}, {
       68.42135200797148, 66.35241985689085}}]], 
    LineBox[{{41.33468574303346, 29.227194837937446`}, {83.8371131861058, 
     59.18622789053063}}], 
    LineBox[NCache[{{22 + 47 Cos[9 Degree], 59 + 47 Sin[9 Degree]}, {
       83.8371131861058, 59.18622789053063}, {121.46970665037499`, 
       41.69228867853363}, {22 + 47 Cos[9 Degree], 59 + 47 Sin[9 Degree]}}, {{
      68.42135200797148, 66.35241985689085}, {83.8371131861058, 
      59.18622789053063}, {121.46970665037499`, 41.69228867853363}, {
      68.42135200797148, 66.35241985689085}}]], 
    InsetBox["A0", 
     NCache[{Rational[356, 15], Rational[859, 15]}, {23.733333333333334`, 
      57.266666666666666`}]], 
    InsetBox["A", 
     NCache[{Rational[356, 15] + 47 Cos[9 Degree], Rational[911, 15] + 
       47 Sin[9 Degree]}, {70.15468534130481, 68.08575319022418}]], 
    InsetBox["B", {85.57044651943913, 60.919561223863965`}], 
    InsetBox["K", {123.20303998370832`, 43.42562201186696}], 
    InsetBox["B0", {43.068019076366795`, 27.493861504604112`}]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 2)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{
  3.46746301746504*^9, 3.467463230869689*^9, {3.467463328583921*^9, 
   3.467463346976651*^9}, 3.4674651566757402`*^9, 3.467465366855465*^9, 
   3.4674656243916273`*^9, 3.467465688402937*^9, {3.467465722271455*^9, 
   3.467465763661873*^9}, 3.467465843968862*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmgk0lG0Ux1sU2iRECi2SyhYt9q5mGGbDzNhmmMlSyRaVSPYt2yBpkVaJ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      "]]}}, {
    CircleBox[{22, 59}, 47], 
    CircleBox[{22, 59}, NCache[Rational[13, 25], 0.52]], 
    CircleBox[
     NCache[{22 + Rational[47, 2] 2^Rational[-1, 2] (1 + 3^Rational[1, 2]), 
       59 + Rational[47, 2] 2^Rational[-1, 2] (-1 + 3^Rational[1, 2])}, {
      67.39851383558621, 71.16449511981847}], NCache[Rational[13, 25], 0.52]],
     CircleBox[{81.71255913949688, 61.99344790384617}, NCache[
     Rational[13, 25], 0.52]], 
    CircleBox[{116.65566973433758`, 39.60530322956085}, NCache[
     Rational[13, 25], 0.52]], 
    CircleBox[{41.33468574303346, 29.227194837937446`}, NCache[
     Rational[13, 25], 0.52]], 
    LineBox[{{22, 59}, {41.33468574303346, 29.227194837937446`}}], 
    LineBox[NCache[{{22, 59}, {
       22 + Rational[47, 2] 2^Rational[-1, 2] (1 + 3^Rational[1, 2]), 59 + 
        Rational[47, 2] 2^Rational[-1, 2] (-1 + 3^Rational[1, 2])}}, {{22, 
       59}, {67.39851383558621, 71.16449511981847}}]], 
    LineBox[{{41.33468574303346, 29.227194837937446`}, {81.71255913949688, 
     61.99344790384617}}], 
    LineBox[NCache[{{
       22 + Rational[47, 2] 2^Rational[-1, 2] (1 + 3^Rational[1, 2]), 59 + 
        Rational[47, 2] 2^Rational[-1, 2] (-1 + 3^Rational[1, 2])}, {
       81.71255913949688, 61.99344790384617}, {116.65566973433758`, 
       39.60530322956085}, {
       22 + Rational[47, 2] 2^Rational[-1, 2] (1 + 3^Rational[1, 2]), 59 + 
        Rational[47, 2] 2^Rational[-1, 2] (-1 + 3^Rational[1, 2])}}, {{
      67.39851383558621, 71.16449511981847}, {81.71255913949688, 
      61.99344790384617}, {116.65566973433758`, 39.60530322956085}, {
      67.39851383558621, 71.16449511981847}}]], 
    InsetBox["A0", 
     NCache[{Rational[356, 15], Rational[859, 15]}, {23.733333333333334`, 
      57.266666666666666`}]], 
    InsetBox["A", 
     NCache[{Rational[356, 15] + 
       Rational[47, 2] 2^Rational[-1, 2] (1 + 3^Rational[1, 2]), 
       Rational[911, 15] + 
       Rational[47, 2] 2^Rational[-1, 2] (-1 + 3^Rational[1, 2])}, {
      69.13184716891953, 72.8978284531518}]], 
    InsetBox["B", {83.44589247283021, 63.7267812371795}], 
    InsetBox["K", {118.38900306767091`, 41.33863656289419}], 
    InsetBox["B0", {43.068019076366795`, 27.493861504604112`}]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 2)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{
  3.46746301746504*^9, 3.467463230869689*^9, {3.467463328583921*^9, 
   3.467463346976651*^9}, 3.4674651566757402`*^9, 3.467465366855465*^9, 
   3.4674656243916273`*^9, 3.467465688402937*^9, {3.467465722271455*^9, 
   3.467465763661873*^9}, 3.4674658440680637`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmgk0lG0Ux1sU2iRECi2SyhYt9q5mGGbDzNhmmMlSyRaVSPYt2yBpkVaJ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      "]]}}, {
    CircleBox[{22, 59}, 47], 
    CircleBox[{22, 59}, NCache[Rational[13, 25], 0.52]], 
    CircleBox[
     NCache[{22 + 47 Cos[21 Degree], 59 + 47 Sin[21 Degree]}, {
      65.87828004536848, 75.84329362862911}], NCache[Rational[13, 25], 0.52]],
     CircleBox[{79.01925985257617, 65.05836666056116}, NCache[
     Rational[13, 25], 0.52]], 
    CircleBox[{111.09871055840674`, 38.730456709101134`}, NCache[
     Rational[13, 25], 0.52]], 
    CircleBox[{41.33468574303346, 29.227194837937446`}, NCache[
     Rational[13, 25], 0.52]], 
    LineBox[{{22, 59}, {41.33468574303346, 29.227194837937446`}}], 
    LineBox[NCache[{{22, 59}, {
       22 + 47 Cos[21 Degree], 59 + 47 Sin[21 Degree]}}, {{22, 59}, {
       65.87828004536848, 75.84329362862911}}]], 
    LineBox[{{41.33468574303346, 29.227194837937446`}, {79.01925985257617, 
     65.05836666056116}}], 
    LineBox[NCache[{{22 + 47 Cos[21 Degree], 59 + 47 Sin[21 Degree]}, {
       79.01925985257617, 65.05836666056116}, {111.09871055840674`, 
       38.730456709101134`}, {
       22 + 47 Cos[21 Degree], 59 + 47 Sin[21 Degree]}}, {{65.87828004536848, 
      75.84329362862911}, {79.01925985257617, 65.05836666056116}, {
      111.09871055840674`, 38.730456709101134`}, {65.87828004536848, 
      75.84329362862911}}]], 
    InsetBox["A0", 
     NCache[{Rational[356, 15], Rational[859, 15]}, {23.733333333333334`, 
      57.266666666666666`}]], 
    InsetBox["A", 
     NCache[{Rational[356, 15] + 47 Cos[21 Degree], Rational[911, 15] + 
       47 Sin[21 Degree]}, {67.61161337870182, 77.57662696196245}]], 
    InsetBox["B", {80.7525931859095, 66.7916999938945}], 
    InsetBox["K", {112.83204389174007`, 40.46379004243447}], 
    InsetBox["B0", {43.068019076366795`, 27.493861504604112`}]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 2)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{
  3.46746301746504*^9, 3.467463230869689*^9, {3.467463328583921*^9, 
   3.467463346976651*^9}, 3.4674651566757402`*^9, 3.467465366855465*^9, 
   3.4674656243916273`*^9, 3.467465688402937*^9, {3.467465722271455*^9, 
   3.467465763661873*^9}, 3.467465844186886*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmgk0lG0Ux1sU2iRECi2SyhYt9q5mGGbDzNhmmMlSyRaVSPYt2yBpkVaJ
kr5KlohkCQlllyVSsiXao+K7c07ndH5n3ud9n+c+9/7v//Z9jCNOGw7Mmzdv
Af75LvgbHGqEEyMvhgNLm+KnbpgDDs0XuHf77wJrsz87TW0/OPReXv53VRqw
JJhF/vOawOGLTkbioDcwp1qnzNa1AFfqzaYxKX9gPswWPRBSCVyG0D/184rA
JMzkG6TpATdncnrISB4YZ47nxD6dBO79BL/Q6DfAOJ3QI7mTBtz8VR6n1FYB
I6jKTOiKFXBL+zJaI2yB4XZ692YjYeA2RvDThq8Dw5i1t+VNLXDHT99gcGTA
cs7VSdh3BfDktPMXbdQCy7BJ/ROzi4G3XvVL4KgIWAYsaFOd1wq8TdLxLira
YHl0i9TbJhXgKdc1twd9BEun6+ZXGS+Ap5WzsWxxIlgSaTqmibeARzr3bG1/
JlgusdrpY2UPPLOxtEWzymC50PLD1NavwKPu/pV31hUs/nI2cq/xgGdR2F9T
9gEsPqcEXLiaAzw7G0bt13qwaE1yNVL/DrzDewJ9MrrB4tpli6Xv44HnLpm/
dHswWKRRC54v8Aeex7jn2LoZsDgrLBLergs876hGF08qWERf/HyyFr/n5907
LVcCFl5q2kZzhcCL1EpWjpMGi71CPWd6Q4GX9rlu34+bYN7oGPHN5jbw0sUy
JgtTwLwqyi3dYiPwLqu06Uimgnlxgc454xbgXbV3OZHUDeZZ2nIQ/gB4GWes
oy2ywDyk9nO0ZSLwcthNpJ4tYL7zd7FoFRt4d42vf7mrA+bbm+Luj+F+clW5
hZGuYL7xv9vPWxSBd+/bk9vgDOYr+d7elWTgPbRv+0hjA/1T5cvtD4WBV5T1
pe9mN9CzZi6U7nsDvMfOMw2r9gP9qjtNLj0XeMXyjtM1q4B+bmiJO/Ui8Eri
XcyOLAR65DcrqcPfgFdm8mEv/TvQnU8aNeyfBV6l6fDVQXugb1w7nqe8C/lt
+kw4FeiyUupenhiPqqOiPfOdgb5qte8N+yDgVacocb/tAfoCjVfzlMKAV1P0
SSv3ItAGq5QigvH+669U//aqAdotxqn5sxLAeykmJj/vPdCujMOB5gnkYG9l
ZjLQzseN8fdaAK/BJvrIS3ugnX5bfnrICXiN3zw7uFpAc+vUqrwQDrwmqzeR
j92A5nxr6MtOA+TCk9+ZKkCzP6X4ah7u99XRQ1pKdKDRdeSfs+qB97qd+Z++
F9A053+YXo3xat5as+PYBqBtX9inwd+EHBhza40J0BSXiRssw/xskVui934L
0FarL+YSvIDXSrbV3R8N1Jmn66aYy4DXblvla54K1OrpJZdyPyOfzaySqwfq
U/aRAcfTyI2LEttqgVpUEVbXyABeh56F+w1FoOZcj3twEPOvc7HVngtrgJp8
w9x3xWPkXYFZhBVAjVPf0/1KDNlZ24fiA9SISr6eGOZ3Z4mf6FUWUE9M7z81
VQK8LluW1R86UB2yOjt/iiIHOo0K1tvwrA9Ti5CvrVmxYBColnKL+xqOIg9E
aYr/BSox+91mfgzy3N6Ctx5ANTz+988zrI8363LajGWAqk1SKznXiMxMv2ut
C9TtM48zf/+H7Ln5ySEA6ubehRY6v5CjDksJdQBVodL0/UZt5DxFmcPaQJW4
kuOcq4dcc+1z62mgLk8pJl2cQ37T57oTfxdOuD13sA/57y2X3qVA+ZMkfuws
xqN7uZ9qFBEoP1brP8zfjLyu51/1W6B8vim87fJ65G0dVm7pQBnZdXh+TDvy
Htd7j54B5V0j22NJKvK+cyedlgClx631YS0XmcpTbHEASvvyRhXDQGRW3epV
v4HSVLjXhL8VmdOSO20BlDqXjUE7C5Adwwh74oFSKX3EYaAL+UCHis9loDx5
LX9aHeu327W1kDEfKAWJyrcD1JDdApWvbgPKfcvosCtNAm5+To4Byh1ZjcGa
HuTDHXWJhkDJGFmfq78W+RDf9ScfKJef0Ju2uSI7/+o82QaU82fzTY8K9suT
2RvnApRkH/I23w/ItlO1yvh7HEs05aOALSMSf2oDJVJv/P75L8imLXnGH4AS
rDxaZoL51204QFJfCBR/2X/CJzWQtf7jXqkHytFV8iP7sB66t+wVcjkOFI8V
pnVr85HXpO6l/ATKQbHjckVnkZc8EFc8CJT9Upc821C/38yknmhXBAp7fQFl
ZRzyKMHVA+PN0nhqVSmH3PH0jQbeB934vl49EblKpCiXARRTXthjTw/k/zZO
POsCyr5g9dStv5FDX33R1wXK7nqhhrUYvzeuB0+lNgFF45fCjOh+ZHpbZzQV
KNuVZ7ftPoEsA7QAAlAULo0//eyL+frHaL4dPr+me9L2Gx25b31JtjlQJBWu
8gZRv7quRO6b2wQUkcLhmzY5gnpYGheaCJSFoieO8/H7XXb+dX4HgPxvf1pP
I/avLvGln66ygfx1XYzEE2Wsr2MELjMPyD31rtumtZDNlGeVjgK5w2i+w6O7
yPLzS+LPAPl16cIUjgnWc3VK++VOID8vV5ufNYW8iPvxzwkg35+O06x0w/pv
FemUogE5J6X74MIs5Gt5G2ErkG9puF3nf0TeLXK7VRvIl/z3HHI4Arw264me
ljYgR+lMj1RiPrWtv7UsUQjIofS7DoYYn9bR6JSrykA+dXBy/fNVyP6Nko5d
QPbJkHcfLUe94kffvsoFMnffI15BNepd8qUXOW+BrL01qrvuHDLN/+x1PK+W
b8alcxXIomeS8kuBrPZcum+LM+plyMkVS2WBvNlz1lRXE/XUSYd00QDIq4bt
g70aUI+FLCtftoDZZ9/ggOvLUa8LWFO8nWA2+uPc/clp5AMZurnIQ/7NFmGH
UO+r5W/uWAdmvTF3wtxR/174F3aN54BZfWPM0Q8LsD9UrLewY4BZ9ujBsHmR
wHvW5jJ2MRbMXKxKbX9hP3x2qGOl7m8w4/U6Vt+IAl75TNLabx5gxjlIm3TC
fC6X6/Xa/RHMGBETfDXMvzLOX/sjpmAGQ1MMP7y/4iKx+dEPwEx+H8nDCOuv
eO8BZckCMFvz563VaRb2x9qVlxemgpnU4zjHcuwfRW1uyRorwGy53mqFCOw3
BcNg7a8Fpn9dcprc8fwPP6/bnjgIpj0kysy3V8geG0/N+oBpp0bfGhXspw9G
40Sdp8C0Vc5ab8Nr4N0fDLmd+RZM62d/NO/FeN9rlGE4LgfTkg/XxVbj/d+J
Or+5vRBM0/dw3F5dAd71GMOd5bpg6jAyq+KM+X3tp+s+0TYwZetLF/Ax/6+5
LKtJXQam1mfyLCdQv68a1NrwaWBqTnQyvI/1lD4ubv0+C0yh1qd3HP3UBVX3
MSk3MFXcF/qsGvWYz7oTW9oGpE+zbr6a2N8SHq0FxxEgjV4p+gonkcVXT2k5
AenjXpI5fxB4cS/vTWtdB1J/rOLBc1g/MXoHn5g/B1LLnluZ5CrgRSxy3LyY
CqSiWW332/OA529iZtbQBaSozbkvBiTRT2Wkfti0AEjhe409UlWBd2I2shN9
JCmEfavDEn/3LWB8c7MF0snzj0c1MJ+OyT9YRRIBkpei0LN49F+eA/e2GrwF
kk2K3E5zvA/nTRdDkhcCafujD1ERLsBzOv7b1iAASFuFZHbe1geeY82i9f+6
gaRkNeHdjnq4/5BSUCIRSOtn/df8KwWew60kFTgPpNVOk5ocPI+thGpa40kg
zff31tTEfKA+0la4wwKTribmdhe8H8q4pMUPazDpkB3tnRJC3nhh/81jYNJ6
mNCt+gz9avLZra4tYNK0VP+hEfYLE1fX+z6NYFLlIj+xzQx4IFz9WukSmPzn
mpLtgP1La/HvaaINmEQ9GtDww34nI/FnJIAGJjpSG1JMsd6lTVa3+smDye4p
1xE21vdqv6modbh+Z8OfgF14Psnugc6OODDRiJ1TULcEnviVYu+kDDBRlnDb
bYv1tVTaPdhoB5hIO6+X8UZ//6+nZXFMExj/nHros2c1cAcfrLoX4w/Gxen3
miW4wH3Xab4mYQaMixqVfp2XAu7ALOu9jRIYF8zliZ8wBG4/pfRPnj4Y5x36
cy/1PHB7PixQflYPxneNKVEvPIDbvsTPRtkZjK9o2mgFLAJurXrZW74FGIe1
LOB+U8F5ZOCD+4gUGNNFNBV9zwL3zvCDOeULYEy1eXGRMAPc25+J6wdWgDH5
9smAaRngZs089a0QAmMSTeFnXjVwb4ovVj5fA8Zw07emQhu46Zq/XO7VgbFW
RKHL0izgxtNETpxpBGPZFTsKXfOB6/a2/OeJ9UAc21rRrdoH3MOjweG9r4E4
0rrjhet24Lp+F2teeR6Iw0G+8/8kAveQSM7k7iggfmg7lvz4BnCd1avbvrOB
2J9AnLvRDFyOb+p6uaNAbN/YNSF3HLiUgYVzSvJAfDbSIl4QDFwVreW1BzcC
8VIFc4VkGHC3yx1g1QIQ0yIq5AklwN0mHH+mLxeIF0mia6STgbulh8j85QXE
c68Vx+dh/DaFuoY5tAIx+VNw5+Bl4MpWnE5W+w7E0zTmlVhr4IoqBBlnBQPx
eK75lg/V4DBE/QH+C4BoWfMTfsyCwweNO9El64BoUbEreEMYOLyX3KE+juc3
L93epaYGDgPdJc17Y4BIy9d3wLnOoffAY5vmGiCa5Q6uqVMCh9ZjLnEX5YBo
VP7J+XUiOFR4ll8Q+QRETTfX8xt0weHygGmT3R4gSpVJm2UeBYf0htk/PZ+B
KDn1727gQnC4VJwsm7sMefORnEN/weFiCsHoHO5/VdKPIy6rwSHVaKIuXAeI
Yu6h97ZOgUP8JVuolgWiqD5nS9IKcAhQv3VqrTwQ/hEsGpdXgoP1hLy03Gsg
fOzSelllAA5WjzMPK04hy8du6vgKDqzIeUc5n4AwdODI+Pyl4MCQ1SmNvgyE
99+nzuVpggON+PDe2iNAeCdbKEZaBw6EMyUNX1WA0BMmdj94IzhoLKPnXS8F
wuvCnxVh7uAgEklylvMHQmlRTxtbBByE2Ze6Kt8jb3M6NhAIDos16vWvtAPh
yRVbHe4WcFjYW9q52xYIJZHJ9n1+YD+n+SU5PgcIj21V17xXAfsfXZdqbr8B
Qr7EKO/sUbB/L/K7LMYJCHd7pnuKx8D+XXfj2ci/yJx/jSKPwX4gNzgpWhMI
Ob1uZpu/g/1b8+NzOzKBcOdtoGRdJ9i/OfvoPb0LCNnDQc7VI2D/WiqgX3UB
EDKX1QdNioJ96eyuWyb9QLh8U4N4fgDsnzycPLE9ElnJOKv8HdiXHAixjckA
QvqdJp95smBf1LDBKvcEEC7l6ZA8l4B93gUvqsYyIFys8zRZvg3sbyupjD5c
A4RzS9bo9aeB/VlFo3M3VwKBP9B7+vkjsD/TUr7s/VVkn9HKtWSwTw5bdSeM
hbzQaVRsCuz5ffrMh3QgJGy5KPl8PtjHnE3zvoLr43yFkzsywD7od8DbSh4Q
Tm+q6y/B9a4Zbz5a4vlCX5keUlsA9ocYdp9fuSMfUdk03wHsD85/mC5Wgyzm
I3t5Bdg784Z7P9wGQoil3ERvOdhzZY/8WorxC+r6F5yoDvbM0xP/AuyBEDCT
7fxeEewNiZeFNrOB4BtJKCjC+OtPimmY4fO+6p/UhfaDvV6a3ce7K4BwvGcy
tYAK9toTvhMZ+ci7FjtKCIG91tk6wlV8/ui41y0hPL9yV9s0E9nbdc52yBPs
JYiRbePngeB+qznrbh/Yr5q/9cmGOmRHZ9PCLWC/suwugaqBLGfYc3QT2K/Y
TdRqjwWC27lWva+DYC+6udHTCs93OM6j/q8ocGZn9b4twno4FLZvv30/cMZS
gyV6Md7Omcdt1NKAM0rN3z3ZgOz659fvFuCMCNXUdtkgq9Z9uiAJnKHjYdsL
nwDB6bGmkVMicAYY5JryC0BwfG2YW1gLnA5h9QvbS4Cwf7kCo3cSOBXWOxjP
8D7si0XeNtUBp3zih3kwft8+LFe/vAo4T6OSVMtTkcnpY0e1gfMknxghgfnC
6eNFy88Ap1CswKAD75+z+Oh0+Fbg5DzNJc/IAMHuYObAAyfgnP3bHXGkDQjW
XJFHXkeAk5LEuk1Zh6w+mGD0EjhnNmSSqmaQFyx0iNYCTqJx1chxCyBYZa/Z
1/IDODEJQjSxj0BgfT+TuOYYcIJWRvuWLgEC83KySP0b4ByY9n33sBsIlgpZ
7UN4PpdrWkkWVCBY/E2InH8bOM7ElxXvzyK/uXtTqAQ4+5Pib0eJIqeeywtp
AA5nk5ncDi/k5VLJc+XAsSAUZXKwXsxFbhtWzQMOfXidiBoyfVRqQnIzcGhx
7OI6IeQXT5Y5YjzIrw/+FsJ40+PvKvh3AceYXXKqVw55lYLi87fA0XUle31c
DATaVj3t+2zg6Iha/pExQV4urud0Cjh7crQukfF+qV/WlWxYDZyd41ELQrAe
qMWt9/8wgaPusV9MciEy7anc0gngKB78lr+3AwiUEDf5nbuBs2KvL2XxCBDI
ombDSmPAWTaYb9MfCgSz7/M+vKUAZ2lUk+8P1Euzt8O3fhcDR+Tl2fYO1Bez
AuKCSHfgLLRyehSG+mXmsktGkwjs307LWYq4H9P6AU9yMbB/LfjD34zxNX0c
nbbnDLB/3Kw+V0VGzmI3WkwA++uHYaGvz5HDEwaORgB74oDHB8IZZAPJAoN4
YA/y/D+wUY9IJemU3h5gD8yukipDvSLdldr53RHY/Zejmu8lI6c/OdZ4BNi9
XX87jw8gByWctuoEdqeF8pV8PWSCofS5HGA37Dm2UZQGBJOO2tOrLgK7vjVv
oCkP+cWMSeU/YL840vDufDxymU2emS6wa7KTzidrI2embAq+CuwKKXOKNMbH
xHdB4thvYBeMPirZgfpvIleSzZUGdv4Bjbhi1HuTVQ+SKtKBnTcQen4h6oOJ
cEcl4ROw73dcIkx8BYLx10dhpVPAvvPsES37OHJ9TjOfCezbui+IPS7IFQo+
WX3AzsrPIwZgvhsXVVltGwf2zex/BM8HyLcuOn/0A/aVhBMJFKwP44jjKx+4
AvvyIkUJ6STkUzx9GzqwLwVlehUGIB/zzz60GtgXvOTijPD+jV12lcT1A/sM
deqSAeqPMamdnk8CdlL1TjHf9chGapNblYCdqEdWvAnIugWNd72AHa/8WVIC
699YjVz9RQXYUQskyf4HkaUTFY5VATvC79OCJxzkVXTNf/h82MR5xVePkZfr
RrX8BHZwl2PcL6wH44UX3KrwfEG08AoCnoc4J1x2B/dzqvKEcQvqB3HmZrP3
JLD977bJTdxD/soty/oFbL/1hs6xwcifg2x2nAO2b2pATxTqCXGsVqvNG9hH
A91MgmeR3/fqiDwCtveU3HYnrDfiQPamxcLAPuKcoeQlgtx3ueUbB9ge5I37
kjcid4kIvz8ObLcyOav9McjtQfQb94F9WH3MsQnzj9i67m1NE7APZcTuv/MZ
+fXHNDNjYB+UnCGXoV4Qm7p5W6nAdjltINOI/oPY8FvcG8/rNG1ZlY79jPhy
75md8sB2dNcmDBgiv3hQnoz5y+udSrF8ilxHCbq3FthcekD2tWjkWrHcJx7A
ti/vCDw2ifz8n+pPzC/ODiHRYyMClhi8cR7YdhkLSYaC81Yzc5ctAbbtqja1
I6inxKpSd74BsK0jThSlXRcwfUE0H9isb2M9tM0CFmE4zQCb6aKRIiH4fuW4
/oWVwLacnOf98JaAv1/Zh2xxMrstS7Dfqg1KSc7ANhdSKmoTnKfKu7yyDti0
xCBJ2SABv7fYog9sqkzOe6bg+Wr/8hUDwCZnPFBgfRDsV+Nb61Jgm6kkVHzB
eiXWLG1vUwM2qRCqf+0UnFeUenIE2CZ7GzaqnxfEY+teze/AJr5Qa91vIoiX
+znfrcAmMFxbyJg/xPrXu8v8gW3UEyBzt0UQb5slSagP4OJ0Xf8lcuPcbz/M
B8OJjU55+5Bf1Y8sZgFbb3ZLiIib4D5r3KLygK0b7dFgwBXc98+GMtQnnRWx
unPWgnwwfbUd379bnuScuUKQL5bMyC/A3nlrdOVjQbwHhDMnC4Ctper4vFwQ
78H+XYmYvxp6Xart3sgjXx7loz6oVba3/kA9J35S8f56EtiqZjmum9GPEidj
ljX7AHubdRfcxfoh/rwRqhIAbMUjxjND+lgfi9n5gy+BvfH7DJuK+m28JK3m
dAawNwREHdMqRF7x++dUFrDloxQKx1DvjGWkWTcOAlvmonN99Q/k7c2uP+qB
Lb2uUU8e/azxjhUdQpeALXVjuboFEXm3+80cd2CvurMyRjJFUO8RCzZh/i0r
UtRfivVkbKe0R9IC2Et1jZbtEOgNz17iF96naNnOre7ol40PPEj9DMBeXHlF
3RH7n/HRgs10vP95L09mmQv0KHHr1LunYPe93XrNWmuBvt17XW0Fdt923Wt5
gv7RuNXnmXoc2H0517Y0czlyr83PvWlg99kqviNeoCef4579zQS74Zbsxq/Z
qJ+S0VfO7QS77qpY6WZl5INl3z+0gd2b9dWH76B+mvhcvD6ZAnadQY2Z9QI9
DjxbubcX7Nr2mD0ItUNOGfsSoQt2jdnDYv5YzyYVa95uswG7ZyH/ObsrYX/Y
tH94+j3YPX1T9WQoBFljV4CJBNiVaWU5zsN+SjJQfjz0COyKP7Yeno/5SbJx
q19wDewekV9a/cZ+QOKzNz/YBnZZoluf7JxAnm1U3bYc7OJ5NjObxLGf/TLy
XkADu9iSdt1a9JNmwq57Fg+DXczq9Zz0o8jSd3btUgO7yIb1kqcE/Vb75JEy
ALvgXdWwawz5lMXS+lGw8547b2mA+UheVH54bz7YWXuu9tbGeFFUvnulYXzW
35PeVI/3QSvXsw26AHYKMgPWFIw3rfW/UJo92MlFngoc0EUe0RKu6QY7Wc6W
4LQD6DfEjwzrzIGd5GIrAz3cL92lsOrJE7ATZs52i6Femq841G+gCrYTDfs6
e/ei3/F89eWiCtiWqOnSj9Wjn7KNeV4ZDrak1OaV97Ffsel7RvZUg80bpQMG
oxhfR+ZXifiNYHPYjaom8PuuXmFbLHrAevw7Kz0D5ytvmdqwZF+wPnr26kgv
6suJb1xKmzFYe58Kpviif/NbKaP9PhSsvZyFdzVjfvqp1GlaLgBrtx1SS24M
Ih9cMm9qB1g7vlgXL43669clseyVH1hbjBRvFdy3f8m20QxzsFYbksjkY/8L
8P36OZEJVqMvlBV8m9H/1/41HEoGq+HyHarv8f1B/b/PX9IFq6H8oSt9BORf
I/tvaILVu2sWwqamQAjekiGRZAVWb7yVir+eQo4O9JRxBKsX8x9Pi0rhfGH0
rHQrvj/7PWuTTgXOH/8p/Uy3BqtbTadivTF/QqtP5I39BKubxWY7gl8gdz/e
MhgNVtf4HWlCm4AQJrxyUUo1WF3QzJ8eiULmrZKyTgSraHe7tRlYj+HLmE+P
4HqX87Mvjz0DQgTnSMN+WbByCiO8lUD/EHHkBP3wR7Da7666OQnjExHhGdSe
DVb2BuOX1LA/R9xVffTADayY/RLzb2C/j5j+rujkDFYEsUEfe4x3ZGqiV1UZ
WG3Ypn6Civ0zqixTzWwJWCmIXFWaxH4S9er222dSYLXuY854EvqlqHeXn6RW
gpXMjSv9D12BEL3I8iXvCVitXPX+gQfmczRl8s9TFWDNDj7bLo/zTHT7Vx/S
IWD17tbte6aD81xvuaF2ObDedBVKm+L+T0+MHtErAVZnQMHInu/Is7ObXuH6
lrJ962u3AyFm/ce3X/8B64V+ZMIn9CMxzvniY/h84SZPDRmsj5ihHdskIoD1
6OnyCxaYjzHf/84J84H10Fb1vifqV6xQnr/xX2Dlxo3nyr9F3tS9frwKWBlj
Vh2liciOso1F6sBKSk7L0cD+EdtpVReYDSz+phWyPehHYocK4gLTgBWX//fn
B9Tf2G+za7q1gBXVaXqmAvt33EozD1VlYAVK8a/vqUUm1fo8jgWWq3+osvd/
yHlW+Wv2Awva/X7LzwNCvK9TZaE+sAzDlDuvYT7Eh86ffW8GLH0VjtS4M3Jc
/J2rkcDaE7bPsRr7R/w1riIF96+2WUJoDvtZfO3sTeYvYK1l+VwX+YXzs9Tm
hPqXwJL5vfJMBvqbBPlDBDMhYK1O3x7CeSWYr1NaHscAS7y/dUTKHFkn25Z1
DVgiTkNCpRHI9s+FpIuA+cO86E6zYP3VlyoBIcD8Oja+fz7md0JWFjWfAMyp
qHP7zmN8E/5zK9GrAOZ4MVnkJ/qjhLL7nJo+YA7Kqrz/hPqd0KPUbKkEzP6H
wmYjl5AHKcdxHmX2kVi1tZXIo3Yb7x4CZtdRkl9qH/Iv9fD4AmA2VYSGta8F
Al+81rspB5gNzJHIxt/IMlpn9ZYC88XQM3d11Ee+fEz4hT/AfC781FAc/Qx/
26c7TxSA+YT40TFWFXnfFVJGBDCzb8b+u7oH2TPNIVsOmJm/ptwzHiIf/TW7
A7+XQbmVsg71ku+v2/nDGpiXp6arbgu+H+4pOfACmClaOndYqLf8c+F1nZXA
TApf9LrfAPnSApJqPjATXq8Tv4TzOf/qgVKKODBPuykGN6Af4md1ue+5D8zA
c6l7Rq8hF3os1GQA8+Tb69x6nI/5JUu40VnA9FP6UrcS/R2/LOHYtXJg+hQ4
Dm3eglyt9x9TB5hef0JsTS8i17o+r3QCpgf0J/iXItefDLh+GpgHXxzI1V6K
/Nr4hkMYMF2WxZmf/IncOn9R23JgOtInN23DeZLffu3T6AlgcppPPDuC+cPv
jtm6sxaYduIXddpQ//m9zT6NGF9ri18EI5x3+W9nN73YCEyLRnd2Lt43//38
u80HgElfErKSEY78oevEqiBgUkwab9H8kD+mpGz4BEzTcGu3VtQL/oj6DFcb
mMZlMg+XeiKPPrhjZAvMfb8kakVRL/jjkmmOgcAEDZOZRvT3/E+c597DwDRw
fZgGrcgT0cqGbsDUvc74rCW4n89nSwueA3NP5zaiHeoffzIyqP8GMHct3z1E
Rj3jT9keHJQBpuY+/zUBxchfxI7NlwSm+okJZUNBvL7cuXIV800l55xNNfor
/lelQV11YG7tOzKx8q6AT+sfowBzi1igyjxNAdffFsb7UoRiG9w38pf1rfj7
Bh+lB0wVAc9ktFYDU/56lV94goCHt21WBubaV4njw3wBFz4S2gFMmX8xFKfb
Aj6s04T5uXrbfy2XBP8+9mX2yfx1wJSwmV/6S0bAflr6eJ6V4aHEm8qC87Rc
M8J8WH5va0aU4PeplX++HQHmko5/KwwdBefXNLHBfBOem36qLCmIz+5TqbeB
uUhZfthihyB+chd/sYC5wNy97ISLIN7D6RORwJjz7T8min6BP5YaLnoLGH/T
T+psuim4H0WzBWLA+Plhbf51Qf4MffJZYwqM75Kh2c87BPetyhP1AMYX4krn
K4J4DjK0CtOBMX793lKjEkG+kOLDO4Ax0viYWyQhyCeZZWvIwBiaHidvF7zv
TYOXPQMYA+bVd2oE52sbaHOnAqPv5OGAd4J8aoGOjnhgdGdoXhnEeYz/KvKx
mgQw2r6oRdo6Ib94vDq6ABgvIgvU2V+QSxv3VZwFRk22y4/TgnoppuofMgFG
1QtNQ2H0E/yC+6ubR4HxdMmGlmM4X/L/W+8zdRkYeWH6st//IV95+PHicmDc
v1y+UgL7ET/NYkn0MDByi2xt/QX7SW1Ze6UTGFmj9arZucjx4StetgIjnZB8
oRPnGb7fmeht2sC4aHN3IElboCfmPHkZYJxza/+YKagfjy8GG6qAkZTI2JuL
/Zzv+E766zQwIl68ZhYJnif7VOh9BIaH+L/A3YL6XM2x+vEYGIdXx5MbZpDF
OBXNLsA4KCvNmsb5jS8CseedgLFffnPRCPanhOkisvsYMFhr/p6WXyzQW7bn
Szdg6PWfeeqL80hCWvC3mBxg6AiP/NiD+ZdwhleUKgmM3ermTWycvxJilT+v
TAaGxilTl1fCyP7HO78lAWOzcF1WLM5fCVbf8v64AmP517UOx3CeT1h2fmjr
TbDsF6IvlcX8jXd9aRI+CZa9y8IHLqFfjndolk26DJZvJG46ncR5KZ5RIWxX
BJat8hmsUlwfr887Oi4KlrVbjj1n7EJecfFSSR1Y3l+oe1cf9Tbu/vIz3G1g
GfTGx/4u1m/swPWsqhywDDi54/aqJcjNE4Xx4mDpJ30iWx7npdgqxdANi8HS
2zzaPPId8i3zvoexYOl0L1TqrB6ya4bWx1NgSZIfIzg3oB8Y5+hMlIPliprG
Y5PYj08P+gsNj4HFRX7MdrXV6GducTmrlcAidWbazQHvKypV2uv2frA4c/CU
90WcD6LCGwzatoNF3J7MfdtPIu/fFllmBhanKre0qWN/jpKt3ndyJ1hwj9df
29iOfiqpZtfSALDYuPPhJBfzKyJQ477wJFjI27drV6C/inDfXe6oBxay4dE7
Z3CejWCT7utOgcWqmqCtgZhfEdoJWdfLwGKhhpqL/Rz6vx/5A1FKYF67tGgg
Bf1l+DHpbHc2mJeLPBxmYj2HO6/90TsI5kXzpEzfYr8JZ+4+tLEezLP6hrp/
fUPWejB98BGYR7MIU97T6C9/tOUoeIA5UWF6UR7297CQDE+NBjDXGw5dF+WL
7FPS5rUBzLVuv860xX4d5vzza3kEmG+SOXN5JdZjmOnbYI9AMJ+f8zb1JM67
YZKxskr6QJ82nNXyXyrws337ffKAPtVwaHQmH/3uH65+1hDQ+1va3mXuRx4c
S6k/CvSyhE3HmTbI+ZZrC4aBnj+SqTashXxHla6tAfRcg75CV5zvQq+C36s5
oF9qUfEyskeOFT+wuxboKeJr9isI/ntAcMvqJFGgx5p6XQnH+SX0+KtLJ/B9
ftf++bo0ITueppkbAt3r2dIOc4EftyXelYkD+oEulSVB6E9DzY110hYAnTlF
WuhIQTZcfftOMdDJUxJGMxnIu8bn1RgB3Wg41eg19ptQNdGTOi+Brl7GiOpB
fxOqoLKlOxDoSukOl0KwfkJldiqV9wJdzrt4SWo/sji/S0QX6JIG5JB9OJ+H
LtXTe/0f0JfO+7U2W3C+RYYOHxOBPv/JzZNr0f+GzKVZK5QC7ben1k0K+t+Q
Gbpp4QqgTUrFSwr0NOQH72CWP9CG8hPuN+P9h0w1fZZIBlovWfaZFPrhkE/X
tuVKA62lY/WUFOZ7yEjLCSkloL2wdSLFZyIPuWvb3gRa+eu+zZM4T4cMuo/Y
qgGtcO8hA5/dyP2dy4ieQMu92c8vVUPuu6+7RhZoGbOK3NMeyD2/ZOSXAy2N
LqHzuRC5+6GDJx9oSWdjPqagXwt5M9ASiu+LanJ0DEwXcIzlUwbQTs36dZZn
CDinTroWaEc3ZV3rXS1YT9l1oxxorga1mm80BO/3+E/PA2hcat5maRnB91ex
ddqBxrLYK99iLtjfXj9ZXE82JbZZY78LeffLdm8j0GDnxX/dioLzGRx6qA+0
3VIrzYVQj0JGpZTG1gNt+2iw14oLyBPh6rmFQNvwsGAsDPMz5GvMzncUoEl7
xmgl4/2H/N6+MPg80Jave86fwfoLmfWKCNoFtAXlBqKhjYL7sn7coQzU36xS
33ZB/i0brubfA+qn3y1iX7F/hUq92/dNDajv+Js8YhYJ8iNXahsfqB3i7uJ9
+P3QbbRZXzGg1kc5htd/FuRXwxeFJqA+HSnbeg79WOg+9ZVRa4D6SE/TKMtT
kJ8Bj7ZuAGp6rpru+1vIHiOjZ/YCNalevKkjEDlojeGgI1Aj2usWDqF+hibS
r+XoANW9wLQr8Cvyo4/3X68DKi+GnTyB+hJaZyf/9jxQmaSGN2sF9dQ3pbBD
D6i6cYbtOejHwpb9F/nqKFDVlrm/zkW/GLZ5RGwfB6gbTjLPZmM8w8AtyCcI
qCLikQGfcT4NO3lULbYUKH/0ep7UH0C+uCzEvRYon81Fk+twXgp7vKY7KB4o
baotmYJ5LexvaayaAVBqflvNRNajPm1wC6wZA0rxnZDT57B/hpNK6/SSgHK1
zEZ9DPUnPC3qtFogUA5dzD6/AfUigkndd+MdUOyixRcdQ38fEf1UtC4BKBRW
4prLmF8Rpcxiwf8nqHbGIXQR5l+kmk7UZlugKPx7f349zieRbo8Ozg4ARZz0
PkgQ/8g7me/E/IH8zVvHyB/zP0qdznXdAuQPVCeLrcuRT+h4/7gG5Pb5d3Kf
jiM/W+DmMgDkgq8pV8WxX0fbZ7L8PYHsW1OeZYTxOV1WO1dUCeQDxmqQifNB
jIL2ZF4+kFnJOdK1qAcxkdlJ/CQga0YPRKdZYb+y179W8gHMxh9KL67B/Ion
GhWt6gGzN3buqq9wPoh/Gb9gpAPMako+2Fii306wLWTeoYHZ9fRD9Ne4nh8t
sophCGYWvP65OYxX8p57xRUXwEy//t6fvei3ksermXddwEy5886nQKy3M7el
97YXg+lchdq/SYzHWb08xbYRML29lL9HAvvn+UFKxsHlYJpcpZjShH7zwnj6
s+IxMPV/48CXRb+ctrDV+VAXmJp8/Gk6Tx0I6Qdb+RQGkLrMt5dRTgHhhvro
ZLstkIprTDbUYr/OGF19U6gDSGnPbqyysABCZq3Ovst6QGJpDC/LUQLCneXP
1a61gUnmTh7TvxkIBcZ/b03yweSwQlaA/xogFL+pz7ByAhOFuqDXKp1AKH83
UxFwDowfKv5kimD+vHjayzyZBsb2lKs3luP5m3/4Gm1R+h/uTwDb
      "]]}}, {
    CircleBox[{22, 59}, 47], 
    CircleBox[{22, 59}, NCache[Rational[13, 25], 0.52]], 
    CircleBox[
     NCache[{22 + 47 Cos[27 Degree], 59 + 47 Sin[27 Degree]}, {
      63.87730663685329, 80.3375534877587}], NCache[Rational[13, 25], 0.52]], 
    CircleBox[{75.7707679139925, 68.19071937967979}, NCache[
     Rational[13, 25], 0.52]], 
    CircleBox[{104.80480573759712`, 38.53815376289886}, NCache[
     Rational[13, 25], 0.52]], 
    CircleBox[{41.33468574303346, 29.227194837937446`}, NCache[
     Rational[13, 25], 0.52]], 
    LineBox[{{22, 59}, {41.33468574303346, 29.227194837937446`}}], 
    LineBox[NCache[{{22, 59}, {
       22 + 47 Cos[27 Degree], 59 + 47 Sin[27 Degree]}}, {{22, 59}, {
       63.87730663685329, 80.3375534877587}}]], 
    LineBox[{{41.33468574303346, 29.227194837937446`}, {75.7707679139925, 
     68.19071937967979}}], 
    LineBox[NCache[{{22 + 47 Cos[27 Degree], 59 + 47 Sin[27 Degree]}, {
       75.7707679139925, 68.19071937967979}, {104.80480573759712`, 
       38.53815376289886}, {
       22 + 47 Cos[27 Degree], 59 + 47 Sin[27 Degree]}}, {{63.87730663685329, 
      80.3375534877587}, {75.7707679139925, 68.19071937967979}, {
      104.80480573759712`, 38.53815376289886}, {63.87730663685329, 
      80.3375534877587}}]], 
    InsetBox["A0", 
     NCache[{Rational[356, 15], Rational[859, 15]}, {23.733333333333334`, 
      57.266666666666666`}]], 
    InsetBox["A", 
     NCache[{Rational[356, 15] + 47 Cos[27 Degree], Rational[911, 15] + 
       47 Sin[27 Degree]}, {65.61063997018663, 82.07088682109203}]], 
    InsetBox["B", {77.50410124732583, 69.92405271301313}], 
    InsetBox["K", {106.53813907093046`, 40.27148709623219}], 
    InsetBox["B0", {43.068019076366795`, 27.493861504604112`}]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 2)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{
  3.46746301746504*^9, 3.467463230869689*^9, {3.467463328583921*^9, 
   3.467463346976651*^9}, 3.4674651566757402`*^9, 3.467465366855465*^9, 
   3.4674656243916273`*^9, 3.467465688402937*^9, {3.467465722271455*^9, 
   3.467465763661873*^9}, 3.467465844300186*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmgk0lG0Ux1sU2iRECi2SyhYt9q5mGGbDzNhmmMlSyRaVSPYt2yBpkVaJ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      "]]}}, {
    CircleBox[{22, 59}, 47], 
    CircleBox[{22, 59}, NCache[Rational[13, 25], 0.52]], 
    CircleBox[
     NCache[{22 + 47 Cos[33 Degree], 59 + 47 Sin[33 Degree]}, {
      61.41751669343493, 84.59803464570628}], NCache[Rational[13, 25], 0.52]],
     CircleBox[{71.95361536976114, 71.25672194107648}, NCache[
     Rational[13, 25], 0.52]], 
    CircleBox[{97.6740915502046, 38.68822327977428}, NCache[
     Rational[13, 25], 0.52]], 
    CircleBox[{41.33468574303346, 29.227194837937446`}, NCache[
     Rational[13, 25], 0.52]], 
    LineBox[{{22, 59}, {41.33468574303346, 29.227194837937446`}}], 
    LineBox[NCache[{{22, 59}, {
       22 + 47 Cos[33 Degree], 59 + 47 Sin[33 Degree]}}, {{22, 59}, {
       61.41751669343493, 84.59803464570628}}]], 
    LineBox[{{41.33468574303346, 29.227194837937446`}, {71.95361536976114, 
     71.25672194107648}}], 
    LineBox[NCache[{{22 + 47 Cos[33 Degree], 59 + 47 Sin[33 Degree]}, {
       71.95361536976114, 71.25672194107648}, {97.6740915502046, 
       38.68822327977428}, {
       22 + 47 Cos[33 Degree], 59 + 47 Sin[33 Degree]}}, {{61.41751669343493, 
      84.59803464570628}, {71.95361536976114, 71.25672194107648}, {
      97.6740915502046, 38.68822327977428}, {61.41751669343493, 
      84.59803464570628}}]], 
    InsetBox["A0", 
     NCache[{Rational[356, 15], Rational[859, 15]}, {23.733333333333334`, 
      57.266666666666666`}]], 
    InsetBox["A", 
     NCache[{Rational[356, 15] + 47 Cos[33 Degree], Rational[911, 15] + 
       47 Sin[33 Degree]}, {63.15085002676827, 86.33136797903961}]], 
    InsetBox["B", {73.68694870309447, 72.99005527440981}], 
    InsetBox["K", {99.40742488353793, 40.42155661310761}], 
    InsetBox["B0", {43.068019076366795`, 27.493861504604112`}]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 2)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{
  3.46746301746504*^9, 3.467463230869689*^9, {3.467463328583921*^9, 
   3.467463346976651*^9}, 3.4674651566757402`*^9, 3.467465366855465*^9, 
   3.4674656243916273`*^9, 3.467465688402937*^9, {3.467465722271455*^9, 
   3.467465763661873*^9}, 3.467465844415254*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmgk0lG0Ux1sU2iRECi2SyhYt9q5mGGbDzNhmmMlSyRaVSPYt2yBpkVaJ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      "]]}}, {
    CircleBox[{22, 59}, 47], 
    CircleBox[{22, 59}, NCache[Rational[13, 25], 0.52]], 
    CircleBox[
     NCache[{22 + 47 Cos[39 Degree], 59 + 47 Sin[39 Degree]}, {
      58.52586018847763, 88.57805837934237}], NCache[Rational[13, 25], 0.52]],
     CircleBox[{67.52067727632195, 74.15262023846697}, NCache[
     Rational[13, 25], 0.52]], 
    CircleBox[{89.47861310841262, 38.93758007103577}, NCache[
     Rational[13, 25], 0.52]], 
    CircleBox[{41.33468574303346, 29.227194837937446`}, NCache[
     Rational[13, 25], 0.52]], 
    LineBox[{{22, 59}, {41.33468574303346, 29.227194837937446`}}], 
    LineBox[NCache[{{22, 59}, {
       22 + 47 Cos[39 Degree], 59 + 47 Sin[39 Degree]}}, {{22, 59}, {
       58.52586018847763, 88.57805837934237}}]], 
    LineBox[{{41.33468574303346, 29.227194837937446`}, {67.52067727632195, 
     74.15262023846697}}], 
    LineBox[NCache[{{22 + 47 Cos[39 Degree], 59 + 47 Sin[39 Degree]}, {
       67.52067727632195, 74.15262023846697}, {89.47861310841262, 
       38.93758007103577}, {
       22 + 47 Cos[39 Degree], 59 + 47 Sin[39 Degree]}}, {{58.52586018847763, 
      88.57805837934237}, {67.52067727632195, 74.15262023846697}, {
      89.47861310841262, 38.93758007103577}, {58.52586018847763, 
      88.57805837934237}}]], 
    InsetBox["A0", 
     NCache[{Rational[356, 15], Rational[859, 15]}, {23.733333333333334`, 
      57.266666666666666`}]], 
    InsetBox["A", 
     NCache[{Rational[356, 15] + 47 Cos[39 Degree], Rational[911, 15] + 
       47 Sin[39 Degree]}, {60.259193521810964`, 90.31139171267569}]], 
    InsetBox["B", {69.25401060965528, 75.8859535718003}], 
    InsetBox["K", {91.21194644174595, 40.6709134043691}], 
    InsetBox["B0", {43.068019076366795`, 27.493861504604112`}]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 2)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{
  3.46746301746504*^9, 3.467463230869689*^9, {3.467463328583921*^9, 
   3.467463346976651*^9}, 3.4674651566757402`*^9, 3.467465366855465*^9, 
   3.4674656243916273`*^9, 3.467465688402937*^9, {3.467465722271455*^9, 
   3.467465763661873*^9}, 3.467465844479707*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmgk0lG0Ux1sU2iRECi2SyhYt9q5mGGbDzNhmmMlSyRaVSPYt2yBpkVaJ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      "]]}}, {
    CircleBox[{22, 59}, 47], 
    CircleBox[{22, 59}, NCache[Rational[13, 25], 0.52]], 
    CircleBox[
     NCache[{22 + 47 2^Rational[-1, 2], 59 + 47 2^Rational[-1, 2]}, {
      55.23401871576773, 92.23401871576773}], NCache[Rational[13, 25], 0.52]],
     CircleBox[{62.34602810494812, 76.79318575740018}, NCache[
     Rational[13, 25], 0.52]], 
    CircleBox[{79.70769808441788, 39.09938765314994}, NCache[
     Rational[13, 25], 0.52]], 
    CircleBox[{41.33468574303346, 29.227194837937446`}, NCache[
     Rational[13, 25], 0.52]], 
    LineBox[{{22, 59}, {41.33468574303346, 29.227194837937446`}}], 
    LineBox[NCache[{{22, 59}, {
       22 + 47 2^Rational[-1, 2], 59 + 47 2^Rational[-1, 2]}}, {{22, 59}, {
       55.23401871576773, 92.23401871576773}}]], 
    LineBox[{{41.33468574303346, 29.227194837937446`}, {62.34602810494812, 
     76.79318575740018}}], 
    LineBox[NCache[{{22 + 47 2^Rational[-1, 2], 59 + 47 2^Rational[-1, 2]}, {
       62.34602810494812, 76.79318575740018}, {79.70769808441788, 
       39.09938765314994}, {
       22 + 47 2^Rational[-1, 2], 59 + 47 2^Rational[-1, 2]}}, {{
      55.23401871576773, 92.23401871576773}, {62.34602810494812, 
      76.79318575740018}, {79.70769808441788, 39.09938765314994}, {
      55.23401871576773, 92.23401871576773}}]], 
    InsetBox["A0", 
     NCache[{Rational[356, 15], Rational[859, 15]}, {23.733333333333334`, 
      57.266666666666666`}]], 
    InsetBox["A", 
     NCache[{Rational[356, 15] + 47 2^Rational[-1, 2], Rational[911, 15] + 
       47 2^Rational[-1, 2]}, {56.967352049101066`, 93.96735204910107}]], 
    InsetBox["B", {64.07936143828145, 78.52651909073352}], 
    InsetBox["K", {81.44103141775122, 40.832720986483274`}], 
    InsetBox["B0", {43.068019076366795`, 27.493861504604112`}]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 2)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{
  3.46746301746504*^9, 3.467463230869689*^9, {3.467463328583921*^9, 
   3.467463346976651*^9}, 3.4674651566757402`*^9, 3.467465366855465*^9, 
   3.4674656243916273`*^9, 3.467465688402937*^9, {3.467465722271455*^9, 
   3.467465763661873*^9}, 3.467465844565317*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmgk0lG0Ux1sU2iRECi2SyhYt9q5mGGbDzNhmmMlSyRaVSPYt2yBpkVaJ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      "]]}}, {
    CircleBox[{22, 59}, 47], 
    CircleBox[{22, 59}, NCache[Rational[13, 25], 0.52]], 
    CircleBox[
     NCache[{22 + 47 Sin[39 Degree], 59 + 47 Cos[39 Degree]}, {
      51.57805837934236, 95.52586018847762}], NCache[Rational[13, 25], 0.52]],
     CircleBox[{56.00943835622763, 79.11358211684902}, NCache[
     Rational[13, 25], 0.52]], 
    CircleBox[{66.82721888803579, 39.04831505963811}, NCache[
     Rational[13, 25], 0.52]], 
    CircleBox[{41.33468574303346, 29.227194837937446`}, NCache[
     Rational[13, 25], 0.52]], 
    LineBox[{{22, 59}, {41.33468574303346, 29.227194837937446`}}], 
    LineBox[NCache[{{22, 59}, {
       22 + 47 Sin[39 Degree], 59 + 47 Cos[39 Degree]}}, {{22, 59}, {
       51.57805837934236, 95.52586018847762}}]], 
    LineBox[{{41.33468574303346, 29.227194837937446`}, {56.00943835622763, 
     79.11358211684902}}], 
    LineBox[NCache[{{22 + 47 Sin[39 Degree], 59 + 47 Cos[39 Degree]}, {
       56.00943835622763, 79.11358211684902}, {66.82721888803579, 
       39.04831505963811}, {
       22 + 47 Sin[39 Degree], 59 + 47 Cos[39 Degree]}}, {{51.57805837934236, 
      95.52586018847762}, {56.00943835622763, 79.11358211684902}, {
      66.82721888803579, 39.04831505963811}, {51.57805837934236, 
      95.52586018847762}}]], 
    InsetBox["A0", 
     NCache[{Rational[356, 15], Rational[859, 15]}, {23.733333333333334`, 
      57.266666666666666`}]], 
    InsetBox["A", 
     NCache[{Rational[356, 15] + 47 Sin[39 Degree], Rational[911, 15] + 
       47 Cos[39 Degree]}, {53.31139171267569, 97.25919352181097}]], 
    InsetBox["B", {57.74277168956097, 80.84691545018235}], 
    InsetBox["K", {68.56055222136912, 40.78164839297144}], 
    InsetBox["B0", {43.068019076366795`, 27.493861504604112`}]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 2)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{
  3.46746301746504*^9, 3.467463230869689*^9, {3.467463328583921*^9, 
   3.467463346976651*^9}, 3.4674651566757402`*^9, 3.467465366855465*^9, 
   3.4674656243916273`*^9, 3.467465688402937*^9, {3.467465722271455*^9, 
   3.467465763661873*^9}, 3.467465844647456*^9}]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
par set 2 
with B0-F-G-M0 and C, B0 and M0 show the base line : herein, A0 == B0, M0 = \
B0
use  also \[Psi]\[Rule]f\[Psi]2,\
\>", "Subsection",
 CellChangeTimes->{
  3.4674660592765417`*^9, {3.467467155169099*^9, 3.467467162722027*^9}}],

Cell[CellGroupData[{

Cell[BoxData["par"], "Input",
 CellChangeTimes->{{3.467465993233705*^9, 3.467466004146441*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A0x", "\[Rule]", "22"}], ",", 
   RowBox[{"A0y", "\[Rule]", "59"}], ",", 
   RowBox[{"\[Gamma]0", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "57"}], " ", "\[Degree]"}]}], ",", 
   RowBox[{"a", "\[Rule]", "47"}], ",", 
   RowBox[{"b", "\[Rule]", "52"}], ",", 
   RowBox[{"c", "\[Rule]", "17"}], ",", 
   RowBox[{"d", "\[Rule]", "35.5`"}], ",", 
   RowBox[{"\[Kappa]", "\[Rule]", "0"}], ",", 
   RowBox[{"k", "\[Rule]", "58.5`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.467465994636183*^9, 3.467466004474078*^9}, 
   3.467466158366036*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"par2", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"A0x", "\[Rule]", "42"}], ",", 
    RowBox[{"A0y", "\[Rule]", "29"}], ",", 
    RowBox[{"\[Gamma]0", "\[Rule]", 
     RowBox[{
      RowBox[{"-", "57"}], " ", "\[Degree]"}]}], ",", 
    RowBox[{"a", "\[Rule]", "41.5"}], ",", 
    RowBox[{"b", "\[Rule]", "117"}], ",", 
    RowBox[{"c", "\[Rule]", "129"}], ",", 
    RowBox[{"d", "\[Rule]", "85"}], ",", 
    RowBox[{"\[Kappa]", "\[Rule]", 
     RowBox[{"180", " ", "Degree"}]}], ",", 
    RowBox[{"k", "\[Rule]", "52"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.419852365989037*^9, 3.4198524491248837`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A0x", "\[Rule]", "42"}], ",", 
   RowBox[{"A0y", "\[Rule]", "29"}], ",", 
   RowBox[{"\[Gamma]0", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "57"}], " ", "\[Degree]"}]}], ",", 
   RowBox[{"a", "\[Rule]", "41.5`"}], ",", 
   RowBox[{"b", "\[Rule]", "117"}], ",", 
   RowBox[{"c", "\[Rule]", "129"}], ",", 
   RowBox[{"d", "\[Rule]", "85"}], ",", 
   RowBox[{"\[Kappa]", "\[Rule]", 
    RowBox[{"180", " ", "\[Degree]"}]}], ",", 
   RowBox[{"k", "\[Rule]", "52"}]}], "}"}]], "Output",
 CellChangeTimes->{3.467463019480297*^9, 3.467463409785469*^9, 
  3.467464400394824*^9, 3.467465852446456*^9, 3.467466158652483*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xKpar", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"xK", "/.", "\[InvisibleSpace]", 
      RowBox[{"\[Delta]", "\[Rule]", "f\[Delta]"}]}], "/.", 
     "\[InvisibleSpace]", 
     RowBox[{"\[Psi]", "\[Rule]", "f\[Psi]2"}]}], "/.", "\[InvisibleSpace]", 
    "par2"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"yKpar", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"yK", "/.", "\[InvisibleSpace]", 
      RowBox[{"\[Delta]", "\[Rule]", "f\[Delta]"}]}], "/.", 
     "\[InvisibleSpace]", 
     RowBox[{"\[Psi]", "\[Rule]", "f\[Psi]2"}]}], "/.", "\[InvisibleSpace]", 
    "par2"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"plo2", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"xKpar", ",", "yKpar"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[CurlyPhi]", ",", 
       RowBox[{"0", " ", "\[Degree]"}], ",", 
       RowBox[{"360", " ", "\[Degree]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "130"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "120"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Path of K - par set 2\>\""}]}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4198524708446827`*^9, 3.4198524779235077`*^9}, 
   3.46746340379434*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"plo1", ",", "plo2", ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Path of K - par set 1+2\>\""}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmgk0lG0Ux1sU2iRECi2SyhYt9q5mGGbDzNhmmMlSyRaVSPYt2yBpkVaJ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      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt3Hk8VN8bB3AhhbJmDWmhREIhQh9mMMZYZsY+w4iSfcuWQoskSykqpUWS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      "]]}}},
  Axes->True,
  AxesOrigin->{0, 0},
  GridLines->Automatic,
  PlotLabel->FormBox["\"Path of K - par set 1+2\"", TraditionalForm],
  PlotRange->{{0, 130}, {0, 120}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.467463019984543*^9, 3.467463410127864*^9, 
  3.467464400690489*^9, 3.467465852780274*^9, 3.467466158839451*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Animation of crank-rocker mecha par 2  \
\>", "Subsubsection",
 CellChangeTimes->{{3.46746618541076*^9, 3.467466324467415*^9}, {
  3.467467148917997*^9, 3.467467150594192*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pa", "=", "par2"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A0x", "\[Rule]", "42"}], ",", 
   RowBox[{"A0y", "\[Rule]", "29"}], ",", 
   RowBox[{"\[Gamma]0", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "57"}], " ", "\[Degree]"}]}], ",", 
   RowBox[{"a", "\[Rule]", "41.5`"}], ",", 
   RowBox[{"b", "\[Rule]", "117"}], ",", 
   RowBox[{"c", "\[Rule]", "129"}], ",", 
   RowBox[{"d", "\[Rule]", "85"}], ",", 
   RowBox[{"\[Kappa]", "\[Rule]", 
    RowBox[{"180", " ", "\[Degree]"}]}], ",", 
   RowBox[{"k", "\[Rule]", "52"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4674630201303883`*^9, 3.46746440618097*^9, 
  3.467466162483324*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"f\[Psi]i", "=", "f\[Psi]2"}], ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rA0x", "=", 
   RowBox[{"A0x", "/.", "\[InvisibleSpace]", "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rA0y", "=", 
   RowBox[{"A0y", "/.", "\[InvisibleSpace]", "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rB0x", "=", 
   RowBox[{
    RowBox[{"A0x", "+", 
     RowBox[{"d", " ", 
      RowBox[{"Cos", "[", "\[Gamma]0", "]"}]}]}], "/.", "\[InvisibleSpace]", 
    "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rB0y", "=", 
   RowBox[{
    RowBox[{"A0y", "+", 
     RowBox[{"d", " ", 
      RowBox[{"Sin", "[", "\[Gamma]0", "]"}]}]}], "/.", "\[InvisibleSpace]", 
    "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rax", "=", 
   RowBox[{
    RowBox[{"A0x", "+", 
     RowBox[{"a", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[CurlyPhi]", "+", "\[Gamma]0"}], "]"}]}]}], "/.", 
    "\[InvisibleSpace]", "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ray", "=", 
   RowBox[{
    RowBox[{"A0y", "+", 
     RowBox[{"a", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"\[CurlyPhi]", "+", "\[Gamma]0"}], "]"}]}]}], "/.", 
    "\[InvisibleSpace]", "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rbx", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"A0x", "+", 
      RowBox[{"b", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Psi]", "+", "\[Gamma]0"}], "]"}]}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"Cos", "[", "\[Gamma]0", "]"}]}]}], "/.", "\[InvisibleSpace]", 
     
     RowBox[{"\[Psi]", "\[Rule]", "f\[Psi]i"}]}], "/.", "\[InvisibleSpace]", 
    "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rby", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"A0y", "+", 
      RowBox[{"b", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"\[Psi]", "+", "\[Gamma]0"}], "]"}]}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"Sin", "[", "\[Gamma]0", "]"}]}]}], "/.", "\[InvisibleSpace]", 
     
     RowBox[{"\[Psi]", "\[Rule]", "f\[Psi]i"}]}], "/.", "\[InvisibleSpace]", 
    "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rkx", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"xK", "/.", "\[InvisibleSpace]", 
      RowBox[{"\[Delta]", "\[Rule]", "f\[Delta]"}]}], "/.", 
     "\[InvisibleSpace]", 
     RowBox[{"\[Psi]", "\[Rule]", "f\[Psi]i"}]}], "/.", "\[InvisibleSpace]", 
    "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rky", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"yK", "/.", "\[InvisibleSpace]", 
      RowBox[{"\[Delta]", "\[Rule]", "f\[Delta]"}]}], "/.", 
     "\[InvisibleSpace]", 
     RowBox[{"\[Psi]", "\[Rule]", "f\[Psi]i"}]}], "/.", "\[InvisibleSpace]", 
    "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"lmax", "=", 
   RowBox[{
    RowBox[{"Max", "[", 
     RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}], "/.", 
    "\[InvisibleSpace]", "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Plo0", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "100"}], ",", "300"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "150"}], ",", "200"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Coupling Path par set 2)\>\""}]}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{
  3.46746311103645*^9, {3.467465864427812*^9, 3.467465867186174*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"PloMecha1", " ", "=", " ", 
       RowBox[{"Graphics", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"rA0x", ",", " ", "rA0y"}], "}"}], ",", " ", 
            RowBox[{"a", " ", "/.", " ", "pa"}]}], "]"}], ",", " ", 
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"rA0x", ",", " ", "rA0y"}], "}"}], ",", " ", 
            RowBox[{"lmax", "/", "100"}]}], "]"}], ",", " ", "\n", "       ", 
          
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"rax", ",", " ", "ray"}], "}"}], ",", " ", 
            RowBox[{"lmax", "/", "100"}]}], "]"}], ",", " ", 
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"rbx", ",", " ", "rby"}], "}"}], ",", " ", 
            RowBox[{"lmax", "/", "100"}]}], "]"}], ",", " ", 
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"rkx", ",", " ", "rky"}], "}"}], ",", " ", 
            RowBox[{"lmax", "/", "100"}]}], "]"}], ",", " ", "\n", "       ", 
          
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"rB0x", ",", " ", "rB0y"}], "}"}], ",", " ", 
            RowBox[{"lmax", "/", "100"}]}], "]"}], ",", " ", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"rA0x", ",", " ", "rA0y"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"rB0x", ",", " ", "rB0y"}], "}"}]}], "}"}], "]"}], ",", 
          " ", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"rA0x", ",", " ", "rA0y"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"rax", ",", " ", "ray"}], "}"}]}], "}"}], "]"}], ",", 
          " ", "\n", "       ", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"rB0x", ",", " ", "rB0y"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"rbx", ",", " ", "rby"}], "}"}]}], "}"}], "]"}], ",", 
          " ", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"rax", ",", " ", "ray"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"rbx", ",", " ", "rby"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"rkx", ",", " ", "rky"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"rax", ",", " ", "ray"}], "}"}]}], "}"}], "]"}], ",", 
          " ", "\n", "       ", 
          RowBox[{"Text", "[", 
           RowBox[{"A0", ",", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"rA0x", " ", "+", " ", 
               RowBox[{"lmax", "/", "30"}]}], ",", " ", 
              RowBox[{"rA0y", " ", "-", " ", 
               RowBox[{"lmax", "/", "30"}]}]}], "}"}]}], "]"}], ",", " ", 
          RowBox[{"Text", "[", 
           RowBox[{"A", ",", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"rax", " ", "+", " ", 
               RowBox[{"lmax", "/", "30"}]}], ",", " ", 
              RowBox[{"ray", " ", "+", " ", 
               RowBox[{"lmax", "/", "30"}]}]}], "}"}]}], "]"}], ",", " ", 
          "\n", "       ", 
          RowBox[{"Text", "[", 
           RowBox[{"B", ",", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"rbx", " ", "+", " ", 
               RowBox[{"lmax", "/", "30"}]}], ",", " ", 
              RowBox[{"rby", " ", "+", " ", 
               RowBox[{"lmax", "/", "30"}]}]}], "}"}]}], "]"}], ",", " ", 
          RowBox[{"Text", "[", 
           RowBox[{"K", ",", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"rkx", " ", "+", " ", 
               RowBox[{"lmax", "/", "30"}]}], ",", " ", 
              RowBox[{"rky", " ", "+", " ", 
               RowBox[{"lmax", "/", "30"}]}]}], "}"}]}], "]"}], ",", " ", 
          "\n", "       ", 
          RowBox[{"Text", "[", 
           RowBox[{"B0", ",", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"rB0x", " ", "+", " ", 
               RowBox[{"lmax", "/", "30"}]}], ",", " ", 
              RowBox[{"rB0y", " ", "-", " ", 
               RowBox[{"lmax", "/", "30"}]}]}], "}"}]}], "]"}]}], "}"}], 
        "]"}]}], ";", " ", 
      RowBox[{"Print", "[", 
       RowBox[{"Show", "[", 
        RowBox[{"Plo0", ",", " ", "plo2", ",", " ", "PloMecha1"}], "]"}], 
       "]"}]}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"\[CurlyPhi]", ",", " ", "0", ",", " ", 
       RowBox[{"2", "*", "Pi"}], ",", " ", 
       RowBox[{"Pi", "/", "6"}]}], "}"}]}], "]"}], ";"}], " "}]], "Input",
 CellChangeTimes->{3.467463423770702*^9},
 FormatType->"InputForm",
 ImageRegion->{{0, 1}, {0, 1}},
 RenderingOptions->{"RenderThickness"->False}],

Cell[CellGroupData[{

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt3Hk8VN8bB3AhhbJmDWmhREIhQh9mMMZYZsY+w4iSfcuWQoskSykqpUWS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      "]]}}, {CircleBox[{42, 29}, 41.5], 
    CircleBox[{42, 29}, NCache[Rational[129, 100], 1.29]], 
    CircleBox[{64.60251995312362, -5.8048285697351005`}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[{-2.662628129381865, -115.87934811644313`}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[{91.71715328870724, 38.56629558862783}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[
     NCache[{42 + 85 Sin[33 Degree], 29 - 85 Cos[33 Degree]}, {
      88.29431797627731, -42.28699827536104}], NCache[
     Rational[129, 100], 1.29]], 
    LineBox[NCache[{{42, 29}, {
       42 + 85 Sin[33 Degree], 29 - 85 Cos[33 Degree]}}, {{42, 29}, {
       88.29431797627731, -42.28699827536104}}]], 
    LineBox[{{42, 29}, {64.60251995312362, -5.8048285697351005`}}], 
    LineBox[NCache[{{
       42 + 85 Sin[33 Degree], 29 - 85 
        Cos[33 Degree]}, {-2.662628129381865, -115.87934811644313`}}, {{
      88.29431797627731, -42.28699827536104}, {-2.662628129381865, \
-115.87934811644313`}}]], 
    LineBox[{{
     64.60251995312362, -5.8048285697351005`}, {-2.662628129381865, \
-115.87934811644313`}, {91.71715328870724, 38.56629558862783}, {
     64.60251995312362, -5.8048285697351005`}}], 
    InsetBox["A0", 
     NCache[{Rational[463, 10], Rational[247, 10]}, {46.3, 24.7}]], 
    InsetBox["A", {68.90251995312362, -1.5048285697351007`}], 
    InsetBox["B", {1.6373718706181348`, -111.57934811644313`}], 
    InsetBox["K", {96.01715328870723, 42.86629558862783}], 
    InsetBox["B0", 
     NCache[{Rational[463, 10] + 85 Sin[33 Degree], Rational[247, 10] - 85 
       Cos[33 Degree]}, {92.5943179762773, -46.58699827536104}]]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 2)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.467463020891292*^9, 3.467464406512301*^9, 
  3.467465870757783*^9, 3.4674661628834753`*^9},
 AnimationDisplayTime->0.059349290000000006`,
 AnimationCycleOffset->1,
 AnimationCycleRepetitions->Infinity],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt3Hk8VN8bB3AhhbJmDWmhREIhQh9mMMZYZsY+w4iSfcuWQoskSykqpUWS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      "]]}}, {CircleBox[{42, 29}, 41.5], 
    CircleBox[{42, 29}, NCache[Rational[129, 100], 1.29]], 
    CircleBox[{78.97677075381726, 10.159394260808806`}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[{-26.70890326414932, -63.810453024203916`}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[{121.57874787733869`, 39.97669704236432}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[
     NCache[{42 + 85 Sin[33 Degree], 29 - 85 Cos[33 Degree]}, {
      88.29431797627731, -42.28699827536104}], NCache[
     Rational[129, 100], 1.29]], 
    LineBox[NCache[{{42, 29}, {
       42 + 85 Sin[33 Degree], 29 - 85 Cos[33 Degree]}}, {{42, 29}, {
       88.29431797627731, -42.28699827536104}}]], 
    LineBox[{{42, 29}, {78.97677075381726, 10.159394260808806`}}], 
    LineBox[NCache[{{
       42 + 85 Sin[33 Degree], 29 - 85 
        Cos[33 Degree]}, {-26.70890326414932, -63.810453024203916`}}, {{
      88.29431797627731, -42.28699827536104}, {-26.70890326414932, \
-63.810453024203916`}}]], 
    LineBox[{{78.97677075381726, 
     10.159394260808806`}, {-26.70890326414932, -63.810453024203916`}, {
     121.57874787733869`, 39.97669704236432}, {78.97677075381726, 
     10.159394260808806`}}], 
    InsetBox["A0", 
     NCache[{Rational[463, 10], Rational[247, 10]}, {46.3, 24.7}]], 
    InsetBox["A", {83.27677075381726, 14.459394260808807`}], 
    InsetBox["B", {-22.40890326414932, -59.51045302420392}], 
    InsetBox["K", {125.87874787733868`, 44.27669704236432}], 
    InsetBox["B0", 
     NCache[{Rational[463, 10] + 85 Sin[33 Degree], Rational[247, 10] - 85 
       Cos[33 Degree]}, {92.5943179762773, -46.58699827536104}]]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 2)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.467463020891292*^9, 3.467464406512301*^9, 
  3.467465870757783*^9, 3.467466163002355*^9},
 AnimationDisplayTime->0.059349290000000006`,
 AnimationCycleOffset->1,
 AnimationCycleRepetitions->Infinity],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt3Hk8VN8bB3AhhbJmDWmhREIhQh9mMMZYZsY+w4iSfcuWQoskSykqpUWS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      "]]}}, {CircleBox[{42, 29}, 41.5], 
    CircleBox[{42, 29}, NCache[Rational[129, 100], 1.29]], 
    CircleBox[{83.44312569231482, 31.171942184082173`}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[{-28.351759423788344`, -33.19344961832433}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[{128.50773054531763`, 57.1176815152848}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[
     NCache[{42 + 85 Sin[33 Degree], 29 - 85 Cos[33 Degree]}, {
      88.29431797627731, -42.28699827536104}], NCache[
     Rational[129, 100], 1.29]], 
    LineBox[NCache[{{42, 29}, {
       42 + 85 Sin[33 Degree], 29 - 85 Cos[33 Degree]}}, {{42, 29}, {
       88.29431797627731, -42.28699827536104}}]], 
    LineBox[{{42, 29}, {83.44312569231482, 31.171942184082173`}}], 
    LineBox[NCache[{{
       42 + 85 Sin[33 Degree], 29 - 85 
        Cos[33 Degree]}, {-28.351759423788344`, -33.19344961832433}}, {{
      88.29431797627731, -42.28699827536104}, {-28.351759423788344`, \
-33.19344961832433}}]], 
    LineBox[{{83.44312569231482, 
     31.171942184082173`}, {-28.351759423788344`, -33.19344961832433}, {
     128.50773054531763`, 57.1176815152848}, {83.44312569231482, 
     31.171942184082173`}}], 
    InsetBox["A0", 
     NCache[{Rational[463, 10], Rational[247, 10]}, {46.3, 24.7}]], 
    InsetBox["A", {87.74312569231482, 35.471942184082174`}], 
    InsetBox["B", {-24.051759423788344`, -28.89344961832433}], 
    InsetBox["K", {132.80773054531764`, 61.4176815152848}], 
    InsetBox["B0", 
     NCache[{Rational[463, 10] + 85 Sin[33 Degree], Rational[247, 10] - 85 
       Cos[33 Degree]}, {92.5943179762773, -46.58699827536104}]]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 2)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.467463020891292*^9, 3.467464406512301*^9, 
  3.467465870757783*^9, 3.467466163136344*^9},
 AnimationDisplayTime->0.059349290000000006`,
 AnimationCycleOffset->1,
 AnimationCycleRepetitions->Infinity],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt3Hk8VN8bB3AhhbJmDWmhREIhQh9mMMZYZsY+w4iSfcuWQoskSykqpUWS
olLJUpSixVJJKUmUFmsLoSjS73xfr99fXu/XvXPvuec8z3PO8w9WmM/izXx8
fPx8fIKi//2Fy7fe9gG7N6DQdvDK91jDZcJf+FhvMyjWV5J79HfBla+/401V
LShW3V7vqCvgKt2jdkUAoFgaOTxrvAVXo7LNF7ePg2L+iZ8x2wyuyS8nvia3
gLJecCpGeAPc5J8l37kmC4rWgw3higVwWzyaP/plIyia3YtPzGHCTVNq5QvV
G6Cs/DngwTkEN1OrTZJqy0DRWM6cL0SH28bdMbc/B4KilvbiXC8FbsXmxyxG
5UBR8Zop/hcDd/2CgOUHzECRyE5+LZYBd7PpbPnDT0ARLx3+NvYO7jSmR+ZV
Mj6xJ7JU15dw9xg6vfhvIyjzRTsjfnfBPentrJ+8LlCEz2n5v14L98ZLbwfj
g0ERQIJPOx/cn196u1/OFhT+pM93qOJw7zw/vmJLGiiz6pf+3DAE96+prGtS
kaDwOUQynUfhISH4Z1/ld1j8PWjTfkQEHvIvJ2RvPIXFdH+QxHA8PBafbnut
1UVs8VP5eD481qhKR87+CospwQzToWp4OL+eCDL8BYvJG/Wag+bw8Iox17xH
njepobbveyo8toitezZtBouJgt1HtY7DI05TMbNJFBa/zkYMbFKCx86rv+36
WcTLV2gG7YTHfu0ws2Zy/8/rqsqJmvA4IS+6KP4mLMZfKFXuy4BHwR71lCe/
iQMsFVMG4VHS/2D+2x3Egr+KfLPgUXMqItU1DhZjdBPT15fhcf977H21CliM
jo1dS/wKjyfrvl52HiQu2C43LASPrmqJtQnricUgVE3u/zxSMTAeDIsfj/PT
v8vA45vqzZiLZHw/DsjxRcbC4ydd+qKeK7Fz+Z3LHfD4G3x/Y9YW4iXp86bk
wJmdej9fzBAWI+OXlquNgjP/tET8qsPET9TXvMwHR+Zy0aJMMt6R4vk2/Fxw
lMt3drRaEqdHBEbvBket4tScnVeJt/ruX3cCnFVXJ9R+DhF7j++RUQVH/1x6
g0E+sZP+Eol14JhmuR59K01sZ7BwcCk4ljGubt+1iBlzJY9fBMfOed/g00Ji
x5oDHTxwnFf1mQlTiTkbhU9+Bof7L8zHfB1x8NwP5/+As8lqeVDrUuJdkjz5
r+AEpfReEWcQ50XG0wfBiay7MGEuQlxjxBQpBGfbr+BV+7WJeyK/DzmAs0tN
h/rCisyHqBZjuA+cVLtRShmFeH0k06oFnIPh1yzszxJHMFtG74NzNNM/EPOI
L7/em6wFzqlC+V/RR4i/S6g+bQWnsPzeGjkvsj76c9flNYNz6S43wb+DeNcT
x6BJcMruf6WUZBK/9H+9/CY4t+pDBafI/I5pDam/nwvOveoeprEQcTo3ea8I
OC3HDyn95ifx4mEpZUee/yrpqdirOuLmNu94A3C6eOPhciT+f5rvntQk8zsk
NkuuYhOJT/No239T4Iy8/czkvCVufrbVn6zHxLnSnlsPSXx7bKsOcgJ3tuqv
7BPVJP4zviYVbgFXtD1yuRIXFr9XP7669gW4Unufj8xLJH6zwrtUGdxFL9Zf
PNNH8mlDSuGnFeAaLy7O+6sDixnunLdnusBF0To38U+w+LdW8MusTHCtl114
/oHUAz6pVzdsB8B1El/hOCJI8rt34ZV+fnA9thst3mlF8r/j/IbXTeB6f1hp
pUXqkUCbpk1JMrghJ65UTPmAMrvbaUs2E9yt32EwdhcUoW+iogVccOPX34j1
+wPKXIFea9p3cFMemK72zAdFxHrlHtfz4J5J7/sX4k/q1bJprfpecM+XphbN
sSb1LPTlJnY+uJcei61/WAmK5D2FOJ1Z4Fb9aLiS6g3Kgm3z2u8ag/vs15xg
/Y+gKFom907Fg/uq/+2062FQFj6+vpZ3B9y3bScywtVBUXbP6Ar3Arc/902S
XDooqhkRoadMwJ3p3H523WlQljs8EEy/AU/BxN5dI3yk/ooysnm58BRRTtSd
lib1uSXCcHIbPGVsUP14HSjaQRe/xtTDU5OzymkWGZ8B/55DYu7w1Hmu47bk
JCiGU2fEj8vC08A8OCK3GhSj6VTeMS48zSWOHLcg9d5M5m3IIht4ugS8MqG5
kf3lgkrShAw8OdebDfXI/bT31ES7Q/D0Hhf0O5sCiu0i3ysCPvAM2mL/g88P
FIeqs0ErZuC5Uzjom/gjUNxpZ04eiIXnRVOWlrAUKCEjiS9ot+F5ZWWQZggZ
b3iJS94VUXiWSfatnOMMytbgoCNdZ+FZ0yoy90ARKNuEPR7WC8HzmbB59Byy
/yUXXdyutxqe4xGmbP4eUE5F7NM8awbP37OD7GUdQcm/dmJg0S94/s1ROmHo
Asq5SblXSz7DS+is5PDSOlBK8p2VOzzhJb9tb6FtJig3XcTzelbCa736/jeC
q0F55drCfjUDrw13q7m+o6C8Cd8Z2mAALyor/8Vlst92Z+tef0+u223Oi+8t
AaX3V05n3Ai8eMhjn28FZUI/pC62DF67nvpV2cmCujA7a+BoB7xSBLx00gtB
VWVwapQ84JW2Zn3TyXZQ1cTVZdTI+w/vrNhTpA+qdlnF4Jp4eBW8mDQx3g+q
RURhJG0dvOpdfQ+3B4Ma9HTXkfm58Hq0SqNi031QI9QuLdbSgVfTX6HUFAtQ
Y/bVZIdow+t5uoRjlR+ouwL2DXR2wavH++bplCRQj51LHXDcDa/p8d9lvS6g
Pvx+x+ZHL3h8IYfNduSC+vjzgvNV/8AT6IlYxpIH9fmnZWf2KYEnUjH/2oMK
ULtnvA2OFoAnryhtuq4R1F8X36W8VAVP99XLunMbYanRvGfP+Bh4a+9Knf8Z
B8vVg6aC0W/AMzy3vYbSBEsDCQMh+QXgmXp27FM2hKVFzOtzb/PAo+VO5S15
AEtOUWikiRl4Xis7un+/gOXB9LBBUUXwvBtebRxgwfKolm2ksA94vt6qfpf+
wPLkK7XRdn7w/HeXJKiWwbLE7JHLp+fgRR5s1iwrhOXDCMO/V66Bt/eJyOWD
pbD8a9+leXYGvFSVoa58U1gJhqT8+lYLXlqI8Y2Pm2Almt1XuGA3eAemdZk1
9rBSmLg2s14dvGOfrp98ngUrQ8W+lF9D4F3svO7SFg+ryMebFkuPg1fSGxMo
IQareF++izf0wbv8pWk6+iCsdvPzWVYHg3ftyzL+o26wOuQiveV3KHg3y9sf
n1eB1TXn0ZNyS8BriG4iNQZWw1effOksAa+J9+9+1BlYTW5pjFzkAt5jy0Vd
Uo6wnrVCWPeDCnjP+NQez94Ba6k60z1SceC1GyWn3qTC2sC5SP5fJ3ivp6gJ
JiGw3uDAZ5lwFbw3Vf+WrDSDNc1xs/uIBnjdS4LrlKZh7RGkV8RvB96nGp9d
ITdhncQnfLRyELxeZ11TNXI9dd3Qz60PwOsbEvkgognrQ9vyDrRNgTck2Hd/
YzqsC6UYG6YCwRv+Fxs3bQnrpnw5e/Vk8KaEL2gPnAZNVr0wfp8YeNPOIk1n
4kFb1NFvdKoQvL95x5J2D4CmcTjxbLYKvPnmK5SdnwWa6cIM++cW8OYPbWM8
ugDapmRa2asX8BaYZcEU6AAtNNzF5y6b+BCjv1gdtDjfeKOGk/AWLFm3dsQc
tAyvz18PVsBb6G7ip+UXQSsvDmgP0Ib3HLOPcncZoNU+ZZiT85/3nJr+A64y
oDVOzr6t3wfvuaVdO38tBK174zsd1ZXwFolLHtXLgo1QitWXtibiXomK8cOw
kegRuBl1A96iDpaKkTthsxBu86fJ8+YplXRPPoWNzoILsZxYeM/PS6p60A8b
D1F+/rnyxGMN6Y7LYLNpC810pTu8xWzadkrNwCa06dK5QUHiYeNcVyXY7Mm/
dCODPF/c7JjK8x2wOSBjZFzpQZxenbHtN2xyDz4sUT0Bb4lFbh1LD8HmytHb
vy06iDe/khTbD5ubS+Vv9EwSlyj2/TsPm/oK53nn4+EtqSUkw8+BzesvTNsL
QvCWkgn+wdIGnf/knu4Lc4nptEOy06DPd5UICAsk3jEmyokCXV4OE6m7id9W
KWX0gb7qYtjTyml4S895PvG8AvR127yG2+nEurUGdAXQKQ5tjWEtxEnzOZ2b
QHefr+Pkco64IGKnnQTovuNzP+u/I75fvPuKLOihPbRPDTeJP1b8298E+rbn
A/WRycT/jh0+FQt6cmPPCMlr7wWK9u3P9oN+8KFGN/0asV6Xn8FJ0E88qpni
Cya2QSfpY+jnnx6sHp0i9tzR/GsS9GtvTh1MeE8cltW6IwH0mqHuL9e4xEkJ
u7JLQW+YZUNxSSTOpER5VYP+QqlDlF+LOPeT2frjoHeb7r4pPUhc4Ln1kTLo
A77m9+5fJy4uu9g5F/SxA/NPakQSl34KPyIP+sydd/WWx4mvj3i6q8JWePTK
ZeFNxGWdfC3zYCujFdnG0/vvev6XT6OwVQ1Sv6GX8N/vLUtfLYGtZmldQ+wM
8cXGNyvUYWswYZKpH058duXv6y9ha0E9uHt/EPGx4NPHGLC1O3pDvYysx4L0
A86OArB1+3bmj8IK4oSskgv1sN1kY5/ICiEOiVp57yJsw4qrDDT/ez7HaKPM
athuF3tx/tp/turpiCfjTYk7ztLNJdYJWqh6HLaH+gXqbf57vlxH2bEZ2J7y
EEkYNCLr83fl8meTsL34vEjMTZa4Lv7Jqk2wvduS8OYqyVfp/O0ialKwfcy+
pK2+gDhhI2VvJWzbux3SspOIdT7cLWqA7be/70/vjP0vnhLm7efB9nfO7e3c
byTeuvgClGXAmL16tOSXD3FiHS/8NxhKW+28DMl4pRz9n5y+DcZyVllWaSux
6oYLV2LB0NNvWCL6kcR7dYJtsR0YNKG+LSTvvCXeUMrGdoKx9aXz13ZSDyRO
RvxuNwAjsfVA4rl6Ys8X3xbqg7G/1erkWzJ+8bfaEXNcwTjTqVx614rk5z1X
wUQ9MJ7I3mvo6SKOVmtYcAqM19oObAll4hUrPY/tAOOjzarhW59Jvqe2Z394
CMZk6v2aCBJv89Y+HC2og52a9uVdlTnwFjZ0HjxdDbskCfsJ/72k/jy7+iGu
CXZpHkr1WlHEfpZ19t2wO1LU1ai3ntSrA+rlh6xgd9lGiSZJ8mV2Y8Odg8Ow
e3P1V71yKLxnDXaYBZ2EvT7/vPh+Y2I/pepTVNgjjqad20zqa0/B2IWXsLf9
oTBoUgTev/yvMhIlsPcZ8i+oFCT12mBXui1gnzUl/cr5I3g/asK2C4zD/tvB
yzn3eOCNbIy+0FgP+z/L995pJfvPsEBYdWMPHITqZkJfPQLv63rK4sPecFg0
c72fM5/sF/FJ9/tz4cA66mE0qwe8znWys3dpwuHmul0qzyLA6zj1oFi9EA4P
Jvj+1j4k+9e/aMZDZTg8r7qaySX7Q1tlj/ScSTh82bCjV4fsP09+js8P6oaj
+FrR+fFHwKut6Bi8pgJHi/STtKLb4N3uktC7HwBH2p+yhn8U8KpnXIO6g+Ho
EFi8n+8YeFWGCisWCcCRa7fS6NVf8K5u261yezkcY5QUUgO3g3fG4nLzTcCx
+N2dgQJy3tj+NcnlSyaYku/bb2fdAG9bLca0PoIp9/OYUdoK8GIzLjOnzoCp
Ilo7uPwkeFsX7TGkhoC50sjIB4fBC1S2bD7zEkyL3EN7Bch8u267N6cyC8yt
fqksr2nwVtecm76sAearVUcl6hrBW7VMyEkwA8y3tusHJivBW7lfo8OX/P6D
/4QI+w54ajZVflMuYH4rPKeXvhc8xcJZhbOXgCWklJmnROZT8M7UUAmx4bzd
7m3G8GrP+HTdPQOs3Lfvi+aR82DbqZmC/JVgne648mJ4DrxaL0vVTpmBVfjK
smuAnAeb72pEH34K1rWnzeedNsGrtk7ttccfsBprBkX+kfNykb5AFulLWZNp
GRGR3fCK/HDNZn4g2K4fjZ/llcJLYLuU/7x6OMkINpmVO8Hz387rOibhcFro
82ZhbyM8p3ZP9Zw4AafF90Qy6BLwHEs47tR0DU7asY1zfi2H5ydbac1wcr91
l1+3vws8661/V32shFN8nMCHthh4JjwPFZg7H07v+hNH/1mA+2WTgN28G3Au
XPym7vRlcPuGE8UuGcK5+KnmCYlUcD/GOUl0m8P5aqzh41TSr73ZLfM1XgzO
1Q1x84segNsQM7/cqBnOz938JLN3gFvQU95RvhfOM8ZB3ETSj7o2Gvp8M4OL
y2h/6+oX4FQrhXvezIWrwGuD67cY4JQfv+W4+iFchY8Ead54BM7VBetqVdTh
Ks4seP/4D+nn+XoGNGXhqvhgwfwbLHAyb/47TZeCq27Wo5Bd78DxPl+/SE8c
rl4NlT9VLMAR3P72iikXrlWnA6q/n4YHNTzn0K8+uPmkRh+Jc4GH2SZ7K8Us
uG3Jj/q5wwke65yrLmeNwy24UuGbYjM8tHTPVMeHwi2m09730QN4SD8dUTV4
C7d0If1fj3lw/3j8u1JTBdzKhi4MbPCCe2Ial8YNhDvf22OfW6hwu6Z+VY76
B+5H5hdsI+chtxJB90GXfXA/bnB6rHAGbud6PAaH1OF+yhPNxcVwO5a96eOZ
VrifPxceY1MDt8Te2mqTX3CvlPa1i5ODm51JjV+DDNzbd1aiYgiuA3eiaw5P
wUMmzfjznDG4fvTPXONvAA+FzZPOT/jh2iWl3sMNhofyBhMlr1G4PvPuC+eZ
w2PZEFtgTypcK77eOe5Pg8faJYXfGJvguvuu0JFpbXiwFkreO5wB14Wu/bLG
3+GRoSZgsTYdrgtoM2MjafA4OL2V9eAcXOevS1dwJfOU3frmTEsVXP5Jz8kI
6oFHXnhyN+cwXD5WPPAuWQuPknSjUuOTcCm+MejeOgOPxlVmv/2IDc48KyRx
yJmlLDpocgguq335dw9YkXU75ENrLYLLimWfux6tAWcuf1ZZ3gq4KBTe3Wne
AI7Y20jdHTFwnj7C9/ehFDhKW1b/0beEc72R+17Sf3AMet+WKWjAmXH6iPCB
bHAC4rlmAypwtry1eaJSD5xgp6V5mSROzdqszCNHwAnTlFmkKAtnXcH1Cnfo
4ES1RjHWhsJZhrPY8nk6OEm/pW1Pd8Cp+916zpAJOEfqXJ3eN8MplJrJiekD
5+5KyuAlMzhtodrJ5BuDU3eRkj7cBSdvir3wk1BwHizlnpucCyfWBoXefSHg
NEm88VS4DycD7dkuPYHgvGgcMT0jAvbfobS+DjIfvVd05wn9ATtj0Onw3gPg
ClMUriAR7L0mNcr3X4ArmtXa+OU+2AkHd0yc3QLu/LcSdzVrwQ5do3j2zQZw
pTZrxIU4g+0Q+UtV5Bu4Cx3KxGnBYEu2j2QmpICrlXA/6uYrsEVU/0aMtICr
nf1qYsIWbP7AvW/uKYCrUxT4dv4OsEanJSlWEeCurVO0ezgD1ksF+oiILLgm
T1KESFyyjprNDzY7CS5jvWX3HROwDux8kBDwGFx7BefYTzfBSrkv5zr7KLgO
Yx8NxNrAirXKjVEhdYF9OuJP5zyw3GzQ12cFrkeTz6jBYbAUzb5XzPiB6x/D
5L/oA+ap3++FdM+Du2vl85hT+WAedVuTP0XqyO5DEes3PgLzQOXmDgkRcPeM
X5z38iKYSZGBt/+ROpVyrdN55BqY3oOaT8JIHcvgszfXJs9b2mawNNsX3CNT
nlr7yb6gpGPj+T4N3GOaGxdc/Qnmgky3Ctl/4Oa6/snwGwJztvVW1yEy3yeK
vo36kX2wr+bprbvk+88sfGW/XJ7sa0X3xtfFgXth45kj5HscCwTjLbM+gnvR
Y1In5gAcT/jYL+I0glvs2PtnYgUc01XsBCKWg3tJb5d2ZB4cg491XfxyE9zS
J5XlJ/zhuOnXGfcJCXCvltwK6guEo6dzeu1BdXCv7WVm2ubA0V56UD/RFtwy
HQu4LoPj6sNfOui3wK3wXM4f6QfH5WO6y044gVu5qP3UmzA4qrKvWs/SJX6v
tPT6YzhKyniezFYD9yY7gHLyDxx6DUOfqe4Gt0ZazPfAQzi8mhpJfkPeV1Md
1inxHA6P6vjl08vBve3lP0u8Ew4XGZ++Hu4G985JpY6l+nAIChat7I4G9+73
k1qRBnDwNL7ntXUFuPcigoJdTeDgIDLP8A9Zv3s/KHsfjcFBryS6vKYU3LoB
sbrpadj/Hu3VUTEB937Zgl9WNNh/eXTxAe0RuA+UtbMdkmHfnbdw6KwP8V6W
fMhn2NdZKctzyHgeMqoicupgn1rYI7FqLbiPqv5dCsuEfXxitKOCPNmHRIOf
cQphH+z2IkzenpjTq3w5CPaO4iOBZWR9GsYmBoftYW/+tcrlcjC4jesP1ytd
g/2aZhaiyPMadxptW/YT9nKpEiu2LwK3ie+S+bwR2Av7G63xYxCbxJQd/Aq7
KRsL5xhP4mj7B2umYPdNUztnKdkHmy6tuWjzAnbvxfjGMwWI36kd+m4Ju9Yf
t7dHj4HbLLasQkQadvXtm1ZZ/SFer2vFvAO7ooLkxdE7iTO2pukwYJebxh/4
Upv4WnGJhh05x0bGfVv4kvj5d2mpObDbwRkq6SHx2TyCv0fJ+0OtPIpca8F9
LFpwbrUb7Lx1H39wKiReJm2mVA87loq5J51JbJQtHKQOO6po7UKbXGLGEowc
gJ3+H0slPpLPjzl1ixmDsFs++IZXTfLrsX9Y/2Av7BQ6E/q4McSR2i/+kHO2
6BP9qwEZxHEzi7dPgvH3rsCtv97EO95Jr+GCMVz2RfApie/HCS0DV/PA+HDh
+wENsh6Pt7d+ohmD0XZakj1B5vdxzGdLZUcwHh5xYVeUEIcJM+V4YFRl3kuL
tyQmPW//UjCK97HGR9jELvtjZ3uCkbdb4qDbGWLLXsWy82BkJkw7p54m1mNv
n1gHRtJ2BYvB68QLX34oIH1DxLZAVlw8MX9ANsMEDN+40cQHKmT++iTfMAvA
cN5WXveN1NvmR0+nX7eDYb29XKaI1JvmwtPWzZvBMEoc26pHft+ctEfwrQsY
mnui23xIvWl23ZG0ewoM5f1m2rmKxFrpAv9ugiGe5bCjnlxvmil979wJxqzc
yxVet4mfDvAcuLDtveJSd6aY2PdU6urLpI/L+Nlh7kCstuhHN+kTG0I1WL/J
9zV+Mti1az1si/W5+6YXEDsvLvfPhu2Jhb7NTFJvG+dOaOqRPjddQGxnmyaJ
71s+odO7YBv82pNtTScWn5YwvwtbzwdzR0XJ+jyq1LSp4oetfdkWkbxKYrfR
uYs3wFYnx+ZCiDHJrxzr117eoI+HSHqO7iP5+XExe64F6L1bbp3qKSIOUQCr
AvT2TXoWUcng1o9fduqngX7T59zZp/0kv3+f7xg/APqO6O9frMn33u0ca569
DPSQpN37rEk83aW/2FLVDLpXuqBlRyK4tVWOkveugY4LPVM94qS+pKw8JHQG
dMHffp3ryf3VU4FnA/tg80uqTSWfxHe1o8O/E0Ow6de2XZDpCO6tsx2HLObB
pikouEX6Galvxq9i+CJhkznzjmtA6lkFNfNgkRlskjTEZfeR8Zcn5j15Kg2b
cGf/HndpcG9UMM//+QUbVnmRRWI9qa/ylVun/WEjl1m69aMXqc9VUZcls2Ez
tynz4xOSn1fanw2/DAftz5wbGQZkfS6Pvo4b3wNaV1rPgu0kfi+pfrs/nx+0
s1eWRueHkv3BmUZ9tR00rU079t8i+XJmEW78tgFNpfa4WfskuKeVtLMPCIAm
qfgp9wnJ11OyZpU/T8P6Z+e8nhefwc2b1fAjlx/Wd7cKLDEn9eloZWa8ST6s
2VJzdJ6S9cw8ttHvZyisLbM8VhuTeM7wq3h0vwHW6ySF5ds7wE1fo78xLQHW
ygop6nmkPqXev3km7ies+q3tWF2kPu+pf9/0WhFWO+QP1OaQ/WObsWG+fzOs
Qu9MKPmT+I/t2hdGzh1WGzcPjF/6AW7Mjnma7S9hZXUnyotmAO7WssrhMhdY
SabHDbfogRsycy5qUAiWF85fcQl/Aq6PZIBJRT6or/pMtkiNgEtbznrkLwVq
09LCy2pUcK3i1Wp1PUC97fsi7vYQuNRmL8UCb1ALvqZ+iSf7i7nvrIr4a6CG
L7rY84Hsv8bRy3dNF4EqKjbcnEb2Uy3lfZN2+0GhLLXi9x4n56E9WTWueqAY
1NJeSoyS81JykHpVMSgruRvvq5eR89Tuuvv6E6BInn3/6pk+uLNj+w6d2wSL
Hhaz0NEFnL/UpeXSPrBItF3dRRUE5+tmuR2NmTC/faXp0CnSlzS28BZXaMP8
6qU/rPnh4Dyylzj0fQzmBaUrFgnFgnO/eWi2QwvMU2tT+ouiwKm9raCZEAFz
Z/Hzq/LJebN8R4ri8UjgewwfJfgJOGdi0nTf2gPLtjz+HHACnK0uPcnTkoDc
F49OH9LnhCeUDBipAKJbqbd3NoETcvZe+KEObOhVDXCmyoKz5cPzlIQubNj1
t9iZbgsO1/zy3J+PYHbHVyGxlfRF1F1WzxAD0/V859++8wVHei7ndH0GTJfd
e6gV1A+OhKTZkrBOmIrtX+CT0A3OfLk+ZtVKmHzUY3/1ygFnjkp6xQYHmOzv
b/2raQyPKUmrmpporO/8mGpfx4XHx0zvRloCjPesPc+KmIbH1X6Xz35uMA4V
EJ7+wQ+PyyWDTCUtGLt1qn3KqIVHcbBPsP4/GGsXZNfWicGjYHDe9zXxMOo8
eev87ip4HGny/tdgAqO1RpW3aJvhsV395/NQJxh+17MMzjYjfZxnSGvWVRh2
RAgFnCP9D3LGHp+qhmF99XHvNb7wMGnWvPHmEQyPhdJOHt0ED/1Vlf+WasLQ
3I3tIjgKD7U3vqkPD8Pg2HrrQ2wJeAg9cDnong19W8/Iz/Wkj3s02nawZh70
Df7lrcl7Avf6T5t6b0lBf8mVlftSG+Fe+7z9TcgTrP2zMks4R5X0Zxd9cgbm
YW1x6aj9LD64F5lQXBQWY63Ih/7hmQNw38u3PeVIDPTaxTLXN16Au/nskET3
EejdTzRWFlWEu0nT6tsmZtC79ntLukwP3Nely1ia7YdehhTbtYYFdx1hR+W0
SuhZtLwRO9ENd5XhUvPGldAti+4tk1kGt+nNbtna8tA5ceRC2s09cKuY6fqz
6Q909u/ILj1cALfr+7+EbnWDTlxY1FO5AbhdkbZbdC8ZOi7bllbdLYRb4WIJ
1ogjdKSVsu+/F4Lb4RX3ao88xWplO+731y/gFjKkOlkzgVXKd8JS16XCbdmG
y/r1TKziu2KovFYJbosG2MVZBtD6VLZL9fo9uC08eF109k5oFf+9ZmAhCjep
zsNX9ilCy/CYQG/bPrjN2iij1EiDpsubmqnfX+H6Tm9t8+qn0Dh/z8bwiBZc
j37ryvH4AY30gKOvmnLgejjsjrz0KWhErJh6F/8PrpkjO0pZM9AwGVI+sKYB
rsnfT1tG/cWKVzGGoz234RrZffBA3w2sELmVEDejB1f7ffY3nVdAPWXuT5s1
6+E6WzrwmNkyqAfvMl5cQfpcPvGyN/v5oM5eIC3kaQ6XKZGO5pSnUFfdnyPC
pcNl5O+D2JFpqN0ud1Un51GXrnY6TYcfy/7M+2Z/wgEu5ey0q70ZWJo6yPm0
kgoXn7R7zUMPsDTy9md7t1q4ePrNSRo6haXcSxmfmnbBxQ0+5txSLNXptHdz
I32w3ahHXWYNlnQm/NsbOBsuRrb7LrTuwBK9D6GeP+LgIv6SKWUpAdVJ3frS
jTlwvm1bIvigC6p9pX/0PhbDucpPOXF8A1RfUQ37LOfAuSxpTP8FFaplla1i
N7ThfPF686TvGaiG3r716G0KnI+IsbVyV2JRe57mMct4OIdcnhUkLALlb8vF
h2e84ayy5zrXDVBu1dI/1JILZ4VM9ePHcqF8Y+MkQ+g+nBcc1VxRNg3leN6m
XJdTcBYp6v8YfBLKIgUUz7RncPp139WBxobSWlvH3LbjcGoZpO/auwCKly1C
yq8kwSlxzG947BcUj7zsf1S5A07xIvW3Jj2gmHQ06aq/AJyiF3cX/30HRfYF
aYPOl3AKcnBxaL0Ahb8zYicWHYOT64XY6SghKHD2+m1esgBOOnYXlH9GQYEm
0v1TbROcNDcekWq+DYW1d3NxShhO6tGu2xd/h4JYZbe8Xw6clE56/RacDfkH
Xe9cAqzgNHfg1NCjeZA3nutapkP67A/bZ+d8y4e8xu632tVvwO7K6Nz4Ogzy
Clp3Whg5YL8+nTuoawK532JFQZLXwX5a1xF7OAFyNaJav7cPg109J6X+103I
WQ+sWbO+FOzDWU3+9xdAztidvnGeNNiZZ9+skr8IOa3fLx+cPwN2all/P/sQ
5KSarKUie8FOfDUnze4WZHvO1lge/Ah2kEJUflA4ZPcaZfMCR8CmFGrv0fgF
2W13qrT6HoFtRudt6SuAbOi2hkoXK7DXjVxc/P4iZN2OX/dyfwq2tum+l98Z
kF0dV0GJOgC2fMfV4MspkFW7bZeYvBhs6aQWXcubkFUybFcMiwdbbLmU1SN7
yAq334pNPga2QIzkopFlkOm/8XTb9uVgfZeVP3dEADLvK79V5y8Fa6D20Nzp
vZB5/eMfzcUdrE9bTPSurINMk/jP0X3XwOq4pbt/lFyvG+1sbGgBq80nSepK
KWRq5l/jrdoBVss8IZmZ9ZC58kWr+ewhsO7zGsyF2iBz4UqboKkRWLUigvXX
XCBz9qJ/w9IPYN0s3x353AwyRy03mu5jg1UqYilRYAuZrP77s4TMwbpYkenK
txIy6fVSIe+fgXVuo1ICyVeZ3SqxI3rvwMq9JSt/eAYyCfkZdW1fwcrevKd3
cSJktnlkVGhcB+uA1AYYNkEmmhErhmCwUu/avJJdCpmIGFuhh+R79wSft28l
7w/pmNMimgtWoiLbjfEAMoERl/dLV4IV1+h8kvoOMpsYJcaDaWCFqnkmFJlC
ZuOBWTSb+WD5v/QLO2EMGd4ck5jjTWD57mm2VLGDDPemR1VWL1hea9IuzqJB
xuOsx2jZJFhun4rNP9RCxq3eZLbHArDYOctvr8qAjKvidH3NW7DsLefcWxwM
GedLeWPD8WDRftF/NUZBxilK3nXsJliUC2Nzp4ogw44KP1f+BSwzj1lnNpL1
YF0+t1vaGyyjeXE+ITnESlezB93AWnPX7Q/vI2SYD7LDJeeBpR15XpxKrjML
7c4Fkfs11L1oY9uJa7qu9Z4Ea2lnioP4f78X3SCZNAGWykGVJqEs4sNb1zqJ
gaVA1fCS8CfvZ8YmniDrIf37QoV2HxkfjW57wwAssat50at0yPhjBr+tOA2W
sJ8Q9Qz5fpdup5JbSmAJKg02fSgk3789tZ4zDubMS+tL8lVkfpjJ/jQrMH9n
LD6gE0Pmj2f5aCoYzHHqNvm3/ZDxKmz+tyEHzO9/HUZyLkPG+2fhIq0yMIck
lSo1WZDxjZ29yW0jmL1qHMnHIpDxW/FN77kTmD3G89xNyXoGiLr38zrAfOug
+1H1LGSCVWxep30Gs33T01mfciETtrGGeXI/mM/j389vIvERE79wMnUIzIaL
IWaqsZCJd5hzaswVzPq7X+fptEMm0SmkNiQFzDuv+xXy3SCTMlIgNa0HZrmw
K+XVT8icCI3+dlwRzPxIS4FqE8icaeDbWX0NzLzM5mmNA5A57/BrYX49mEeL
Xz/fpwKZa2OKGnv9wcz4lO6l6weZ5kQRPx13MLd5JvGbDkDmuXuZhgADzKgE
774o8n0dm2/UaSSAGXbq5bpqR5LPYjXO19rB3NwTFbyG1A+hwhPPk0TBZAXf
/Rx4GrLi/K06pS/AtDvEklB5BFm5Q4yErx5g0ip3rvqxFLIaG8SH01vB3MBf
kfAjELL23dvlKtaBqVlQLLNBjNSfO/kz4YFgqj/ZsM38NmR9nv42byFe/GuH
ZUUfZGOTDBTyIsCUZ3y3/5wG2XNLcyxeZoE5e1bHUdN3kC3dyxeRdQBMPp1H
Nzbsgmy1bOqTECU4Tnlvzj93CbLPmz5G7zaD44+6GqUlSZATiNiyweY1HN9l
DLw6YgW5sDrx8vYyON60Ck9elgi5JI+dKV32cLyhuCmnLg9yB7XMZdK/wvHK
MFpmtCF3NS6/8uA9OJ7Lu2nNyofcaLmv9zouHA/8a/3sJAP5PeXqXaQPddz8
a8Her18hf7Q1c7w/EI7eb+wtNolCvmTZjG9VJxw5d9IU1W5D/nn0wImaJ3Bk
7hdLe6kKhSVVXurXV8PRVCvWb5ULFJ6VZ5urk+sLilb7dtRCoc/BcZ/ANBzF
T9iKR5aT/W5x0/I8ITiKHNy9ObcFipohHXxrhuDIl0DfojoLimln35o/SoND
x5PXf/2oWMiOentQsBIOqT2XtcZboCyWnzF86TLsh95uWfKYD8ordUd/zfOB
/YfKdHPRcShbjrlOvHGBfUf2eGNOKJQThUTv/FwJ+0fOBUL5ZD8fCcxeJNYH
+7PjJTUcf6i80+zc+KAc9u7nTm8j517V0Er1nPYbsGtu1yuWSoFq0raZYRUN
2NXNNATueQDVLOeUAIHbsLulMXxLMoacR9i5pgc/wO5CqmBGZiJUJ4ISCpef
gV2y766GQ9uwOGXO9BETKdiZHe/O+y6IJeU9I5nTVWBULNhbp2KLJY16G4v6
4sC4XHtPeWIGS96eoCQI94FRGHSb8SUUS/mv2A/rXwQju4X/ZqkiljJ71hfO
poIRWS5Q0xuGpeOxi55EXwdDd84NXf0CqNFdskZS/GF7tSvx6tgo1LzDZ845
6cH2wifR7xEiUIs5mxr0wx22Z76enh3mA7Vz1N5Dn7VgmzW3473lI6j9zdke
6fMJtuGbP0wb5EC90ulu0pJ5sNUtFwyLsseKdVYzhTR+0CtLA+fPPo0V7PXJ
b6cWg14arRNpFI8VoTYlsgojoBdtaDk/k4YVhWUPFNq+g36k56SeDz80pKo6
bMMGQI92vHuCLxgaY2k5C+yyQF/7Ddv9yqHZuF53odEf2FQtP/3TmgrNPs/l
CHoMm6shE0cFa6ElmMsWLX4Cmws3I18sdoSWuYdZh5gIbHLdO+ce/wqt2/PE
TrxPgM22luI9sZNYVbmstU09Bzamuw3Pb4vB6jsy0X5/CkFrVBWpPEzD6q5F
iQW/L4FWF3DQOE4Xq6c2aAhUPQCtunLgZ8Bq6Ci9vzR1uhm0K55LcgJ1oMP5
EEb/vB+0w6/f3q2Oh87bIduTEAbNa9/jpeu2Q/ezcHPDnRpYT3bF9n/Sg+54
3z119ldYj54r3br0KvRmt/j+CjwE66+hXzazZaC3/M4NmW0KsO6RTFyX2wm9
YCWn9x4jsG7Yt5p1bjv0fnW88W0RhPUx/YmIm1+xdgGt9/bTu7A2Ktlz2eg5
1q7gEy/SEIX1mu0KyX2lWLv+/nkFlVOwXuWYxzupgbW+4eJSt8n1xSIBpmLP
sPaGZ4P97h+wnnvL9ftLQeg7Z0i/VUuB1ZvZzUPsbTA4t3r1iR8xsErwuTch
shIGNyNdRFpnYBXbdmK8fx8Mnta92DnnBKwibTLOnRqCweTex80WNbDaQq2p
ayH9qv3Z8nGxe7BixgVIL9eC4V8N+aX1BbBSf/Vr1vf3MPKNqkl/lQPLV+Fv
DuUmwGjb64J5jk6wbD11eOOHxzDKstqSlHIWlo+fMe/iH4zuWB98KFYKy3rz
vu9Vd2As1+GxPUUGlld9E/4IWML42dr5WkN7YZmWO/jcZBgmVu3JlncKYUlt
tY9uzYGJV8XH0zZ+sMTp4WyGBkxizq5SzsmHpUlk0YkDQjApytuf2GoPy7Ua
rnS7wzCdsyg6uOobLJe2NSZ8uQbT5k2v700GwlJQWejIOjFscP96/59DOaiN
O4ciq79jQ8TRzotSHqA+XO2b/ToNG/bbhqpMDIFa95EW2pKFDTdfio+utwG1
xtlJO/UjME/3asWRu6CWhgfx/5sAgu+ctv2tBeqReIsDdo+AuL7Xm4uegHo4
zG62gT+wV8btvkAHqAf9b79bQO4/tdtwtqoxqPv9mw9VVgAtedHG5Z9ATTh1
QL5gC8x1n+T5M8nv/d6sYM2fhLkZvfQVNEHdtGBDR/gPmNNbZF07I0HdyC4z
5SnA3Pfz51eWR0HlvC/0q18F86Oso3keDqAyNYuyJothPr1a5IIsP6gm2c6X
zufA4vHo9tq0UFBlj0+l2MrBotNIlSPUC+oC7VQB8XxYDKRoClLFQZVsFH55
vQ2U2Wtii99PgzpfuG8p/y9QzN5KDaxQAlWg8Uk8kwvKDd6OLSX2oIzqHlx9
zxuU+vmqgy0HQBlZsJe60hKU1jr8fcwD5du0Q5fcLFC+m/yOnlUFymCnO/3w
MlA1dm9dJDkDyodnf8y410A9a9VkYrUalBdnzMs3k3m5xn3uZ2BMntPiWpmc
DOrdbcFiKWtAecavYLCzCdTuR17lhhKgPI7NNu2+A0vFqz6bPX+C8uCEJPOS
NSyP3NX6dG8dKFXVKVXD4rA8v2H+mo8doFTqDTk4LoBl+cNj+yzLQSm/2hAR
HQ7Ltr5rC/74g3K9sufgMg9YSW1TqEgUBOXSH83TiU9hldUjHRRYBspZ5ojC
oxFYnbkdPvqgBpR8tei27fKwKj19PVTqAyinp0sZlSdh9STqfcPgMVBOVq40
r8gneesvuSlqHJRcp+HXCjtgLbf1/MgTX1COWV7ZLLgF1up71Z2+vQHlqDF/
8HIVWFNvfR+zZoGSs2pTSccgrHcF3tEPfgdKlllh8mgtrLPOtxjfIOtw0Pbm
1c/XYH2mry1epQCUA1xr4Y97YF0bX1usdASUjH33hcecYT01tGZNZToo++c8
PvvcALTYAT+BlG+g7L54enjXCGj79mjtKCbrtevLdmUZcdCOLf1Z13aQWDfr
4q6VoFXGZr+YVQ1KUoPLdt9NoP3cIvX3qjIoCfLP81vmw2a2nmB/zVpQdkT9
TT21HjYy/P8Cy0tB2f5ywxqZRtisrZJ4uIeMNz7vh+dPK9hEbakIXHQWlDiH
A7Pf28Em2We6U4jEU+z9XmO1ItjkbGL6nxwhXq8VmPkINuXbllbuqAAlRi/W
oCwUNuNf4vbsJXEXRdnapt4F+my5tTvH3oOyteXejj3FoMvY8J1eRNZrK/eV
VsI06Pq1zQZHRECJ3GX+z8cc9JixFcYvyXqHDx1bnHwd9JS/s3eJk/vDMwNK
TLRBPzav6sIKKrHePcUbPqBXmZ44/vMJKGHJn02fbwa9weuxSyX5njDdC2e/
XwD99d7WNrJulNCeTse7UqBP9LofLjpDbBV3/KIlbOcqdyVf8gQlZPrN+e1M
2Mpz1+TM3k1ckfM+sR2264Y8RSR2EGsLBpLztG08I8ctNR6UYOPVUxf9YJt2
42rMnMXE/M3PUl7ANk81r276LShBT3NU3o3C9rZo7823JF6CAvLuL3kK2ydp
FmsDSD4GGbe0bAuHbbdYSFLwfxZTqF/dB9uZFatuUCVBCazu2T41CwyxO3UK
mgziHMeabkkwFrmr0jwjiMPqXj/5BsbqP/RNIkHEdqv+iM4FA2fNkjVoxFoH
LaPywGDaTVU4DBLPf//qwH4wfPh2TpJ6Qwn4oVCbdRiMPTHvEx+oEt/RbRhJ
ByPHuDL1JomPgCKBr0W/wDgvyNRz6yHOurCVrAOjoq0UR5SIE2Rtj6mA8eji
k6DOaeIgOu+iERiv95TwvpgQc0wPVZ8AY2CTVU3pP2LG4B3vYTB+0/Ml57sS
g1bl+g52Igbln++R8QfoO9kdcYHdwhV7SleS7w3QErJ2c4SdlqrIa417xMvc
Nq+bgp2pMq3m+w9iFepGowDY2auuL3l2nljh/vf2U7DjrfjweWEasWxrjaI0
7MINjY6PkPgNkNkUfKkJdrtsMTLf7z/Hnft8BXaHN/2cunCfWE7oz4d02J1L
drlvSvIrQFF49tEdsCsv3mgW4PHf++KYH2th9/CltHNFzH/jsd9yXgl2rwUD
P4aZEWsmN7begt2A8ebSba+I1y74sTsGdr9jZkUtVic2nXSTrYe9SNX67q83
iW1WhGwYh/3CGamUSD1i59MnlZVhv4q+e3L5ALGvE50ZAHuzk2lXDKOIIy06
Fv6FvcP4cnGHduLdvvnhrrDfyHSOjX1BnH31t7gh7CPLpVf1GP23fov18qVh
n6zkGVDxmvjWtVzSv9oX/U2fXEvqa8Bn8Vl6F2B/azR/2dB/459+7M9QgP2T
79r6FsUkXmRvrinNhf3o5IWP6zqJ7fkMddvgsMEjT3htCXGTc+AjLTiw9sw9
Me1FPJR/wiwSDpuvPzX4G0zieV67Eskbh4wltJUfM4nZXZc/CsPhjX0sbQGZ
/6AvPO1kUzh8LZbQKl9G8kda0CzyH+lbBL+gs4V4PWPTwmg4SocO0faQ/SY4
s0DizhgcjbfElsiQ+QhZt4W6ohGOqQOz+kazST6fjlEIJH3Y4YcWl1pJ/Ql9
ssCjahyOJ89v9mrfQvz7YVIk6cuuhZprXTck9cHZZOOEExw7Fn8SsiHvDxfd
GbsqEswV85XWlS4EJSIkzWcW6Xv1ZNM+3yPxEJG7ROnpMJgmS44ukeYQ15s+
97oBpqNF6H5TUl8jF7yTFlkIZlx+bvpCUn8iy56OBR0Fc3etZz3TlLjjkJ3L
UtKHvzsq30D2k8i/2cY+fmCeVacLvr9E6qGlTs2zxWA2vVjU1nybuKlPopb0
1W1O7vK1qcR9JU4MeTC7OjIyU8j+GcWfsWGDFJjDfS0qg2T/jDI8sM3tDZi/
w18sObKE2PFs7ixzsPinby9bTOI3yr/qb9FGsGQVV9F/knoddeRl6eRXsBZd
Kn7fReYjqqRFJbcALA2zCeaLl8S115WvNYCl91JijdIU8fNYj8lQsEwCh4WG
ST2N+qR4aLUuWFYCB8wDSD5GjeXsCxQFy+HUgPVReVCi+d9LeieB5W40EeYd
SywxLl69Ciyf1xX/jpH5jVZ+Gs49AVZwrMrqvmfEGpu1b7HAipFfueLNCuI1
FU5KtmAlVb8UaCPrH21SNfHnEFj7eTKPF4wSU8nhTAesbMHBbbfIeKLpdzYW
MsE6eZk2VUHORdEO5We+HweryFl71TsfYra1vWMFWFf/He7+9JHYOezZdWmw
bl0Kb3YXJ3ZZcXSqEaz7bnUF5Z3/XQ9eHknG93RO0hyXbf/9Xn/BXw2w2qsK
9u//+t/zEwW3rQGrJ0DtUqbJf+83vywyBdaQ0qyeo1uJKfFtIefAGmvVyejU
JV6/zIlSD9bfvZdmZ88n1jVS3NIK9hyTwEPCpH5Fq5UvM3kItsS4v9+pjcTy
WbtnUsFWvHKq9Ol/4xFu4kglgr3MX2CPJaknUb/dP7uOgq299PD3j43E/aaB
cXFgG/ZQvzW4ELeF2a3TB9uWO86IsyIuuiwmegpsZ6VPHLNm4sxSqb9GYHt1
d3A8yXktKvJr/WAy2JE+ld9+gniduGemDtg71A/VnCP5GyX3RSlsBOy9X5x+
6KuRePw5ttr8HdjHY2NCrmsRX44brR0G+5zZw0R9Mp6tycPatUlgXxF6t/8P
2R+2cna/+sEF+95xh0ydJGL+8T1Xt4Dd7Hvs/erPJB/aHrcHkfe91E77cIdO
XHBjFTsE7P5HTHn7fGLj8znGTWD/yF5g3JxDLFBS/eAf2FPeG4f+kHyIaC6X
VrsOJ7HpHciVJmY1Xoi6CScDo4eznY+S/KaXB9gehRO66t9J9pH8/7v39TM3
ONnuXEB/TdY37MrXMw+V4eTdkLJ2NdkPwuZEqGxthVO6WwRfmCapN6dUOoPo
cDoy3V7iTOInxMR3dt4rOOWfNRiWJvEe/EY7sr8OThWDty4U6BCLui6mbINT
T9xeyo8JUh+Z3acuJMDpy8KEU+Xk+wK6abufBcPpZ610zzYSTwF+hrrbVeEs
OmuoaW8dKP7hZ+NzfeGsv3tcbn4AKH5bavNZcnBO472bPrIAlI09Hhe2kOs5
E5JPcnOJqVnHnmnD+Uym6uJwUn+9izafa6TCubziVOzFL6DwfP74TZL73/26
rfCrGxTuPYOybEe4rNFOKv/nCIqrWJe1rA5cTK/s3fJdGBQX+98tzy/Dhbby
ZMKtcFCcM/llHZvh4qny+KEOWQ8n/q8HNNvhkvKtafkTsl84tvdnndsMl86F
UvuXXgOFri6SqLGSOJC5dBnpW+iLwvxdyf2dtw6q6pL9iy7fNibzHC5v3YQp
snHEonlDSVfh0pXzS+MkOb/Y/Fju89gYLu/Fyvw0yHWb21r7bP/A5fOs8lnP
TxMzRySadIkd372g2hLb2miJDhLnC/NPk/pnQz07+NELLr1mnOSPecSGLLv0
Mrj0xf+eq0z2Oxul0srcv3AZGJeZJOc0Cq3fRZl8t8sgxeC+KdkfaT3FgTLP
iA+7fE0k30d7M+3+2gIuQzpHOPak/tOenF0WIASXLyEiF26Seka73rflCJX4
trpfjRvxJYMXrjfg8lXUfM8wm7gw5YNhFXFxdEfWMPExtS+Hc4knD4q/MCDO
iurXPgCXb9YXCr+Q8yBt//19K62Jj9499qiVeI/k46Ps//9/gtf///8Elv8D
ozmj4Q==
      "]]}}, {CircleBox[{42, 29}, 41.5], 
    CircleBox[{42, 29}, NCache[Rational[129, 100], 1.29]], 
    CircleBox[{76.8048285697351, 51.602519953123625`}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[{-27.347462670182857`, -24.511212247283595`}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[{118.7886979067563, 82.28402440600095}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[
     NCache[{42 + 85 Sin[33 Degree], 29 - 85 Cos[33 Degree]}, {
      88.29431797627731, -42.28699827536104}], NCache[
     Rational[129, 100], 1.29]], 
    LineBox[NCache[{{42, 29}, {
       42 + 85 Sin[33 Degree], 29 - 85 Cos[33 Degree]}}, {{42, 29}, {
       88.29431797627731, -42.28699827536104}}]], 
    LineBox[{{42, 29}, {76.8048285697351, 51.602519953123625`}}], 
    LineBox[NCache[{{
       42 + 85 Sin[33 Degree], 29 - 85 
        Cos[33 Degree]}, {-27.347462670182857`, -24.511212247283595`}}, {{
      88.29431797627731, -42.28699827536104}, {-27.347462670182857`, \
-24.511212247283595`}}]], 
    LineBox[{{76.8048285697351, 
     51.602519953123625`}, {-27.347462670182857`, -24.511212247283595`}, {
     118.7886979067563, 82.28402440600095}, {76.8048285697351, 
     51.602519953123625`}}], 
    InsetBox["A0", 
     NCache[{Rational[463, 10], Rational[247, 10]}, {46.3, 24.7}]], 
    InsetBox["A", {81.10482856973509, 55.90251995312362}], 
    InsetBox["B", {-23.047462670182856`, -20.211212247283594`}], 
    InsetBox["K", {123.0886979067563, 86.58402440600095}], 
    InsetBox["B0", 
     NCache[{Rational[463, 10] + 85 Sin[33 Degree], Rational[247, 10] - 85 
       Cos[33 Degree]}, {92.5943179762773, -46.58699827536104}]]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 2)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.467463020891292*^9, 3.467464406512301*^9, 
  3.467465870757783*^9, 3.467466163266136*^9},
 AnimationDisplayTime->0.059349290000000006`,
 AnimationCycleOffset->1,
 AnimationCycleRepetitions->Infinity],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt3Hk8VN8bB3AhhbJmDWmhREIhQh9mMMZYZsY+w4iSfcuWQoskSykqpUWS
olLJUpSixVJJKUmUFmsLoSjS73xfr99fXu/XvXPvuec8z3PO8w9WmM/izXx8
fPx8fIKi//2Fy7fe9gG7N6DQdvDK91jDZcJf+FhvMyjWV5J79HfBla+/401V
LShW3V7vqCvgKt2jdkUAoFgaOTxrvAVXo7LNF7ePg2L+iZ8x2wyuyS8nvia3
gLJecCpGeAPc5J8l37kmC4rWgw3higVwWzyaP/plIyia3YtPzGHCTVNq5QvV
G6Cs/DngwTkEN1OrTZJqy0DRWM6cL0SH28bdMbc/B4KilvbiXC8FbsXmxyxG
5UBR8Zop/hcDd/2CgOUHzECRyE5+LZYBd7PpbPnDT0ARLx3+NvYO7jSmR+ZV
Mj6xJ7JU15dw9xg6vfhvIyjzRTsjfnfBPentrJ+8LlCEz2n5v14L98ZLbwfj
g0ERQIJPOx/cn196u1/OFhT+pM93qOJw7zw/vmJLGiiz6pf+3DAE96+prGtS
kaDwOUQynUfhISH4Z1/ld1j8PWjTfkQEHvIvJ2RvPIXFdH+QxHA8PBafbnut
1UVs8VP5eD481qhKR87+CospwQzToWp4OL+eCDL8BYvJG/Wag+bw8Iox17xH
njepobbveyo8toitezZtBouJgt1HtY7DI05TMbNJFBa/zkYMbFKCx86rv+36
WcTLV2gG7YTHfu0ws2Zy/8/rqsqJmvA4IS+6KP4mLMZfKFXuy4BHwR71lCe/
iQMsFVMG4VHS/2D+2x3Egr+KfLPgUXMqItU1DhZjdBPT15fhcf977H21CliM
jo1dS/wKjyfrvl52HiQu2C43LASPrmqJtQnricUgVE3u/zxSMTAeDIsfj/PT
v8vA45vqzZiLZHw/DsjxRcbC4ydd+qKeK7Fz+Z3LHfD4G3x/Y9YW4iXp86bk
wJmdej9fzBAWI+OXlquNgjP/tET8qsPET9TXvMwHR+Zy0aJMMt6R4vk2/Fxw
lMt3drRaEqdHBEbvBket4tScnVeJt/ruX3cCnFVXJ9R+DhF7j++RUQVH/1x6
g0E+sZP+Eol14JhmuR59K01sZ7BwcCk4ljGubt+1iBlzJY9fBMfOed/g00Ji
x5oDHTxwnFf1mQlTiTkbhU9+Bof7L8zHfB1x8NwP5/+As8lqeVDrUuJdkjz5
r+AEpfReEWcQ50XG0wfBiay7MGEuQlxjxBQpBGfbr+BV+7WJeyK/DzmAs0tN
h/rCisyHqBZjuA+cVLtRShmFeH0k06oFnIPh1yzszxJHMFtG74NzNNM/EPOI
L7/em6wFzqlC+V/RR4i/S6g+bQWnsPzeGjkvsj76c9flNYNz6S43wb+DeNcT
x6BJcMruf6WUZBK/9H+9/CY4t+pDBafI/I5pDam/nwvOveoeprEQcTo3ea8I
OC3HDyn95ifx4mEpZUee/yrpqdirOuLmNu94A3C6eOPhciT+f5rvntQk8zsk
NkuuYhOJT/No239T4Iy8/czkvCVufrbVn6zHxLnSnlsPSXx7bKsOcgJ3tuqv
7BPVJP4zviYVbgFXtD1yuRIXFr9XP7669gW4Unufj8xLJH6zwrtUGdxFL9Zf
PNNH8mlDSuGnFeAaLy7O+6sDixnunLdnusBF0To38U+w+LdW8MusTHCtl114
/oHUAz6pVzdsB8B1El/hOCJI8rt34ZV+fnA9thst3mlF8r/j/IbXTeB6f1hp
pUXqkUCbpk1JMrghJ65UTPmAMrvbaUs2E9yt32EwdhcUoW+iogVccOPX34j1
+wPKXIFea9p3cFMemK72zAdFxHrlHtfz4J5J7/sX4k/q1bJprfpecM+XphbN
sSb1LPTlJnY+uJcei61/WAmK5D2FOJ1Z4Fb9aLiS6g3Kgm3z2u8ag/vs15xg
/Y+gKFom907Fg/uq/+2062FQFj6+vpZ3B9y3bScywtVBUXbP6Ar3Arc/902S
XDooqhkRoadMwJ3p3H523WlQljs8EEy/AU/BxN5dI3yk/ooysnm58BRRTtSd
lib1uSXCcHIbPGVsUP14HSjaQRe/xtTDU5OzymkWGZ8B/55DYu7w1Hmu47bk
JCiGU2fEj8vC08A8OCK3GhSj6VTeMS48zSWOHLcg9d5M5m3IIht4ugS8MqG5
kf3lgkrShAw8OdebDfXI/bT31ES7Q/D0Hhf0O5sCiu0i3ysCPvAM2mL/g88P
FIeqs0ErZuC5Uzjom/gjUNxpZ04eiIXnRVOWlrAUKCEjiS9ot+F5ZWWQZggZ
b3iJS94VUXiWSfatnOMMytbgoCNdZ+FZ0yoy90ARKNuEPR7WC8HzmbB59Byy
/yUXXdyutxqe4xGmbP4eUE5F7NM8awbP37OD7GUdQcm/dmJg0S94/s1ROmHo
Asq5SblXSz7DS+is5PDSOlBK8p2VOzzhJb9tb6FtJig3XcTzelbCa736/jeC
q0F55drCfjUDrw13q7m+o6C8Cd8Z2mAALyor/8Vlst92Z+tef0+u223Oi+8t
AaX3V05n3Ai8eMhjn28FZUI/pC62DF67nvpV2cmCujA7a+BoB7xSBLx00gtB
VWVwapQ84JW2Zn3TyXZQ1cTVZdTI+w/vrNhTpA+qdlnF4Jp4eBW8mDQx3g+q
RURhJG0dvOpdfQ+3B4Ma9HTXkfm58Hq0SqNi031QI9QuLdbSgVfTX6HUFAtQ
Y/bVZIdow+t5uoRjlR+ouwL2DXR2wavH++bplCRQj51LHXDcDa/p8d9lvS6g
Pvx+x+ZHL3h8IYfNduSC+vjzgvNV/8AT6IlYxpIH9fmnZWf2KYEnUjH/2oMK
ULtnvA2OFoAnryhtuq4R1F8X36W8VAVP99XLunMbYanRvGfP+Bh4a+9Knf8Z
B8vVg6aC0W/AMzy3vYbSBEsDCQMh+QXgmXp27FM2hKVFzOtzb/PAo+VO5S15
AEtOUWikiRl4Xis7un+/gOXB9LBBUUXwvBtebRxgwfKolm2ksA94vt6qfpf+
wPLkK7XRdn7w/HeXJKiWwbLE7JHLp+fgRR5s1iwrhOXDCMO/V66Bt/eJyOWD
pbD8a9+leXYGvFSVoa58U1gJhqT8+lYLXlqI8Y2Pm2Almt1XuGA3eAemdZk1
9rBSmLg2s14dvGOfrp98ngUrQ8W+lF9D4F3svO7SFg+ryMebFkuPg1fSGxMo
IQareF++izf0wbv8pWk6+iCsdvPzWVYHg3ftyzL+o26wOuQiveV3KHg3y9sf
n1eB1TXn0ZNyS8BriG4iNQZWw1effOksAa+J9+9+1BlYTW5pjFzkAt5jy0Vd
Uo6wnrVCWPeDCnjP+NQez94Ba6k60z1SceC1GyWn3qTC2sC5SP5fJ3ivp6gJ
JiGw3uDAZ5lwFbw3Vf+WrDSDNc1xs/uIBnjdS4LrlKZh7RGkV8RvB96nGp9d
ITdhncQnfLRyELxeZ11TNXI9dd3Qz60PwOsbEvkgognrQ9vyDrRNgTck2Hd/
YzqsC6UYG6YCwRv+Fxs3bQnrpnw5e/Vk8KaEL2gPnAZNVr0wfp8YeNPOIk1n
4kFb1NFvdKoQvL95x5J2D4CmcTjxbLYKvPnmK5SdnwWa6cIM++cW8OYPbWM8
ugDapmRa2asX8BaYZcEU6AAtNNzF5y6b+BCjv1gdtDjfeKOGk/AWLFm3dsQc
tAyvz18PVsBb6G7ip+UXQSsvDmgP0Ib3HLOPcncZoNU+ZZiT85/3nJr+A64y
oDVOzr6t3wfvuaVdO38tBK174zsd1ZXwFolLHtXLgo1QitWXtibiXomK8cOw
kegRuBl1A96iDpaKkTthsxBu86fJ8+YplXRPPoWNzoILsZxYeM/PS6p60A8b
D1F+/rnyxGMN6Y7LYLNpC810pTu8xWzadkrNwCa06dK5QUHiYeNcVyXY7Mm/
dCODPF/c7JjK8x2wOSBjZFzpQZxenbHtN2xyDz4sUT0Bb4lFbh1LD8HmytHb
vy06iDe/khTbD5ubS+Vv9EwSlyj2/TsPm/oK53nn4+EtqSUkw8+BzesvTNsL
QvCWkgn+wdIGnf/knu4Lc4nptEOy06DPd5UICAsk3jEmyokCXV4OE6m7id9W
KWX0gb7qYtjTyml4S895PvG8AvR127yG2+nEurUGdAXQKQ5tjWEtxEnzOZ2b
QHefr+Pkco64IGKnnQTovuNzP+u/I75fvPuKLOihPbRPDTeJP1b8298E+rbn
A/WRycT/jh0+FQt6cmPPCMlr7wWK9u3P9oN+8KFGN/0asV6Xn8FJ0E88qpni
Cya2QSfpY+jnnx6sHp0i9tzR/GsS9GtvTh1MeE8cltW6IwH0mqHuL9e4xEkJ
u7JLQW+YZUNxSSTOpER5VYP+QqlDlF+LOPeT2frjoHeb7r4pPUhc4Ln1kTLo
A77m9+5fJy4uu9g5F/SxA/NPakQSl34KPyIP+sydd/WWx4mvj3i6q8JWePTK
ZeFNxGWdfC3zYCujFdnG0/vvev6XT6OwVQ1Sv6GX8N/vLUtfLYGtZmldQ+wM
8cXGNyvUYWswYZKpH058duXv6y9ha0E9uHt/EPGx4NPHGLC1O3pDvYysx4L0
A86OArB1+3bmj8IK4oSskgv1sN1kY5/ICiEOiVp57yJsw4qrDDT/ez7HaKPM
athuF3tx/tp/turpiCfjTYk7ztLNJdYJWqh6HLaH+gXqbf57vlxH2bEZ2J7y
EEkYNCLr83fl8meTsL34vEjMTZa4Lv7Jqk2wvduS8OYqyVfp/O0ialKwfcy+
pK2+gDhhI2VvJWzbux3SspOIdT7cLWqA7be/70/vjP0vnhLm7efB9nfO7e3c
byTeuvgClGXAmL16tOSXD3FiHS/8NxhKW+28DMl4pRz9n5y+DcZyVllWaSux
6oYLV2LB0NNvWCL6kcR7dYJtsR0YNKG+LSTvvCXeUMrGdoKx9aXz13ZSDyRO
RvxuNwAjsfVA4rl6Ys8X3xbqg7G/1erkWzJ+8bfaEXNcwTjTqVx614rk5z1X
wUQ9MJ7I3mvo6SKOVmtYcAqM19oObAll4hUrPY/tAOOjzarhW59Jvqe2Z394
CMZk6v2aCBJv89Y+HC2og52a9uVdlTnwFjZ0HjxdDbskCfsJ/72k/jy7+iGu
CXZpHkr1WlHEfpZ19t2wO1LU1ai3ntSrA+rlh6xgd9lGiSZJ8mV2Y8Odg8Ow
e3P1V71yKLxnDXaYBZ2EvT7/vPh+Y2I/pepTVNgjjqad20zqa0/B2IWXsLf9
oTBoUgTev/yvMhIlsPcZ8i+oFCT12mBXui1gnzUl/cr5I3g/asK2C4zD/tvB
yzn3eOCNbIy+0FgP+z/L995pJfvPsEBYdWMPHITqZkJfPQLv63rK4sPecFg0
c72fM5/sF/FJ9/tz4cA66mE0qwe8znWys3dpwuHmul0qzyLA6zj1oFi9EA4P
Jvj+1j4k+9e/aMZDZTg8r7qaySX7Q1tlj/ScSTh82bCjV4fsP09+js8P6oaj
+FrR+fFHwKut6Bi8pgJHi/STtKLb4N3uktC7HwBH2p+yhn8U8KpnXIO6g+Ho
EFi8n+8YeFWGCisWCcCRa7fS6NVf8K5u261yezkcY5QUUgO3g3fG4nLzTcCx
+N2dgQJy3tj+NcnlSyaYku/bb2fdAG9bLca0PoIp9/OYUdoK8GIzLjOnzoCp
Ilo7uPwkeFsX7TGkhoC50sjIB4fBC1S2bD7zEkyL3EN7Bch8u267N6cyC8yt
fqksr2nwVtecm76sAearVUcl6hrBW7VMyEkwA8y3tusHJivBW7lfo8OX/P6D
/4QI+w54ajZVflMuYH4rPKeXvhc8xcJZhbOXgCWklJmnROZT8M7UUAmx4bzd
7m3G8GrP+HTdPQOs3Lfvi+aR82DbqZmC/JVgne648mJ4DrxaL0vVTpmBVfjK
smuAnAeb72pEH34K1rWnzeedNsGrtk7ttccfsBprBkX+kfNykb5AFulLWZNp
GRGR3fCK/HDNZn4g2K4fjZ/llcJLYLuU/7x6OMkINpmVO8Hz387rOibhcFro
82ZhbyM8p3ZP9Zw4AafF90Qy6BLwHEs47tR0DU7asY1zfi2H5ydbac1wcr91
l1+3vws8661/V32shFN8nMCHthh4JjwPFZg7H07v+hNH/1mA+2WTgN28G3Au
XPym7vRlcPuGE8UuGcK5+KnmCYlUcD/GOUl0m8P5aqzh41TSr73ZLfM1XgzO
1Q1x84segNsQM7/cqBnOz938JLN3gFvQU95RvhfOM8ZB3ETSj7o2Gvp8M4OL
y2h/6+oX4FQrhXvezIWrwGuD67cY4JQfv+W4+iFchY8Ead54BM7VBetqVdTh
Ks4seP/4D+nn+XoGNGXhqvhgwfwbLHAyb/47TZeCq27Wo5Bd78DxPl+/SE8c
rl4NlT9VLMAR3P72iikXrlWnA6q/n4YHNTzn0K8+uPmkRh+Jc4GH2SZ7K8Us
uG3Jj/q5wwke65yrLmeNwy24UuGbYjM8tHTPVMeHwi2m09730QN4SD8dUTV4
C7d0If1fj3lw/3j8u1JTBdzKhi4MbPCCe2Ial8YNhDvf22OfW6hwu6Z+VY76
B+5H5hdsI+chtxJB90GXfXA/bnB6rHAGbud6PAaH1OF+yhPNxcVwO5a96eOZ
VrifPxceY1MDt8Te2mqTX3CvlPa1i5ODm51JjV+DDNzbd1aiYgiuA3eiaw5P
wUMmzfjznDG4fvTPXONvAA+FzZPOT/jh2iWl3sMNhofyBhMlr1G4PvPuC+eZ
w2PZEFtgTypcK77eOe5Pg8faJYXfGJvguvuu0JFpbXiwFkreO5wB14Wu/bLG
3+GRoSZgsTYdrgtoM2MjafA4OL2V9eAcXOevS1dwJfOU3frmTEsVXP5Jz8kI
6oFHXnhyN+cwXD5WPPAuWQuPknSjUuOTcCm+MejeOgOPxlVmv/2IDc48KyRx
yJmlLDpocgguq335dw9YkXU75ENrLYLLimWfux6tAWcuf1ZZ3gq4KBTe3Wne
AI7Y20jdHTFwnj7C9/ehFDhKW1b/0beEc72R+17Sf3AMet+WKWjAmXH6iPCB
bHAC4rlmAypwtry1eaJSD5xgp6V5mSROzdqszCNHwAnTlFmkKAtnXcH1Cnfo
4ES1RjHWhsJZhrPY8nk6OEm/pW1Pd8Cp+916zpAJOEfqXJ3eN8MplJrJiekD
5+5KyuAlMzhtodrJ5BuDU3eRkj7cBSdvir3wk1BwHizlnpucCyfWBoXefSHg
NEm88VS4DycD7dkuPYHgvGgcMT0jAvbfobS+DjIfvVd05wn9ATtj0Onw3gPg
ClMUriAR7L0mNcr3X4ArmtXa+OU+2AkHd0yc3QLu/LcSdzVrwQ5do3j2zQZw
pTZrxIU4g+0Q+UtV5Bu4Cx3KxGnBYEu2j2QmpICrlXA/6uYrsEVU/0aMtICr
nf1qYsIWbP7AvW/uKYCrUxT4dv4OsEanJSlWEeCurVO0ezgD1ksF+oiILLgm
T1KESFyyjprNDzY7CS5jvWX3HROwDux8kBDwGFx7BefYTzfBSrkv5zr7KLgO
Yx8NxNrAirXKjVEhdYF9OuJP5zyw3GzQ12cFrkeTz6jBYbAUzb5XzPiB6x/D
5L/oA+ap3++FdM+Du2vl85hT+WAedVuTP0XqyO5DEes3PgLzQOXmDgkRcPeM
X5z38iKYSZGBt/+ROpVyrdN55BqY3oOaT8JIHcvgszfXJs9b2mawNNsX3CNT
nlr7yb6gpGPj+T4N3GOaGxdc/Qnmgky3Ctl/4Oa6/snwGwJztvVW1yEy3yeK
vo36kX2wr+bprbvk+88sfGW/XJ7sa0X3xtfFgXth45kj5HscCwTjLbM+gnvR
Y1In5gAcT/jYL+I0glvs2PtnYgUc01XsBCKWg3tJb5d2ZB4cg491XfxyE9zS
J5XlJ/zhuOnXGfcJCXCvltwK6guEo6dzeu1BdXCv7WVm2ubA0V56UD/RFtwy
HQu4LoPj6sNfOui3wK3wXM4f6QfH5WO6y044gVu5qP3UmzA4qrKvWs/SJX6v
tPT6YzhKyniezFYD9yY7gHLyDxx6DUOfqe4Gt0ZazPfAQzi8mhpJfkPeV1Md
1inxHA6P6vjl08vBve3lP0u8Ew4XGZ++Hu4G985JpY6l+nAIChat7I4G9+73
k1qRBnDwNL7ntXUFuPcigoJdTeDgIDLP8A9Zv3s/KHsfjcFBryS6vKYU3LoB
sbrpadj/Hu3VUTEB937Zgl9WNNh/eXTxAe0RuA+UtbMdkmHfnbdw6KwP8V6W
fMhn2NdZKctzyHgeMqoicupgn1rYI7FqLbiPqv5dCsuEfXxitKOCPNmHRIOf
cQphH+z2IkzenpjTq3w5CPaO4iOBZWR9GsYmBoftYW/+tcrlcjC4jesP1ytd
g/2aZhaiyPMadxptW/YT9nKpEiu2LwK3ie+S+bwR2Av7G63xYxCbxJQd/Aq7
KRsL5xhP4mj7B2umYPdNUztnKdkHmy6tuWjzAnbvxfjGMwWI36kd+m4Ju9Yf
t7dHj4HbLLasQkQadvXtm1ZZ/SFer2vFvAO7ooLkxdE7iTO2pukwYJebxh/4
Upv4WnGJhh05x0bGfVv4kvj5d2mpObDbwRkq6SHx2TyCv0fJ+0OtPIpca8F9
LFpwbrUb7Lx1H39wKiReJm2mVA87loq5J51JbJQtHKQOO6po7UKbXGLGEowc
gJ3+H0slPpLPjzl1ixmDsFs++IZXTfLrsX9Y/2Av7BQ6E/q4McSR2i/+kHO2
6BP9qwEZxHEzi7dPgvH3rsCtv97EO95Jr+GCMVz2RfApie/HCS0DV/PA+HDh
+wENsh6Pt7d+ohmD0XZakj1B5vdxzGdLZUcwHh5xYVeUEIcJM+V4YFRl3kuL
tyQmPW//UjCK97HGR9jELvtjZ3uCkbdb4qDbGWLLXsWy82BkJkw7p54m1mNv
n1gHRtJ2BYvB68QLX34oIH1DxLZAVlw8MX9ANsMEDN+40cQHKmT++iTfMAvA
cN5WXveN1NvmR0+nX7eDYb29XKaI1JvmwtPWzZvBMEoc26pHft+ctEfwrQsY
mnui23xIvWl23ZG0ewoM5f1m2rmKxFrpAv9ugiGe5bCjnlxvmil979wJxqzc
yxVet4mfDvAcuLDtveJSd6aY2PdU6urLpI/L+Nlh7kCstuhHN+kTG0I1WL/J
9zV+Mti1az1si/W5+6YXEDsvLvfPhu2Jhb7NTFJvG+dOaOqRPjddQGxnmyaJ
71s+odO7YBv82pNtTScWn5YwvwtbzwdzR0XJ+jyq1LSp4oetfdkWkbxKYrfR
uYs3wFYnx+ZCiDHJrxzr117eoI+HSHqO7iP5+XExe64F6L1bbp3qKSIOUQCr
AvT2TXoWUcng1o9fduqngX7T59zZp/0kv3+f7xg/APqO6O9frMn33u0ca569
DPSQpN37rEk83aW/2FLVDLpXuqBlRyK4tVWOkveugY4LPVM94qS+pKw8JHQG
dMHffp3ryf3VU4FnA/tg80uqTSWfxHe1o8O/E0Ow6de2XZDpCO6tsx2HLObB
pikouEX6Galvxq9i+CJhkznzjmtA6lkFNfNgkRlskjTEZfeR8Zcn5j15Kg2b
cGf/HndpcG9UMM//+QUbVnmRRWI9qa/ylVun/WEjl1m69aMXqc9VUZcls2Ez
tynz4xOSn1fanw2/DAftz5wbGQZkfS6Pvo4b3wNaV1rPgu0kfi+pfrs/nx+0
s1eWRueHkv3BmUZ9tR00rU079t8i+XJmEW78tgFNpfa4WfskuKeVtLMPCIAm
qfgp9wnJ11OyZpU/T8P6Z+e8nhefwc2b1fAjlx/Wd7cKLDEn9eloZWa8ST6s
2VJzdJ6S9cw8ttHvZyisLbM8VhuTeM7wq3h0vwHW6ySF5ds7wE1fo78xLQHW
ygop6nmkPqXev3km7ies+q3tWF2kPu+pf9/0WhFWO+QP1OaQ/WObsWG+fzOs
Qu9MKPmT+I/t2hdGzh1WGzcPjF/6AW7Mjnma7S9hZXUnyotmAO7WssrhMhdY
SabHDbfogRsycy5qUAiWF85fcQl/Aq6PZIBJRT6or/pMtkiNgEtbznrkLwVq
09LCy2pUcK3i1Wp1PUC97fsi7vYQuNRmL8UCb1ALvqZ+iSf7i7nvrIr4a6CG
L7rY84Hsv8bRy3dNF4EqKjbcnEb2Uy3lfZN2+0GhLLXi9x4n56E9WTWueqAY
1NJeSoyS81JykHpVMSgruRvvq5eR89Tuuvv6E6BInn3/6pk+uLNj+w6d2wSL
Hhaz0NEFnL/UpeXSPrBItF3dRRUE5+tmuR2NmTC/faXp0CnSlzS28BZXaMP8
6qU/rPnh4Dyylzj0fQzmBaUrFgnFgnO/eWi2QwvMU2tT+ouiwKm9raCZEAFz
Z/Hzq/LJebN8R4ri8UjgewwfJfgJOGdi0nTf2gPLtjz+HHACnK0uPcnTkoDc
F49OH9LnhCeUDBipAKJbqbd3NoETcvZe+KEObOhVDXCmyoKz5cPzlIQubNj1
t9iZbgsO1/zy3J+PYHbHVyGxlfRF1F1WzxAD0/V859++8wVHei7ndH0GTJfd
e6gV1A+OhKTZkrBOmIrtX+CT0A3OfLk+ZtVKmHzUY3/1ygFnjkp6xQYHmOzv
b/2raQyPKUmrmpporO/8mGpfx4XHx0zvRloCjPesPc+KmIbH1X6Xz35uMA4V
EJ7+wQ+PyyWDTCUtGLt1qn3KqIVHcbBPsP4/GGsXZNfWicGjYHDe9zXxMOo8
eev87ip4HGny/tdgAqO1RpW3aJvhsV395/NQJxh+17MMzjYjfZxnSGvWVRh2
RAgFnCP9D3LGHp+qhmF99XHvNb7wMGnWvPHmEQyPhdJOHt0ED/1Vlf+WasLQ
3I3tIjgKD7U3vqkPD8Pg2HrrQ2wJeAg9cDnong19W8/Iz/Wkj3s02nawZh70
Df7lrcl7Avf6T5t6b0lBf8mVlftSG+Fe+7z9TcgTrP2zMks4R5X0Zxd9cgbm
YW1x6aj9LD64F5lQXBQWY63Ih/7hmQNw38u3PeVIDPTaxTLXN16Au/nskET3
EejdTzRWFlWEu0nT6tsmZtC79ntLukwP3Nely1ia7YdehhTbtYYFdx1hR+W0
SuhZtLwRO9ENd5XhUvPGldAti+4tk1kGt+nNbtna8tA5ceRC2s09cKuY6fqz
6Q909u/ILj1cALfr+7+EbnWDTlxY1FO5AbhdkbZbdC8ZOi7bllbdLYRb4WIJ
1ogjdKSVsu+/F4Lb4RX3ao88xWplO+731y/gFjKkOlkzgVXKd8JS16XCbdmG
y/r1TKziu2KovFYJbosG2MVZBtD6VLZL9fo9uC08eF109k5oFf+9ZmAhCjep
zsNX9ilCy/CYQG/bPrjN2iij1EiDpsubmqnfX+H6Tm9t8+qn0Dh/z8bwiBZc
j37ryvH4AY30gKOvmnLgejjsjrz0KWhErJh6F/8PrpkjO0pZM9AwGVI+sKYB
rsnfT1tG/cWKVzGGoz234RrZffBA3w2sELmVEDejB1f7ffY3nVdAPWXuT5s1
6+E6WzrwmNkyqAfvMl5cQfpcPvGyN/v5oM5eIC3kaQ6XKZGO5pSnUFfdnyPC
pcNl5O+D2JFpqN0ud1Un51GXrnY6TYcfy/7M+2Z/wgEu5ey0q70ZWJo6yPm0
kgoXn7R7zUMPsDTy9md7t1q4ePrNSRo6haXcSxmfmnbBxQ0+5txSLNXptHdz
I32w3ahHXWYNlnQm/NsbOBsuRrb7LrTuwBK9D6GeP+LgIv6SKWUpAdVJ3frS
jTlwvm1bIvigC6p9pX/0PhbDucpPOXF8A1RfUQ37LOfAuSxpTP8FFaplla1i
N7ThfPF686TvGaiG3r716G0KnI+IsbVyV2JRe57mMct4OIdcnhUkLALlb8vF
h2e84ayy5zrXDVBu1dI/1JILZ4VM9ePHcqF8Y+MkQ+g+nBcc1VxRNg3leN6m
XJdTcBYp6v8YfBLKIgUUz7RncPp139WBxobSWlvH3LbjcGoZpO/auwCKly1C
yq8kwSlxzG947BcUj7zsf1S5A07xIvW3Jj2gmHQ06aq/AJyiF3cX/30HRfYF
aYPOl3AKcnBxaL0Ahb8zYicWHYOT64XY6SghKHD2+m1esgBOOnYXlH9GQYEm
0v1TbROcNDcekWq+DYW1d3NxShhO6tGu2xd/h4JYZbe8Xw6clE56/RacDfkH
Xe9cAqzgNHfg1NCjeZA3nutapkP67A/bZ+d8y4e8xu632tVvwO7K6Nz4Ogzy
Clp3Whg5YL8+nTuoawK532JFQZLXwX5a1xF7OAFyNaJav7cPg109J6X+103I
WQ+sWbO+FOzDWU3+9xdAztidvnGeNNiZZ9+skr8IOa3fLx+cPwN2all/P/sQ
5KSarKUie8FOfDUnze4WZHvO1lge/Ah2kEJUflA4ZPcaZfMCR8CmFGrv0fgF
2W13qrT6HoFtRudt6SuAbOi2hkoXK7DXjVxc/P4iZN2OX/dyfwq2tum+l98Z
kF0dV0GJOgC2fMfV4MspkFW7bZeYvBhs6aQWXcubkFUybFcMiwdbbLmU1SN7
yAq334pNPga2QIzkopFlkOm/8XTb9uVgfZeVP3dEADLvK79V5y8Fa6D20Nzp
vZB5/eMfzcUdrE9bTPSurINMk/jP0X3XwOq4pbt/lFyvG+1sbGgBq80nSepK
KWRq5l/jrdoBVss8IZmZ9ZC58kWr+ewhsO7zGsyF2iBz4UqboKkRWLUigvXX
XCBz9qJ/w9IPYN0s3x353AwyRy03mu5jg1UqYilRYAuZrP77s4TMwbpYkenK
txIy6fVSIe+fgXVuo1ICyVeZ3SqxI3rvwMq9JSt/eAYyCfkZdW1fwcrevKd3
cSJktnlkVGhcB+uA1AYYNkEmmhErhmCwUu/avJJdCpmIGFuhh+R79wSft28l
7w/pmNMimgtWoiLbjfEAMoERl/dLV4IV1+h8kvoOMpsYJcaDaWCFqnkmFJlC
ZuOBWTSb+WD5v/QLO2EMGd4ck5jjTWD57mm2VLGDDPemR1VWL1hea9IuzqJB
xuOsx2jZJFhun4rNP9RCxq3eZLbHArDYOctvr8qAjKvidH3NW7DsLefcWxwM
GedLeWPD8WDRftF/NUZBxilK3nXsJliUC2Nzp4ogw44KP1f+BSwzj1lnNpL1
YF0+t1vaGyyjeXE+ITnESlezB93AWnPX7Q/vI2SYD7LDJeeBpR15XpxKrjML
7c4Fkfs11L1oY9uJa7qu9Z4Ea2lnioP4f78X3SCZNAGWykGVJqEs4sNb1zqJ
gaVA1fCS8CfvZ8YmniDrIf37QoV2HxkfjW57wwAssat50at0yPhjBr+tOA2W
sJ8Q9Qz5fpdup5JbSmAJKg02fSgk3789tZ4zDubMS+tL8lVkfpjJ/jQrMH9n
LD6gE0Pmj2f5aCoYzHHqNvm3/ZDxKmz+tyEHzO9/HUZyLkPG+2fhIq0yMIck
lSo1WZDxjZ29yW0jmL1qHMnHIpDxW/FN77kTmD3G89xNyXoGiLr38zrAfOug
+1H1LGSCVWxep30Gs33T01mfciETtrGGeXI/mM/j389vIvERE79wMnUIzIaL
IWaqsZCJd5hzaswVzPq7X+fptEMm0SmkNiQFzDuv+xXy3SCTMlIgNa0HZrmw
K+XVT8icCI3+dlwRzPxIS4FqE8icaeDbWX0NzLzM5mmNA5A57/BrYX49mEeL
Xz/fpwKZa2OKGnv9wcz4lO6l6weZ5kQRPx13MLd5JvGbDkDmuXuZhgADzKgE
774o8n0dm2/UaSSAGXbq5bpqR5LPYjXO19rB3NwTFbyG1A+hwhPPk0TBZAXf
/Rx4GrLi/K06pS/AtDvEklB5BFm5Q4yErx5g0ip3rvqxFLIaG8SH01vB3MBf
kfAjELL23dvlKtaBqVlQLLNBjNSfO/kz4YFgqj/ZsM38NmR9nv42byFe/GuH
ZUUfZGOTDBTyIsCUZ3y3/5wG2XNLcyxeZoE5e1bHUdN3kC3dyxeRdQBMPp1H
Nzbsgmy1bOqTECU4Tnlvzj93CbLPmz5G7zaD44+6GqUlSZATiNiyweY1HN9l
DLw6YgW5sDrx8vYyON60Ck9elgi5JI+dKV32cLyhuCmnLg9yB7XMZdK/wvHK
MFpmtCF3NS6/8uA9OJ7Lu2nNyofcaLmv9zouHA/8a/3sJAP5PeXqXaQPddz8
a8Her18hf7Q1c7w/EI7eb+wtNolCvmTZjG9VJxw5d9IU1W5D/nn0wImaJ3Bk
7hdLe6kKhSVVXurXV8PRVCvWb5ULFJ6VZ5urk+sLilb7dtRCoc/BcZ/ANBzF
T9iKR5aT/W5x0/I8ITiKHNy9ObcFipohHXxrhuDIl0DfojoLimln35o/SoND
x5PXf/2oWMiOentQsBIOqT2XtcZboCyWnzF86TLsh95uWfKYD8ordUd/zfOB
/YfKdHPRcShbjrlOvHGBfUf2eGNOKJQThUTv/FwJ+0fOBUL5ZD8fCcxeJNYH
+7PjJTUcf6i80+zc+KAc9u7nTm8j517V0Er1nPYbsGtu1yuWSoFq0raZYRUN
2NXNNATueQDVLOeUAIHbsLulMXxLMoacR9i5pgc/wO5CqmBGZiJUJ4ISCpef
gV2y766GQ9uwOGXO9BETKdiZHe/O+y6IJeU9I5nTVWBULNhbp2KLJY16G4v6
4sC4XHtPeWIGS96eoCQI94FRGHSb8SUUS/mv2A/rXwQju4X/ZqkiljJ71hfO
poIRWS5Q0xuGpeOxi55EXwdDd84NXf0CqNFdskZS/GF7tSvx6tgo1LzDZ845
6cH2wifR7xEiUIs5mxr0wx22Z76enh3mA7Vz1N5Dn7VgmzW3473lI6j9zdke
6fMJtuGbP0wb5EC90ulu0pJ5sNUtFwyLsseKdVYzhTR+0CtLA+fPPo0V7PXJ
b6cWg14arRNpFI8VoTYlsgojoBdtaDk/k4YVhWUPFNq+g36k56SeDz80pKo6
bMMGQI92vHuCLxgaY2k5C+yyQF/7Ddv9yqHZuF53odEf2FQtP/3TmgrNPs/l
CHoMm6shE0cFa6ElmMsWLX4Cmws3I18sdoSWuYdZh5gIbHLdO+ce/wqt2/PE
TrxPgM22luI9sZNYVbmstU09Bzamuw3Pb4vB6jsy0X5/CkFrVBWpPEzD6q5F
iQW/L4FWF3DQOE4Xq6c2aAhUPQCtunLgZ8Bq6Ci9vzR1uhm0K55LcgJ1oMP5
EEb/vB+0w6/f3q2Oh87bIduTEAbNa9/jpeu2Q/ezcHPDnRpYT3bF9n/Sg+54
3z119ldYj54r3br0KvRmt/j+CjwE66+hXzazZaC3/M4NmW0KsO6RTFyX2wm9
YCWn9x4jsG7Yt5p1bjv0fnW88W0RhPUx/YmIm1+xdgGt9/bTu7A2Ktlz2eg5
1q7gEy/SEIX1mu0KyX2lWLv+/nkFlVOwXuWYxzupgbW+4eJSt8n1xSIBpmLP
sPaGZ4P97h+wnnvL9ftLQeg7Z0i/VUuB1ZvZzUPsbTA4t3r1iR8xsErwuTch
shIGNyNdRFpnYBXbdmK8fx8Mnta92DnnBKwibTLOnRqCweTex80WNbDaQq2p
ayH9qv3Z8nGxe7BixgVIL9eC4V8N+aX1BbBSf/Vr1vf3MPKNqkl/lQPLV+Fv
DuUmwGjb64J5jk6wbD11eOOHxzDKstqSlHIWlo+fMe/iH4zuWB98KFYKy3rz
vu9Vd2As1+GxPUUGlld9E/4IWML42dr5WkN7YZmWO/jcZBgmVu3JlncKYUlt
tY9uzYGJV8XH0zZ+sMTp4WyGBkxizq5SzsmHpUlk0YkDQjApytuf2GoPy7Ua
rnS7wzCdsyg6uOobLJe2NSZ8uQbT5k2v700GwlJQWejIOjFscP96/59DOaiN
O4ciq79jQ8TRzotSHqA+XO2b/ToNG/bbhqpMDIFa95EW2pKFDTdfio+utwG1
xtlJO/UjME/3asWRu6CWhgfx/5sAgu+ctv2tBeqReIsDdo+AuL7Xm4uegHo4
zG62gT+wV8btvkAHqAf9b79bQO4/tdtwtqoxqPv9mw9VVgAtedHG5Z9ATTh1
QL5gC8x1n+T5M8nv/d6sYM2fhLkZvfQVNEHdtGBDR/gPmNNbZF07I0HdyC4z
5SnA3Pfz51eWR0HlvC/0q18F86Oso3keDqAyNYuyJothPr1a5IIsP6gm2c6X
zufA4vHo9tq0UFBlj0+l2MrBotNIlSPUC+oC7VQB8XxYDKRoClLFQZVsFH55
vQ2U2Wtii99PgzpfuG8p/y9QzN5KDaxQAlWg8Uk8kwvKDd6OLSX2oIzqHlx9
zxuU+vmqgy0HQBlZsJe60hKU1jr8fcwD5du0Q5fcLFC+m/yOnlUFymCnO/3w
MlA1dm9dJDkDyodnf8y410A9a9VkYrUalBdnzMs3k3m5xn3uZ2BMntPiWpmc
DOrdbcFiKWtAecavYLCzCdTuR17lhhKgPI7NNu2+A0vFqz6bPX+C8uCEJPOS
NSyP3NX6dG8dKFXVKVXD4rA8v2H+mo8doFTqDTk4LoBl+cNj+yzLQSm/2hAR
HQ7Ltr5rC/74g3K9sufgMg9YSW1TqEgUBOXSH83TiU9hldUjHRRYBspZ5ojC
oxFYnbkdPvqgBpR8tei27fKwKj19PVTqAyinp0sZlSdh9STqfcPgMVBOVq40
r8gneesvuSlqHJRcp+HXCjtgLbf1/MgTX1COWV7ZLLgF1up71Z2+vQHlqDF/
8HIVWFNvfR+zZoGSs2pTSccgrHcF3tEPfgdKlllh8mgtrLPOtxjfIOtw0Pbm
1c/XYH2mry1epQCUA1xr4Y97YF0bX1usdASUjH33hcecYT01tGZNZToo++c8
PvvcALTYAT+BlG+g7L54enjXCGj79mjtKCbrtevLdmUZcdCOLf1Z13aQWDfr
4q6VoFXGZr+YVQ1KUoPLdt9NoP3cIvX3qjIoCfLP81vmw2a2nmB/zVpQdkT9
TT21HjYy/P8Cy0tB2f5ywxqZRtisrZJ4uIeMNz7vh+dPK9hEbakIXHQWlDiH
A7Pf28Em2We6U4jEU+z9XmO1ItjkbGL6nxwhXq8VmPkINuXbllbuqAAlRi/W
oCwUNuNf4vbsJXEXRdnapt4F+my5tTvH3oOyteXejj3FoMvY8J1eRNZrK/eV
VsI06Pq1zQZHRECJ3GX+z8cc9JixFcYvyXqHDx1bnHwd9JS/s3eJk/vDMwNK
TLRBPzav6sIKKrHePcUbPqBXmZ44/vMJKGHJn02fbwa9weuxSyX5njDdC2e/
XwD99d7WNrJulNCeTse7UqBP9LofLjpDbBV3/KIlbOcqdyVf8gQlZPrN+e1M
2Mpz1+TM3k1ckfM+sR2264Y8RSR2EGsLBpLztG08I8ctNR6UYOPVUxf9YJt2
42rMnMXE/M3PUl7ANk81r276LShBT3NU3o3C9rZo7823JF6CAvLuL3kK2ydp
FmsDSD4GGbe0bAuHbbdYSFLwfxZTqF/dB9uZFatuUCVBCazu2T41CwyxO3UK
mgziHMeabkkwFrmr0jwjiMPqXj/5BsbqP/RNIkHEdqv+iM4FA2fNkjVoxFoH
LaPywGDaTVU4DBLPf//qwH4wfPh2TpJ6Qwn4oVCbdRiMPTHvEx+oEt/RbRhJ
ByPHuDL1JomPgCKBr0W/wDgvyNRz6yHOurCVrAOjoq0UR5SIE2Rtj6mA8eji
k6DOaeIgOu+iERiv95TwvpgQc0wPVZ8AY2CTVU3pP2LG4B3vYTB+0/Ml57sS
g1bl+g52Igbln++R8QfoO9kdcYHdwhV7SleS7w3QErJ2c4SdlqrIa417xMvc
Nq+bgp2pMq3m+w9iFepGowDY2auuL3l2nljh/vf2U7DjrfjweWEasWxrjaI0
7MINjY6PkPgNkNkUfKkJdrtsMTLf7z/Hnft8BXaHN/2cunCfWE7oz4d02J1L
drlvSvIrQFF49tEdsCsv3mgW4PHf++KYH2th9/CltHNFzH/jsd9yXgl2rwUD
P4aZEWsmN7begt2A8ebSba+I1y74sTsGdr9jZkUtVic2nXSTrYe9SNX67q83
iW1WhGwYh/3CGamUSD1i59MnlZVhv4q+e3L5ALGvE50ZAHuzk2lXDKOIIy06
Fv6FvcP4cnGHduLdvvnhrrDfyHSOjX1BnH31t7gh7CPLpVf1GP23fov18qVh
n6zkGVDxmvjWtVzSv9oX/U2fXEvqa8Bn8Vl6F2B/azR/2dB/459+7M9QgP2T
79r6FsUkXmRvrinNhf3o5IWP6zqJ7fkMddvgsMEjT3htCXGTc+AjLTiw9sw9
Me1FPJR/wiwSDpuvPzX4G0zieV67Eskbh4wltJUfM4nZXZc/CsPhjX0sbQGZ
/6AvPO1kUzh8LZbQKl9G8kda0CzyH+lbBL+gs4V4PWPTwmg4SocO0faQ/SY4
s0DizhgcjbfElsiQ+QhZt4W6ohGOqQOz+kazST6fjlEIJH3Y4YcWl1pJ/Ql9
ssCjahyOJ89v9mrfQvz7YVIk6cuuhZprXTck9cHZZOOEExw7Fn8SsiHvDxfd
GbsqEswV85XWlS4EJSIkzWcW6Xv1ZNM+3yPxEJG7ROnpMJgmS44ukeYQ15s+
97oBpqNF6H5TUl8jF7yTFlkIZlx+bvpCUn8iy56OBR0Fc3etZz3TlLjjkJ3L
UtKHvzsq30D2k8i/2cY+fmCeVacLvr9E6qGlTs2zxWA2vVjU1nybuKlPopb0
1W1O7vK1qcR9JU4MeTC7OjIyU8j+GcWfsWGDFJjDfS0qg2T/jDI8sM3tDZi/
w18sObKE2PFs7ixzsPinby9bTOI3yr/qb9FGsGQVV9F/knoddeRl6eRXsBZd
Kn7fReYjqqRFJbcALA2zCeaLl8S115WvNYCl91JijdIU8fNYj8lQsEwCh4WG
ST2N+qR4aLUuWFYCB8wDSD5GjeXsCxQFy+HUgPVReVCi+d9LeieB5W40EeYd
SywxLl69Ciyf1xX/jpH5jVZ+Gs49AVZwrMrqvmfEGpu1b7HAipFfueLNCuI1
FU5KtmAlVb8UaCPrH21SNfHnEFj7eTKPF4wSU8nhTAesbMHBbbfIeKLpdzYW
MsE6eZk2VUHORdEO5We+HweryFl71TsfYra1vWMFWFf/He7+9JHYOezZdWmw
bl0Kb3YXJ3ZZcXSqEaz7bnUF5Z3/XQ9eHknG93RO0hyXbf/9Xn/BXw2w2qsK
9u//+t/zEwW3rQGrJ0DtUqbJf+83vywyBdaQ0qyeo1uJKfFtIefAGmvVyejU
JV6/zIlSD9bfvZdmZ88n1jVS3NIK9hyTwEPCpH5Fq5UvM3kItsS4v9+pjcTy
WbtnUsFWvHKq9Ol/4xFu4kglgr3MX2CPJaknUb/dP7uOgq299PD3j43E/aaB
cXFgG/ZQvzW4ELeF2a3TB9uWO86IsyIuuiwmegpsZ6VPHLNm4sxSqb9GYHt1
d3A8yXktKvJr/WAy2JE+ld9+gniduGemDtg71A/VnCP5GyX3RSlsBOy9X5x+
6KuRePw5ttr8HdjHY2NCrmsRX44brR0G+5zZw0R9Mp6tycPatUlgXxF6t/8P
2R+2cna/+sEF+95xh0ydJGL+8T1Xt4Dd7Hvs/erPJB/aHrcHkfe91E77cIdO
XHBjFTsE7P5HTHn7fGLj8znGTWD/yF5g3JxDLFBS/eAf2FPeG4f+kHyIaC6X
VrsOJ7HpHciVJmY1Xoi6CScDo4eznY+S/KaXB9gehRO66t9J9pH8/7v39TM3
ONnuXEB/TdY37MrXMw+V4eTdkLJ2NdkPwuZEqGxthVO6WwRfmCapN6dUOoPo
cDoy3V7iTOInxMR3dt4rOOWfNRiWJvEe/EY7sr8OThWDty4U6BCLui6mbINT
T9xeyo8JUh+Z3acuJMDpy8KEU+Xk+wK6abufBcPpZ610zzYSTwF+hrrbVeEs
OmuoaW8dKP7hZ+NzfeGsv3tcbn4AKH5bavNZcnBO472bPrIAlI09Hhe2kOs5
E5JPcnOJqVnHnmnD+Uym6uJwUn+9izafa6TCubziVOzFL6DwfP74TZL73/26
rfCrGxTuPYOybEe4rNFOKv/nCIqrWJe1rA5cTK/s3fJdGBQX+98tzy/Dhbby
ZMKtcFCcM/llHZvh4qny+KEOWQ8n/q8HNNvhkvKtafkTsl84tvdnndsMl86F
UvuXXgOFri6SqLGSOJC5dBnpW+iLwvxdyf2dtw6q6pL9iy7fNibzHC5v3YQp
snHEonlDSVfh0pXzS+MkOb/Y/Fju89gYLu/Fyvw0yHWb21r7bP/A5fOs8lnP
TxMzRySadIkd372g2hLb2miJDhLnC/NPk/pnQz07+NELLr1mnOSPecSGLLv0
Mrj0xf+eq0z2Oxul0srcv3AZGJeZJOc0Cq3fRZl8t8sgxeC+KdkfaT3FgTLP
iA+7fE0k30d7M+3+2gIuQzpHOPak/tOenF0WIASXLyEiF26Seka73rflCJX4
trpfjRvxJYMXrjfg8lXUfM8wm7gw5YNhFXFxdEfWMPExtS+Hc4knD4q/MCDO
iurXPgCXb9YXCr+Q8yBt//19K62Jj9499qiVeI/k46Ps//9/gtf///8Elv8D
ozmj4Q==
      "]]}}, {CircleBox[{42, 29}, 41.5], 
    CircleBox[{42, 29}, NCache[Rational[129, 100], 1.29]], 
    CircleBox[{60.84060573919119, 65.97677075381726}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[{-27.79865571540703, -27.74665923454465}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[{96.57116074414552, 103.75675803594766`}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[
     NCache[{42 + 85 Sin[33 Degree], 29 - 85 Cos[33 Degree]}, {
      88.29431797627731, -42.28699827536104}], NCache[
     Rational[129, 100], 1.29]], 
    LineBox[NCache[{{42, 29}, {
       42 + 85 Sin[33 Degree], 29 - 85 Cos[33 Degree]}}, {{42, 29}, {
       88.29431797627731, -42.28699827536104}}]], 
    LineBox[{{42, 29}, {60.84060573919119, 65.97677075381726}}], 
    LineBox[NCache[{{
       42 + 85 Sin[33 Degree], 29 - 85 
        Cos[33 Degree]}, {-27.79865571540703, -27.74665923454465}}, {{
      88.29431797627731, -42.28699827536104}, {-27.79865571540703, \
-27.74665923454465}}]], 
    LineBox[{{60.84060573919119, 
     65.97677075381726}, {-27.79865571540703, -27.74665923454465}, {
     96.57116074414552, 103.75675803594766`}, {60.84060573919119, 
     65.97677075381726}}], 
    InsetBox["A0", 
     NCache[{Rational[463, 10], Rational[247, 10]}, {46.3, 24.7}]], 
    InsetBox["A", {65.14060573919119, 70.27677075381726}], 
    InsetBox["B", {-23.49865571540703, -23.44665923454465}], 
    InsetBox["K", {100.87116074414551`, 108.05675803594765`}], 
    InsetBox["B0", 
     NCache[{Rational[463, 10] + 85 Sin[33 Degree], Rational[247, 10] - 85 
       Cos[33 Degree]}, {92.5943179762773, -46.58699827536104}]]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 2)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.467463020891292*^9, 3.467464406512301*^9, 
  3.467465870757783*^9, 3.467466163383099*^9},
 AnimationDisplayTime->0.059349290000000006`,
 AnimationCycleOffset->1,
 AnimationCycleRepetitions->Infinity],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt3Hk8VN8bB3AhhbJmDWmhREIhQh9mMMZYZsY+w4iSfcuWQoskSykqpUWS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      "]]}}, {CircleBox[{42, 29}, 41.5], 
    CircleBox[{42, 29}, NCache[Rational[129, 100], 1.29]], 
    CircleBox[{39.82805781591783, 70.44312569231482}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[{-28.65598491722414, -38.87721043470767}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[{67.43402853005259, 114.5102379295642}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[
     NCache[{42 + 85 Sin[33 Degree], 29 - 85 Cos[33 Degree]}, {
      88.29431797627731, -42.28699827536104}], NCache[
     Rational[129, 100], 1.29]], 
    LineBox[NCache[{{42, 29}, {
       42 + 85 Sin[33 Degree], 29 - 85 Cos[33 Degree]}}, {{42, 29}, {
       88.29431797627731, -42.28699827536104}}]], 
    LineBox[{{42, 29}, {39.82805781591783, 70.44312569231482}}], 
    LineBox[NCache[{{
       42 + 85 Sin[33 Degree], 29 - 85 
        Cos[33 Degree]}, {-28.65598491722414, -38.87721043470767}}, {{
      88.29431797627731, -42.28699827536104}, {-28.65598491722414, \
-38.87721043470767}}]], 
    LineBox[{{39.82805781591783, 
     70.44312569231482}, {-28.65598491722414, -38.87721043470767}, {
     67.43402853005259, 114.5102379295642}, {39.82805781591783, 
     70.44312569231482}}], 
    InsetBox["A0", 
     NCache[{Rational[463, 10], Rational[247, 10]}, {46.3, 24.7}]], 
    InsetBox["A", {44.12805781591783, 74.74312569231482}], 
    InsetBox["B", {-24.355984917224138`, -34.57721043470767}], 
    InsetBox["K", {71.73402853005258, 118.8102379295642}], 
    InsetBox["B0", 
     NCache[{Rational[463, 10] + 85 Sin[33 Degree], Rational[247, 10] - 85 
       Cos[33 Degree]}, {92.5943179762773, -46.58699827536104}]]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 2)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.467463020891292*^9, 3.467464406512301*^9, 
  3.467465870757783*^9, 3.467466163494177*^9},
 AnimationDisplayTime->0.059349290000000006`,
 AnimationCycleOffset->1,
 AnimationCycleRepetitions->Infinity],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt3Hk8VN8bB3AhhbJmDWmhREIhQh9mMMZYZsY+w4iSfcuWQoskSykqpUWS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      "]]}}, {CircleBox[{42, 29}, 41.5], 
    CircleBox[{42, 29}, NCache[Rational[129, 100], 1.29]], 
    CircleBox[{19.397480046876375`, 63.8048285697351}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[{-27.87283170587613, -56.22232513640586}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[{38.45217935806344, 112.18786727298571`}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[
     NCache[{42 + 85 Sin[33 Degree], 29 - 85 Cos[33 Degree]}, {
      88.29431797627731, -42.28699827536104}], NCache[
     Rational[129, 100], 1.29]], 
    LineBox[NCache[{{42, 29}, {
       42 + 85 Sin[33 Degree], 29 - 85 Cos[33 Degree]}}, {{42, 29}, {
       88.29431797627731, -42.28699827536104}}]], 
    LineBox[{{42, 29}, {19.397480046876375`, 63.8048285697351}}], 
    LineBox[NCache[{{
       42 + 85 Sin[33 Degree], 29 - 85 
        Cos[33 Degree]}, {-27.87283170587613, -56.22232513640586}}, {{
      88.29431797627731, -42.28699827536104}, {-27.87283170587613, \
-56.22232513640586}}]], 
    LineBox[{{19.397480046876375`, 
     63.8048285697351}, {-27.87283170587613, -56.22232513640586}, {
     38.45217935806344, 112.18786727298571`}, {19.397480046876375`, 
     63.8048285697351}}], 
    InsetBox["A0", 
     NCache[{Rational[463, 10], Rational[247, 10]}, {46.3, 24.7}]], 
    InsetBox["A", {23.697480046876375`, 68.1048285697351}], 
    InsetBox["B", {-23.57283170587613, -51.92232513640586}], 
    InsetBox["K", {42.75217935806344, 116.48786727298571`}], 
    InsetBox["B0", 
     NCache[{Rational[463, 10] + 85 Sin[33 Degree], Rational[247, 10] - 85 
       Cos[33 Degree]}, {92.5943179762773, -46.58699827536104}]]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 2)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.467463020891292*^9, 3.467464406512301*^9, 
  3.467465870757783*^9, 3.4674661635823593`*^9},
 AnimationDisplayTime->0.059349290000000006`,
 AnimationCycleOffset->1,
 AnimationCycleRepetitions->Infinity],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt3Hk8VN8bB3AhhbJmDWmhREIhQh9mMMZYZsY+w4iSfcuWQoskSykqpUWS
olLJUpSixVJJKUmUFmsLoSjS73xfr99fXu/XvXPvuec8z3PO8w9WmM/izXx8
fPx8fIKi//2Fy7fe9gG7N6DQdvDK91jDZcJf+FhvMyjWV5J79HfBla+/401V
LShW3V7vqCvgKt2jdkUAoFgaOTxrvAVXo7LNF7ePg2L+iZ8x2wyuyS8nvia3
gLJecCpGeAPc5J8l37kmC4rWgw3higVwWzyaP/plIyia3YtPzGHCTVNq5QvV
G6Cs/DngwTkEN1OrTZJqy0DRWM6cL0SH28bdMbc/B4KilvbiXC8FbsXmxyxG
5UBR8Zop/hcDd/2CgOUHzECRyE5+LZYBd7PpbPnDT0ARLx3+NvYO7jSmR+ZV
Mj6xJ7JU15dw9xg6vfhvIyjzRTsjfnfBPentrJ+8LlCEz2n5v14L98ZLbwfj
g0ERQIJPOx/cn196u1/OFhT+pM93qOJw7zw/vmJLGiiz6pf+3DAE96+prGtS
kaDwOUQynUfhISH4Z1/ld1j8PWjTfkQEHvIvJ2RvPIXFdH+QxHA8PBafbnut
1UVs8VP5eD481qhKR87+CospwQzToWp4OL+eCDL8BYvJG/Wag+bw8Iox17xH
njepobbveyo8toitezZtBouJgt1HtY7DI05TMbNJFBa/zkYMbFKCx86rv+36
WcTLV2gG7YTHfu0ws2Zy/8/rqsqJmvA4IS+6KP4mLMZfKFXuy4BHwR71lCe/
iQMsFVMG4VHS/2D+2x3Egr+KfLPgUXMqItU1DhZjdBPT15fhcf977H21CliM
jo1dS/wKjyfrvl52HiQu2C43LASPrmqJtQnricUgVE3u/zxSMTAeDIsfj/PT
v8vA45vqzZiLZHw/DsjxRcbC4ydd+qKeK7Fz+Z3LHfD4G3x/Y9YW4iXp86bk
wJmdej9fzBAWI+OXlquNgjP/tET8qsPET9TXvMwHR+Zy0aJMMt6R4vk2/Fxw
lMt3drRaEqdHBEbvBket4tScnVeJt/ruX3cCnFVXJ9R+DhF7j++RUQVH/1x6
g0E+sZP+Eol14JhmuR59K01sZ7BwcCk4ljGubt+1iBlzJY9fBMfOed/g00Ji
x5oDHTxwnFf1mQlTiTkbhU9+Bof7L8zHfB1x8NwP5/+As8lqeVDrUuJdkjz5
r+AEpfReEWcQ50XG0wfBiay7MGEuQlxjxBQpBGfbr+BV+7WJeyK/DzmAs0tN
h/rCisyHqBZjuA+cVLtRShmFeH0k06oFnIPh1yzszxJHMFtG74NzNNM/EPOI
L7/em6wFzqlC+V/RR4i/S6g+bQWnsPzeGjkvsj76c9flNYNz6S43wb+DeNcT
x6BJcMruf6WUZBK/9H+9/CY4t+pDBafI/I5pDam/nwvOveoeprEQcTo3ea8I
OC3HDyn95ifx4mEpZUee/yrpqdirOuLmNu94A3C6eOPhciT+f5rvntQk8zsk
NkuuYhOJT/No239T4Iy8/czkvCVufrbVn6zHxLnSnlsPSXx7bKsOcgJ3tuqv
7BPVJP4zviYVbgFXtD1yuRIXFr9XP7669gW4Unufj8xLJH6zwrtUGdxFL9Zf
PNNH8mlDSuGnFeAaLy7O+6sDixnunLdnusBF0To38U+w+LdW8MusTHCtl114
/oHUAz6pVzdsB8B1El/hOCJI8rt34ZV+fnA9thst3mlF8r/j/IbXTeB6f1hp
pUXqkUCbpk1JMrghJ65UTPmAMrvbaUs2E9yt32EwdhcUoW+iogVccOPX34j1
+wPKXIFea9p3cFMemK72zAdFxHrlHtfz4J5J7/sX4k/q1bJprfpecM+XphbN
sSb1LPTlJnY+uJcei61/WAmK5D2FOJ1Z4Fb9aLiS6g3Kgm3z2u8ag/vs15xg
/Y+gKFom907Fg/uq/+2062FQFj6+vpZ3B9y3bScywtVBUXbP6Ar3Arc/902S
XDooqhkRoadMwJ3p3H523WlQljs8EEy/AU/BxN5dI3yk/ooysnm58BRRTtSd
lib1uSXCcHIbPGVsUP14HSjaQRe/xtTDU5OzymkWGZ8B/55DYu7w1Hmu47bk
JCiGU2fEj8vC08A8OCK3GhSj6VTeMS48zSWOHLcg9d5M5m3IIht4ugS8MqG5
kf3lgkrShAw8OdebDfXI/bT31ES7Q/D0Hhf0O5sCiu0i3ysCPvAM2mL/g88P
FIeqs0ErZuC5Uzjom/gjUNxpZ04eiIXnRVOWlrAUKCEjiS9ot+F5ZWWQZggZ
b3iJS94VUXiWSfatnOMMytbgoCNdZ+FZ0yoy90ARKNuEPR7WC8HzmbB59Byy
/yUXXdyutxqe4xGmbP4eUE5F7NM8awbP37OD7GUdQcm/dmJg0S94/s1ROmHo
Asq5SblXSz7DS+is5PDSOlBK8p2VOzzhJb9tb6FtJig3XcTzelbCa736/jeC
q0F55drCfjUDrw13q7m+o6C8Cd8Z2mAALyor/8Vlst92Z+tef0+u223Oi+8t
AaX3V05n3Ai8eMhjn28FZUI/pC62DF67nvpV2cmCujA7a+BoB7xSBLx00gtB
VWVwapQ84JW2Zn3TyXZQ1cTVZdTI+w/vrNhTpA+qdlnF4Jp4eBW8mDQx3g+q
RURhJG0dvOpdfQ+3B4Ma9HTXkfm58Hq0SqNi031QI9QuLdbSgVfTX6HUFAtQ
Y/bVZIdow+t5uoRjlR+ouwL2DXR2wavH++bplCRQj51LHXDcDa/p8d9lvS6g
Pvx+x+ZHL3h8IYfNduSC+vjzgvNV/8AT6IlYxpIH9fmnZWf2KYEnUjH/2oMK
ULtnvA2OFoAnryhtuq4R1F8X36W8VAVP99XLunMbYanRvGfP+Bh4a+9Knf8Z
B8vVg6aC0W/AMzy3vYbSBEsDCQMh+QXgmXp27FM2hKVFzOtzb/PAo+VO5S15
AEtOUWikiRl4Xis7un+/gOXB9LBBUUXwvBtebRxgwfKolm2ksA94vt6qfpf+
wPLkK7XRdn7w/HeXJKiWwbLE7JHLp+fgRR5s1iwrhOXDCMO/V66Bt/eJyOWD
pbD8a9+leXYGvFSVoa58U1gJhqT8+lYLXlqI8Y2Pm2Almt1XuGA3eAemdZk1
9rBSmLg2s14dvGOfrp98ngUrQ8W+lF9D4F3svO7SFg+ryMebFkuPg1fSGxMo
IQareF++izf0wbv8pWk6+iCsdvPzWVYHg3ftyzL+o26wOuQiveV3KHg3y9sf
n1eB1TXn0ZNyS8BriG4iNQZWw1effOksAa+J9+9+1BlYTW5pjFzkAt5jy0Vd
Uo6wnrVCWPeDCnjP+NQez94Ba6k60z1SceC1GyWn3qTC2sC5SP5fJ3ivp6gJ
JiGw3uDAZ5lwFbw3Vf+WrDSDNc1xs/uIBnjdS4LrlKZh7RGkV8RvB96nGp9d
ITdhncQnfLRyELxeZ11TNXI9dd3Qz60PwOsbEvkgognrQ9vyDrRNgTck2Hd/
YzqsC6UYG6YCwRv+Fxs3bQnrpnw5e/Vk8KaEL2gPnAZNVr0wfp8YeNPOIk1n
4kFb1NFvdKoQvL95x5J2D4CmcTjxbLYKvPnmK5SdnwWa6cIM++cW8OYPbWM8
ugDapmRa2asX8BaYZcEU6AAtNNzF5y6b+BCjv1gdtDjfeKOGk/AWLFm3dsQc
tAyvz18PVsBb6G7ip+UXQSsvDmgP0Ib3HLOPcncZoNU+ZZiT85/3nJr+A64y
oDVOzr6t3wfvuaVdO38tBK174zsd1ZXwFolLHtXLgo1QitWXtibiXomK8cOw
kegRuBl1A96iDpaKkTthsxBu86fJ8+YplXRPPoWNzoILsZxYeM/PS6p60A8b
D1F+/rnyxGMN6Y7LYLNpC810pTu8xWzadkrNwCa06dK5QUHiYeNcVyXY7Mm/
dCODPF/c7JjK8x2wOSBjZFzpQZxenbHtN2xyDz4sUT0Bb4lFbh1LD8HmytHb
vy06iDe/khTbD5ubS+Vv9EwSlyj2/TsPm/oK53nn4+EtqSUkw8+BzesvTNsL
QvCWkgn+wdIGnf/knu4Lc4nptEOy06DPd5UICAsk3jEmyokCXV4OE6m7id9W
KWX0gb7qYtjTyml4S895PvG8AvR127yG2+nEurUGdAXQKQ5tjWEtxEnzOZ2b
QHefr+Pkco64IGKnnQTovuNzP+u/I75fvPuKLOihPbRPDTeJP1b8298E+rbn
A/WRycT/jh0+FQt6cmPPCMlr7wWK9u3P9oN+8KFGN/0asV6Xn8FJ0E88qpni
Cya2QSfpY+jnnx6sHp0i9tzR/GsS9GtvTh1MeE8cltW6IwH0mqHuL9e4xEkJ
u7JLQW+YZUNxSSTOpER5VYP+QqlDlF+LOPeT2frjoHeb7r4pPUhc4Ln1kTLo
A77m9+5fJy4uu9g5F/SxA/NPakQSl34KPyIP+sydd/WWx4mvj3i6q8JWePTK
ZeFNxGWdfC3zYCujFdnG0/vvev6XT6OwVQ1Sv6GX8N/vLUtfLYGtZmldQ+wM
8cXGNyvUYWswYZKpH058duXv6y9ha0E9uHt/EPGx4NPHGLC1O3pDvYysx4L0
A86OArB1+3bmj8IK4oSskgv1sN1kY5/ICiEOiVp57yJsw4qrDDT/ez7HaKPM
athuF3tx/tp/turpiCfjTYk7ztLNJdYJWqh6HLaH+gXqbf57vlxH2bEZ2J7y
EEkYNCLr83fl8meTsL34vEjMTZa4Lv7Jqk2wvduS8OYqyVfp/O0ialKwfcy+
pK2+gDhhI2VvJWzbux3SspOIdT7cLWqA7be/70/vjP0vnhLm7efB9nfO7e3c
byTeuvgClGXAmL16tOSXD3FiHS/8NxhKW+28DMl4pRz9n5y+DcZyVllWaSux
6oYLV2LB0NNvWCL6kcR7dYJtsR0YNKG+LSTvvCXeUMrGdoKx9aXz13ZSDyRO
RvxuNwAjsfVA4rl6Ys8X3xbqg7G/1erkWzJ+8bfaEXNcwTjTqVx614rk5z1X
wUQ9MJ7I3mvo6SKOVmtYcAqM19oObAll4hUrPY/tAOOjzarhW59Jvqe2Z394
CMZk6v2aCBJv89Y+HC2og52a9uVdlTnwFjZ0HjxdDbskCfsJ/72k/jy7+iGu
CXZpHkr1WlHEfpZ19t2wO1LU1ai3ntSrA+rlh6xgd9lGiSZJ8mV2Y8Odg8Ow
e3P1V71yKLxnDXaYBZ2EvT7/vPh+Y2I/pepTVNgjjqad20zqa0/B2IWXsLf9
oTBoUgTev/yvMhIlsPcZ8i+oFCT12mBXui1gnzUl/cr5I3g/asK2C4zD/tvB
yzn3eOCNbIy+0FgP+z/L995pJfvPsEBYdWMPHITqZkJfPQLv63rK4sPecFg0
c72fM5/sF/FJ9/tz4cA66mE0qwe8znWys3dpwuHmul0qzyLA6zj1oFi9EA4P
Jvj+1j4k+9e/aMZDZTg8r7qaySX7Q1tlj/ScSTh82bCjV4fsP09+js8P6oaj
+FrR+fFHwKut6Bi8pgJHi/STtKLb4N3uktC7HwBH2p+yhn8U8KpnXIO6g+Ho
EFi8n+8YeFWGCisWCcCRa7fS6NVf8K5u261yezkcY5QUUgO3g3fG4nLzTcCx
+N2dgQJy3tj+NcnlSyaYku/bb2fdAG9bLca0PoIp9/OYUdoK8GIzLjOnzoCp
Ilo7uPwkeFsX7TGkhoC50sjIB4fBC1S2bD7zEkyL3EN7Bch8u267N6cyC8yt
fqksr2nwVtecm76sAearVUcl6hrBW7VMyEkwA8y3tusHJivBW7lfo8OX/P6D
/4QI+w54ajZVflMuYH4rPKeXvhc8xcJZhbOXgCWklJmnROZT8M7UUAmx4bzd
7m3G8GrP+HTdPQOs3Lfvi+aR82DbqZmC/JVgne648mJ4DrxaL0vVTpmBVfjK
smuAnAeb72pEH34K1rWnzeedNsGrtk7ttccfsBprBkX+kfNykb5AFulLWZNp
GRGR3fCK/HDNZn4g2K4fjZ/llcJLYLuU/7x6OMkINpmVO8Hz387rOibhcFro
82ZhbyM8p3ZP9Zw4AafF90Qy6BLwHEs47tR0DU7asY1zfi2H5ydbac1wcr91
l1+3vws8661/V32shFN8nMCHthh4JjwPFZg7H07v+hNH/1mA+2WTgN28G3Au
XPym7vRlcPuGE8UuGcK5+KnmCYlUcD/GOUl0m8P5aqzh41TSr73ZLfM1XgzO
1Q1x84segNsQM7/cqBnOz938JLN3gFvQU95RvhfOM8ZB3ETSj7o2Gvp8M4OL
y2h/6+oX4FQrhXvezIWrwGuD67cY4JQfv+W4+iFchY8Ead54BM7VBetqVdTh
Ks4seP/4D+nn+XoGNGXhqvhgwfwbLHAyb/47TZeCq27Wo5Bd78DxPl+/SE8c
rl4NlT9VLMAR3P72iikXrlWnA6q/n4YHNTzn0K8+uPmkRh+Jc4GH2SZ7K8Us
uG3Jj/q5wwke65yrLmeNwy24UuGbYjM8tHTPVMeHwi2m09730QN4SD8dUTV4
C7d0If1fj3lw/3j8u1JTBdzKhi4MbPCCe2Ial8YNhDvf22OfW6hwu6Z+VY76
B+5H5hdsI+chtxJB90GXfXA/bnB6rHAGbud6PAaH1OF+yhPNxcVwO5a96eOZ
VrifPxceY1MDt8Te2mqTX3CvlPa1i5ODm51JjV+DDNzbd1aiYgiuA3eiaw5P
wUMmzfjznDG4fvTPXONvAA+FzZPOT/jh2iWl3sMNhofyBhMlr1G4PvPuC+eZ
w2PZEFtgTypcK77eOe5Pg8faJYXfGJvguvuu0JFpbXiwFkreO5wB14Wu/bLG
3+GRoSZgsTYdrgtoM2MjafA4OL2V9eAcXOevS1dwJfOU3frmTEsVXP5Jz8kI
6oFHXnhyN+cwXD5WPPAuWQuPknSjUuOTcCm+MejeOgOPxlVmv/2IDc48KyRx
yJmlLDpocgguq335dw9YkXU75ENrLYLLimWfux6tAWcuf1ZZ3gq4KBTe3Wne
AI7Y20jdHTFwnj7C9/ehFDhKW1b/0beEc72R+17Sf3AMet+WKWjAmXH6iPCB
bHAC4rlmAypwtry1eaJSD5xgp6V5mSROzdqszCNHwAnTlFmkKAtnXcH1Cnfo
4ES1RjHWhsJZhrPY8nk6OEm/pW1Pd8Cp+916zpAJOEfqXJ3eN8MplJrJiekD
5+5KyuAlMzhtodrJ5BuDU3eRkj7cBSdvir3wk1BwHizlnpucCyfWBoXefSHg
NEm88VS4DycD7dkuPYHgvGgcMT0jAvbfobS+DjIfvVd05wn9ATtj0Onw3gPg
ClMUriAR7L0mNcr3X4ArmtXa+OU+2AkHd0yc3QLu/LcSdzVrwQ5do3j2zQZw
pTZrxIU4g+0Q+UtV5Bu4Cx3KxGnBYEu2j2QmpICrlXA/6uYrsEVU/0aMtICr
nf1qYsIWbP7AvW/uKYCrUxT4dv4OsEanJSlWEeCurVO0ezgD1ksF+oiILLgm
T1KESFyyjprNDzY7CS5jvWX3HROwDux8kBDwGFx7BefYTzfBSrkv5zr7KLgO
Yx8NxNrAirXKjVEhdYF9OuJP5zyw3GzQ12cFrkeTz6jBYbAUzb5XzPiB6x/D
5L/oA+ap3++FdM+Du2vl85hT+WAedVuTP0XqyO5DEes3PgLzQOXmDgkRcPeM
X5z38iKYSZGBt/+ROpVyrdN55BqY3oOaT8JIHcvgszfXJs9b2mawNNsX3CNT
nlr7yb6gpGPj+T4N3GOaGxdc/Qnmgky3Ctl/4Oa6/snwGwJztvVW1yEy3yeK
vo36kX2wr+bprbvk+88sfGW/XJ7sa0X3xtfFgXth45kj5HscCwTjLbM+gnvR
Y1In5gAcT/jYL+I0glvs2PtnYgUc01XsBCKWg3tJb5d2ZB4cg491XfxyE9zS
J5XlJ/zhuOnXGfcJCXCvltwK6guEo6dzeu1BdXCv7WVm2ubA0V56UD/RFtwy
HQu4LoPj6sNfOui3wK3wXM4f6QfH5WO6y044gVu5qP3UmzA4qrKvWs/SJX6v
tPT6YzhKyniezFYD9yY7gHLyDxx6DUOfqe4Gt0ZazPfAQzi8mhpJfkPeV1Md
1inxHA6P6vjl08vBve3lP0u8Ew4XGZ++Hu4G985JpY6l+nAIChat7I4G9+73
k1qRBnDwNL7ntXUFuPcigoJdTeDgIDLP8A9Zv3s/KHsfjcFBryS6vKYU3LoB
sbrpadj/Hu3VUTEB937Zgl9WNNh/eXTxAe0RuA+UtbMdkmHfnbdw6KwP8V6W
fMhn2NdZKctzyHgeMqoicupgn1rYI7FqLbiPqv5dCsuEfXxitKOCPNmHRIOf
cQphH+z2IkzenpjTq3w5CPaO4iOBZWR9GsYmBoftYW/+tcrlcjC4jesP1ytd
g/2aZhaiyPMadxptW/YT9nKpEiu2LwK3ie+S+bwR2Av7G63xYxCbxJQd/Aq7
KRsL5xhP4mj7B2umYPdNUztnKdkHmy6tuWjzAnbvxfjGMwWI36kd+m4Ju9Yf
t7dHj4HbLLasQkQadvXtm1ZZ/SFer2vFvAO7ooLkxdE7iTO2pukwYJebxh/4
Upv4WnGJhh05x0bGfVv4kvj5d2mpObDbwRkq6SHx2TyCv0fJ+0OtPIpca8F9
LFpwbrUb7Lx1H39wKiReJm2mVA87loq5J51JbJQtHKQOO6po7UKbXGLGEowc
gJ3+H0slPpLPjzl1ixmDsFs++IZXTfLrsX9Y/2Av7BQ6E/q4McSR2i/+kHO2
6BP9qwEZxHEzi7dPgvH3rsCtv97EO95Jr+GCMVz2RfApie/HCS0DV/PA+HDh
+wENsh6Pt7d+ohmD0XZakj1B5vdxzGdLZUcwHh5xYVeUEIcJM+V4YFRl3kuL
tyQmPW//UjCK97HGR9jELvtjZ3uCkbdb4qDbGWLLXsWy82BkJkw7p54m1mNv
n1gHRtJ2BYvB68QLX34oIH1DxLZAVlw8MX9ANsMEDN+40cQHKmT++iTfMAvA
cN5WXveN1NvmR0+nX7eDYb29XKaI1JvmwtPWzZvBMEoc26pHft+ctEfwrQsY
mnui23xIvWl23ZG0ewoM5f1m2rmKxFrpAv9ugiGe5bCjnlxvmil979wJxqzc
yxVet4mfDvAcuLDtveJSd6aY2PdU6urLpI/L+Nlh7kCstuhHN+kTG0I1WL/J
9zV+Mti1az1si/W5+6YXEDsvLvfPhu2Jhb7NTFJvG+dOaOqRPjddQGxnmyaJ
71s+odO7YBv82pNtTScWn5YwvwtbzwdzR0XJ+jyq1LSp4oetfdkWkbxKYrfR
uYs3wFYnx+ZCiDHJrxzr117eoI+HSHqO7iP5+XExe64F6L1bbp3qKSIOUQCr
AvT2TXoWUcng1o9fduqngX7T59zZp/0kv3+f7xg/APqO6O9frMn33u0ca569
DPSQpN37rEk83aW/2FLVDLpXuqBlRyK4tVWOkveugY4LPVM94qS+pKw8JHQG
dMHffp3ryf3VU4FnA/tg80uqTSWfxHe1o8O/E0Ow6de2XZDpCO6tsx2HLObB
pikouEX6Galvxq9i+CJhkznzjmtA6lkFNfNgkRlskjTEZfeR8Zcn5j15Kg2b
cGf/HndpcG9UMM//+QUbVnmRRWI9qa/ylVun/WEjl1m69aMXqc9VUZcls2Ez
tynz4xOSn1fanw2/DAftz5wbGQZkfS6Pvo4b3wNaV1rPgu0kfi+pfrs/nx+0
s1eWRueHkv3BmUZ9tR00rU079t8i+XJmEW78tgFNpfa4WfskuKeVtLMPCIAm
qfgp9wnJ11OyZpU/T8P6Z+e8nhefwc2b1fAjlx/Wd7cKLDEn9eloZWa8ST6s
2VJzdJ6S9cw8ttHvZyisLbM8VhuTeM7wq3h0vwHW6ySF5ds7wE1fo78xLQHW
ygop6nmkPqXev3km7ies+q3tWF2kPu+pf9/0WhFWO+QP1OaQ/WObsWG+fzOs
Qu9MKPmT+I/t2hdGzh1WGzcPjF/6AW7Mjnma7S9hZXUnyotmAO7WssrhMhdY
SabHDbfogRsycy5qUAiWF85fcQl/Aq6PZIBJRT6or/pMtkiNgEtbznrkLwVq
09LCy2pUcK3i1Wp1PUC97fsi7vYQuNRmL8UCb1ALvqZ+iSf7i7nvrIr4a6CG
L7rY84Hsv8bRy3dNF4EqKjbcnEb2Uy3lfZN2+0GhLLXi9x4n56E9WTWueqAY
1NJeSoyS81JykHpVMSgruRvvq5eR89Tuuvv6E6BInn3/6pk+uLNj+w6d2wSL
Hhaz0NEFnL/UpeXSPrBItF3dRRUE5+tmuR2NmTC/faXp0CnSlzS28BZXaMP8
6qU/rPnh4Dyylzj0fQzmBaUrFgnFgnO/eWi2QwvMU2tT+ouiwKm9raCZEAFz
Z/Hzq/LJebN8R4ri8UjgewwfJfgJOGdi0nTf2gPLtjz+HHACnK0uPcnTkoDc
F49OH9LnhCeUDBipAKJbqbd3NoETcvZe+KEObOhVDXCmyoKz5cPzlIQubNj1
t9iZbgsO1/zy3J+PYHbHVyGxlfRF1F1WzxAD0/V859++8wVHei7ndH0GTJfd
e6gV1A+OhKTZkrBOmIrtX+CT0A3OfLk+ZtVKmHzUY3/1ygFnjkp6xQYHmOzv
b/2raQyPKUmrmpporO/8mGpfx4XHx0zvRloCjPesPc+KmIbH1X6Xz35uMA4V
EJ7+wQ+PyyWDTCUtGLt1qn3KqIVHcbBPsP4/GGsXZNfWicGjYHDe9zXxMOo8
eev87ip4HGny/tdgAqO1RpW3aJvhsV395/NQJxh+17MMzjYjfZxnSGvWVRh2
RAgFnCP9D3LGHp+qhmF99XHvNb7wMGnWvPHmEQyPhdJOHt0ED/1Vlf+WasLQ
3I3tIjgKD7U3vqkPD8Pg2HrrQ2wJeAg9cDnong19W8/Iz/Wkj3s02nawZh70
Df7lrcl7Avf6T5t6b0lBf8mVlftSG+Fe+7z9TcgTrP2zMks4R5X0Zxd9cgbm
YW1x6aj9LD64F5lQXBQWY63Ih/7hmQNw38u3PeVIDPTaxTLXN16Au/nskET3
EejdTzRWFlWEu0nT6tsmZtC79ntLukwP3Nely1ia7YdehhTbtYYFdx1hR+W0
SuhZtLwRO9ENd5XhUvPGldAti+4tk1kGt+nNbtna8tA5ceRC2s09cKuY6fqz
6Q909u/ILj1cALfr+7+EbnWDTlxY1FO5AbhdkbZbdC8ZOi7bllbdLYRb4WIJ
1ogjdKSVsu+/F4Lb4RX3ao88xWplO+731y/gFjKkOlkzgVXKd8JS16XCbdmG
y/r1TKziu2KovFYJbosG2MVZBtD6VLZL9fo9uC08eF109k5oFf+9ZmAhCjep
zsNX9ilCy/CYQG/bPrjN2iij1EiDpsubmqnfX+H6Tm9t8+qn0Dh/z8bwiBZc
j37ryvH4AY30gKOvmnLgejjsjrz0KWhErJh6F/8PrpkjO0pZM9AwGVI+sKYB
rsnfT1tG/cWKVzGGoz234RrZffBA3w2sELmVEDejB1f7ffY3nVdAPWXuT5s1
6+E6WzrwmNkyqAfvMl5cQfpcPvGyN/v5oM5eIC3kaQ6XKZGO5pSnUFfdnyPC
pcNl5O+D2JFpqN0ud1Un51GXrnY6TYcfy/7M+2Z/wgEu5ey0q70ZWJo6yPm0
kgoXn7R7zUMPsDTy9md7t1q4ePrNSRo6haXcSxmfmnbBxQ0+5txSLNXptHdz
I32w3ahHXWYNlnQm/NsbOBsuRrb7LrTuwBK9D6GeP+LgIv6SKWUpAdVJ3frS
jTlwvm1bIvigC6p9pX/0PhbDucpPOXF8A1RfUQ37LOfAuSxpTP8FFaplla1i
N7ThfPF686TvGaiG3r716G0KnI+IsbVyV2JRe57mMct4OIdcnhUkLALlb8vF
h2e84ayy5zrXDVBu1dI/1JILZ4VM9ePHcqF8Y+MkQ+g+nBcc1VxRNg3leN6m
XJdTcBYp6v8YfBLKIgUUz7RncPp139WBxobSWlvH3LbjcGoZpO/auwCKly1C
yq8kwSlxzG947BcUj7zsf1S5A07xIvW3Jj2gmHQ06aq/AJyiF3cX/30HRfYF
aYPOl3AKcnBxaL0Ahb8zYicWHYOT64XY6SghKHD2+m1esgBOOnYXlH9GQYEm
0v1TbROcNDcekWq+DYW1d3NxShhO6tGu2xd/h4JYZbe8Xw6clE56/RacDfkH
Xe9cAqzgNHfg1NCjeZA3nutapkP67A/bZ+d8y4e8xu632tVvwO7K6Nz4Ogzy
Clp3Whg5YL8+nTuoawK532JFQZLXwX5a1xF7OAFyNaJav7cPg109J6X+103I
WQ+sWbO+FOzDWU3+9xdAztidvnGeNNiZZ9+skr8IOa3fLx+cPwN2all/P/sQ
5KSarKUie8FOfDUnze4WZHvO1lge/Ah2kEJUflA4ZPcaZfMCR8CmFGrv0fgF
2W13qrT6HoFtRudt6SuAbOi2hkoXK7DXjVxc/P4iZN2OX/dyfwq2tum+l98Z
kF0dV0GJOgC2fMfV4MspkFW7bZeYvBhs6aQWXcubkFUybFcMiwdbbLmU1SN7
yAq334pNPga2QIzkopFlkOm/8XTb9uVgfZeVP3dEADLvK79V5y8Fa6D20Nzp
vZB5/eMfzcUdrE9bTPSurINMk/jP0X3XwOq4pbt/lFyvG+1sbGgBq80nSepK
KWRq5l/jrdoBVss8IZmZ9ZC58kWr+ewhsO7zGsyF2iBz4UqboKkRWLUigvXX
XCBz9qJ/w9IPYN0s3x353AwyRy03mu5jg1UqYilRYAuZrP77s4TMwbpYkenK
txIy6fVSIe+fgXVuo1ICyVeZ3SqxI3rvwMq9JSt/eAYyCfkZdW1fwcrevKd3
cSJktnlkVGhcB+uA1AYYNkEmmhErhmCwUu/avJJdCpmIGFuhh+R79wSft28l
7w/pmNMimgtWoiLbjfEAMoERl/dLV4IV1+h8kvoOMpsYJcaDaWCFqnkmFJlC
ZuOBWTSb+WD5v/QLO2EMGd4ck5jjTWD57mm2VLGDDPemR1VWL1hea9IuzqJB
xuOsx2jZJFhun4rNP9RCxq3eZLbHArDYOctvr8qAjKvidH3NW7DsLefcWxwM
GedLeWPD8WDRftF/NUZBxilK3nXsJliUC2Nzp4ogw44KP1f+BSwzj1lnNpL1
YF0+t1vaGyyjeXE+ITnESlezB93AWnPX7Q/vI2SYD7LDJeeBpR15XpxKrjML
7c4Fkfs11L1oY9uJa7qu9Z4Ea2lnioP4f78X3SCZNAGWykGVJqEs4sNb1zqJ
gaVA1fCS8CfvZ8YmniDrIf37QoV2HxkfjW57wwAssat50at0yPhjBr+tOA2W
sJ8Q9Qz5fpdup5JbSmAJKg02fSgk3789tZ4zDubMS+tL8lVkfpjJ/jQrMH9n
LD6gE0Pmj2f5aCoYzHHqNvm3/ZDxKmz+tyEHzO9/HUZyLkPG+2fhIq0yMIck
lSo1WZDxjZ29yW0jmL1qHMnHIpDxW/FN77kTmD3G89xNyXoGiLr38zrAfOug
+1H1LGSCVWxep30Gs33T01mfciETtrGGeXI/mM/j389vIvERE79wMnUIzIaL
IWaqsZCJd5hzaswVzPq7X+fptEMm0SmkNiQFzDuv+xXy3SCTMlIgNa0HZrmw
K+XVT8icCI3+dlwRzPxIS4FqE8icaeDbWX0NzLzM5mmNA5A57/BrYX49mEeL
Xz/fpwKZa2OKGnv9wcz4lO6l6weZ5kQRPx13MLd5JvGbDkDmuXuZhgADzKgE
774o8n0dm2/UaSSAGXbq5bpqR5LPYjXO19rB3NwTFbyG1A+hwhPPk0TBZAXf
/Rx4GrLi/K06pS/AtDvEklB5BFm5Q4yErx5g0ip3rvqxFLIaG8SH01vB3MBf
kfAjELL23dvlKtaBqVlQLLNBjNSfO/kz4YFgqj/ZsM38NmR9nv42byFe/GuH
ZUUfZGOTDBTyIsCUZ3y3/5wG2XNLcyxeZoE5e1bHUdN3kC3dyxeRdQBMPp1H
Nzbsgmy1bOqTECU4Tnlvzj93CbLPmz5G7zaD44+6GqUlSZATiNiyweY1HN9l
DLw6YgW5sDrx8vYyON60Ck9elgi5JI+dKV32cLyhuCmnLg9yB7XMZdK/wvHK
MFpmtCF3NS6/8uA9OJ7Lu2nNyofcaLmv9zouHA/8a/3sJAP5PeXqXaQPddz8
a8Her18hf7Q1c7w/EI7eb+wtNolCvmTZjG9VJxw5d9IU1W5D/nn0wImaJ3Bk
7hdLe6kKhSVVXurXV8PRVCvWb5ULFJ6VZ5urk+sLilb7dtRCoc/BcZ/ANBzF
T9iKR5aT/W5x0/I8ITiKHNy9ObcFipohHXxrhuDIl0DfojoLimln35o/SoND
x5PXf/2oWMiOentQsBIOqT2XtcZboCyWnzF86TLsh95uWfKYD8ordUd/zfOB
/YfKdHPRcShbjrlOvHGBfUf2eGNOKJQThUTv/FwJ+0fOBUL5ZD8fCcxeJNYH
+7PjJTUcf6i80+zc+KAc9u7nTm8j517V0Er1nPYbsGtu1yuWSoFq0raZYRUN
2NXNNATueQDVLOeUAIHbsLulMXxLMoacR9i5pgc/wO5CqmBGZiJUJ4ISCpef
gV2y766GQ9uwOGXO9BETKdiZHe/O+y6IJeU9I5nTVWBULNhbp2KLJY16G4v6
4sC4XHtPeWIGS96eoCQI94FRGHSb8SUUS/mv2A/rXwQju4X/ZqkiljJ71hfO
poIRWS5Q0xuGpeOxi55EXwdDd84NXf0CqNFdskZS/GF7tSvx6tgo1LzDZ845
6cH2wifR7xEiUIs5mxr0wx22Z76enh3mA7Vz1N5Dn7VgmzW3473lI6j9zdke
6fMJtuGbP0wb5EC90ulu0pJ5sNUtFwyLsseKdVYzhTR+0CtLA+fPPo0V7PXJ
b6cWg14arRNpFI8VoTYlsgojoBdtaDk/k4YVhWUPFNq+g36k56SeDz80pKo6
bMMGQI92vHuCLxgaY2k5C+yyQF/7Ddv9yqHZuF53odEf2FQtP/3TmgrNPs/l
CHoMm6shE0cFa6ElmMsWLX4Cmws3I18sdoSWuYdZh5gIbHLdO+ce/wqt2/PE
TrxPgM22luI9sZNYVbmstU09Bzamuw3Pb4vB6jsy0X5/CkFrVBWpPEzD6q5F
iQW/L4FWF3DQOE4Xq6c2aAhUPQCtunLgZ8Bq6Ci9vzR1uhm0K55LcgJ1oMP5
EEb/vB+0w6/f3q2Oh87bIduTEAbNa9/jpeu2Q/ezcHPDnRpYT3bF9n/Sg+54
3z119ldYj54r3br0KvRmt/j+CjwE66+hXzazZaC3/M4NmW0KsO6RTFyX2wm9
YCWn9x4jsG7Yt5p1bjv0fnW88W0RhPUx/YmIm1+xdgGt9/bTu7A2Ktlz2eg5
1q7gEy/SEIX1mu0KyX2lWLv+/nkFlVOwXuWYxzupgbW+4eJSt8n1xSIBpmLP
sPaGZ4P97h+wnnvL9ftLQeg7Z0i/VUuB1ZvZzUPsbTA4t3r1iR8xsErwuTch
shIGNyNdRFpnYBXbdmK8fx8Mnta92DnnBKwibTLOnRqCweTex80WNbDaQq2p
ayH9qv3Z8nGxe7BixgVIL9eC4V8N+aX1BbBSf/Vr1vf3MPKNqkl/lQPLV+Fv
DuUmwGjb64J5jk6wbD11eOOHxzDKstqSlHIWlo+fMe/iH4zuWB98KFYKy3rz
vu9Vd2As1+GxPUUGlld9E/4IWML42dr5WkN7YZmWO/jcZBgmVu3JlncKYUlt
tY9uzYGJV8XH0zZ+sMTp4WyGBkxizq5SzsmHpUlk0YkDQjApytuf2GoPy7Ua
rnS7wzCdsyg6uOobLJe2NSZ8uQbT5k2v700GwlJQWejIOjFscP96/59DOaiN
O4ciq79jQ8TRzotSHqA+XO2b/ToNG/bbhqpMDIFa95EW2pKFDTdfio+utwG1
xtlJO/UjME/3asWRu6CWhgfx/5sAgu+ctv2tBeqReIsDdo+AuL7Xm4uegHo4
zG62gT+wV8btvkAHqAf9b79bQO4/tdtwtqoxqPv9mw9VVgAtedHG5Z9ATTh1
QL5gC8x1n+T5M8nv/d6sYM2fhLkZvfQVNEHdtGBDR/gPmNNbZF07I0HdyC4z
5SnA3Pfz51eWR0HlvC/0q18F86Oso3keDqAyNYuyJothPr1a5IIsP6gm2c6X
zufA4vHo9tq0UFBlj0+l2MrBotNIlSPUC+oC7VQB8XxYDKRoClLFQZVsFH55
vQ2U2Wtii99PgzpfuG8p/y9QzN5KDaxQAlWg8Uk8kwvKDd6OLSX2oIzqHlx9
zxuU+vmqgy0HQBlZsJe60hKU1jr8fcwD5du0Q5fcLFC+m/yOnlUFymCnO/3w
MlA1dm9dJDkDyodnf8y410A9a9VkYrUalBdnzMs3k3m5xn3uZ2BMntPiWpmc
DOrdbcFiKWtAecavYLCzCdTuR17lhhKgPI7NNu2+A0vFqz6bPX+C8uCEJPOS
NSyP3NX6dG8dKFXVKVXD4rA8v2H+mo8doFTqDTk4LoBl+cNj+yzLQSm/2hAR
HQ7Ltr5rC/74g3K9sufgMg9YSW1TqEgUBOXSH83TiU9hldUjHRRYBspZ5ojC
oxFYnbkdPvqgBpR8tei27fKwKj19PVTqAyinp0sZlSdh9STqfcPgMVBOVq40
r8gneesvuSlqHJRcp+HXCjtgLbf1/MgTX1COWV7ZLLgF1up71Z2+vQHlqDF/
8HIVWFNvfR+zZoGSs2pTSccgrHcF3tEPfgdKlllh8mgtrLPOtxjfIOtw0Pbm
1c/XYH2mry1epQCUA1xr4Y97YF0bX1usdASUjH33hcecYT01tGZNZToo++c8
PvvcALTYAT+BlG+g7L54enjXCGj79mjtKCbrtevLdmUZcdCOLf1Z13aQWDfr
4q6VoFXGZr+YVQ1KUoPLdt9NoP3cIvX3qjIoCfLP81vmw2a2nmB/zVpQdkT9
TT21HjYy/P8Cy0tB2f5ywxqZRtisrZJ4uIeMNz7vh+dPK9hEbakIXHQWlDiH
A7Pf28Em2We6U4jEU+z9XmO1ItjkbGL6nxwhXq8VmPkINuXbllbuqAAlRi/W
oCwUNuNf4vbsJXEXRdnapt4F+my5tTvH3oOyteXejj3FoMvY8J1eRNZrK/eV
VsI06Pq1zQZHRECJ3GX+z8cc9JixFcYvyXqHDx1bnHwd9JS/s3eJk/vDMwNK
TLRBPzav6sIKKrHePcUbPqBXmZ44/vMJKGHJn02fbwa9weuxSyX5njDdC2e/
XwD99d7WNrJulNCeTse7UqBP9LofLjpDbBV3/KIlbOcqdyVf8gQlZPrN+e1M
2Mpz1+TM3k1ckfM+sR2264Y8RSR2EGsLBpLztG08I8ctNR6UYOPVUxf9YJt2
42rMnMXE/M3PUl7ANk81r276LShBT3NU3o3C9rZo7823JF6CAvLuL3kK2ydp
FmsDSD4GGbe0bAuHbbdYSFLwfxZTqF/dB9uZFatuUCVBCazu2T41CwyxO3UK
mgziHMeabkkwFrmr0jwjiMPqXj/5BsbqP/RNIkHEdqv+iM4FA2fNkjVoxFoH
LaPywGDaTVU4DBLPf//qwH4wfPh2TpJ6Qwn4oVCbdRiMPTHvEx+oEt/RbRhJ
ByPHuDL1JomPgCKBr0W/wDgvyNRz6yHOurCVrAOjoq0UR5SIE2Rtj6mA8eji
k6DOaeIgOu+iERiv95TwvpgQc0wPVZ8AY2CTVU3pP2LG4B3vYTB+0/Ml57sS
g1bl+g52Igbln++R8QfoO9kdcYHdwhV7SleS7w3QErJ2c4SdlqrIa417xMvc
Nq+bgp2pMq3m+w9iFepGowDY2auuL3l2nljh/vf2U7DjrfjweWEasWxrjaI0
7MINjY6PkPgNkNkUfKkJdrtsMTLf7z/Hnft8BXaHN/2cunCfWE7oz4d02J1L
drlvSvIrQFF49tEdsCsv3mgW4PHf++KYH2th9/CltHNFzH/jsd9yXgl2rwUD
P4aZEWsmN7begt2A8ebSba+I1y74sTsGdr9jZkUtVic2nXSTrYe9SNX67q83
iW1WhGwYh/3CGamUSD1i59MnlZVhv4q+e3L5ALGvE50ZAHuzk2lXDKOIIy06
Fv6FvcP4cnGHduLdvvnhrrDfyHSOjX1BnH31t7gh7CPLpVf1GP23fov18qVh
n6zkGVDxmvjWtVzSv9oX/U2fXEvqa8Bn8Vl6F2B/azR/2dB/459+7M9QgP2T
79r6FsUkXmRvrinNhf3o5IWP6zqJ7fkMddvgsMEjT3htCXGTc+AjLTiw9sw9
Me1FPJR/wiwSDpuvPzX4G0zieV67Eskbh4wltJUfM4nZXZc/CsPhjX0sbQGZ
/6AvPO1kUzh8LZbQKl9G8kda0CzyH+lbBL+gs4V4PWPTwmg4SocO0faQ/SY4
s0DizhgcjbfElsiQ+QhZt4W6ohGOqQOz+kazST6fjlEIJH3Y4YcWl1pJ/Ql9
ssCjahyOJ89v9mrfQvz7YVIk6cuuhZprXTck9cHZZOOEExw7Fn8SsiHvDxfd
GbsqEswV85XWlS4EJSIkzWcW6Xv1ZNM+3yPxEJG7ROnpMJgmS44ukeYQ15s+
97oBpqNF6H5TUl8jF7yTFlkIZlx+bvpCUn8iy56OBR0Fc3etZz3TlLjjkJ3L
UtKHvzsq30D2k8i/2cY+fmCeVacLvr9E6qGlTs2zxWA2vVjU1nybuKlPopb0
1W1O7vK1qcR9JU4MeTC7OjIyU8j+GcWfsWGDFJjDfS0qg2T/jDI8sM3tDZi/
w18sObKE2PFs7ixzsPinby9bTOI3yr/qb9FGsGQVV9F/knoddeRl6eRXsBZd
Kn7fReYjqqRFJbcALA2zCeaLl8S115WvNYCl91JijdIU8fNYj8lQsEwCh4WG
ST2N+qR4aLUuWFYCB8wDSD5GjeXsCxQFy+HUgPVReVCi+d9LeieB5W40EeYd
SywxLl69Ciyf1xX/jpH5jVZ+Gs49AVZwrMrqvmfEGpu1b7HAipFfueLNCuI1
FU5KtmAlVb8UaCPrH21SNfHnEFj7eTKPF4wSU8nhTAesbMHBbbfIeKLpdzYW
MsE6eZk2VUHORdEO5We+HweryFl71TsfYra1vWMFWFf/He7+9JHYOezZdWmw
bl0Kb3YXJ3ZZcXSqEaz7bnUF5Z3/XQ9eHknG93RO0hyXbf/9Xn/BXw2w2qsK
9u//+t/zEwW3rQGrJ0DtUqbJf+83vywyBdaQ0qyeo1uJKfFtIefAGmvVyejU
JV6/zIlSD9bfvZdmZ88n1jVS3NIK9hyTwEPCpH5Fq5UvM3kItsS4v9+pjcTy
WbtnUsFWvHKq9Ol/4xFu4kglgr3MX2CPJaknUb/dP7uOgq299PD3j43E/aaB
cXFgG/ZQvzW4ELeF2a3TB9uWO86IsyIuuiwmegpsZ6VPHLNm4sxSqb9GYHt1
d3A8yXktKvJr/WAy2JE+ld9+gniduGemDtg71A/VnCP5GyX3RSlsBOy9X5x+
6KuRePw5ttr8HdjHY2NCrmsRX44brR0G+5zZw0R9Mp6tycPatUlgXxF6t/8P
2R+2cna/+sEF+95xh0ydJGL+8T1Xt4Dd7Hvs/erPJB/aHrcHkfe91E77cIdO
XHBjFTsE7P5HTHn7fGLj8znGTWD/yF5g3JxDLFBS/eAf2FPeG4f+kHyIaC6X
VrsOJ7HpHciVJmY1Xoi6CScDo4eznY+S/KaXB9gehRO66t9J9pH8/7v39TM3
ONnuXEB/TdY37MrXMw+V4eTdkLJ2NdkPwuZEqGxthVO6WwRfmCapN6dUOoPo
cDoy3V7iTOInxMR3dt4rOOWfNRiWJvEe/EY7sr8OThWDty4U6BCLui6mbINT
T9xeyo8JUh+Z3acuJMDpy8KEU+Xk+wK6abufBcPpZ610zzYSTwF+hrrbVeEs
OmuoaW8dKP7hZ+NzfeGsv3tcbn4AKH5bavNZcnBO472bPrIAlI09Hhe2kOs5
E5JPcnOJqVnHnmnD+Uym6uJwUn+9izafa6TCubziVOzFL6DwfP74TZL73/26
rfCrGxTuPYOybEe4rNFOKv/nCIqrWJe1rA5cTK/s3fJdGBQX+98tzy/Dhbby
ZMKtcFCcM/llHZvh4qny+KEOWQ8n/q8HNNvhkvKtafkTsl84tvdnndsMl86F
UvuXXgOFri6SqLGSOJC5dBnpW+iLwvxdyf2dtw6q6pL9iy7fNibzHC5v3YQp
snHEonlDSVfh0pXzS+MkOb/Y/Fju89gYLu/Fyvw0yHWb21r7bP/A5fOs8lnP
TxMzRySadIkd372g2hLb2miJDhLnC/NPk/pnQz07+NELLr1mnOSPecSGLLv0
Mrj0xf+eq0z2Oxul0srcv3AZGJeZJOc0Cq3fRZl8t8sgxeC+KdkfaT3FgTLP
iA+7fE0k30d7M+3+2gIuQzpHOPak/tOenF0WIASXLyEiF26Seka73rflCJX4
trpfjRvxJYMXrjfg8lXUfM8wm7gw5YNhFXFxdEfWMPExtS+Hc4knD4q/MCDO
iurXPgCXb9YXCr+Q8yBt//19K62Jj9499qiVeI/k46Ps//9/gtf///8Elv8D
ozmj4Q==
      "]]}}, {CircleBox[{42, 29}, 41.5], 
    CircleBox[{42, 29}, NCache[Rational[129, 100], 1.29]], 
    CircleBox[{5.023229246182737, 47.84060573919119}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[{-23.10409982536209, -78.05559499498912}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[{16.361377399053524`, 98.58946184909334}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[
     NCache[{42 + 85 Sin[33 Degree], 29 - 85 Cos[33 Degree]}, {
      88.29431797627731, -42.28699827536104}], NCache[
     Rational[129, 100], 1.29]], 
    LineBox[NCache[{{42, 29}, {
       42 + 85 Sin[33 Degree], 29 - 85 Cos[33 Degree]}}, {{42, 29}, {
       88.29431797627731, -42.28699827536104}}]], 
    LineBox[{{42, 29}, {5.023229246182737, 47.84060573919119}}], 
    LineBox[NCache[{{
       42 + 85 Sin[33 Degree], 29 - 85 
        Cos[33 Degree]}, {-23.10409982536209, -78.05559499498912}}, {{
      88.29431797627731, -42.28699827536104}, {-23.10409982536209, \
-78.05559499498912}}]], 
    LineBox[{{5.023229246182737, 
     47.84060573919119}, {-23.10409982536209, -78.05559499498912}, {
     16.361377399053524`, 98.58946184909334}, {5.023229246182737, 
     47.84060573919119}}], 
    InsetBox["A0", 
     NCache[{Rational[463, 10], Rational[247, 10]}, {46.3, 24.7}]], 
    InsetBox["A", {9.323229246182738, 52.14060573919119}], 
    InsetBox["B", {-18.80409982536209, -73.75559499498912}], 
    InsetBox["K", {20.661377399053524`, 102.88946184909334`}], 
    InsetBox["B0", 
     NCache[{Rational[463, 10] + 85 Sin[33 Degree], Rational[247, 10] - 85 
       Cos[33 Degree]}, {92.5943179762773, -46.58699827536104}]]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 2)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.467463020891292*^9, 3.467464406512301*^9, 
  3.467465870757783*^9, 3.467466163669191*^9},
 AnimationDisplayTime->0.059349290000000006`,
 AnimationCycleOffset->1,
 AnimationCycleRepetitions->Infinity],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt3Hk8VN8bB3AhhbJmDWmhREIhQh9mMMZYZsY+w4iSfcuWQoskSykqpUWS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      "]]}}, {CircleBox[{42, 29}, 41.5], 
    CircleBox[{42, 29}, NCache[Rational[129, 100], 1.29]], 
    CircleBox[{0.5568743076851845, 26.828057815917827`}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[{-12.617117448052518`, -101.49748890498945`}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[{5.867320596819766, 78.55618517628355}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[
     NCache[{42 + 85 Sin[33 Degree], 29 - 85 Cos[33 Degree]}, {
      88.29431797627731, -42.28699827536104}], NCache[
     Rational[129, 100], 1.29]], 
    LineBox[NCache[{{42, 29}, {
       42 + 85 Sin[33 Degree], 29 - 85 Cos[33 Degree]}}, {{42, 29}, {
       88.29431797627731, -42.28699827536104}}]], 
    LineBox[{{42, 29}, {0.5568743076851845, 26.828057815917827`}}], 
    LineBox[NCache[{{
       42 + 85 Sin[33 Degree], 29 - 85 
        Cos[33 Degree]}, {-12.617117448052518`, -101.49748890498945`}}, {{
      88.29431797627731, -42.28699827536104}, {-12.617117448052518`, \
-101.49748890498945`}}]], 
    LineBox[{{0.5568743076851845, 
     26.828057815917827`}, {-12.617117448052518`, -101.49748890498945`}, {
     5.867320596819766, 78.55618517628355}, {0.5568743076851845, 
     26.828057815917827`}}], 
    InsetBox["A0", 
     NCache[{Rational[463, 10], Rational[247, 10]}, {46.3, 24.7}]], 
    InsetBox["A", {4.856874307685184, 31.128057815917828`}], 
    InsetBox["B", {-8.317117448052517, -97.19748890498946}], 
    InsetBox["K", {10.167320596819767`, 82.85618517628355}], 
    InsetBox["B0", 
     NCache[{Rational[463, 10] + 85 Sin[33 Degree], Rational[247, 10] - 85 
       Cos[33 Degree]}, {92.5943179762773, -46.58699827536104}]]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 2)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.467463020891292*^9, 3.467464406512301*^9, 
  3.467465870757783*^9, 3.467466163807704*^9},
 AnimationDisplayTime->0.059349290000000006`,
 AnimationCycleOffset->1,
 AnimationCycleRepetitions->Infinity],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt3Hk8VN8bB3AhhbJmDWmhREIhQh9mMMZYZsY+w4iSfcuWQoskSykqpUWS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      "]]}}, {CircleBox[{42, 29}, 41.5], 
    CircleBox[{42, 29}, NCache[Rational[129, 100], 1.29]], 
    CircleBox[{7.1951714302648995`, 6.397480046876375}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[{3.155758208706821, -122.53926080236916`}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[{8.823462031203036, 58.37198023416914}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[
     NCache[{42 + 85 Sin[33 Degree], 29 - 85 Cos[33 Degree]}, {
      88.29431797627731, -42.28699827536104}], NCache[
     Rational[129, 100], 1.29]], 
    LineBox[NCache[{{42, 29}, {
       42 + 85 Sin[33 Degree], 29 - 85 Cos[33 Degree]}}, {{42, 29}, {
       88.29431797627731, -42.28699827536104}}]], 
    LineBox[{{42, 29}, {7.1951714302648995`, 6.397480046876375}}], 
    LineBox[NCache[{{42 + 85 Sin[33 Degree], 29 - 85 Cos[33 Degree]}, {
       3.155758208706821, -122.53926080236916`}}, {{
      88.29431797627731, -42.28699827536104}, {
      3.155758208706821, -122.53926080236916`}}]], 
    LineBox[{{7.1951714302648995`, 6.397480046876375}, {
     3.155758208706821, -122.53926080236916`}, {8.823462031203036, 
     58.37198023416914}, {7.1951714302648995`, 6.397480046876375}}], 
    InsetBox["A0", 
     NCache[{Rational[463, 10], Rational[247, 10]}, {46.3, 24.7}]], 
    InsetBox["A", {11.4951714302649, 10.697480046876375`}], 
    InsetBox["B", {7.455758208706821, -118.23926080236916`}], 
    InsetBox["K", {13.123462031203037`, 62.67198023416914}], 
    InsetBox["B0", 
     NCache[{Rational[463, 10] + 85 Sin[33 Degree], Rational[247, 10] - 85 
       Cos[33 Degree]}, {92.5943179762773, -46.58699827536104}]]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 2)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.467463020891292*^9, 3.467464406512301*^9, 
  3.467465870757783*^9, 3.4674661639125023`*^9},
 AnimationDisplayTime->0.059349290000000006`,
 AnimationCycleOffset->1,
 AnimationCycleRepetitions->Infinity],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt3Hk8VN8bB3AhhbJmDWmhREIhQh9mMMZYZsY+w4iSfcuWQoskSykqpUWS
olLJUpSixVJJKUmUFmsLoSjS73xfr99fXu/XvXPvuec8z3PO8w9WmM/izXx8
fPx8fIKi//2Fy7fe9gG7N6DQdvDK91jDZcJf+FhvMyjWV5J79HfBla+/401V
LShW3V7vqCvgKt2jdkUAoFgaOTxrvAVXo7LNF7ePg2L+iZ8x2wyuyS8nvia3
gLJecCpGeAPc5J8l37kmC4rWgw3higVwWzyaP/plIyia3YtPzGHCTVNq5QvV
G6Cs/DngwTkEN1OrTZJqy0DRWM6cL0SH28bdMbc/B4KilvbiXC8FbsXmxyxG
5UBR8Zop/hcDd/2CgOUHzECRyE5+LZYBd7PpbPnDT0ARLx3+NvYO7jSmR+ZV
Mj6xJ7JU15dw9xg6vfhvIyjzRTsjfnfBPentrJ+8LlCEz2n5v14L98ZLbwfj
g0ERQIJPOx/cn196u1/OFhT+pM93qOJw7zw/vmJLGiiz6pf+3DAE96+prGtS
kaDwOUQynUfhISH4Z1/ld1j8PWjTfkQEHvIvJ2RvPIXFdH+QxHA8PBafbnut
1UVs8VP5eD481qhKR87+CospwQzToWp4OL+eCDL8BYvJG/Wag+bw8Iox17xH
njepobbveyo8toitezZtBouJgt1HtY7DI05TMbNJFBa/zkYMbFKCx86rv+36
WcTLV2gG7YTHfu0ws2Zy/8/rqsqJmvA4IS+6KP4mLMZfKFXuy4BHwR71lCe/
iQMsFVMG4VHS/2D+2x3Egr+KfLPgUXMqItU1DhZjdBPT15fhcf977H21CliM
jo1dS/wKjyfrvl52HiQu2C43LASPrmqJtQnricUgVE3u/zxSMTAeDIsfj/PT
v8vA45vqzZiLZHw/DsjxRcbC4ydd+qKeK7Fz+Z3LHfD4G3x/Y9YW4iXp86bk
wJmdej9fzBAWI+OXlquNgjP/tET8qsPET9TXvMwHR+Zy0aJMMt6R4vk2/Fxw
lMt3drRaEqdHBEbvBket4tScnVeJt/ruX3cCnFVXJ9R+DhF7j++RUQVH/1x6
g0E+sZP+Eol14JhmuR59K01sZ7BwcCk4ljGubt+1iBlzJY9fBMfOed/g00Ji
x5oDHTxwnFf1mQlTiTkbhU9+Bof7L8zHfB1x8NwP5/+As8lqeVDrUuJdkjz5
r+AEpfReEWcQ50XG0wfBiay7MGEuQlxjxBQpBGfbr+BV+7WJeyK/DzmAs0tN
h/rCisyHqBZjuA+cVLtRShmFeH0k06oFnIPh1yzszxJHMFtG74NzNNM/EPOI
L7/em6wFzqlC+V/RR4i/S6g+bQWnsPzeGjkvsj76c9flNYNz6S43wb+DeNcT
x6BJcMruf6WUZBK/9H+9/CY4t+pDBafI/I5pDam/nwvOveoeprEQcTo3ea8I
OC3HDyn95ifx4mEpZUee/yrpqdirOuLmNu94A3C6eOPhciT+f5rvntQk8zsk
NkuuYhOJT/No239T4Iy8/czkvCVufrbVn6zHxLnSnlsPSXx7bKsOcgJ3tuqv
7BPVJP4zviYVbgFXtD1yuRIXFr9XP7669gW4Unufj8xLJH6zwrtUGdxFL9Zf
PNNH8mlDSuGnFeAaLy7O+6sDixnunLdnusBF0To38U+w+LdW8MusTHCtl114
/oHUAz6pVzdsB8B1El/hOCJI8rt34ZV+fnA9thst3mlF8r/j/IbXTeB6f1hp
pUXqkUCbpk1JMrghJ65UTPmAMrvbaUs2E9yt32EwdhcUoW+iogVccOPX34j1
+wPKXIFea9p3cFMemK72zAdFxHrlHtfz4J5J7/sX4k/q1bJprfpecM+XphbN
sSb1LPTlJnY+uJcei61/WAmK5D2FOJ1Z4Fb9aLiS6g3Kgm3z2u8ag/vs15xg
/Y+gKFom907Fg/uq/+2062FQFj6+vpZ3B9y3bScywtVBUXbP6Ar3Arc/902S
XDooqhkRoadMwJ3p3H523WlQljs8EEy/AU/BxN5dI3yk/ooysnm58BRRTtSd
lib1uSXCcHIbPGVsUP14HSjaQRe/xtTDU5OzymkWGZ8B/55DYu7w1Hmu47bk
JCiGU2fEj8vC08A8OCK3GhSj6VTeMS48zSWOHLcg9d5M5m3IIht4ugS8MqG5
kf3lgkrShAw8OdebDfXI/bT31ES7Q/D0Hhf0O5sCiu0i3ysCPvAM2mL/g88P
FIeqs0ErZuC5Uzjom/gjUNxpZ04eiIXnRVOWlrAUKCEjiS9ot+F5ZWWQZggZ
b3iJS94VUXiWSfatnOMMytbgoCNdZ+FZ0yoy90ARKNuEPR7WC8HzmbB59Byy
/yUXXdyutxqe4xGmbP4eUE5F7NM8awbP37OD7GUdQcm/dmJg0S94/s1ROmHo
Asq5SblXSz7DS+is5PDSOlBK8p2VOzzhJb9tb6FtJig3XcTzelbCa736/jeC
q0F55drCfjUDrw13q7m+o6C8Cd8Z2mAALyor/8Vlst92Z+tef0+u223Oi+8t
AaX3V05n3Ai8eMhjn28FZUI/pC62DF67nvpV2cmCujA7a+BoB7xSBLx00gtB
VWVwapQ84JW2Zn3TyXZQ1cTVZdTI+w/vrNhTpA+qdlnF4Jp4eBW8mDQx3g+q
RURhJG0dvOpdfQ+3B4Ma9HTXkfm58Hq0SqNi031QI9QuLdbSgVfTX6HUFAtQ
Y/bVZIdow+t5uoRjlR+ouwL2DXR2wavH++bplCRQj51LHXDcDa/p8d9lvS6g
Pvx+x+ZHL3h8IYfNduSC+vjzgvNV/8AT6IlYxpIH9fmnZWf2KYEnUjH/2oMK
ULtnvA2OFoAnryhtuq4R1F8X36W8VAVP99XLunMbYanRvGfP+Bh4a+9Knf8Z
B8vVg6aC0W/AMzy3vYbSBEsDCQMh+QXgmXp27FM2hKVFzOtzb/PAo+VO5S15
AEtOUWikiRl4Xis7un+/gOXB9LBBUUXwvBtebRxgwfKolm2ksA94vt6qfpf+
wPLkK7XRdn7w/HeXJKiWwbLE7JHLp+fgRR5s1iwrhOXDCMO/V66Bt/eJyOWD
pbD8a9+leXYGvFSVoa58U1gJhqT8+lYLXlqI8Y2Pm2Almt1XuGA3eAemdZk1
9rBSmLg2s14dvGOfrp98ngUrQ8W+lF9D4F3svO7SFg+ryMebFkuPg1fSGxMo
IQareF++izf0wbv8pWk6+iCsdvPzWVYHg3ftyzL+o26wOuQiveV3KHg3y9sf
n1eB1TXn0ZNyS8BriG4iNQZWw1effOksAa+J9+9+1BlYTW5pjFzkAt5jy0Vd
Uo6wnrVCWPeDCnjP+NQez94Ba6k60z1SceC1GyWn3qTC2sC5SP5fJ3ivp6gJ
JiGw3uDAZ5lwFbw3Vf+WrDSDNc1xs/uIBnjdS4LrlKZh7RGkV8RvB96nGp9d
ITdhncQnfLRyELxeZ11TNXI9dd3Qz60PwOsbEvkgognrQ9vyDrRNgTck2Hd/
YzqsC6UYG6YCwRv+Fxs3bQnrpnw5e/Vk8KaEL2gPnAZNVr0wfp8YeNPOIk1n
4kFb1NFvdKoQvL95x5J2D4CmcTjxbLYKvPnmK5SdnwWa6cIM++cW8OYPbWM8
ugDapmRa2asX8BaYZcEU6AAtNNzF5y6b+BCjv1gdtDjfeKOGk/AWLFm3dsQc
tAyvz18PVsBb6G7ip+UXQSsvDmgP0Ib3HLOPcncZoNU+ZZiT85/3nJr+A64y
oDVOzr6t3wfvuaVdO38tBK174zsd1ZXwFolLHtXLgo1QitWXtibiXomK8cOw
kegRuBl1A96iDpaKkTthsxBu86fJ8+YplXRPPoWNzoILsZxYeM/PS6p60A8b
D1F+/rnyxGMN6Y7LYLNpC810pTu8xWzadkrNwCa06dK5QUHiYeNcVyXY7Mm/
dCODPF/c7JjK8x2wOSBjZFzpQZxenbHtN2xyDz4sUT0Bb4lFbh1LD8HmytHb
vy06iDe/khTbD5ubS+Vv9EwSlyj2/TsPm/oK53nn4+EtqSUkw8+BzesvTNsL
QvCWkgn+wdIGnf/knu4Lc4nptEOy06DPd5UICAsk3jEmyokCXV4OE6m7id9W
KWX0gb7qYtjTyml4S895PvG8AvR127yG2+nEurUGdAXQKQ5tjWEtxEnzOZ2b
QHefr+Pkco64IGKnnQTovuNzP+u/I75fvPuKLOihPbRPDTeJP1b8298E+rbn
A/WRycT/jh0+FQt6cmPPCMlr7wWK9u3P9oN+8KFGN/0asV6Xn8FJ0E88qpni
Cya2QSfpY+jnnx6sHp0i9tzR/GsS9GtvTh1MeE8cltW6IwH0mqHuL9e4xEkJ
u7JLQW+YZUNxSSTOpER5VYP+QqlDlF+LOPeT2frjoHeb7r4pPUhc4Ln1kTLo
A77m9+5fJy4uu9g5F/SxA/NPakQSl34KPyIP+sydd/WWx4mvj3i6q8JWePTK
ZeFNxGWdfC3zYCujFdnG0/vvev6XT6OwVQ1Sv6GX8N/vLUtfLYGtZmldQ+wM
8cXGNyvUYWswYZKpH058duXv6y9ha0E9uHt/EPGx4NPHGLC1O3pDvYysx4L0
A86OArB1+3bmj8IK4oSskgv1sN1kY5/ICiEOiVp57yJsw4qrDDT/ez7HaKPM
athuF3tx/tp/turpiCfjTYk7ztLNJdYJWqh6HLaH+gXqbf57vlxH2bEZ2J7y
EEkYNCLr83fl8meTsL34vEjMTZa4Lv7Jqk2wvduS8OYqyVfp/O0ialKwfcy+
pK2+gDhhI2VvJWzbux3SspOIdT7cLWqA7be/70/vjP0vnhLm7efB9nfO7e3c
byTeuvgClGXAmL16tOSXD3FiHS/8NxhKW+28DMl4pRz9n5y+DcZyVllWaSux
6oYLV2LB0NNvWCL6kcR7dYJtsR0YNKG+LSTvvCXeUMrGdoKx9aXz13ZSDyRO
RvxuNwAjsfVA4rl6Ys8X3xbqg7G/1erkWzJ+8bfaEXNcwTjTqVx614rk5z1X
wUQ9MJ7I3mvo6SKOVmtYcAqM19oObAll4hUrPY/tAOOjzarhW59Jvqe2Z394
CMZk6v2aCBJv89Y+HC2og52a9uVdlTnwFjZ0HjxdDbskCfsJ/72k/jy7+iGu
CXZpHkr1WlHEfpZ19t2wO1LU1ai3ntSrA+rlh6xgd9lGiSZJ8mV2Y8Odg8Ow
e3P1V71yKLxnDXaYBZ2EvT7/vPh+Y2I/pepTVNgjjqad20zqa0/B2IWXsLf9
oTBoUgTev/yvMhIlsPcZ8i+oFCT12mBXui1gnzUl/cr5I3g/asK2C4zD/tvB
yzn3eOCNbIy+0FgP+z/L995pJfvPsEBYdWMPHITqZkJfPQLv63rK4sPecFg0
c72fM5/sF/FJ9/tz4cA66mE0qwe8znWys3dpwuHmul0qzyLA6zj1oFi9EA4P
Jvj+1j4k+9e/aMZDZTg8r7qaySX7Q1tlj/ScSTh82bCjV4fsP09+js8P6oaj
+FrR+fFHwKut6Bi8pgJHi/STtKLb4N3uktC7HwBH2p+yhn8U8KpnXIO6g+Ho
EFi8n+8YeFWGCisWCcCRa7fS6NVf8K5u261yezkcY5QUUgO3g3fG4nLzTcCx
+N2dgQJy3tj+NcnlSyaYku/bb2fdAG9bLca0PoIp9/OYUdoK8GIzLjOnzoCp
Ilo7uPwkeFsX7TGkhoC50sjIB4fBC1S2bD7zEkyL3EN7Bch8u267N6cyC8yt
fqksr2nwVtecm76sAearVUcl6hrBW7VMyEkwA8y3tusHJivBW7lfo8OX/P6D
/4QI+w54ajZVflMuYH4rPKeXvhc8xcJZhbOXgCWklJmnROZT8M7UUAmx4bzd
7m3G8GrP+HTdPQOs3Lfvi+aR82DbqZmC/JVgne648mJ4DrxaL0vVTpmBVfjK
smuAnAeb72pEH34K1rWnzeedNsGrtk7ttccfsBprBkX+kfNykb5AFulLWZNp
GRGR3fCK/HDNZn4g2K4fjZ/llcJLYLuU/7x6OMkINpmVO8Hz387rOibhcFro
82ZhbyM8p3ZP9Zw4AafF90Qy6BLwHEs47tR0DU7asY1zfi2H5ydbac1wcr91
l1+3vws8661/V32shFN8nMCHthh4JjwPFZg7H07v+hNH/1mA+2WTgN28G3Au
XPym7vRlcPuGE8UuGcK5+KnmCYlUcD/GOUl0m8P5aqzh41TSr73ZLfM1XgzO
1Q1x84segNsQM7/cqBnOz938JLN3gFvQU95RvhfOM8ZB3ETSj7o2Gvp8M4OL
y2h/6+oX4FQrhXvezIWrwGuD67cY4JQfv+W4+iFchY8Ead54BM7VBetqVdTh
Ks4seP/4D+nn+XoGNGXhqvhgwfwbLHAyb/47TZeCq27Wo5Bd78DxPl+/SE8c
rl4NlT9VLMAR3P72iikXrlWnA6q/n4YHNTzn0K8+uPmkRh+Jc4GH2SZ7K8Us
uG3Jj/q5wwke65yrLmeNwy24UuGbYjM8tHTPVMeHwi2m09730QN4SD8dUTV4
C7d0If1fj3lw/3j8u1JTBdzKhi4MbPCCe2Ial8YNhDvf22OfW6hwu6Z+VY76
B+5H5hdsI+chtxJB90GXfXA/bnB6rHAGbud6PAaH1OF+yhPNxcVwO5a96eOZ
VrifPxceY1MDt8Te2mqTX3CvlPa1i5ODm51JjV+DDNzbd1aiYgiuA3eiaw5P
wUMmzfjznDG4fvTPXONvAA+FzZPOT/jh2iWl3sMNhofyBhMlr1G4PvPuC+eZ
w2PZEFtgTypcK77eOe5Pg8faJYXfGJvguvuu0JFpbXiwFkreO5wB14Wu/bLG
3+GRoSZgsTYdrgtoM2MjafA4OL2V9eAcXOevS1dwJfOU3frmTEsVXP5Jz8kI
6oFHXnhyN+cwXD5WPPAuWQuPknSjUuOTcCm+MejeOgOPxlVmv/2IDc48KyRx
yJmlLDpocgguq335dw9YkXU75ENrLYLLimWfux6tAWcuf1ZZ3gq4KBTe3Wne
AI7Y20jdHTFwnj7C9/ehFDhKW1b/0beEc72R+17Sf3AMet+WKWjAmXH6iPCB
bHAC4rlmAypwtry1eaJSD5xgp6V5mSROzdqszCNHwAnTlFmkKAtnXcH1Cnfo
4ES1RjHWhsJZhrPY8nk6OEm/pW1Pd8Cp+916zpAJOEfqXJ3eN8MplJrJiekD
5+5KyuAlMzhtodrJ5BuDU3eRkj7cBSdvir3wk1BwHizlnpucCyfWBoXefSHg
NEm88VS4DycD7dkuPYHgvGgcMT0jAvbfobS+DjIfvVd05wn9ATtj0Onw3gPg
ClMUriAR7L0mNcr3X4ArmtXa+OU+2AkHd0yc3QLu/LcSdzVrwQ5do3j2zQZw
pTZrxIU4g+0Q+UtV5Bu4Cx3KxGnBYEu2j2QmpICrlXA/6uYrsEVU/0aMtICr
nf1qYsIWbP7AvW/uKYCrUxT4dv4OsEanJSlWEeCurVO0ezgD1ksF+oiILLgm
T1KESFyyjprNDzY7CS5jvWX3HROwDux8kBDwGFx7BefYTzfBSrkv5zr7KLgO
Yx8NxNrAirXKjVEhdYF9OuJP5zyw3GzQ12cFrkeTz6jBYbAUzb5XzPiB6x/D
5L/oA+ap3++FdM+Du2vl85hT+WAedVuTP0XqyO5DEes3PgLzQOXmDgkRcPeM
X5z38iKYSZGBt/+ROpVyrdN55BqY3oOaT8JIHcvgszfXJs9b2mawNNsX3CNT
nlr7yb6gpGPj+T4N3GOaGxdc/Qnmgky3Ctl/4Oa6/snwGwJztvVW1yEy3yeK
vo36kX2wr+bprbvk+88sfGW/XJ7sa0X3xtfFgXth45kj5HscCwTjLbM+gnvR
Y1In5gAcT/jYL+I0glvs2PtnYgUc01XsBCKWg3tJb5d2ZB4cg491XfxyE9zS
J5XlJ/zhuOnXGfcJCXCvltwK6guEo6dzeu1BdXCv7WVm2ubA0V56UD/RFtwy
HQu4LoPj6sNfOui3wK3wXM4f6QfH5WO6y044gVu5qP3UmzA4qrKvWs/SJX6v
tPT6YzhKyniezFYD9yY7gHLyDxx6DUOfqe4Gt0ZazPfAQzi8mhpJfkPeV1Md
1inxHA6P6vjl08vBve3lP0u8Ew4XGZ++Hu4G985JpY6l+nAIChat7I4G9+73
k1qRBnDwNL7ntXUFuPcigoJdTeDgIDLP8A9Zv3s/KHsfjcFBryS6vKYU3LoB
sbrpadj/Hu3VUTEB937Zgl9WNNh/eXTxAe0RuA+UtbMdkmHfnbdw6KwP8V6W
fMhn2NdZKctzyHgeMqoicupgn1rYI7FqLbiPqv5dCsuEfXxitKOCPNmHRIOf
cQphH+z2IkzenpjTq3w5CPaO4iOBZWR9GsYmBoftYW/+tcrlcjC4jesP1ytd
g/2aZhaiyPMadxptW/YT9nKpEiu2LwK3ie+S+bwR2Av7G63xYxCbxJQd/Aq7
KRsL5xhP4mj7B2umYPdNUztnKdkHmy6tuWjzAnbvxfjGMwWI36kd+m4Ju9Yf
t7dHj4HbLLasQkQadvXtm1ZZ/SFer2vFvAO7ooLkxdE7iTO2pukwYJebxh/4
Upv4WnGJhh05x0bGfVv4kvj5d2mpObDbwRkq6SHx2TyCv0fJ+0OtPIpca8F9
LFpwbrUb7Lx1H39wKiReJm2mVA87loq5J51JbJQtHKQOO6po7UKbXGLGEowc
gJ3+H0slPpLPjzl1ixmDsFs++IZXTfLrsX9Y/2Av7BQ6E/q4McSR2i/+kHO2
6BP9qwEZxHEzi7dPgvH3rsCtv97EO95Jr+GCMVz2RfApie/HCS0DV/PA+HDh
+wENsh6Pt7d+ohmD0XZakj1B5vdxzGdLZUcwHh5xYVeUEIcJM+V4YFRl3kuL
tyQmPW//UjCK97HGR9jELvtjZ3uCkbdb4qDbGWLLXsWy82BkJkw7p54m1mNv
n1gHRtJ2BYvB68QLX34oIH1DxLZAVlw8MX9ANsMEDN+40cQHKmT++iTfMAvA
cN5WXveN1NvmR0+nX7eDYb29XKaI1JvmwtPWzZvBMEoc26pHft+ctEfwrQsY
mnui23xIvWl23ZG0ewoM5f1m2rmKxFrpAv9ugiGe5bCjnlxvmil979wJxqzc
yxVet4mfDvAcuLDtveJSd6aY2PdU6urLpI/L+Nlh7kCstuhHN+kTG0I1WL/J
9zV+Mti1az1si/W5+6YXEDsvLvfPhu2Jhb7NTFJvG+dOaOqRPjddQGxnmyaJ
71s+odO7YBv82pNtTScWn5YwvwtbzwdzR0XJ+jyq1LSp4oetfdkWkbxKYrfR
uYs3wFYnx+ZCiDHJrxzr117eoI+HSHqO7iP5+XExe64F6L1bbp3qKSIOUQCr
AvT2TXoWUcng1o9fduqngX7T59zZp/0kv3+f7xg/APqO6O9frMn33u0ca569
DPSQpN37rEk83aW/2FLVDLpXuqBlRyK4tVWOkveugY4LPVM94qS+pKw8JHQG
dMHffp3ryf3VU4FnA/tg80uqTSWfxHe1o8O/E0Ow6de2XZDpCO6tsx2HLObB
pikouEX6Galvxq9i+CJhkznzjmtA6lkFNfNgkRlskjTEZfeR8Zcn5j15Kg2b
cGf/HndpcG9UMM//+QUbVnmRRWI9qa/ylVun/WEjl1m69aMXqc9VUZcls2Ez
tynz4xOSn1fanw2/DAftz5wbGQZkfS6Pvo4b3wNaV1rPgu0kfi+pfrs/nx+0
s1eWRueHkv3BmUZ9tR00rU079t8i+XJmEW78tgFNpfa4WfskuKeVtLMPCIAm
qfgp9wnJ11OyZpU/T8P6Z+e8nhefwc2b1fAjlx/Wd7cKLDEn9eloZWa8ST6s
2VJzdJ6S9cw8ttHvZyisLbM8VhuTeM7wq3h0vwHW6ySF5ds7wE1fo78xLQHW
ygop6nmkPqXev3km7ies+q3tWF2kPu+pf9/0WhFWO+QP1OaQ/WObsWG+fzOs
Qu9MKPmT+I/t2hdGzh1WGzcPjF/6AW7Mjnma7S9hZXUnyotmAO7WssrhMhdY
SabHDbfogRsycy5qUAiWF85fcQl/Aq6PZIBJRT6or/pMtkiNgEtbznrkLwVq
09LCy2pUcK3i1Wp1PUC97fsi7vYQuNRmL8UCb1ALvqZ+iSf7i7nvrIr4a6CG
L7rY84Hsv8bRy3dNF4EqKjbcnEb2Uy3lfZN2+0GhLLXi9x4n56E9WTWueqAY
1NJeSoyS81JykHpVMSgruRvvq5eR89Tuuvv6E6BInn3/6pk+uLNj+w6d2wSL
Hhaz0NEFnL/UpeXSPrBItF3dRRUE5+tmuR2NmTC/faXp0CnSlzS28BZXaMP8
6qU/rPnh4Dyylzj0fQzmBaUrFgnFgnO/eWi2QwvMU2tT+ouiwKm9raCZEAFz
Z/Hzq/LJebN8R4ri8UjgewwfJfgJOGdi0nTf2gPLtjz+HHACnK0uPcnTkoDc
F49OH9LnhCeUDBipAKJbqbd3NoETcvZe+KEObOhVDXCmyoKz5cPzlIQubNj1
t9iZbgsO1/zy3J+PYHbHVyGxlfRF1F1WzxAD0/V859++8wVHei7ndH0GTJfd
e6gV1A+OhKTZkrBOmIrtX+CT0A3OfLk+ZtVKmHzUY3/1ygFnjkp6xQYHmOzv
b/2raQyPKUmrmpporO/8mGpfx4XHx0zvRloCjPesPc+KmIbH1X6Xz35uMA4V
EJ7+wQ+PyyWDTCUtGLt1qn3KqIVHcbBPsP4/GGsXZNfWicGjYHDe9zXxMOo8
eev87ip4HGny/tdgAqO1RpW3aJvhsV395/NQJxh+17MMzjYjfZxnSGvWVRh2
RAgFnCP9D3LGHp+qhmF99XHvNb7wMGnWvPHmEQyPhdJOHt0ED/1Vlf+WasLQ
3I3tIjgKD7U3vqkPD8Pg2HrrQ2wJeAg9cDnong19W8/Iz/Wkj3s02nawZh70
Df7lrcl7Avf6T5t6b0lBf8mVlftSG+Fe+7z9TcgTrP2zMks4R5X0Zxd9cgbm
YW1x6aj9LD64F5lQXBQWY63Ih/7hmQNw38u3PeVIDPTaxTLXN16Au/nskET3
EejdTzRWFlWEu0nT6tsmZtC79ntLukwP3Nely1ia7YdehhTbtYYFdx1hR+W0
SuhZtLwRO9ENd5XhUvPGldAti+4tk1kGt+nNbtna8tA5ceRC2s09cKuY6fqz
6Q909u/ILj1cALfr+7+EbnWDTlxY1FO5AbhdkbZbdC8ZOi7bllbdLYRb4WIJ
1ogjdKSVsu+/F4Lb4RX3ao88xWplO+731y/gFjKkOlkzgVXKd8JS16XCbdmG
y/r1TKziu2KovFYJbosG2MVZBtD6VLZL9fo9uC08eF109k5oFf+9ZmAhCjep
zsNX9ilCy/CYQG/bPrjN2iij1EiDpsubmqnfX+H6Tm9t8+qn0Dh/z8bwiBZc
j37ryvH4AY30gKOvmnLgejjsjrz0KWhErJh6F/8PrpkjO0pZM9AwGVI+sKYB
rsnfT1tG/cWKVzGGoz234RrZffBA3w2sELmVEDejB1f7ffY3nVdAPWXuT5s1
6+E6WzrwmNkyqAfvMl5cQfpcPvGyN/v5oM5eIC3kaQ6XKZGO5pSnUFfdnyPC
pcNl5O+D2JFpqN0ud1Un51GXrnY6TYcfy/7M+2Z/wgEu5ey0q70ZWJo6yPm0
kgoXn7R7zUMPsDTy9md7t1q4ePrNSRo6haXcSxmfmnbBxQ0+5txSLNXptHdz
I32w3ahHXWYNlnQm/NsbOBsuRrb7LrTuwBK9D6GeP+LgIv6SKWUpAdVJ3frS
jTlwvm1bIvigC6p9pX/0PhbDucpPOXF8A1RfUQ37LOfAuSxpTP8FFaplla1i
N7ThfPF686TvGaiG3r716G0KnI+IsbVyV2JRe57mMct4OIdcnhUkLALlb8vF
h2e84ayy5zrXDVBu1dI/1JILZ4VM9ePHcqF8Y+MkQ+g+nBcc1VxRNg3leN6m
XJdTcBYp6v8YfBLKIgUUz7RncPp139WBxobSWlvH3LbjcGoZpO/auwCKly1C
yq8kwSlxzG947BcUj7zsf1S5A07xIvW3Jj2gmHQ06aq/AJyiF3cX/30HRfYF
aYPOl3AKcnBxaL0Ahb8zYicWHYOT64XY6SghKHD2+m1esgBOOnYXlH9GQYEm
0v1TbROcNDcekWq+DYW1d3NxShhO6tGu2xd/h4JYZbe8Xw6clE56/RacDfkH
Xe9cAqzgNHfg1NCjeZA3nutapkP67A/bZ+d8y4e8xu632tVvwO7K6Nz4Ogzy
Clp3Whg5YL8+nTuoawK532JFQZLXwX5a1xF7OAFyNaJav7cPg109J6X+103I
WQ+sWbO+FOzDWU3+9xdAztidvnGeNNiZZ9+skr8IOa3fLx+cPwN2all/P/sQ
5KSarKUie8FOfDUnze4WZHvO1lge/Ah2kEJUflA4ZPcaZfMCR8CmFGrv0fgF
2W13qrT6HoFtRudt6SuAbOi2hkoXK7DXjVxc/P4iZN2OX/dyfwq2tum+l98Z
kF0dV0GJOgC2fMfV4MspkFW7bZeYvBhs6aQWXcubkFUybFcMiwdbbLmU1SN7
yAq334pNPga2QIzkopFlkOm/8XTb9uVgfZeVP3dEADLvK79V5y8Fa6D20Nzp
vZB5/eMfzcUdrE9bTPSurINMk/jP0X3XwOq4pbt/lFyvG+1sbGgBq80nSepK
KWRq5l/jrdoBVss8IZmZ9ZC58kWr+ewhsO7zGsyF2iBz4UqboKkRWLUigvXX
XCBz9qJ/w9IPYN0s3x353AwyRy03mu5jg1UqYilRYAuZrP77s4TMwbpYkenK
txIy6fVSIe+fgXVuo1ICyVeZ3SqxI3rvwMq9JSt/eAYyCfkZdW1fwcrevKd3
cSJktnlkVGhcB+uA1AYYNkEmmhErhmCwUu/avJJdCpmIGFuhh+R79wSft28l
7w/pmNMimgtWoiLbjfEAMoERl/dLV4IV1+h8kvoOMpsYJcaDaWCFqnkmFJlC
ZuOBWTSb+WD5v/QLO2EMGd4ck5jjTWD57mm2VLGDDPemR1VWL1hea9IuzqJB
xuOsx2jZJFhun4rNP9RCxq3eZLbHArDYOctvr8qAjKvidH3NW7DsLefcWxwM
GedLeWPD8WDRftF/NUZBxilK3nXsJliUC2Nzp4ogw44KP1f+BSwzj1lnNpL1
YF0+t1vaGyyjeXE+ITnESlezB93AWnPX7Q/vI2SYD7LDJeeBpR15XpxKrjML
7c4Fkfs11L1oY9uJa7qu9Z4Ea2lnioP4f78X3SCZNAGWykGVJqEs4sNb1zqJ
gaVA1fCS8CfvZ8YmniDrIf37QoV2HxkfjW57wwAssat50at0yPhjBr+tOA2W
sJ8Q9Qz5fpdup5JbSmAJKg02fSgk3789tZ4zDubMS+tL8lVkfpjJ/jQrMH9n
LD6gE0Pmj2f5aCoYzHHqNvm3/ZDxKmz+tyEHzO9/HUZyLkPG+2fhIq0yMIck
lSo1WZDxjZ29yW0jmL1qHMnHIpDxW/FN77kTmD3G89xNyXoGiLr38zrAfOug
+1H1LGSCVWxep30Gs33T01mfciETtrGGeXI/mM/j389vIvERE79wMnUIzIaL
IWaqsZCJd5hzaswVzPq7X+fptEMm0SmkNiQFzDuv+xXy3SCTMlIgNa0HZrmw
K+XVT8icCI3+dlwRzPxIS4FqE8icaeDbWX0NzLzM5mmNA5A57/BrYX49mEeL
Xz/fpwKZa2OKGnv9wcz4lO6l6weZ5kQRPx13MLd5JvGbDkDmuXuZhgADzKgE
774o8n0dm2/UaSSAGXbq5bpqR5LPYjXO19rB3NwTFbyG1A+hwhPPk0TBZAXf
/Rx4GrLi/K06pS/AtDvEklB5BFm5Q4yErx5g0ip3rvqxFLIaG8SH01vB3MBf
kfAjELL23dvlKtaBqVlQLLNBjNSfO/kz4YFgqj/ZsM38NmR9nv42byFe/GuH
ZUUfZGOTDBTyIsCUZ3y3/5wG2XNLcyxeZoE5e1bHUdN3kC3dyxeRdQBMPp1H
Nzbsgmy1bOqTECU4Tnlvzj93CbLPmz5G7zaD44+6GqUlSZATiNiyweY1HN9l
DLw6YgW5sDrx8vYyON60Ck9elgi5JI+dKV32cLyhuCmnLg9yB7XMZdK/wvHK
MFpmtCF3NS6/8uA9OJ7Lu2nNyofcaLmv9zouHA/8a/3sJAP5PeXqXaQPddz8
a8Her18hf7Q1c7w/EI7eb+wtNolCvmTZjG9VJxw5d9IU1W5D/nn0wImaJ3Bk
7hdLe6kKhSVVXurXV8PRVCvWb5ULFJ6VZ5urk+sLilb7dtRCoc/BcZ/ANBzF
T9iKR5aT/W5x0/I8ITiKHNy9ObcFipohHXxrhuDIl0DfojoLimln35o/SoND
x5PXf/2oWMiOentQsBIOqT2XtcZboCyWnzF86TLsh95uWfKYD8ordUd/zfOB
/YfKdHPRcShbjrlOvHGBfUf2eGNOKJQThUTv/FwJ+0fOBUL5ZD8fCcxeJNYH
+7PjJTUcf6i80+zc+KAc9u7nTm8j517V0Er1nPYbsGtu1yuWSoFq0raZYRUN
2NXNNATueQDVLOeUAIHbsLulMXxLMoacR9i5pgc/wO5CqmBGZiJUJ4ISCpef
gV2y766GQ9uwOGXO9BETKdiZHe/O+y6IJeU9I5nTVWBULNhbp2KLJY16G4v6
4sC4XHtPeWIGS96eoCQI94FRGHSb8SUUS/mv2A/rXwQju4X/ZqkiljJ71hfO
poIRWS5Q0xuGpeOxi55EXwdDd84NXf0CqNFdskZS/GF7tSvx6tgo1LzDZ845
6cH2wifR7xEiUIs5mxr0wx22Z76enh3mA7Vz1N5Dn7VgmzW3473lI6j9zdke
6fMJtuGbP0wb5EC90ulu0pJ5sNUtFwyLsseKdVYzhTR+0CtLA+fPPo0V7PXJ
b6cWg14arRNpFI8VoTYlsgojoBdtaDk/k4YVhWUPFNq+g36k56SeDz80pKo6
bMMGQI92vHuCLxgaY2k5C+yyQF/7Ddv9yqHZuF53odEf2FQtP/3TmgrNPs/l
CHoMm6shE0cFa6ElmMsWLX4Cmws3I18sdoSWuYdZh5gIbHLdO+ce/wqt2/PE
TrxPgM22luI9sZNYVbmstU09Bzamuw3Pb4vB6jsy0X5/CkFrVBWpPEzD6q5F
iQW/L4FWF3DQOE4Xq6c2aAhUPQCtunLgZ8Bq6Ci9vzR1uhm0K55LcgJ1oMP5
EEb/vB+0w6/f3q2Oh87bIduTEAbNa9/jpeu2Q/ezcHPDnRpYT3bF9n/Sg+54
3z119ldYj54r3br0KvRmt/j+CjwE66+hXzazZaC3/M4NmW0KsO6RTFyX2wm9
YCWn9x4jsG7Yt5p1bjv0fnW88W0RhPUx/YmIm1+xdgGt9/bTu7A2Ktlz2eg5
1q7gEy/SEIX1mu0KyX2lWLv+/nkFlVOwXuWYxzupgbW+4eJSt8n1xSIBpmLP
sPaGZ4P97h+wnnvL9ftLQeg7Z0i/VUuB1ZvZzUPsbTA4t3r1iR8xsErwuTch
shIGNyNdRFpnYBXbdmK8fx8Mnta92DnnBKwibTLOnRqCweTex80WNbDaQq2p
ayH9qv3Z8nGxe7BixgVIL9eC4V8N+aX1BbBSf/Vr1vf3MPKNqkl/lQPLV+Fv
DuUmwGjb64J5jk6wbD11eOOHxzDKstqSlHIWlo+fMe/iH4zuWB98KFYKy3rz
vu9Vd2As1+GxPUUGlld9E/4IWML42dr5WkN7YZmWO/jcZBgmVu3JlncKYUlt
tY9uzYGJV8XH0zZ+sMTp4WyGBkxizq5SzsmHpUlk0YkDQjApytuf2GoPy7Ua
rnS7wzCdsyg6uOobLJe2NSZ8uQbT5k2v700GwlJQWejIOjFscP96/59DOaiN
O4ciq79jQ8TRzotSHqA+XO2b/ToNG/bbhqpMDIFa95EW2pKFDTdfio+utwG1
xtlJO/UjME/3asWRu6CWhgfx/5sAgu+ctv2tBeqReIsDdo+AuL7Xm4uegHo4
zG62gT+wV8btvkAHqAf9b79bQO4/tdtwtqoxqPv9mw9VVgAtedHG5Z9ATTh1
QL5gC8x1n+T5M8nv/d6sYM2fhLkZvfQVNEHdtGBDR/gPmNNbZF07I0HdyC4z
5SnA3Pfz51eWR0HlvC/0q18F86Oso3keDqAyNYuyJothPr1a5IIsP6gm2c6X
zufA4vHo9tq0UFBlj0+l2MrBotNIlSPUC+oC7VQB8XxYDKRoClLFQZVsFH55
vQ2U2Wtii99PgzpfuG8p/y9QzN5KDaxQAlWg8Uk8kwvKDd6OLSX2oIzqHlx9
zxuU+vmqgy0HQBlZsJe60hKU1jr8fcwD5du0Q5fcLFC+m/yOnlUFymCnO/3w
MlA1dm9dJDkDyodnf8y410A9a9VkYrUalBdnzMs3k3m5xn3uZ2BMntPiWpmc
DOrdbcFiKWtAecavYLCzCdTuR17lhhKgPI7NNu2+A0vFqz6bPX+C8uCEJPOS
NSyP3NX6dG8dKFXVKVXD4rA8v2H+mo8doFTqDTk4LoBl+cNj+yzLQSm/2hAR
HQ7Ltr5rC/74g3K9sufgMg9YSW1TqEgUBOXSH83TiU9hldUjHRRYBspZ5ojC
oxFYnbkdPvqgBpR8tei27fKwKj19PVTqAyinp0sZlSdh9STqfcPgMVBOVq40
r8gneesvuSlqHJRcp+HXCjtgLbf1/MgTX1COWV7ZLLgF1up71Z2+vQHlqDF/
8HIVWFNvfR+zZoGSs2pTSccgrHcF3tEPfgdKlllh8mgtrLPOtxjfIOtw0Pbm
1c/XYH2mry1epQCUA1xr4Y97YF0bX1usdASUjH33hcecYT01tGZNZToo++c8
PvvcALTYAT+BlG+g7L54enjXCGj79mjtKCbrtevLdmUZcdCOLf1Z13aQWDfr
4q6VoFXGZr+YVQ1KUoPLdt9NoP3cIvX3qjIoCfLP81vmw2a2nmB/zVpQdkT9
TT21HjYy/P8Cy0tB2f5ywxqZRtisrZJ4uIeMNz7vh+dPK9hEbakIXHQWlDiH
A7Pf28Em2We6U4jEU+z9XmO1ItjkbGL6nxwhXq8VmPkINuXbllbuqAAlRi/W
oCwUNuNf4vbsJXEXRdnapt4F+my5tTvH3oOyteXejj3FoMvY8J1eRNZrK/eV
VsI06Pq1zQZHRECJ3GX+z8cc9JixFcYvyXqHDx1bnHwd9JS/s3eJk/vDMwNK
TLRBPzav6sIKKrHePcUbPqBXmZ44/vMJKGHJn02fbwa9weuxSyX5njDdC2e/
XwD99d7WNrJulNCeTse7UqBP9LofLjpDbBV3/KIlbOcqdyVf8gQlZPrN+e1M
2Mpz1+TM3k1ckfM+sR2264Y8RSR2EGsLBpLztG08I8ctNR6UYOPVUxf9YJt2
42rMnMXE/M3PUl7ANk81r276LShBT3NU3o3C9rZo7823JF6CAvLuL3kK2ydp
FmsDSD4GGbe0bAuHbbdYSFLwfxZTqF/dB9uZFatuUCVBCazu2T41CwyxO3UK
mgziHMeabkkwFrmr0jwjiMPqXj/5BsbqP/RNIkHEdqv+iM4FA2fNkjVoxFoH
LaPywGDaTVU4DBLPf//qwH4wfPh2TpJ6Qwn4oVCbdRiMPTHvEx+oEt/RbRhJ
ByPHuDL1JomPgCKBr0W/wDgvyNRz6yHOurCVrAOjoq0UR5SIE2Rtj6mA8eji
k6DOaeIgOu+iERiv95TwvpgQc0wPVZ8AY2CTVU3pP2LG4B3vYTB+0/Ml57sS
g1bl+g52Igbln++R8QfoO9kdcYHdwhV7SleS7w3QErJ2c4SdlqrIa417xMvc
Nq+bgp2pMq3m+w9iFepGowDY2auuL3l2nljh/vf2U7DjrfjweWEasWxrjaI0
7MINjY6PkPgNkNkUfKkJdrtsMTLf7z/Hnft8BXaHN/2cunCfWE7oz4d02J1L
drlvSvIrQFF49tEdsCsv3mgW4PHf++KYH2th9/CltHNFzH/jsd9yXgl2rwUD
P4aZEWsmN7begt2A8ebSba+I1y74sTsGdr9jZkUtVic2nXSTrYe9SNX67q83
iW1WhGwYh/3CGamUSD1i59MnlZVhv4q+e3L5ALGvE50ZAHuzk2lXDKOIIy06
Fv6FvcP4cnGHduLdvvnhrrDfyHSOjX1BnH31t7gh7CPLpVf1GP23fov18qVh
n6zkGVDxmvjWtVzSv9oX/U2fXEvqa8Bn8Vl6F2B/azR/2dB/459+7M9QgP2T
79r6FsUkXmRvrinNhf3o5IWP6zqJ7fkMddvgsMEjT3htCXGTc+AjLTiw9sw9
Me1FPJR/wiwSDpuvPzX4G0zieV67Eskbh4wltJUfM4nZXZc/CsPhjX0sbQGZ
/6AvPO1kUzh8LZbQKl9G8kda0CzyH+lbBL+gs4V4PWPTwmg4SocO0faQ/SY4
s0DizhgcjbfElsiQ+QhZt4W6ohGOqQOz+kazST6fjlEIJH3Y4YcWl1pJ/Ql9
ssCjahyOJ89v9mrfQvz7YVIk6cuuhZprXTck9cHZZOOEExw7Fn8SsiHvDxfd
GbsqEswV85XWlS4EJSIkzWcW6Xv1ZNM+3yPxEJG7ROnpMJgmS44ukeYQ15s+
97oBpqNF6H5TUl8jF7yTFlkIZlx+bvpCUn8iy56OBR0Fc3etZz3TlLjjkJ3L
UtKHvzsq30D2k8i/2cY+fmCeVacLvr9E6qGlTs2zxWA2vVjU1nybuKlPopb0
1W1O7vK1qcR9JU4MeTC7OjIyU8j+GcWfsWGDFJjDfS0qg2T/jDI8sM3tDZi/
w18sObKE2PFs7ixzsPinby9bTOI3yr/qb9FGsGQVV9F/knoddeRl6eRXsBZd
Kn7fReYjqqRFJbcALA2zCeaLl8S115WvNYCl91JijdIU8fNYj8lQsEwCh4WG
ST2N+qR4aLUuWFYCB8wDSD5GjeXsCxQFy+HUgPVReVCi+d9LeieB5W40EeYd
SywxLl69Ciyf1xX/jpH5jVZ+Gs49AVZwrMrqvmfEGpu1b7HAipFfueLNCuI1
FU5KtmAlVb8UaCPrH21SNfHnEFj7eTKPF4wSU8nhTAesbMHBbbfIeKLpdzYW
MsE6eZk2VUHORdEO5We+HweryFl71TsfYra1vWMFWFf/He7+9JHYOezZdWmw
bl0Kb3YXJ3ZZcXSqEaz7bnUF5Z3/XQ9eHknG93RO0hyXbf/9Xn/BXw2w2qsK
9u//+t/zEwW3rQGrJ0DtUqbJf+83vywyBdaQ0qyeo1uJKfFtIefAGmvVyejU
JV6/zIlSD9bfvZdmZ88n1jVS3NIK9hyTwEPCpH5Fq5UvM3kItsS4v9+pjcTy
WbtnUsFWvHKq9Ol/4xFu4kglgr3MX2CPJaknUb/dP7uOgq299PD3j43E/aaB
cXFgG/ZQvzW4ELeF2a3TB9uWO86IsyIuuiwmegpsZ6VPHLNm4sxSqb9GYHt1
d3A8yXktKvJr/WAy2JE+ld9+gniduGemDtg71A/VnCP5GyX3RSlsBOy9X5x+
6KuRePw5ttr8HdjHY2NCrmsRX44brR0G+5zZw0R9Mp6tycPatUlgXxF6t/8P
2R+2cna/+sEF+95xh0ydJGL+8T1Xt4Dd7Hvs/erPJB/aHrcHkfe91E77cIdO
XHBjFTsE7P5HTHn7fGLj8znGTWD/yF5g3JxDLFBS/eAf2FPeG4f+kHyIaC6X
VrsOJ7HpHciVJmY1Xoi6CScDo4eznY+S/KaXB9gehRO66t9J9pH8/7v39TM3
ONnuXEB/TdY37MrXMw+V4eTdkLJ2NdkPwuZEqGxthVO6WwRfmCapN6dUOoPo
cDoy3V7iTOInxMR3dt4rOOWfNRiWJvEe/EY7sr8OThWDty4U6BCLui6mbINT
T9xeyo8JUh+Z3acuJMDpy8KEU+Xk+wK6abufBcPpZ610zzYSTwF+hrrbVeEs
OmuoaW8dKP7hZ+NzfeGsv3tcbn4AKH5bavNZcnBO472bPrIAlI09Hhe2kOs5
E5JPcnOJqVnHnmnD+Uym6uJwUn+9izafa6TCubziVOzFL6DwfP74TZL73/26
rfCrGxTuPYOybEe4rNFOKv/nCIqrWJe1rA5cTK/s3fJdGBQX+98tzy/Dhbby
ZMKtcFCcM/llHZvh4qny+KEOWQ8n/q8HNNvhkvKtafkTsl84tvdnndsMl86F
UvuXXgOFri6SqLGSOJC5dBnpW+iLwvxdyf2dtw6q6pL9iy7fNibzHC5v3YQp
snHEonlDSVfh0pXzS+MkOb/Y/Fju89gYLu/Fyvw0yHWb21r7bP/A5fOs8lnP
TxMzRySadIkd372g2hLb2miJDhLnC/NPk/pnQz07+NELLr1mnOSPecSGLLv0
Mrj0xf+eq0z2Oxul0srcv3AZGJeZJOc0Cq3fRZl8t8sgxeC+KdkfaT3FgTLP
iA+7fE0k30d7M+3+2gIuQzpHOPak/tOenF0WIASXLyEiF26Seka73rflCJX4
trpfjRvxJYMXrjfg8lXUfM8wm7gw5YNhFXFxdEfWMPExtS+Hc4knD4q/MCDO
iurXPgCXb9YXCr+Q8yBt//19K62Jj9499qiVeI/k46Ps//9/gtf///8Elv8D
ozmj4Q==
      "]]}}, {CircleBox[{42, 29}, 41.5], 
    CircleBox[{42, 29}, NCache[Rational[129, 100], 1.29]], 
    CircleBox[{23.159394260808806`, -7.976770753817263}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[{19.49986693823596, -136.9248527859877}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[{24.634552561380808`, 44.002301073104135`}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[
     NCache[{42 + 85 Sin[33 Degree], 29 - 85 Cos[33 Degree]}, {
      88.29431797627731, -42.28699827536104}], NCache[
     Rational[129, 100], 1.29]], 
    LineBox[NCache[{{42, 29}, {
       42 + 85 Sin[33 Degree], 29 - 85 Cos[33 Degree]}}, {{42, 29}, {
       88.29431797627731, -42.28699827536104}}]], 
    LineBox[{{42, 29}, {23.159394260808806`, -7.976770753817263}}], 
    LineBox[NCache[{{42 + 85 Sin[33 Degree], 29 - 85 Cos[33 Degree]}, {
       19.49986693823596, -136.9248527859877}}, {{
      88.29431797627731, -42.28699827536104}, {
      19.49986693823596, -136.9248527859877}}]], 
    LineBox[{{23.159394260808806`, -7.976770753817263}, {
     19.49986693823596, -136.9248527859877}, {24.634552561380808`, 
     44.002301073104135`}, {23.159394260808806`, -7.976770753817263}}], 
    InsetBox["A0", 
     NCache[{Rational[463, 10], Rational[247, 10]}, {46.3, 24.7}]], 
    InsetBox["A", {27.459394260808807`, -3.676770753817263}], 
    InsetBox["B", {23.79986693823596, -132.62485278598768`}], 
    InsetBox["K", {28.93455256138081, 48.30230107310413}], 
    InsetBox["B0", 
     NCache[{Rational[463, 10] + 85 Sin[33 Degree], Rational[247, 10] - 85 
       Cos[33 Degree]}, {92.5943179762773, -46.58699827536104}]]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 2)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.467463020891292*^9, 3.467464406512301*^9, 
  3.467465870757783*^9, 3.467466163998384*^9},
 AnimationDisplayTime->0.059349290000000006`,
 AnimationCycleOffset->1,
 AnimationCycleRepetitions->Infinity],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt3Hk8VN8bB3AhhbJmDWmhREIhQh9mMMZYZsY+w4iSfcuWQoskSykqpUWS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      "]]}}, {CircleBox[{42, 29}, 41.5], 
    CircleBox[{42, 29}, NCache[Rational[129, 100], 1.29]], 
    CircleBox[{44.17194218408217, -12.443125692314815`}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[{23.637042369059806`, -139.7982115333875}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[{52.44957621804468, 38.89380813509433}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[
     NCache[{42 + 85 Sin[33 Degree], 29 - 85 Cos[33 Degree]}, {
      88.29431797627731, -42.28699827536104}], NCache[
     Rational[129, 100], 1.29]], 
    LineBox[NCache[{{42, 29}, {
       42 + 85 Sin[33 Degree], 29 - 85 Cos[33 Degree]}}, {{42, 29}, {
       88.29431797627731, -42.28699827536104}}]], 
    LineBox[{{42, 29}, {44.17194218408217, -12.443125692314815`}}], 
    LineBox[NCache[{{42 + 85 Sin[33 Degree], 29 - 85 Cos[33 Degree]}, {
       23.637042369059806`, -139.7982115333875}}, {{
      88.29431797627731, -42.28699827536104}, {
      23.637042369059806`, -139.7982115333875}}]], 
    LineBox[{{44.17194218408217, -12.443125692314815`}, {
     23.637042369059806`, -139.7982115333875}, {52.44957621804468, 
     38.89380813509433}, {44.17194218408217, -12.443125692314815`}}], 
    InsetBox["A0", 
     NCache[{Rational[463, 10], Rational[247, 10]}, {46.3, 24.7}]], 
    InsetBox["A", {48.47194218408217, -8.143125692314815}], 
    InsetBox["B", {27.937042369059807`, -135.4982115333875}], 
    InsetBox["K", {56.74957621804468, 43.19380813509433}], 
    InsetBox["B0", 
     NCache[{Rational[463, 10] + 85 Sin[33 Degree], Rational[247, 10] - 85 
       Cos[33 Degree]}, {92.5943179762773, -46.58699827536104}]]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 2)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.467463020891292*^9, 3.467464406512301*^9, 
  3.467465870757783*^9, 3.467466164081358*^9},
 AnimationDisplayTime->0.059349290000000006`,
 AnimationCycleOffset->1,
 AnimationCycleRepetitions->Infinity],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt3Hk8VN8bB3AhhbJmDWmhREIhQh9mMMZYZsY+w4iSfcuWQoskSykqpUWS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      "]]}}, {CircleBox[{42, 29}, 41.5], 
    CircleBox[{42, 29}, NCache[Rational[129, 100], 1.29]], 
    CircleBox[{64.60251995312362, -5.8048285697351005`}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[{-2.662628129381865, -115.87934811644313`}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[{91.71715328870724, 38.56629558862783}, NCache[
     Rational[129, 100], 1.29]], 
    CircleBox[
     NCache[{42 + 85 Sin[33 Degree], 29 - 85 Cos[33 Degree]}, {
      88.29431797627731, -42.28699827536104}], NCache[
     Rational[129, 100], 1.29]], 
    LineBox[NCache[{{42, 29}, {
       42 + 85 Sin[33 Degree], 29 - 85 Cos[33 Degree]}}, {{42, 29}, {
       88.29431797627731, -42.28699827536104}}]], 
    LineBox[{{42, 29}, {64.60251995312362, -5.8048285697351005`}}], 
    LineBox[NCache[{{
       42 + 85 Sin[33 Degree], 29 - 85 
        Cos[33 Degree]}, {-2.662628129381865, -115.87934811644313`}}, {{
      88.29431797627731, -42.28699827536104}, {-2.662628129381865, \
-115.87934811644313`}}]], 
    LineBox[{{
     64.60251995312362, -5.8048285697351005`}, {-2.662628129381865, \
-115.87934811644313`}, {91.71715328870724, 38.56629558862783}, {
     64.60251995312362, -5.8048285697351005`}}], 
    InsetBox["A0", 
     NCache[{Rational[463, 10], Rational[247, 10]}, {46.3, 24.7}]], 
    InsetBox["A", {68.90251995312362, -1.5048285697351007`}], 
    InsetBox["B", {1.6373718706181348`, -111.57934811644313`}], 
    InsetBox["K", {96.01715328870723, 42.86629558862783}], 
    InsetBox["B0", 
     NCache[{Rational[463, 10] + 85 Sin[33 Degree], Rational[247, 10] - 85 
       Cos[33 Degree]}, {92.5943179762773, -46.58699827536104}]]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 2)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.467463020891292*^9, 3.467464406512301*^9, 
  3.467465870757783*^9, 3.467466164164357*^9},
 AnimationDisplayTime->0.059349290000000006`,
 AnimationCycleOffset->1,
 AnimationCycleRepetitions->Infinity]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
par set 3 
with A0-E-G-M0 and C, B0 and M0 show the base line : herein, M0 = B0
 (\[Psi]->f\[Psi]\
\>", "Subsection",
 CellChangeTimes->{{3.467466344908614*^9, 3.467466401242914*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"par3", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"A0x", "\[Rule]", "22"}], ",", 
    RowBox[{"A0y", "\[Rule]", "59"}], ",", 
    RowBox[{"\[Gamma]0", "\[Rule]", 
     RowBox[{
      RowBox[{"-", "57"}], " ", "\[Degree]"}]}], ",", 
    RowBox[{"a", "\[Rule]", "58.5"}], ",", 
    RowBox[{"b", "\[Rule]", "180"}], ",", 
    RowBox[{"c", "\[Rule]", 
     RowBox[{"115", "+", "47"}]}], ",", 
    RowBox[{"d", "\[Rule]", 
     RowBox[{"85", "+", "35.5"}]}], ",", 
    RowBox[{"\[Kappa]", "\[Rule]", 
     RowBox[{"0", " ", "Degree"}]}], ",", 
    RowBox[{"k", "\[Rule]", "47"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.419852365989037*^9, 3.4198524491248837`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A0x", "\[Rule]", "22"}], ",", 
   RowBox[{"A0y", "\[Rule]", "59"}], ",", 
   RowBox[{"\[Gamma]0", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "57"}], " ", "\[Degree]"}]}], ",", 
   RowBox[{"a", "\[Rule]", "58.5`"}], ",", 
   RowBox[{"b", "\[Rule]", "180"}], ",", 
   RowBox[{"c", "\[Rule]", "162"}], ",", 
   RowBox[{"d", "\[Rule]", "120.5`"}], ",", 
   RowBox[{"\[Kappa]", "\[Rule]", "0"}], ",", 
   RowBox[{"k", "\[Rule]", "47"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4674630218866577`*^9, 3.46746641209976*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xKpar", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"xK", "/.", "\[InvisibleSpace]", 
      RowBox[{"\[Delta]", "\[Rule]", "f\[Delta]"}]}], "/.", 
     "\[InvisibleSpace]", 
     RowBox[{"\[Psi]", "\[Rule]", "f\[Psi]"}]}], "/.", "\[InvisibleSpace]", 
    "par3"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"yKpar", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"yK", "/.", "\[InvisibleSpace]", 
      RowBox[{"\[Delta]", "\[Rule]", "f\[Delta]"}]}], "/.", 
     "\[InvisibleSpace]", 
     RowBox[{"\[Psi]", "\[Rule]", "f\[Psi]"}]}], "/.", "\[InvisibleSpace]", 
    "par3"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"plo3", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"xKpar", ",", "yKpar"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[CurlyPhi]", ",", 
       RowBox[{"0", " ", "\[Degree]"}], ",", 
       RowBox[{"360", " ", "\[Degree]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "130"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "120"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Path of K - par set 2\>\""}]}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4198524708446827`*^9, 3.4198524779235077`*^9}, 
   3.467466408116053*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"plo1", ",", "plo2", ",", "plo3", ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Path of K - par set 1+2+3\>\""}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmgk0lG0Ux1sU2iRECi2SyhYt9q5mGGbDzNhmmMlSyRaVSPYt2yBpkVaJ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      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt3Hk8VN8bB3AhhbJmDWmhREIhQh9mMMZYZsY+w4iSfcuWQoskSykqpUWS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      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt3Hc81d8fB3BJkj0qu6ykUPaI9Mq95r24rmvd4UoJRUraGVEyStKgrYxU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      "]]}}},
  Axes->True,
  AxesOrigin->{0, 0},
  GridLines->Automatic,
  PlotLabel->FormBox["\"Path of K - par set 1+2+3\"", TraditionalForm],
  PlotRange->{{0, 130}, {0, 120}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.467463022061945*^9, 3.467466412487048*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Animation of crank-rocker mecha par 3 ( ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f\[Psi]i", "=", "f\[Psi]"}], ";"}]], "Input"]
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pa", "=", "par3"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A0x", "\[Rule]", "22"}], ",", 
   RowBox[{"A0y", "\[Rule]", "59"}], ",", 
   RowBox[{"\[Gamma]0", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "57"}], " ", "\[Degree]"}]}], ",", 
   RowBox[{"a", "\[Rule]", "58.5`"}], ",", 
   RowBox[{"b", "\[Rule]", "180"}], ",", 
   RowBox[{"c", "\[Rule]", "162"}], ",", 
   RowBox[{"d", "\[Rule]", "120.5`"}], ",", 
   RowBox[{"\[Kappa]", "\[Rule]", "0"}], ",", 
   RowBox[{"k", "\[Rule]", "47"}]}], "}"}]], "Output",
 CellChangeTimes->{3.467463022111065*^9, 3.467466438704918*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"f\[Psi]i", "=", "f\[Psi]"}], ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rA0x", "=", 
   RowBox[{"A0x", "/.", "\[InvisibleSpace]", "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rA0y", "=", 
   RowBox[{"A0y", "/.", "\[InvisibleSpace]", "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rB0x", "=", 
   RowBox[{
    RowBox[{"A0x", "+", 
     RowBox[{"d", " ", 
      RowBox[{"Cos", "[", "\[Gamma]0", "]"}]}]}], "/.", "\[InvisibleSpace]", 
    "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rB0y", "=", 
   RowBox[{
    RowBox[{"A0y", "+", 
     RowBox[{"d", " ", 
      RowBox[{"Sin", "[", "\[Gamma]0", "]"}]}]}], "/.", "\[InvisibleSpace]", 
    "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rax", "=", 
   RowBox[{
    RowBox[{"A0x", "+", 
     RowBox[{"a", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[CurlyPhi]", "+", "\[Gamma]0"}], "]"}]}]}], "/.", 
    "\[InvisibleSpace]", "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ray", "=", 
   RowBox[{
    RowBox[{"A0y", "+", 
     RowBox[{"a", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"\[CurlyPhi]", "+", "\[Gamma]0"}], "]"}]}]}], "/.", 
    "\[InvisibleSpace]", "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rbx", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"A0x", "+", 
      RowBox[{"b", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Psi]", "+", "\[Gamma]0"}], "]"}]}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"Cos", "[", "\[Gamma]0", "]"}]}]}], "/.", "\[InvisibleSpace]", 
     
     RowBox[{"\[Psi]", "\[Rule]", "f\[Psi]i"}]}], "/.", "\[InvisibleSpace]", 
    "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rby", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"A0y", "+", 
      RowBox[{"b", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"\[Psi]", "+", "\[Gamma]0"}], "]"}]}], "+", 
      RowBox[{"d", " ", 
       RowBox[{"Sin", "[", "\[Gamma]0", "]"}]}]}], "/.", "\[InvisibleSpace]", 
     
     RowBox[{"\[Psi]", "\[Rule]", "f\[Psi]i"}]}], "/.", "\[InvisibleSpace]", 
    "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rkx", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"xK", "/.", "\[InvisibleSpace]", 
      RowBox[{"\[Delta]", "\[Rule]", "f\[Delta]"}]}], "/.", 
     "\[InvisibleSpace]", 
     RowBox[{"\[Psi]", "\[Rule]", "f\[Psi]i"}]}], "/.", "\[InvisibleSpace]", 
    "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rky", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"yK", "/.", "\[InvisibleSpace]", 
      RowBox[{"\[Delta]", "\[Rule]", "f\[Delta]"}]}], "/.", 
     "\[InvisibleSpace]", 
     RowBox[{"\[Psi]", "\[Rule]", "f\[Psi]i"}]}], "/.", "\[InvisibleSpace]", 
    "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"lmax", "=", 
   RowBox[{
    RowBox[{"Max", "[", 
     RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}], "/.", 
    "\[InvisibleSpace]", "pa"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Plo0", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "100"}], ",", "300"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "150"}], ",", "200"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Coupling Path par set 3)\>\""}]}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4674664212056017`*^9, 3.46746643574057*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"PloMecha1", " ", "=", " ", 
       RowBox[{"Graphics", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"rA0x", ",", " ", "rA0y"}], "}"}], ",", " ", 
            RowBox[{"a", " ", "/.", " ", "pa"}]}], "]"}], ",", " ", 
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"rA0x", ",", " ", "rA0y"}], "}"}], ",", " ", 
            RowBox[{"lmax", "/", "100"}]}], "]"}], ",", " ", "\n", "       ", 
          
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"rax", ",", " ", "ray"}], "}"}], ",", " ", 
            RowBox[{"lmax", "/", "100"}]}], "]"}], ",", " ", 
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"rbx", ",", " ", "rby"}], "}"}], ",", " ", 
            RowBox[{"lmax", "/", "100"}]}], "]"}], ",", " ", 
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"rkx", ",", " ", "rky"}], "}"}], ",", " ", 
            RowBox[{"lmax", "/", "100"}]}], "]"}], ",", " ", "\n", "       ", 
          
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"rB0x", ",", " ", "rB0y"}], "}"}], ",", " ", 
            RowBox[{"lmax", "/", "100"}]}], "]"}], ",", " ", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"rA0x", ",", " ", "rA0y"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"rB0x", ",", " ", "rB0y"}], "}"}]}], "}"}], "]"}], ",", 
          " ", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"rA0x", ",", " ", "rA0y"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"rax", ",", " ", "ray"}], "}"}]}], "}"}], "]"}], ",", 
          " ", "\n", "       ", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"rB0x", ",", " ", "rB0y"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"rbx", ",", " ", "rby"}], "}"}]}], "}"}], "]"}], ",", 
          " ", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"rax", ",", " ", "ray"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"rbx", ",", " ", "rby"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"rkx", ",", " ", "rky"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"rax", ",", " ", "ray"}], "}"}]}], "}"}], "]"}], ",", 
          " ", "\n", "       ", 
          RowBox[{"Text", "[", 
           RowBox[{"A0", ",", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"rA0x", " ", "+", " ", 
               RowBox[{"lmax", "/", "30"}]}], ",", " ", 
              RowBox[{"rA0y", " ", "-", " ", 
               RowBox[{"lmax", "/", "30"}]}]}], "}"}]}], "]"}], ",", " ", 
          RowBox[{"Text", "[", 
           RowBox[{"A", ",", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"rax", " ", "+", " ", 
               RowBox[{"lmax", "/", "30"}]}], ",", " ", 
              RowBox[{"ray", " ", "+", " ", 
               RowBox[{"lmax", "/", "30"}]}]}], "}"}]}], "]"}], ",", " ", 
          "\n", "       ", 
          RowBox[{"Text", "[", 
           RowBox[{"B", ",", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"rbx", " ", "+", " ", 
               RowBox[{"lmax", "/", "30"}]}], ",", " ", 
              RowBox[{"rby", " ", "+", " ", 
               RowBox[{"lmax", "/", "30"}]}]}], "}"}]}], "]"}], ",", " ", 
          RowBox[{"Text", "[", 
           RowBox[{"K", ",", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"rkx", " ", "+", " ", 
               RowBox[{"lmax", "/", "30"}]}], ",", " ", 
              RowBox[{"rky", " ", "+", " ", 
               RowBox[{"lmax", "/", "30"}]}]}], "}"}]}], "]"}], ",", " ", 
          "\n", "       ", 
          RowBox[{"Text", "[", 
           RowBox[{"B0", ",", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"rB0x", " ", "+", " ", 
               RowBox[{"lmax", "/", "30"}]}], ",", " ", 
              RowBox[{"rB0y", " ", "-", " ", 
               RowBox[{"lmax", "/", "30"}]}]}], "}"}]}], "]"}]}], "}"}], 
        "]"}]}], ";", " ", 
      RowBox[{"Print", "[", 
       RowBox[{"Show", "[", 
        RowBox[{"Plo0", ",", " ", "plo3", ",", " ", "PloMecha1"}], "]"}], 
       "]"}]}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"\[CurlyPhi]", ",", " ", "0", ",", " ", 
       RowBox[{"2", "*", "Pi"}], ",", " ", 
       RowBox[{"Pi", "/", "6"}]}], "}"}]}], "]"}], ";"}], " "}]], "Input",
 FormatType->"InputForm",
 ImageRegion->{{0, 1}, {0, 1}},
 RenderingOptions->{"RenderThickness"->False}],

Cell[CellGroupData[{

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt3Hc81d8fB3BJkj0qu6ykUPaI9Mq95r24rmvd4UoJRUraGVEyStKgrYxU
tEQlRRkNGSEyQmlQlIxIqt/5Ph6/v+7j+fh8Pme+z/uc889lhgeoBwoICAgK
CAgJ/fcLr/0Hn1EpDaCM7utvjXCHV6q014PBEVBGvleVP70Lr4yTF0eO2BNz
WcaU8/C6etZhY9EKUH4YXjm1Ix9ejcll3+4Rf6ubLJdhw1v5a9PD0jpQBpo/
NmvLw/vmnjap4zdB6XF3NXjzGN73r/jFLk8FpTs38vBjHXg/ad5aX7IFlLe/
gvszZOD9WlXLxdYPlK6sT2tap+H960CuXp0HKO3fA/l7UuGzOvtI8gNSX8tx
p+dXLeBT/2ZESncNKC8YLxzCTsPnje0J1TvNoDzPFxdKzofPu7yJEI2VxAKt
Pwr+wmeM3/KPlQjK07u0lZ874KuYNrlgjToo1ZYHwrbFwlejITOsXwCUqvOf
J0pOw1dP5GbPlSvEwhyZvX/ga7NBx2ebKChPOu8WDivBN2DAWYvlBErFpWXy
u5bDd+NUZeCNk8SKk65q8+G7TXjrqbrLoJQf52Ume8L3oDhbbuEeUB4dXeWa
8wm+V1+FOf5xBaWs0KmBGwrfoqLaiCENYqvW6Ts34VuWtig5dQyUB3Uphx72
wrfe7FZ3YQcopVO3LBv84PtjRbie7lpQ7kd15txuhu+vr8Naga+JF6cV2e4G
WzDDwrtbG5R7Lb8+fX4NtlznrOmsRmKrZRPf3oCtsjVm6+8/oNwdU/1cBrAX
zco3ukf6f/fWbDWjMrDN5g8XqDsTm0syS46DbXNyluX1TGIBt+W7/cB2kLx9
xyMblJK6RkUF8r5b7Gh1AJX4wqUw2cVgew9WLi/UI97WFtO9GWx/pnJD9Cgx
I/asxyawg29Onj5C+lOy/MZMCWmwt8xhXZgKIpbbOtCaCfYujq7IsnJQin/3
7pkXCfa+vB1zP/QSD8x6beoFdtJXE3WJPOKOcdF5T8FOX8LLelJA/Kp8wS4W
2Kf9v6ubkvkqrts2Z7sQ2JeOfnA8TeK7uH5x0WdS/tUyi1YVA+LmzxN9OmDf
7um/+PC/8rprsvTCwS6d/n6Wlk78rSWo4B7YlXJODbZDpH1C6pNf14NdqzHK
vX+JeEH5UOIysJt1+2PsXhLbPKor+Ql257JFSR/IeJasWy71MBHsviV5n7vi
iI+oy0e8BPvrghCVy2nE5bmmFaJgj4oHVzY+Ih6vzde8AfbU6KW0dn8y3oY5
mWaS4Ai65r8+/Zh40/3FLfbgzMl+ohRoTXyzl2tfAo70yNfPj68RTy7We3AW
HAVrzTeyM8h8U0/H9CWAszAmKGOXBfFJB90sLXC0y+70PWkjHrIcu8MFx3TR
2i3db0n8XNM6HS0OjjWjIuF6PIk3WdP8NQCHsn1BvTaJ19LoclP//eC4X2/z
CRIi8Rkctm79bXB8nuhPsJnEH69eqrkPDr8hep8s6X9Z8NHMYD9wwt4IVxf5
gPIw5rDYKhNwIputAkIfkvUgd/+g/jA4e56tLXSdT1xYftdNA5ykrKSqc7fI
+hlNdAvIASctfv/Ykyqyvi4ESNMY4GT4bzptsx2Ux+5Us85gcHJFREofRZP1
+dRtt/kqcK413ZXfMg5KZcoR2wekv7cz3Aoyb5P17CX0dOAmOBWSVoPKpD/V
fx6GJAuD03H7yy+vQZIvTp28OVsPnHf0ls+hpD0v0kqytimA87k3e/0nMl+1
qQEl/7rAGRsf9FUXBqXuXOKLmr3gSrZp1V0g8d8kvmTjs0Jw52FJbnE3KM0W
z2RvPgFXOVt6RHYDyV+hFHpZKbg6XgmtBxaB0vp5vH3JB3BXR8qqJXWR/GfM
9L+rA65DgV5azQeSHzPe8iwqwHXpXnraMpnk05lH5l4PBpe9vGnkI8mP74aT
emJWgBuR9O7MtiZQ+tXruB/awN15dNEa10MkH1fE+Pn2gxudznh7ZRkoX9ef
eRYUCG5y3JoOnUKSv58b38srAPeSYhzdfC8o4/33N1Kkwb3c1LaplMT3RKmp
G48HbmGCd9ARY1B+HRPf2HgU3HudneU2LaD8YX+29PgLbsNqOZXCi6DOogob
6KSB21Lb+ez7WlBnu8sdxg9wOxhtg907QJ0TeGOH11lwPzqFJ6gYgSqRe/Wp
Txe4U+OQ6DsL6vx9jMrMpeAJuD9zeyUIqkJt5KX0b+DNyk89P8IBVVmVZX7t
J3jS1E4zPWFQF77h2P25DN4ii/MRJkdBXVIw9/ONQfBcJY0e714Hqk29vfXH
MPA8pLzXKlqCuvrkmp4ycfB8RFtUz6SDSl2/j/rEEbw1w2/VOtpAdV7QIae9
Hrxtu9bYprWA6jns2VglCd6ZqJ6tdmOghiuusHraDl7WouCWE0OgRqxVUZee
AV7O0xCPL02gbis2shvQA69wqm1kbz6oeyOEPC8+Aa9iYZ79M0VQk113jVoX
gdcX8JE+XxrUy8fNtwdbg9cvbSh3cxTUa8XLd1pHgTd4VwMzHoF6o2doNIl4
fERAq4+M5z1mpajpJPxElKfMs0pBfV7Yf9iyBn66lE0dZf2gfltxnu+6DH7L
D21wnegFdWSSucVWBn7GDZZxLBtQJ8qbD7Zeg5+1rd/Q0g+wmxG6ojVCBX70
HoUQfWXYzVuRopwQAL/Qsc4/O+NhZ1NAD47Xgd/mrm1XjjfBjiq87kfjW/hF
PpL1+XUOdk4bzH9uF4Df3nD/I/HRsGO5zbpB8qxfSvKljtPDsNtwWKiHdwl+
+XkMnXfSsMt8s+2pTTf8CpbvPnLdEnbn69QbPe/A78bt1rr5IrDLqeUPHO2F
X0m+gVdFC+xufjgQJ/gJflUu95SuCMHueZJCRdI4/LoTMgP+kfenMy2V9g3A
7120fPuSj7AXvGO1dC0p/8Pmm1jJgL3IG/5wdx78vjiYvPfugv08y5kv7/vB
b/z+SzV1bdgv47gHtLSAL3ZXY9Y/P9gHqFUxN10CX3KNlUx1GuyDH1qFls0C
X0Y4zS5YCfbhazK7BcvAn287cdNYHvZ7H/9cJb4TfLW48YnKSNhn9FYbCZiA
b6K+/9EbV9g3pH/WOf4afLNY7t7STbBvvVaRVrwafIuOo7l2zbB/+3KF6Efy
/cp9Kiujg2A/qDm1Y5s8+PYnv1C2v4XDnGV6jsrC4Ht/VrMXN4AD9Ypc5xM/
8H2nHwiJT8CBblmwYcgSfK5EE335bjh4vDp5Z78k+P4aUeNHreGwVp72fQup
L3jen5Sw7XDY9+vySOx78HcsNt10pBUOj+cla8qsA3+X8tgDtwtweF7VtqFQ
Dfw9YkkLedfh0LTX1+DtFPjRnZbT+jPh8GFmt7PpQvATrH8Jrw2F4+zIJSXh
d8FPFDmvVnwQjtLrvJYw94Kf1LDkIu0nHBW50cdLksA/TJ+m5GjDUXdd3tmx
MPCPi73YMG0GR7fmJH2tPvBPXH+7NLQcjr6CtY5CqeBn0D/1PA2AY4BlA2dh
LPind322Xs6GY2S5gLBBJvhZGc1JqpvgeHqRSb7YGPjXPkrtvK0Cx0/s9csr
b4FfaBEV73cPjsOC9Our6OBfPzhj5xElOP66FXXieAH4t+Yxo6aewUliUZZR
0RPwiydo3c45cDJZJ/t7x33w72qetTx+G042djuWqW4B/x5NevhcNJwc9fsv
WOWCX5qyaafzKThx5VrC/ySA/6hpabKMLZz2G01khX0Gv7ytfktxI5xSaUM3
tu8Dv+JNTsySQThlbizSoGaA/6R2qIKsE6eC8sNK/Crwa3ZpOlR1wen13WwL
m0Lwn/oktB/XhlOv8Aqf7a3gPzNeUiY0DKcvnIBdF4rBf95h3HEvGU7/FO3D
BMXAf/n9QEsJDc467/cd8mgCvy73XhfjJ5yNjfMOf9cFv957rT37B5xXJvdt
kREEv6FQS/xNJJyZtINyISrgN7qvdHpYAWfune7BJQ+Ih5uv/BmBc5CWQftF
0v4mjagY1xlw3js3V9X6DvGdY1XPD8E54cS9hJ9kvTTb6tXHbILzUZV8vRs8
8FvcBu//jYdzntVfF1E78FtNX3jpjsO5sfzOjd3mxDmqBuJ/4dy56U0tUxH8
Nok/RXVVcP6keY6jySBuCRPJZ8H597mBoc+vwH9j8DdKawI04bUB0zZHiJM0
3rsZgiazzO9EKBv8dr0lt+UDQNNuKY+Z60i8Q/K24k7QDG/O61zqQ/wwpe7U
btCs0xrb130n/neJJsoBzWF7/78pMl4dKz3CjeNAYwZ4veaT+enYnhVl0goa
z0O211Wc+FpySXIVaMFO8y43uRB3yXFkfUHbSvUu8hgGv1PE6oqEJWjR1FfJ
FyqIDYTeLroJWpLznuIf14g9NhtF3APtuKfrw79U4ojo93vGQLsQSNGdXkN8
2GjRykegXd3tnnSdrO/O7BRDfXXQio9HrNm4g7g4xcrqNWgVRedtdGqIK423
d60Grbat7lpcMPHLA/NnRYLWJvDLtMqI+NU+J3Ml0N4vVwwZSSNuWrIqaito
QwHar5uliOujtbc5gjZ5Wmn22Bfimn1L3bpAn9n69ch9Mn+dpcbbWltBl1I4
9odD1n/nlZNGm01AV+KLvZsqJT5+NVFjGeiLrtIazqsS79lyLkMNdIMpui9+
EfMGM9VDQbd2E5Z9401srXKmnA26Q/6Wo5zFxPMFaxf8BN1D+OCG56Q/HV+z
HC7+AN0vBGamJF90lP00XLMR9JDG4ynPhIiTZ1027AB9m3WU0As+sbxnwfzr
oB9SH3wp9pzMZ1tmxPlHoGecCWSW5hEfO2WinQd6tiIrrKaLxMvf9jk9ZaCX
auzsiTUgvq5E+5kGenXhhZ3XTxP7qn7o+Qv6q5ULdZ1Ifmy7tHkD9zvo/SHi
m485EztEyrlcAn105X7fSRIfrf0vqlkbQP8779qFoGfEapElBpJwkWscDpdY
TuJ/bdN9egZcVkUUFCdGkfXxNeH8x8VwcV77S+yuL3H4ce5KWbh4+lSvXE7y
V1NoxV3ZaLhspFcnUkn9jVaRxiFP4ZLBq1gjv4us1zxJDdcSuFzasF7X+Cqx
hEgilw2Xwt3c84tI/+sa1advHYRLZY7mX7Wz4Ncu/Wsa7weX4QU7w/Ovg19t
IuVXoAdXpytKv66R/awqUMapngJXVr+EVtsN8CvTYzefuQNX/yUjp03Og//4
/ZXUahm4bi+JXaVF4ueRj3WFiTBcs0eEnkeR+So5JSeozofr36GrT1TJ/lF8
1E7t5Qe4ifouSCw+Af6dA8MP9MfgNu/pkkcpJL5ur7u7zlkAbnpXv9/vp5H8
PCm/50sC3NhpZ5TekXjP2f58tdMI3EoaoiOdyXrNVn4m80MLbpWcx7Hub8G/
WHajyGISbg1f8oRTd4N/fmSlRlwN3AakzaVNRMA/pbeh7Hs0GBJl7ZRxB/AP
ve3ViVQHySQ/fIzJfpCyutN2zxkw7O9vP1OwlOxPF+vGuzzAcJk716mH5OsE
z3NNdH8wfF8m/9XdAH7MYYHfOxzB2OosdMedrP8tVhf9t0mAkRe5SMSajFc4
P/5CfgQYBW/TQ6NswQ+LCZUMzgOjyOGdQU87+CFFHirvWsCoWDjPjlEJ/pqv
x0J1YsBob9vZqh4Jvvv5fNumZrhLhFk9riX7z7J5scfPjMF927zgS2M24Ot+
mBmmexnue7RnXH5L1sOSGzrHAlzhvs9csKmfzP8iK27N6vNwP8w2Vqol601F
d1/ZUDzcc3MFF3fpgz9n43ozTRrcW53lmJ/XkfPRpo8jM8TBNK+YcWbsLzk/
Nes8fl8G5so3Z+tzE+HXZaK99M4jMCk/XNUkT8GvddCj99g0mAyNAS2r3/B7
aZp2QcEIzOCEBzKym8j5TM9mk509mKdccz7mB8Hv4I0xNZ14MKfqd9cExMBv
f5mtnVMhPARqwp09u+C3r3q/cMQyeAg/WuYyJxN+e+o/bkYJPGQLBT++3QO/
8IemUe5b4LH04LOVG13g5y1yL0EhCR7s5a/Dd2rBT9O/Xj7JGx73Vzx4bG0B
XpFtVrfVJbC2VQ2WfvMF78bqEqWHXWDtVW0zCysH79rKiJUX14IVt60v/tx+
8LKX9l15CbCOaHpvnLcavPS3LwLzO8DK3xp4YeIweFtyshv808Hq+Diwa90L
8PQepVgIyMJz1UxbU606cE8F7oxwuAmvmafmPYvMBvf4QLu6xV54zVmV8a7N
Bty0jUeHlqXDS/JDy5yLp8E9GCQtuPMQvJR0t7obvQJ3mw2H5hkFL4Mrymni
J8BlhCvSdFjw4q3bv+veInCFenNTy+rhVdyw0yY7DJz1q0ERWwHvAPm5Jzw0
wfEvWSjZ9gTeQQ3fUuWUweHoGDbwZOEdlvDic8AtcBgzf6nakfd3fot78SsE
HMvTFqcKNsD7SO490Z+rwRG3fXFv2BzeZbfiNrAegn0jtWvu9Qr4zDPUfbhU
E77fQt5vaByDT3nIC38TG/j2s972On2AT9VeanibOnzfrzxYkHUePs8PBbR+
S4Zv6+zB+OEo+DTnJqyn68H34T7t961p8Pn8wHogKgK+h4QffjC/B1+prZJ7
aLrwXRxyuONOOnx5cx44CevAx7t/hUbFWfgOxw3/Ht8JH/eHSbKRz+E7lreV
OUHaQTuq3/rnH3wnn54qNP0Cn1XG0V7BHWDPEKxnLG+Hj/a6NUnyFmDLcEur
ynXhPbZzXdGsPrANz5WLmXeTfm+V2uwwBvZml1O/7OvgnTSvenuwCtiRmjcf
p9PhHVfy586pSbB3TNA3SxTAe9vY1J7V38GOyZB8M2AMby6ffmu1F9ip9/Ki
g6LgrfMt7cE6f7AL4n1Nfg7D6/GM1FOPHMH+ZFDW+uEuvO4PnHjx6BrYX2a0
Cw+Ww+t2o8yN/bJgDzUM3M5LgVdO5qZRfzOwxwM+hAT+hFfi/FGZunvgCK3T
lMrZDy/XlxXofw6OetNns4U68OzU2WZA9lsOm91lPmMWPJvfX9u7zgIc3rPc
vhue8Hx5Jl3FMAucNcZ2DV5/4Plozo7e9zrgBP0T+h4dDM+s1x3uPT7gbNsc
HAojeK43uuRnqgDOkdI5xuf/gjU8J6kvXBycx32Kk+l3wRpQmZ+85QE4VSWp
F9+ywXqvX3QpjAfO04O6vVzyvMV10Zo4Fjh1C9/WJ60H695+2VqJ2eC8WS4V
/e0DWLHVW13iPoEzVKX/oDEcLOkrFFubZHDnV2cL5s8Ca07WJ9OMdeAqrlSd
LEsBSzCj9qkHC1zlWzfb+q/BYyw+cO6HInDV0lV2e5K88MZ9+mA2F9yly/9e
FCZ55EK9Wk5SK7jWPYfErK3gsczF/Qf/Jbj+ov07z2jAQztTMzxEA9wAdzZD
wQ8eC94zzVZFgLvuuMfK8K3wkIpsuLNBFtwQqTeZQ5pgDqfHy273A3fL20Ws
0z1g3r6ddirrE7hxjRvFD6uBeXVsSfAu0v79PSoODi/BzDZd9V5gCtyEL67a
vzrAPFY89P3fL3CTfxoFCl4CM/LWQbOB5+Cm941KTaaAaXYs8sjaG+Bekhd9
+2M/mMvqOh3TSH+yh8616fmBuXh2r8q/leDmVhTYOb0BU373S5O27+Be4a7g
Vz6C+yR3/VD+GXBvhsgN+9bBvVQ6dGSLMLgP2+PzjDRATuvf7NKCwW2VawjR
jIS7aVaQ0SrSvraI94Y/uXDX/1nhsIUB7pv65Pgb6nBfkK10Mm4FuJ17zti9
6gTj31RuhBEb3N6CUjWTUjCe5D1e5Z4J7pcNbWWH3oFROq1xUeADuF+Pmb3n
bCb7mntco9Q9cAfvLdX8uQaM7GkH6yffwP028bImzwKMA8x5b/YfBXfUdQZP
zxQMR4Hts5iHwP3tpSFbSSP7sNeV5LOa4E47lC//5gCGRcHURk8yH39Mh5Vu
dYOxxPd396VccP+JSITyG8AQLb79fq0feILxZtXN/WDMlBA+dU8BvJm+WyWi
/sDt53OJxmBt8IT0KOvNvsPtjc6S2oZ+8GY9zdp3YBncTn81N1O8DZ7Ia1fl
EcAt5ZxswpM74M1J08t6kAq3vW6BG3X+gifqcKEibgbceMX7VORugSdWQF3a
uAduagen7FNawJOkJ3K1veAms3Kav32EeFAy4J0G3GaMHef5R4Enlbik5bAg
XPvWnljqS+qXLlHfFmAM1zwnygfJBvBkB+SZYbfgmil6QXsC4MmtS6x+0AbX
pJcnxxVViN8KCsjqwjWMGbyV5DPe3Gpx5+r3cOXPd7S1OQvePJNz53Jt4Mro
aOw00SW+aG6dFgJXk8D+3JYO8OZviR9MiICrtl7UWIAg8Wtz+8wouMqPPrOP
+QqevOlodJUnXH7vT9StriH+dlAreBdcntwQDRTaC56i9cIb9gvgcmfPOet6
G+LEBX7t8nDJc/yzd4cX8avF5sdj4JL0yYjvRAFPie2jGJQClz0lEvJJ0sSn
Y6PHAuESlvB4TUsBcVtRzbFSuLgvfdL0LRE8ZSerh3Un4GL7d7642ELiqLRG
2gBcTJpcf9ffI77+Izl7Ai7alzdf3fOW+K2fmmMZXBSiohdOssBTEWmt3r0U
LqKs3WtfriM25NygfgB9Wi84SoPUr+I1JBenCvq3WbSIqkDiXSk6betA7+nR
pi0oJj5lpl0SSc7196fFrd4TF3+z480CvfJEw4PqLOKGooctZ0Avjsjhzywh
/pTwfMQX9MuMvVOdLsRTQTleDaCfWs49Vk/iTVXMKzHsGegpUvb6v0aJFT1u
b9IAfe+wdZ38AWItPt/3MOibmiiRuxcR6+16OR0Gun8xb7EkiSdVw2zLobOg
M08d+sw5Tmzc+THVFnRq9Ou70Rf/s5b0HNIes8AVp/TJfKku3zPFIvXr0B8d
LibtVdXp+7TsHrmHma47MUn6o7qQO39hKejiC5ffDr9ALPuhblcSaH9FNfq0
04lnRjO8pkH7/nP14kf/jc8Pnb4z7aC96zscs2GcuPPDy7GLoDU3ifaP/Dce
lbeZrUGgVT8uCyhMIc4/WhZ9BLS7t3O+7CfxrZIc7z5yA7QrOU+jRqjEIQe5
Ag6gHT5U88CW1Key4Om4ELlHx8Rd4fV9IPM5Pktxrx5oW3a9+nMyjfiZ59vU
H6B5hs5Qe2RGvN5457xacg8PkjjlXU9sUPHFNg00y7Ubfzknk3iaXGu8JwQ0
Vf+lrB0kvpWiP6fMJu2XNOqsDfUmttCL+jQbzv9m6zx4Gk/i9ZvQNcHTcO69
k7P4YxOx22au7AM4vzrcYXj+CXgKv4VKyh7D+UlwaWPeNHG2/i+ZvXDO0Uzu
syoi62MAQ80DcD4xc1/P2s3EB3VjtsbD+cBHozjJVmL1grtqf+AcVNhQlT1F
1hs98v3l83DWZa3ltCqR9btL52twGpxVbNMKv/+3vn+/Dpr/HM4SRicuvyD9
ldujYqHfCqfvCqYHBn1IfgjfXbNsJZxuT5mGoIvkj+VJK2c3wil7InHPi2iS
XzLmi1gATsd/vpqzVoDkn9+rledVwGn7b/ct7uTcK3E/UqvoDJysVHY4X3Ek
+UuCy/Ewh5Pekm6ZYDrJb74Dw3Hv4aRq6f3zADkHz8lWmvH5Ghz/+R3rbqog
+VF37VMVGhwrnxxjuOqQ/ClX6CksAEf66Ge26BZw/1IyctpnwdFGy9JiUyjJ
1+y0HREr4Ljc603fC12SzzeZjG7zgqNMpbSBYT64UynxXmtN4dB6t8o7owPc
n+cdhI89h8OaeWEvjr8g+4XWBM2lHw4egUY/6F/AHVISeZ5xCw52d/W2VkeT
/UXcWnmSCYela56Zf+oDd6BfdKPcGOxHX4053b8I7scozwVTv2F/UC3/+goh
cLsWql03moT9rhPSdgscwO34lM67OBf2oWIdJ9XiwG2/tuy7vw/s3QUufZTI
Ifuj7ld5pfOwV57NjN9AB7dJLFZ/5Q3Y3UgpLP08Ae5TSm68SAHsLi3OxCuy
f1V3S9QctoXd8Ro5rYnr4FZtu1ocHw673aLVXocnwX189oC6sRDsqEUbfAud
wH3wrH7xHiqoHfv1tLeT/t84S5nBWASqiLmUywWy/50wDnP6NxeU36Ez0y0L
wD0WvWc1pRSUb9lVKhdI+47WfEsZDQTltfIdx1YPcFMZs18vPwzKJf3Mhw4J
5F5BUQjz7wLFurNwi8EfcHcWumxhlMI2MqKkJGoEXN8MoX+9P2AbLLzgGGsv
uN5pStMyxrDlnM32Kz4PrmdCoZ1qHGxtmyUuCAyB6x7qVL1vFWxlAq9cvrIM
XCfFHa2XkrD6hpaWcuV6cM2nWe9jJIEheXmLk8vBlRs4uf10N9ArMR7UugNc
Gf93O10uA80ib26Hl4Ir+ZrVVKYA3BctzRa2B3dO8b36d8PAgVWrBj/cBucf
69gDo1vAgrCvre+awfkilnDh7inYXB6seT8YCc7D9bKWnx7BJvUzRR4C4JTu
3+82tAM2274cMM99BM7dLFtFbR3YUMUihNaqgXOrITdAZgVW9t49dB2y4ORJ
6sLzKVYqP7yza64IOKliK5QavsIqM//WYi8qOFyJe2foXrCK8/sQySXnWV/J
j2a9q2AVqup5wNYVHC+JN0uKH8NqVZEgO4Sclxmz5qk0h2LFZ1sBg49+4FDa
Zyd36mOF+QgjOq8MHF3526WXk2HRc/9H40cbsCcmeN8yvGDxIlbT+psW2GNF
zEMyu2FR7KZ4eGwQ7B9hy64PSsEiZXagQRaD3Bc6Lr64MQ8WZu++mBcuA/vt
2aO8QSrM02wNJ9WbwH7y8GC65zmYOdXu+Or9BOyUPZGjkzthZjJTd9fBfLAP
Xm2/ELgUZgvsKkrCcsCOb/sRGBMB05Gv2Ud7SPl7dVf9juyH6dnSV5HXrMEO
LdkXb9AOk5ENk/kPl4Lt4t+e+sgSxnnGmsKt5H4kISVf2RUH46ON+leaT4Mt
MnHzUHQvjKN2Xj8qS+5fQt26zKNKMGYNan0az4HvdM7LN8IHYCzE489dFgnf
QYWBwWPTMAoMbe+8yoXvi3M9MuMHYWjAq5AJSIVvwqL1Ca2iMFR9sbJj7CZ8
972L3xprBkMxW2d26wf4Rp2p1r3+GQafPBcUX7KA7zbRsv7eHBicE15wu2gZ
fNc2XZ6f/BgG4pkVu+l/4btarOiSSRH0B0yUfj8j99Up/WWW4UegX/NPYtlg
PnzGbz4fW8CGfs57oe2iVPj8MCo9MdAIff9h1fSNXPj0G2YVXDkGvQ79u32J
PvBpVb4mvvYPdF+ZBNkevgOfW5ekx1VPYcmrcxbj9wTgExQ3ISfnhSV3Dq/5
KEXKW6vV0yO3HUsyjmneKKTDx686Vm+LOJbweg5skyP2EhwMPKMEna97nUVW
xcKHuilDfg0fOqIv5tQHk/api7I2UpdD27f194XUfni3cyPoTXrQXhUf+NNn
Lrxb2p7xmzdCe5Hd9CgrC96N7v9Mj1Zj0Q+JJ/La9+D9lDKX/6AZi5Ly1fbE
lMG7WGGG+dzZ0CoXa8+MJ+Wlpc5pU2RBc8W1C9f6g+Ftf2f2C4GX0FRfKiNa
AnivvhJ5xuAJNGdX6g8mUOFtfe6xmSIVGq/tohRTVeBtFC9wiMeGxpbk0WcW
pD0L4KDavRvqN1Rtdb8dgtf4wfALCcugZhMt9IV6B17ZrPlf+aJQ02Gnaor4
w+u8ztMNN9OhJst0Wb2/C16Z06nLDwdjYZ32r7jfwfBKvRgYGJqIhWqlCkVV
O+G1q3dDykJBqDaphcTlKsCLYco4WFMOZb+Fsou8s+A5bZ/ZxToKZavleu/H
GPCc4CzV/dgAZYXw7bcUKuA5Er6wPO4tlJpjrx1My4dn/4mVrFUtUKJ90jI6
Iw3Plo6Qi1G5ULR7vG+c3Cs8C52eRHyUgDyvfUvgFLl382o8A/o3Qx6TIc5P
0uDp82JpRiMgr+Wo2iuVCE+PuqOWWWzM/7rrpV3iJDydmhVCrYYwf692nqDy
TniatpvpDI5gXt6VsOEzPvCUaPo6KnARc9U28A9l3wPrYcISnw2bMFdUse39
lSxyj86kpr3YA7nRySSWlQJYRVfVhS2UIPeMctHXrhGsK3Uaf6ZOQW6rdP+t
fwywTkpv3lnWBNlXSfXHYmPB2nSYS6echOwj/aG5apNghZzVZT/Wh+y1GcHC
U2lgrbva+DvpBGQPmO0e2iYAFvtprmPyN8hatTsmJgaDZf8vw+/0LMjcnjkr
8SN5f2FI7SunbshcPFeebkjKV9qe3WWoCZmjQcO9v5+BNS8+6OmtTMhsSX70
9jppr9jZe+n5cyFjIqofZBwLj4n6bJOOBkg//hGg9KkRHo0GNWuGGZC+s3/R
Py0LeNRa/55WPwbpy/ZbL1IS4VHjZHR/UxqkD/veOPtnMzzK1uR/7f8MaU7p
YyXKMDzy098ytxlBekbQh6oY8n3sROpUSwCkBrWU7y8GPPZkXlLeVgup1/07
Txb5w2O7ZcOVjSxIXX3sJR1uAI+Ne2Pr225DyreoeLG6Gjy8Zm6IvyAEKfvE
iITN5HtGbqxH5nZIGdetqpQi7aU5PJKutIGU1GXR2o0MeODQPWkjP0i+PBMo
zyPPdRVeO5+6D8my4exfVsSLynwLFl+EZGHxyJaXAvBQ85eLCBKBZFpaWfBH
8v28fP1P4uT7uDyzpuukPmn60e/nRCG5TffRlYdZ8BD9YTTf+CUkOQmjyc1k
/ASs9Leo+ULSjXv+tRYDzKneQwIhpZCkXGJJrDcAczxBP+BCCCT1o9q66yrA
/NK0ymPKAZKacjmSF8n7H3cWWdeR7xUVt/m2+YPZu3Dztc85kBTepp64SA3M
12H19VFKkPjz4pdvYSOYjfMiOtz/QmI8rVHzaBaYLx4GqarlQWKoJkengbg6
sNA2XxASn0K3ZmQQV0ja/9xtAImeOOskz81glt417ZtWh0T77D+CZaS8Yv89
JYHCkKhby7UQIM+v3pEtfrcJEs8sfp6UJfXn+gVZ7G6BRGV0TIUraX/WHEWa
sCwkyo3HWdGkvafvLM1oWAiJB76szp9pYJ7gn3324xAk7n47U5tH3k8T25Lo
IwKJO6NP92sJgJl892rMg5+QuB382r2YjM+BdU4+OcOQuOnyJNTvJpixMm5l
wV6QuH4pZeI7qX/3o3KWzgdIFAYtFxIj728LPfWslfSn4Ez+IcteMDcr9Vbq
2RCvGt/xgzzf8PzE1yLSnwKW7OlL5PvAnaVfHpH6C9qmi6pjwfTXcQ/e2ErK
q7256fMwmOw3HPHc05C4sXzp2ruk/56J7TELsiFxSzBoviTpD8OyPshjGhJF
dgE/Bclz569WoSkjkCieVOJ/lwbT7pyG6evjkLivlHR2P+kf3PZvEHGFRFlB
Qe8rgGkluPZG5XZIVFyPdWWR/pkWPy4Mq4VE9cJ/o8KkfIOQrDmmEpB4MWPx
8/WkfboLBEIkEiFRP+pWm0PK09bPvTlWBYkW++wvc0h56isfDd53JvP3W+12
HXmu4uoSkZgCiV7pJ7mHSDzJ85mZaxXI/B9MMPYg78tubrij4kbigx/0KI+0
VyKuRpktColpo+1SJ8nzmflaGnNHICmkf8Z9qALufx+kbpzwgaR4UkOKrxrc
fzXs8NJRgOSCQE+bLgbcv0++8FsxAUn7/MA5H8j7Xe6nt6t5Q9L92tEXTZvh
3hayYPquDCR5UgXPZmTBvWmfXpXdbkhGTp2VSLkJ92e3BwJ+S0PyCvt9y9th
uBerig1mr4Dk3UChgY+kvpsW/5KXPoFkdcPw363k+TXPhOnPVEj2PZs74zIp
72KaV77zXEhpYXrbXeJUCdUJg+eQMmV8HDxK6k/Sf61mF0ryxeMt996S8va7
Lc19cB9SG6o4e7sa4b77WMksv2FI3WW8nzjtD/cgrYhnPtchVRvo/HCuANwD
nFcnNH6DVE/HktdN5Hve5vvKGoKQFho5U+mSBneP8st/WvZB2nDVJGezD9wR
eGXp5kRIW9fev1izE+5WaX0KJuch7XjwQvhZwN2srNF+6Buk/Y+8zPAl9evP
f54ZFAXp9HfeYdcs4K7YzPWyE4WMQELYPkosGKObNZ8XDkBG2pWqtHISjG+w
OXV6P2TUXLf8+yQCxoAMdWf1fMhg4smaQxVgdJfIDw0IQWb/UOlBU2kwXoiJ
8WWuQVZ+7XwbMQswsvrSkqXtIbv0utNxy2EwzlQuvEAtg6yNYYpnmwEYJ7OL
Hn61g2xgr/YrLwUwDgX9SJrzHrJ335r8/kK+3zE9zLHvhtx6JoOxnXzvxl5T
e9YFclEqCiuvZ4HhTJsxPlMBcsdVz8uJ9YJhZ11RMfcT5J48rfe9SdpnpZl1
TM0cczXu6YlNpIGh/W/e3kcTmDskpLz1sBrc/nRtGPFqx/xr6ps1jBXgxt8c
K74jFvNruqtSq6Xh5mXXGn7gIea/fzkvJ4jYRXVH8pyDkFc2Oy1VGAu3Fc3Z
XUNPIJ/qnNUdwYDbfM6XE4eOQyFqA2rn+cC1rpv9yN0cSjFrm2MXSsPV5sGP
DTc/Qeni/L6W1ky4mvas2zgEKD35RbvkKAJX/Vmbw6YaoTybLq4oTqzsyxMp
soVyus69geU6cJlUq93Bew2Vm/enDXhpcLltIBNeewkLZeaFu5P166LjX7Kr
0hALzd+VHfEQgYua8Mn1rX1Y6NfRay82DBf5GytTk4SwsNDjxBWmAlxmi3zR
XZwNNe3l0j3U/aB/fDtZUsmB2vOQeDHpLtBzpJ/rPEiBhlry75e+vaBrXP7l
+2EjNMzu00wGnoGudLXL3Jo8p/+53j2aBbrszeeJ1bbQ2PXs8l+5adAFq2tv
tapCoyVo7pGTXND65l4WUe6G5uHKzbPeZIGW4xA1nqeFRdKfpjPQAtoSqdN6
H7WxSPd7B0fEBzS1Zv1zC9ZjkYMsTZA5CJrC6Qvl6vuwKCq7TbmAWMR0SVcL
C4u+/rJMzjoO58+nFJMu1UK7boOm5OtNcL68IE7MVRY62fRcB14wnJcYzMi6
+RQ6j/dZ5Xt3w1k9ck787D/Q6amfNGGugLNimZXD93YsUSluvbhrEs6ivou2
XiPOuFknG50Mp6/VzNqPFCxN93meNW8+nG4E/7t2LAt6p9l18Wdd4WQ5eHfv
m53Qux9pntvwBk7GJiM14EPvTbaRi0EJnPT2iYqd74G+/OqGw1d3wmmhVrPK
E03on9gXND/dB05Cp/+IxE1g2cnZfww2VsCxkaJw7fdBGHgc3Z0emgzHDYfX
NWRchMG6yL+U5lQ4rmMZOUTXwmDbWu34pX1w9FsoEXp/FQwy+P4Xb2XA0b1i
JGXjHBh0tvGjvT7C0dI0i3lECIbrq673GAnDUaSvxuFxO4z2p5rGH18Ph2vc
SsEuARhl0oQvr1SAQ67+0Jud82BUMNf0fpcWHC4ISfz6GwWj5tornbGBcEgv
N+EXasBYs75xrs1uOOzeQu3QDIFxzSK3KG8TODhXV31yGILpXIlrnUdOw/77
CuPFsk0wXcK61PnnCOwHCjpiuLthanO5ZzLlIuw/aGW36VTBNGTr0iROOuzb
NS/6bCb30/KzY8LHv8G+kh9cqqIGs03Wf8W1SmGf2bA44NELmLcU/M1bYA57
h5MFNCVzmH+VSdF13Qh725rYYvshWMzY9+HbxCTsV/5e36VoBotlCQKh8y/A
3iRyo29eHCySlNubTd/CXj07ZKk0D5aIXiE2oQ676fE6n3mdWHFvYVVG8HHY
3d2s+SL9FlY0/A39EOIBuyIKL+9JLLnv9w+ZbDCH3Q3lUt3UrbCSf7dz7wMq
7PI6u2gGa2C1079ukYMM7E6eqn18wwrWVqeUnTjKsNshHlsp44OVL34+rHjJ
g51VXf7hY7VY+f7cdbcN4rCziBN8kC2LlVNus/9dZMLOdMXrzRsGYbOk8beA
2gDslt3vi/8QDpsk978Cnt2wUx86o+DwC6ucnXbJub2B3Rxdwwy9CKwKyIgb
O9oPO2Ht4fZxaazaPSxS9P0n7GYu1lwpNIZV1yoOzw5RB/WPSU/MxweA8PcG
q+OXQf1x4PLrv1eADWKpcb3ZoHb8nhxzVAe2J1T1fuwH9Y1N/jtGBBA/m3rg
kRSorw882eFUDJxV0HjIWQdqo/ry/FYmUL9ri4BoOKjVh7oiVlditYmV2AuG
JKi3zCpV55jDdmYFY8f7DaCm1PV7GzyFraygx0OF5aAmhXbUCIvCVs35hteS
JaAelG6tfx4IW+tvkUcTAWpc0IfnM4Zguz2O/ef9A1B3MbWj5c7C9ktXWVSC
K6jB806p/DKE7a/9vRcsSX/WC9k/PRcLiohxxGK7LFDXTvSIqhAvyn7/pe89
qPyhmgOG7qD4N2nMvaMGqs9cw+ZWAVDeBLr3ZF0B1ckp4NllNVA+R45ZSciA
6nAga33cJlB+piil7xsD1a7m4smxd6DOfTH5d2MEqLZefVURF0B1P7UotPsF
qFY3FcYb9EF9uTnefKAd1OW2JRuUckHtHJDrn30VVP3nzdqVO0D9Grzqcyrp
r55nfMk+BdiJ7g6/Vh8H6pLdx1S8KmHn+M1bVkIDVM3f4gdD3GH3dF6Sf+4B
UBWbvNxKfsDu9ReLBapk/BSKjQ03XoPdh6qyv4E6oMqf6XwVFAp7wRSXYvG9
oM6LjD+m2A17G7+rh9lGoMowmzjvrGDvErBkej75Xtrjdna/LOy5GxPj5zFA
lfKhhpXXw373kc+m5h9AlQjd1BweA/u7C52sDnwEdU5FFC4Iw77GvSfpSzeo
It2JOkZdsH+dzNvSNEosoMNuVob9mMRczdMkfoRdFQezxeBg6Jska5sO6sy5
vnMMkuBQKBVUKBIIyh/7T6wjwnAoyxo0/V4ByvTZPeWOPDi8tAjyHCoC5fd4
0Md2kpe+7qJe1BUBZeqW8fnF5nBcantrPa8PlEmGeuDvQ3BcISRQtScVlIny
8ROzEuHoVEtvzRcmNvorayoJx5CNbxtmN5F51DitOjYIx/yxsT/ZSaCMLY65
mn4Gjvc+WYsWWYIyenNHiYsdHJ+93V+85wuxdUz0dkM49ner/FAkcTHCu+a9
JheOk5/Ddp0ncfFjpLpLPxROIj8fp/59Q5z8dtaOs3Basni7uKoFKMOVQ/Xr
npF9w7HNsnyIeN3bsw1dcHLavDKmmkEsUhLmJASnkFdKGUnLQPnuKyV7vQZO
VzsXrMrxBuWbcn105GI4lXbEMqKOgTLU8vYT2V+cXvQUGs+IIU5LV3GcgtOX
30Hl23OJpV7LiY/B6bfMeKyCPCiDzb6vHnrDWWyZ66o4CvGpcN+FpnDW3el/
7KE0sb5FYO8xOFvlKc2wJuP/derdlXAunGnt5xec30BcO9toniucubKDlU/J
+1/PZdeaOsM5lDmrYrkWccRtC+8COO892d/xiIzXV2d902W9cD707sSrq8PE
WlLbzq6Cc2EiXV1aAZQv3WMhz+hwfviB9VzXgbh80G/tazjX2y8aPNdLnG2m
wB6Dc3dhufKvT8SJL7Ve7oPzd+WF3bZ6xJuvzFlC2vsv1eFmFanvC/spxToW
NOnZZsLjrcQO6k4GS8i54sAXZ0cynl9MbyVlnAHNUHRth0gCsXbExu1yoK0+
fknMTJNY0c/VgQIaUytHh7uCWDI8WUQAtIDSkC0bSX+/zMoKX0Web/X8oZyW
CMrA368Os3eBFj+xwl06n3jK2UPBDbTj56mGC0h8DkzcrWssAi2XJtFw6+R/
1v+ymjwv/nPSNGA/8WRei7kHaDXFXfyVncTTKjcdboLWtrXH5lwNqW9G0pmO
S6D1m5+7L3CWWORzofll0H7NmH+5h8TvF1mD0aM9oM9pdHyTUEasyt8xt4qc
03KNxfr/e740zOIHC3TdmOafOyWJLVnGG8+Abu2/dNXv/+ws6dt/HXQXe5P4
gOvE3BOZf+aA7mf4w/XCm//Gt691jzfo4Zp8jZ1/iRNGfsTfBz1WaW8E34n4
fNmTY6T8o/IOOZTLxPeslI8ngH5JsVx64wfi5qCn311Ar1p+rcj2HJl/ySId
PV/QX1NUWefJevy6rJo59A/0T1yTWasKiBmhjwYN4SJywbFWp5E4M0BIwQsu
is9tW0eOED/K1uitgcvSyfbu6/7En/wlbW/CxSW4Vec9idfBFcYntPbAxe+K
Wf9SEv+D61c67PwEl/DvumevjBIfyx+zug2X9JSnhurFxCOH9A/+hsub2TEp
f06Q9VL+IjGdnKu/fF+/c1sa8VS79bdsuPx5W71Y/CdZf+ZOk11z4apZ11Fg
XUt8Z3mYsR9cw6cmNM6S+r8/VDJJc4bbnAM691T9SH6Y2TVvqgEMtdNlF26S
/DKx+HDRTBYYS7ckF46S+JiImpKWjgPDhGYTok3ifaLlxlJbcg9ynO244gDJ
X5NxDT3fdoIRfnH3v11bQfnV+yPlXAwY5ezmh1OB/+XHob9qgnD3fxxpHaMF
6oxWzz6aGdw32ETcnyb7seDCQ7XbT8N968NIhthb4mAZ1aRAuCc8DjurkEn8
87NTuyncC3pv8OyvgyokJv0kMgnuJWErr5uQ/UjI5VeFwwy4l/++7GB2lvjI
7+tbv8K9WXXCfRnJ57NkDLqFmsm9fcdYvCyP5PfZN1NPniH3fNmnK3zJ/iVs
e7MWvWCK33AqYZP9U3hv5pKzbWAuHHJY6H+DeEjIbe5RMO33xq69MBvU2eWF
jOgRMBlay7z3thD/WO3p2Aembx23scKT7Cfqh4deC4IZpqWRkU36JxK94lrZ
CTCPvb8ofWEV2Y8WO2eIR4F57kS2kc1+Ylcx8fUaYF52Gul2m0+81TdgWyiY
pSX+NpsEie+nnBcdBbNq0+Z9f4SJOwIvT5L36xcXhcucIP51v2tWDZjvzhVX
Hif1iRo/7FwSBuZXdpDdnhhi13Vr/faDOa6wPHeE7K+iQRFpqfvA/Ns2u17w
G3F03+jWZniInOzPZAUSH79juN4aHrLeL15ZBRPn9wjl0+GhonjZ7DnZ30Uf
+FvfeQiPRV3bd3aWEr80fpRyFh7Lswwtl6cSd3ru/ycHD8t1jWJb9Ij7H18U
mA0PylLaNrcfxGORll/84UEfPvPt6B7ivyGHG3/Dw+vu/XeLPoEqJnzux3M7
ePjHnLti/YpYQqLJLAoeGxxXneAsIJYpLpq7Dx6RMhmftpD2is1NN7B1g0dU
5/mGURbxvAt/aofhcTCPvuP70/+ed/abiMLj6JbMiSUkPsRkbVvKPsHjzMq9
voZO/5X/6vHNKXjkzvl2Nua/72cfqLnaB4/rrZ9vHyHzI/qPO7erDR73cvgx
02S+RcfdJ7x3w+NJhEvXeQPigXXNjEXweImrx3KE/ut/us568rz1veqaPc3E
L8IjDE/B4138n9TCeuK74id8JuExqI3tF4yJL66vK9sPj5/POteOHSFO2hNl
4QHWjI2VaVUixOGOerONwBKX/Kb9rIyY+SJJSxUsdc/uDy0DxLKf642XgaX7
64h0qAWJh+/R7aa2YJmd8yx4Rr6f87yy3Q9g0T78OuF6iHiH+wPp+2B5JVZs
aLMids4UMvoB1hq9zVW++cTKB2XZoWBt3+q/vegRid8SrnzZHbD2zU/8RPvP
saj+qAdWyv2w2b3kXCniUHv5cAZYWX8tp5zJfM9uaKZ9rQXrWpbYjlBV4jTG
gjZTsEpWh/y7fZzYdau9jSFYtXEXZowWkvVVeT3T8jVYrRq8mgPTxLufmbrL
gtX7eLeeAGmP8PIU8RAOWON/zozqk3iYlS5jY/AHnmqhhp1nosh6t6IlFsXB
U3fWIX9XMl8ze9rTT66Ap+m5vtvxZL3PjFuoL34Dns613nna5HwrWN552z8H
ntvkf/NzE0g+Utt0uUgBnjGX+7QEn4MqUCSe8TgCnslm6ypCTYgpe7WCP8Hz
gtvMpBozUP7xei9VPoLn8zDG7iEqOQ/uWnm+ngvP5uF8Bx45t09PfTzyygee
3RGmcTH/nQ93H1CNZ8JzNPzh84QBcj7c+vhi/WV4qXpoPrYg/uX6puPFO3ht
vmnMcdUg57vCNeOp48T/chYL7SPOL8/RH4PXFre5fiEkv4/lqIweCiQeGpUa
qCI+3Rr5+Da8tupe2cOcIE60E8y9C69teVP+eyKJ10r7KhyH1+5zus+vbSNW
8Pf28CMeTOrdd5BY7vYKyy/w2mP12Z96gFhqZnlxI3FH1mlLcl4am5V7+4o0
vKIUxMa3kvPf6MjHFaqn4BWTXmPac4m4jtnlGEr8XunVsgjiZ+e/xxjAK9Zw
U8ucYOLKL3mW34kb50mL7SUujf27g7wfJ8H2awPx5SuckhvE3Ksmqt3El0YO
3XpGfO3XZtgQn7dac0URXvHOJ1UqjIiP1048I/2NP9V36Mcd4jS5+1IaxAMG
a/PIeWI0hbMgVQte+y32Zj0n/RtNuKTDavn//wXU////Alz/B9NjcHE=
      "]]}}, {
    CircleBox[{22, 59}, 58.5], 
    CircleBox[{22, 59}, NCache[Rational[9, 5], 1.8]], 
    CircleBox[{53.86138354837908, 9.937771775192694}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{178.66826523116958`, 113.22011433488649`}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{90.0707874933862, 39.902402023992735`}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{87.62900371931076, -42.0598034374236}, NCache[
     Rational[9, 5], 1.8]], 
    LineBox[{{22, 59}, {87.62900371931076, -42.0598034374236}}], 
    LineBox[{{22, 59}, {53.86138354837908, 9.937771775192694}}], 
    LineBox[{{87.62900371931076, -42.0598034374236}, {178.66826523116958`, 
     113.22011433488649`}}], 
    LineBox[{{53.86138354837908, 9.937771775192694}, {178.66826523116958`, 
     113.22011433488649`}, {90.0707874933862, 39.902402023992735`}, {
     53.86138354837908, 9.937771775192694}}], InsetBox["A0", {28, 53}], 
    InsetBox["A", {59.86138354837908, 15.937771775192694`}], 
    InsetBox["B", {184.66826523116958`, 119.22011433488649`}], 
    InsetBox["K", {96.0707874933862, 45.902402023992735`}], 
    InsetBox["B0", {93.62900371931076, -48.0598034374236}]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 3)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.467463022695632*^9, 3.467466439111833*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt3Hc81d8fB3BJkj0qu6ykUPaI9Mq95r24rmvd4UoJRUraGVEyStKgrYxU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      "]]}}, {
    CircleBox[{22, 59}, 58.5], 
    CircleBox[{22, 59}, NCache[Rational[9, 5], 1.8]], 
    CircleBox[{74.12388166501952, 32.44155576523651}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{233.00392182210993`, 64.08223906508545}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{120.21870813034822`, 41.621260179390205`}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{87.62900371931076, -42.0598034374236}, NCache[
     Rational[9, 5], 1.8]], 
    LineBox[{{22, 59}, {87.62900371931076, -42.0598034374236}}], 
    LineBox[{{22, 59}, {74.12388166501952, 32.44155576523651}}], 
    LineBox[{{87.62900371931076, -42.0598034374236}, {233.00392182210993`, 
     64.08223906508545}}], 
    LineBox[{{74.12388166501952, 32.44155576523651}, {233.00392182210993`, 
     64.08223906508545}, {120.21870813034822`, 41.621260179390205`}, {
     74.12388166501952, 32.44155576523651}}], InsetBox["A0", {28, 53}], 
    InsetBox["A", {80.12388166501952, 38.44155576523651}], 
    InsetBox["B", {239.00392182210993`, 70.08223906508545}], 
    InsetBox["K", {126.21870813034822`, 47.621260179390205`}], 
    InsetBox["B0", {93.62900371931076, -48.0598034374236}]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 3)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.467463022695632*^9, 3.467466439216432*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt3Hc81d8fB3BJkj0qu6ykUPaI9Mq95r24rmvd4UoJRUraGVEyStKgrYxU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      "]]}}, {
    CircleBox[{22, 59}, 58.5], 
    CircleBox[{22, 59}, NCache[Rational[9, 5], 1.8]], 
    CircleBox[{80.41982778314258, 62.06165344021222}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{242.006802523337, 50.500961665418984`}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{127.29999946702614`, 58.70762557962406}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{87.62900371931076, -42.0598034374236}, NCache[
     Rational[9, 5], 1.8]], 
    LineBox[{{22, 59}, {87.62900371931076, -42.0598034374236}}], 
    LineBox[{{22, 59}, {80.41982778314258, 62.06165344021222}}], 
    LineBox[{{87.62900371931076, -42.0598034374236}, {242.006802523337, 
     50.500961665418984`}}], 
    LineBox[{{80.41982778314258, 62.06165344021222}, {242.006802523337, 
     50.500961665418984`}, {127.29999946702614`, 58.70762557962406}, {
     80.41982778314258, 62.06165344021222}}], InsetBox["A0", {28, 53}], 
    InsetBox["A", {86.41982778314258, 68.06165344021221}], 
    InsetBox["B", {248.006802523337, 56.500961665418984`}], 
    InsetBox["K", {133.29999946702614`, 64.70762557962405}], 
    InsetBox["B0", {93.62900371931076, -48.0598034374236}]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 3)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.467463022695632*^9, 3.467466439329298*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt3Hc81d8fB3BJkj0qu6ykUPaI9Mq95r24rmvd4UoJRUraGVEyStKgrYxU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      "]]}}, {
    CircleBox[{22, 59}, 58.5], 
    CircleBox[{22, 59}, NCache[Rational[9, 5], 1.8]], 
    CircleBox[{71.06222822480731, 90.86138354837908}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{231.2179256716202, 66.48613841474142}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{117.52715279270981`, 83.7895531701015}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{87.62900371931076, -42.0598034374236}, NCache[
     Rational[9, 5], 1.8]], 
    LineBox[{{22, 59}, {87.62900371931076, -42.0598034374236}}], 
    LineBox[{{22, 59}, {71.06222822480731, 90.86138354837908}}], 
    LineBox[{{87.62900371931076, -42.0598034374236}, {231.2179256716202, 
     66.48613841474142}}], 
    LineBox[{{71.06222822480731, 90.86138354837908}, {231.2179256716202, 
     66.48613841474142}, {117.52715279270981`, 83.7895531701015}, {
     71.06222822480731, 90.86138354837908}}], InsetBox["A0", {28, 53}], 
    InsetBox["A", {77.06222822480731, 96.86138354837908}], 
    InsetBox["B", {237.2179256716202, 72.48613841474142}], 
    InsetBox["K", {123.52715279270981`, 89.7895531701015}], 
    InsetBox["B0", {93.62900371931076, -48.0598034374236}]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 3)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.467463022695632*^9, 3.467466439411518*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt3Hc81d8fB3BJkj0qu6ykUPaI9Mq95r24rmvd4UoJRUraGVEyStKgrYxU
tEQlRRkNGSEyQmlQlIxIqt/5Ph6/v+7j+fh8Pme+z/uc889lhgeoBwoICAgK
CAgJ/fcLr/0Hn1EpDaCM7utvjXCHV6q014PBEVBGvleVP70Lr4yTF0eO2BNz
WcaU8/C6etZhY9EKUH4YXjm1Ix9ejcll3+4Rf6ubLJdhw1v5a9PD0jpQBpo/
NmvLw/vmnjap4zdB6XF3NXjzGN73r/jFLk8FpTs38vBjHXg/ad5aX7IFlLe/
gvszZOD9WlXLxdYPlK6sT2tap+H960CuXp0HKO3fA/l7UuGzOvtI8gNSX8tx
p+dXLeBT/2ZESncNKC8YLxzCTsPnje0J1TvNoDzPFxdKzofPu7yJEI2VxAKt
Pwr+wmeM3/KPlQjK07u0lZ874KuYNrlgjToo1ZYHwrbFwlejITOsXwCUqvOf
J0pOw1dP5GbPlSvEwhyZvX/ga7NBx2ebKChPOu8WDivBN2DAWYvlBErFpWXy
u5bDd+NUZeCNk8SKk65q8+G7TXjrqbrLoJQf52Ume8L3oDhbbuEeUB4dXeWa
8wm+V1+FOf5xBaWs0KmBGwrfoqLaiCENYqvW6Ts34VuWtig5dQyUB3Uphx72
wrfe7FZ3YQcopVO3LBv84PtjRbie7lpQ7kd15txuhu+vr8Naga+JF6cV2e4G
WzDDwrtbG5R7Lb8+fX4NtlznrOmsRmKrZRPf3oCtsjVm6+8/oNwdU/1cBrAX
zco3ukf6f/fWbDWjMrDN5g8XqDsTm0syS46DbXNyluX1TGIBt+W7/cB2kLx9
xyMblJK6RkUF8r5b7Gh1AJX4wqUw2cVgew9WLi/UI97WFtO9GWx/pnJD9Cgx
I/asxyawg29Onj5C+lOy/MZMCWmwt8xhXZgKIpbbOtCaCfYujq7IsnJQin/3
7pkXCfa+vB1zP/QSD8x6beoFdtJXE3WJPOKOcdF5T8FOX8LLelJA/Kp8wS4W
2Kf9v6ubkvkqrts2Z7sQ2JeOfnA8TeK7uH5x0WdS/tUyi1YVA+LmzxN9OmDf
7um/+PC/8rprsvTCwS6d/n6Wlk78rSWo4B7YlXJODbZDpH1C6pNf14NdqzHK
vX+JeEH5UOIysJt1+2PsXhLbPKor+Ql257JFSR/IeJasWy71MBHsviV5n7vi
iI+oy0e8BPvrghCVy2nE5bmmFaJgj4oHVzY+Ih6vzde8AfbU6KW0dn8y3oY5
mWaS4Ai65r8+/Zh40/3FLfbgzMl+ohRoTXyzl2tfAo70yNfPj68RTy7We3AW
HAVrzTeyM8h8U0/H9CWAszAmKGOXBfFJB90sLXC0y+70PWkjHrIcu8MFx3TR
2i3db0n8XNM6HS0OjjWjIuF6PIk3WdP8NQCHsn1BvTaJ19LoclP//eC4X2/z
CRIi8Rkctm79bXB8nuhPsJnEH69eqrkPDr8hep8s6X9Z8NHMYD9wwt4IVxf5
gPIw5rDYKhNwIputAkIfkvUgd/+g/jA4e56tLXSdT1xYftdNA5ykrKSqc7fI
+hlNdAvIASctfv/Ykyqyvi4ESNMY4GT4bzptsx2Ux+5Us85gcHJFREofRZP1
+dRtt/kqcK413ZXfMg5KZcoR2wekv7cz3Aoyb5P17CX0dOAmOBWSVoPKpD/V
fx6GJAuD03H7yy+vQZIvTp28OVsPnHf0ls+hpD0v0kqytimA87k3e/0nMl+1
qQEl/7rAGRsf9FUXBqXuXOKLmr3gSrZp1V0g8d8kvmTjs0Jw52FJbnE3KM0W
z2RvPgFXOVt6RHYDyV+hFHpZKbg6XgmtBxaB0vp5vH3JB3BXR8qqJXWR/GfM
9L+rA65DgV5azQeSHzPe8iwqwHXpXnraMpnk05lH5l4PBpe9vGnkI8mP74aT
emJWgBuR9O7MtiZQ+tXruB/awN15dNEa10MkH1fE+Pn2gxudznh7ZRkoX9ef
eRYUCG5y3JoOnUKSv58b38srAPeSYhzdfC8o4/33N1Kkwb3c1LaplMT3RKmp
G48HbmGCd9ARY1B+HRPf2HgU3HudneU2LaD8YX+29PgLbsNqOZXCi6DOogob
6KSB21Lb+ez7WlBnu8sdxg9wOxhtg907QJ0TeGOH11lwPzqFJ6gYgSqRe/Wp
Txe4U+OQ6DsL6vx9jMrMpeAJuD9zeyUIqkJt5KX0b+DNyk89P8IBVVmVZX7t
J3jS1E4zPWFQF77h2P25DN4ii/MRJkdBXVIw9/ONQfBcJY0e714Hqk29vfXH
MPA8pLzXKlqCuvrkmp4ycfB8RFtUz6SDSl2/j/rEEbw1w2/VOtpAdV7QIae9
Hrxtu9bYprWA6jns2VglCd6ZqJ6tdmOghiuusHraDl7WouCWE0OgRqxVUZee
AV7O0xCPL02gbis2shvQA69wqm1kbz6oeyOEPC8+Aa9iYZ79M0VQk113jVoX
gdcX8JE+XxrUy8fNtwdbg9cvbSh3cxTUa8XLd1pHgTd4VwMzHoF6o2doNIl4
fERAq4+M5z1mpajpJPxElKfMs0pBfV7Yf9iyBn66lE0dZf2gfltxnu+6DH7L
D21wnegFdWSSucVWBn7GDZZxLBtQJ8qbD7Zeg5+1rd/Q0g+wmxG6ojVCBX70
HoUQfWXYzVuRopwQAL/Qsc4/O+NhZ1NAD47Xgd/mrm1XjjfBjiq87kfjW/hF
PpL1+XUOdk4bzH9uF4Df3nD/I/HRsGO5zbpB8qxfSvKljtPDsNtwWKiHdwl+
+XkMnXfSsMt8s+2pTTf8CpbvPnLdEnbn69QbPe/A78bt1rr5IrDLqeUPHO2F
X0m+gVdFC+xufjgQJ/gJflUu95SuCMHueZJCRdI4/LoTMgP+kfenMy2V9g3A
7120fPuSj7AXvGO1dC0p/8Pmm1jJgL3IG/5wdx78vjiYvPfugv08y5kv7/vB
b/z+SzV1bdgv47gHtLSAL3ZXY9Y/P9gHqFUxN10CX3KNlUx1GuyDH1qFls0C
X0Y4zS5YCfbhazK7BcvAn287cdNYHvZ7H/9cJb4TfLW48YnKSNhn9FYbCZiA
b6K+/9EbV9g3pH/WOf4afLNY7t7STbBvvVaRVrwafIuOo7l2zbB/+3KF6Efy
/cp9Kiujg2A/qDm1Y5s8+PYnv1C2v4XDnGV6jsrC4Ht/VrMXN4AD9Ypc5xM/
8H2nHwiJT8CBblmwYcgSfK5EE335bjh4vDp5Z78k+P4aUeNHreGwVp72fQup
L3jen5Sw7XDY9+vySOx78HcsNt10pBUOj+cla8qsA3+X8tgDtwtweF7VtqFQ
Dfw9YkkLedfh0LTX1+DtFPjRnZbT+jPh8GFmt7PpQvATrH8Jrw2F4+zIJSXh
d8FPFDmvVnwQjtLrvJYw94Kf1LDkIu0nHBW50cdLksA/TJ+m5GjDUXdd3tmx
MPCPi73YMG0GR7fmJH2tPvBPXH+7NLQcjr6CtY5CqeBn0D/1PA2AY4BlA2dh
LPind322Xs6GY2S5gLBBJvhZGc1JqpvgeHqRSb7YGPjXPkrtvK0Cx0/s9csr
b4FfaBEV73cPjsOC9Our6OBfPzhj5xElOP66FXXieAH4t+Yxo6aewUliUZZR
0RPwiydo3c45cDJZJ/t7x33w72qetTx+G042djuWqW4B/x5NevhcNJwc9fsv
WOWCX5qyaafzKThx5VrC/ySA/6hpabKMLZz2G01khX0Gv7ytfktxI5xSaUM3
tu8Dv+JNTsySQThlbizSoGaA/6R2qIKsE6eC8sNK/Crwa3ZpOlR1wen13WwL
m0Lwn/oktB/XhlOv8Aqf7a3gPzNeUiY0DKcvnIBdF4rBf95h3HEvGU7/FO3D
BMXAf/n9QEsJDc467/cd8mgCvy73XhfjJ5yNjfMOf9cFv957rT37B5xXJvdt
kREEv6FQS/xNJJyZtINyISrgN7qvdHpYAWfune7BJQ+Ih5uv/BmBc5CWQftF
0v4mjagY1xlw3js3V9X6DvGdY1XPD8E54cS9hJ9kvTTb6tXHbILzUZV8vRs8
8FvcBu//jYdzntVfF1E78FtNX3jpjsO5sfzOjd3mxDmqBuJ/4dy56U0tUxH8
Nok/RXVVcP6keY6jySBuCRPJZ8H597mBoc+vwH9j8DdKawI04bUB0zZHiJM0
3rsZgiazzO9EKBv8dr0lt+UDQNNuKY+Z60i8Q/K24k7QDG/O61zqQ/wwpe7U
btCs0xrb130n/neJJsoBzWF7/78pMl4dKz3CjeNAYwZ4veaT+enYnhVl0goa
z0O211Wc+FpySXIVaMFO8y43uRB3yXFkfUHbSvUu8hgGv1PE6oqEJWjR1FfJ
FyqIDYTeLroJWpLznuIf14g9NhtF3APtuKfrw79U4ojo93vGQLsQSNGdXkN8
2GjRykegXd3tnnSdrO/O7BRDfXXQio9HrNm4g7g4xcrqNWgVRedtdGqIK423
d60Grbat7lpcMPHLA/NnRYLWJvDLtMqI+NU+J3Ml0N4vVwwZSSNuWrIqaito
QwHar5uliOujtbc5gjZ5Wmn22Bfimn1L3bpAn9n69ch9Mn+dpcbbWltBl1I4
9odD1n/nlZNGm01AV+KLvZsqJT5+NVFjGeiLrtIazqsS79lyLkMNdIMpui9+
EfMGM9VDQbd2E5Z9401srXKmnA26Q/6Wo5zFxPMFaxf8BN1D+OCG56Q/HV+z
HC7+AN0vBGamJF90lP00XLMR9JDG4ynPhIiTZ1027AB9m3WU0As+sbxnwfzr
oB9SH3wp9pzMZ1tmxPlHoGecCWSW5hEfO2WinQd6tiIrrKaLxMvf9jk9ZaCX
auzsiTUgvq5E+5kGenXhhZ3XTxP7qn7o+Qv6q5ULdZ1Ifmy7tHkD9zvo/SHi
m485EztEyrlcAn105X7fSRIfrf0vqlkbQP8779qFoGfEapElBpJwkWscDpdY
TuJ/bdN9egZcVkUUFCdGkfXxNeH8x8VwcV77S+yuL3H4ce5KWbh4+lSvXE7y
V1NoxV3ZaLhspFcnUkn9jVaRxiFP4ZLBq1gjv4us1zxJDdcSuFzasF7X+Cqx
hEgilw2Xwt3c84tI/+sa1advHYRLZY7mX7Wz4Ncu/Wsa7weX4QU7w/Ovg19t
IuVXoAdXpytKv66R/awqUMapngJXVr+EVtsN8CvTYzefuQNX/yUjp03Og//4
/ZXUahm4bi+JXaVF4ueRj3WFiTBcs0eEnkeR+So5JSeozofr36GrT1TJ/lF8
1E7t5Qe4ifouSCw+Af6dA8MP9MfgNu/pkkcpJL5ur7u7zlkAbnpXv9/vp5H8
PCm/50sC3NhpZ5TekXjP2f58tdMI3EoaoiOdyXrNVn4m80MLbpWcx7Hub8G/
WHajyGISbg1f8oRTd4N/fmSlRlwN3AakzaVNRMA/pbeh7Hs0GBJl7ZRxB/AP
ve3ViVQHySQ/fIzJfpCyutN2zxkw7O9vP1OwlOxPF+vGuzzAcJk716mH5OsE
z3NNdH8wfF8m/9XdAH7MYYHfOxzB2OosdMedrP8tVhf9t0mAkRe5SMSajFc4
P/5CfgQYBW/TQ6NswQ+LCZUMzgOjyOGdQU87+CFFHirvWsCoWDjPjlEJ/pqv
x0J1YsBob9vZqh4Jvvv5fNumZrhLhFk9riX7z7J5scfPjMF927zgS2M24Ot+
mBmmexnue7RnXH5L1sOSGzrHAlzhvs9csKmfzP8iK27N6vNwP8w2Vqol601F
d1/ZUDzcc3MFF3fpgz9n43ozTRrcW53lmJ/XkfPRpo8jM8TBNK+YcWbsLzk/
Nes8fl8G5so3Z+tzE+HXZaK99M4jMCk/XNUkT8GvddCj99g0mAyNAS2r3/B7
aZp2QcEIzOCEBzKym8j5TM9mk509mKdccz7mB8Hv4I0xNZ14MKfqd9cExMBv
f5mtnVMhPARqwp09u+C3r3q/cMQyeAg/WuYyJxN+e+o/bkYJPGQLBT++3QO/
8IemUe5b4LH04LOVG13g5y1yL0EhCR7s5a/Dd2rBT9O/Xj7JGx73Vzx4bG0B
XpFtVrfVJbC2VQ2WfvMF78bqEqWHXWDtVW0zCysH79rKiJUX14IVt60v/tx+
8LKX9l15CbCOaHpvnLcavPS3LwLzO8DK3xp4YeIweFtyshv808Hq+Diwa90L
8PQepVgIyMJz1UxbU606cE8F7oxwuAmvmafmPYvMBvf4QLu6xV54zVmV8a7N
Bty0jUeHlqXDS/JDy5yLp8E9GCQtuPMQvJR0t7obvQJ3mw2H5hkFL4Mrymni
J8BlhCvSdFjw4q3bv+veInCFenNTy+rhVdyw0yY7DJz1q0ERWwHvAPm5Jzw0
wfEvWSjZ9gTeQQ3fUuWUweHoGDbwZOEdlvDic8AtcBgzf6nakfd3fot78SsE
HMvTFqcKNsD7SO490Z+rwRG3fXFv2BzeZbfiNrAegn0jtWvu9Qr4zDPUfbhU
E77fQt5vaByDT3nIC38TG/j2s972On2AT9VeanibOnzfrzxYkHUePs8PBbR+
S4Zv6+zB+OEo+DTnJqyn68H34T7t961p8Pn8wHogKgK+h4QffjC/B1+prZJ7
aLrwXRxyuONOOnx5cx44CevAx7t/hUbFWfgOxw3/Ht8JH/eHSbKRz+E7lreV
OUHaQTuq3/rnH3wnn54qNP0Cn1XG0V7BHWDPEKxnLG+Hj/a6NUnyFmDLcEur
ynXhPbZzXdGsPrANz5WLmXeTfm+V2uwwBvZml1O/7OvgnTSvenuwCtiRmjcf
p9PhHVfy586pSbB3TNA3SxTAe9vY1J7V38GOyZB8M2AMby6ffmu1F9ip9/Ki
g6LgrfMt7cE6f7AL4n1Nfg7D6/GM1FOPHMH+ZFDW+uEuvO4PnHjx6BrYX2a0
Cw+Ww+t2o8yN/bJgDzUM3M5LgVdO5qZRfzOwxwM+hAT+hFfi/FGZunvgCK3T
lMrZDy/XlxXofw6OetNns4U68OzU2WZA9lsOm91lPmMWPJvfX9u7zgIc3rPc
vhue8Hx5Jl3FMAucNcZ2DV5/4Plozo7e9zrgBP0T+h4dDM+s1x3uPT7gbNsc
HAojeK43uuRnqgDOkdI5xuf/gjU8J6kvXBycx32Kk+l3wRpQmZ+85QE4VSWp
F9+ywXqvX3QpjAfO04O6vVzyvMV10Zo4Fjh1C9/WJ60H695+2VqJ2eC8WS4V
/e0DWLHVW13iPoEzVKX/oDEcLOkrFFubZHDnV2cL5s8Ca07WJ9OMdeAqrlSd
LEsBSzCj9qkHC1zlWzfb+q/BYyw+cO6HInDV0lV2e5K88MZ9+mA2F9yly/9e
FCZ55EK9Wk5SK7jWPYfErK3gsczF/Qf/Jbj+ov07z2jAQztTMzxEA9wAdzZD
wQ8eC94zzVZFgLvuuMfK8K3wkIpsuLNBFtwQqTeZQ5pgDqfHy273A3fL20Ws
0z1g3r6ddirrE7hxjRvFD6uBeXVsSfAu0v79PSoODi/BzDZd9V5gCtyEL67a
vzrAPFY89P3fL3CTfxoFCl4CM/LWQbOB5+Cm941KTaaAaXYs8sjaG+Bekhd9
+2M/mMvqOh3TSH+yh8616fmBuXh2r8q/leDmVhTYOb0BU373S5O27+Be4a7g
Vz6C+yR3/VD+GXBvhsgN+9bBvVQ6dGSLMLgP2+PzjDRATuvf7NKCwW2VawjR
jIS7aVaQ0SrSvraI94Y/uXDX/1nhsIUB7pv65Pgb6nBfkK10Mm4FuJ17zti9
6gTj31RuhBEb3N6CUjWTUjCe5D1e5Z4J7pcNbWWH3oFROq1xUeADuF+Pmb3n
bCb7mntco9Q9cAfvLdX8uQaM7GkH6yffwP028bImzwKMA8x5b/YfBXfUdQZP
zxQMR4Hts5iHwP3tpSFbSSP7sNeV5LOa4E47lC//5gCGRcHURk8yH39Mh5Vu
dYOxxPd396VccP+JSITyG8AQLb79fq0feILxZtXN/WDMlBA+dU8BvJm+WyWi
/sDt53OJxmBt8IT0KOvNvsPtjc6S2oZ+8GY9zdp3YBncTn81N1O8DZ7Ia1fl
EcAt5ZxswpM74M1J08t6kAq3vW6BG3X+gifqcKEibgbceMX7VORugSdWQF3a
uAduagen7FNawJOkJ3K1veAms3Kav32EeFAy4J0G3GaMHef5R4Enlbik5bAg
XPvWnljqS+qXLlHfFmAM1zwnygfJBvBkB+SZYbfgmil6QXsC4MmtS6x+0AbX
pJcnxxVViN8KCsjqwjWMGbyV5DPe3Gpx5+r3cOXPd7S1OQvePJNz53Jt4Mro
aOw00SW+aG6dFgJXk8D+3JYO8OZviR9MiICrtl7UWIAg8Wtz+8wouMqPPrOP
+QqevOlodJUnXH7vT9StriH+dlAreBdcntwQDRTaC56i9cIb9gvgcmfPOet6
G+LEBX7t8nDJc/yzd4cX8avF5sdj4JL0yYjvRAFPie2jGJQClz0lEvJJ0sSn
Y6PHAuESlvB4TUsBcVtRzbFSuLgvfdL0LRE8ZSerh3Un4GL7d7642ELiqLRG
2gBcTJpcf9ffI77+Izl7Ai7alzdf3fOW+K2fmmMZXBSiohdOssBTEWmt3r0U
LqKs3WtfriM25NygfgB9Wi84SoPUr+I1JBenCvq3WbSIqkDiXSk6betA7+nR
pi0oJj5lpl0SSc7196fFrd4TF3+z480CvfJEw4PqLOKGooctZ0Avjsjhzywh
/pTwfMQX9MuMvVOdLsRTQTleDaCfWs49Vk/iTVXMKzHsGegpUvb6v0aJFT1u
b9IAfe+wdZ38AWItPt/3MOibmiiRuxcR6+16OR0Gun8xb7EkiSdVw2zLobOg
M08d+sw5Tmzc+THVFnRq9Ou70Rf/s5b0HNIes8AVp/TJfKku3zPFIvXr0B8d
LibtVdXp+7TsHrmHma47MUn6o7qQO39hKejiC5ffDr9ALPuhblcSaH9FNfq0
04lnRjO8pkH7/nP14kf/jc8Pnb4z7aC96zscs2GcuPPDy7GLoDU3ifaP/Dce
lbeZrUGgVT8uCyhMIc4/WhZ9BLS7t3O+7CfxrZIc7z5yA7QrOU+jRqjEIQe5
Ag6gHT5U88CW1Key4Om4ELlHx8Rd4fV9IPM5Pktxrx5oW3a9+nMyjfiZ59vU
H6B5hs5Qe2RGvN5457xacg8PkjjlXU9sUPHFNg00y7Ubfzknk3iaXGu8JwQ0
Vf+lrB0kvpWiP6fMJu2XNOqsDfUmttCL+jQbzv9m6zx4Gk/i9ZvQNcHTcO69
k7P4YxOx22au7AM4vzrcYXj+CXgKv4VKyh7D+UlwaWPeNHG2/i+ZvXDO0Uzu
syoi62MAQ80DcD4xc1/P2s3EB3VjtsbD+cBHozjJVmL1grtqf+AcVNhQlT1F
1hs98v3l83DWZa3ltCqR9btL52twGpxVbNMKv/+3vn+/Dpr/HM4SRicuvyD9
ldujYqHfCqfvCqYHBn1IfgjfXbNsJZxuT5mGoIvkj+VJK2c3wil7InHPi2iS
XzLmi1gATsd/vpqzVoDkn9+rledVwGn7b/ct7uTcK3E/UqvoDJysVHY4X3Ek
+UuCy/Ewh5Pekm6ZYDrJb74Dw3Hv4aRq6f3zADkHz8lWmvH5Ghz/+R3rbqog
+VF37VMVGhwrnxxjuOqQ/ClX6CksAEf66Ge26BZw/1IyctpnwdFGy9JiUyjJ
1+y0HREr4Ljc603fC12SzzeZjG7zgqNMpbSBYT64UynxXmtN4dB6t8o7owPc
n+cdhI89h8OaeWEvjr8g+4XWBM2lHw4egUY/6F/AHVISeZ5xCw52d/W2VkeT
/UXcWnmSCYela56Zf+oDd6BfdKPcGOxHX4053b8I7scozwVTv2F/UC3/+goh
cLsWql03moT9rhPSdgscwO34lM67OBf2oWIdJ9XiwG2/tuy7vw/s3QUufZTI
Ifuj7ld5pfOwV57NjN9AB7dJLFZ/5Q3Y3UgpLP08Ae5TSm68SAHsLi3OxCuy
f1V3S9QctoXd8Ro5rYnr4FZtu1ocHw673aLVXocnwX189oC6sRDsqEUbfAud
wH3wrH7xHiqoHfv1tLeT/t84S5nBWASqiLmUywWy/50wDnP6NxeU36Ez0y0L
wD0WvWc1pRSUb9lVKhdI+47WfEsZDQTltfIdx1YPcFMZs18vPwzKJf3Mhw4J
5F5BUQjz7wLFurNwi8EfcHcWumxhlMI2MqKkJGoEXN8MoX+9P2AbLLzgGGsv
uN5pStMyxrDlnM32Kz4PrmdCoZ1qHGxtmyUuCAyB6x7qVL1vFWxlAq9cvrIM
XCfFHa2XkrD6hpaWcuV6cM2nWe9jJIEheXmLk8vBlRs4uf10N9ArMR7UugNc
Gf93O10uA80ib26Hl4Ir+ZrVVKYA3BctzRa2B3dO8b36d8PAgVWrBj/cBucf
69gDo1vAgrCvre+awfkilnDh7inYXB6seT8YCc7D9bKWnx7BJvUzRR4C4JTu
3+82tAM2274cMM99BM7dLFtFbR3YUMUihNaqgXOrITdAZgVW9t49dB2y4ORJ
6sLzKVYqP7yza64IOKliK5QavsIqM//WYi8qOFyJe2foXrCK8/sQySXnWV/J
j2a9q2AVqup5wNYVHC+JN0uKH8NqVZEgO4Sclxmz5qk0h2LFZ1sBg49+4FDa
Zyd36mOF+QgjOq8MHF3526WXk2HRc/9H40cbsCcmeN8yvGDxIlbT+psW2GNF
zEMyu2FR7KZ4eGwQ7B9hy64PSsEiZXagQRaD3Bc6Lr64MQ8WZu++mBcuA/vt
2aO8QSrM02wNJ9WbwH7y8GC65zmYOdXu+Or9BOyUPZGjkzthZjJTd9fBfLAP
Xm2/ELgUZgvsKkrCcsCOb/sRGBMB05Gv2Ud7SPl7dVf9juyH6dnSV5HXrMEO
LdkXb9AOk5ENk/kPl4Lt4t+e+sgSxnnGmsKt5H4kISVf2RUH46ON+leaT4Mt
MnHzUHQvjKN2Xj8qS+5fQt26zKNKMGYNan0az4HvdM7LN8IHYCzE489dFgnf
QYWBwWPTMAoMbe+8yoXvi3M9MuMHYWjAq5AJSIVvwqL1Ca2iMFR9sbJj7CZ8
972L3xprBkMxW2d26wf4Rp2p1r3+GQafPBcUX7KA7zbRsv7eHBicE15wu2gZ
fNc2XZ6f/BgG4pkVu+l/4btarOiSSRH0B0yUfj8j99Up/WWW4UegX/NPYtlg
PnzGbz4fW8CGfs57oe2iVPj8MCo9MdAIff9h1fSNXPj0G2YVXDkGvQ79u32J
PvBpVb4mvvYPdF+ZBNkevgOfW5ekx1VPYcmrcxbj9wTgExQ3ISfnhSV3Dq/5
KEXKW6vV0yO3HUsyjmneKKTDx686Vm+LOJbweg5skyP2EhwMPKMEna97nUVW
xcKHuilDfg0fOqIv5tQHk/api7I2UpdD27f194XUfni3cyPoTXrQXhUf+NNn
Lrxb2p7xmzdCe5Hd9CgrC96N7v9Mj1Zj0Q+JJ/La9+D9lDKX/6AZi5Ly1fbE
lMG7WGGG+dzZ0CoXa8+MJ+Wlpc5pU2RBc8W1C9f6g+Ftf2f2C4GX0FRfKiNa
AnivvhJ5xuAJNGdX6g8mUOFtfe6xmSIVGq/tohRTVeBtFC9wiMeGxpbk0WcW
pD0L4KDavRvqN1Rtdb8dgtf4wfALCcugZhMt9IV6B17ZrPlf+aJQ02Gnaor4
w+u8ztMNN9OhJst0Wb2/C16Z06nLDwdjYZ32r7jfwfBKvRgYGJqIhWqlCkVV
O+G1q3dDykJBqDaphcTlKsCLYco4WFMOZb+Fsou8s+A5bZ/ZxToKZavleu/H
GPCc4CzV/dgAZYXw7bcUKuA5Er6wPO4tlJpjrx1My4dn/4mVrFUtUKJ90jI6
Iw3Plo6Qi1G5ULR7vG+c3Cs8C52eRHyUgDyvfUvgFLl382o8A/o3Qx6TIc5P
0uDp82JpRiMgr+Wo2iuVCE+PuqOWWWzM/7rrpV3iJDydmhVCrYYwf692nqDy
TniatpvpDI5gXt6VsOEzPvCUaPo6KnARc9U28A9l3wPrYcISnw2bMFdUse39
lSxyj86kpr3YA7nRySSWlQJYRVfVhS2UIPeMctHXrhGsK3Uaf6ZOQW6rdP+t
fwywTkpv3lnWBNlXSfXHYmPB2nSYS6echOwj/aG5apNghZzVZT/Wh+y1GcHC
U2lgrbva+DvpBGQPmO0e2iYAFvtprmPyN8hatTsmJgaDZf8vw+/0LMjcnjkr
8SN5f2FI7SunbshcPFeebkjKV9qe3WWoCZmjQcO9v5+BNS8+6OmtTMhsSX70
9jppr9jZe+n5cyFjIqofZBwLj4n6bJOOBkg//hGg9KkRHo0GNWuGGZC+s3/R
Py0LeNRa/55WPwbpy/ZbL1IS4VHjZHR/UxqkD/veOPtnMzzK1uR/7f8MaU7p
YyXKMDzy098ytxlBekbQh6oY8n3sROpUSwCkBrWU7y8GPPZkXlLeVgup1/07
Txb5w2O7ZcOVjSxIXX3sJR1uAI+Ne2Pr225DyreoeLG6Gjy8Zm6IvyAEKfvE
iITN5HtGbqxH5nZIGdetqpQi7aU5PJKutIGU1GXR2o0MeODQPWkjP0i+PBMo
zyPPdRVeO5+6D8my4exfVsSLynwLFl+EZGHxyJaXAvBQ85eLCBKBZFpaWfBH
8v28fP1P4uT7uDyzpuukPmn60e/nRCG5TffRlYdZ8BD9YTTf+CUkOQmjyc1k
/ASs9Leo+ULSjXv+tRYDzKneQwIhpZCkXGJJrDcAczxBP+BCCCT1o9q66yrA
/NK0ymPKAZKacjmSF8n7H3cWWdeR7xUVt/m2+YPZu3Dztc85kBTepp64SA3M
12H19VFKkPjz4pdvYSOYjfMiOtz/QmI8rVHzaBaYLx4GqarlQWKoJkengbg6
sNA2XxASn0K3ZmQQV0ja/9xtAImeOOskz81glt417ZtWh0T77D+CZaS8Yv89
JYHCkKhby7UQIM+v3pEtfrcJEs8sfp6UJfXn+gVZ7G6BRGV0TIUraX/WHEWa
sCwkyo3HWdGkvafvLM1oWAiJB76szp9pYJ7gn3324xAk7n47U5tH3k8T25Lo
IwKJO6NP92sJgJl892rMg5+QuB382r2YjM+BdU4+OcOQuOnyJNTvJpixMm5l
wV6QuH4pZeI7qX/3o3KWzgdIFAYtFxIj728LPfWslfSn4Ez+IcteMDcr9Vbq
2RCvGt/xgzzf8PzE1yLSnwKW7OlL5PvAnaVfHpH6C9qmi6pjwfTXcQ/e2ErK
q7256fMwmOw3HPHc05C4sXzp2ruk/56J7TELsiFxSzBoviTpD8OyPshjGhJF
dgE/Bclz569WoSkjkCieVOJ/lwbT7pyG6evjkLivlHR2P+kf3PZvEHGFRFlB
Qe8rgGkluPZG5XZIVFyPdWWR/pkWPy4Mq4VE9cJ/o8KkfIOQrDmmEpB4MWPx
8/WkfboLBEIkEiFRP+pWm0PK09bPvTlWBYkW++wvc0h56isfDd53JvP3W+12
HXmu4uoSkZgCiV7pJ7mHSDzJ85mZaxXI/B9MMPYg78tubrij4kbigx/0KI+0
VyKuRpktColpo+1SJ8nzmflaGnNHICmkf8Z9qALufx+kbpzwgaR4UkOKrxrc
fzXs8NJRgOSCQE+bLgbcv0++8FsxAUn7/MA5H8j7Xe6nt6t5Q9L92tEXTZvh
3hayYPquDCR5UgXPZmTBvWmfXpXdbkhGTp2VSLkJ92e3BwJ+S0PyCvt9y9th
uBerig1mr4Dk3UChgY+kvpsW/5KXPoFkdcPw363k+TXPhOnPVEj2PZs74zIp
72KaV77zXEhpYXrbXeJUCdUJg+eQMmV8HDxK6k/Sf61mF0ryxeMt996S8va7
Lc19cB9SG6o4e7sa4b77WMksv2FI3WW8nzjtD/cgrYhnPtchVRvo/HCuANwD
nFcnNH6DVE/HktdN5Hve5vvKGoKQFho5U+mSBneP8st/WvZB2nDVJGezD9wR
eGXp5kRIW9fev1izE+5WaX0KJuch7XjwQvhZwN2srNF+6Buk/Y+8zPAl9evP
f54ZFAXp9HfeYdcs4K7YzPWyE4WMQELYPkosGKObNZ8XDkBG2pWqtHISjG+w
OXV6P2TUXLf8+yQCxoAMdWf1fMhg4smaQxVgdJfIDw0IQWb/UOlBU2kwXoiJ
8WWuQVZ+7XwbMQswsvrSkqXtIbv0utNxy2EwzlQuvEAtg6yNYYpnmwEYJ7OL
Hn61g2xgr/YrLwUwDgX9SJrzHrJ335r8/kK+3zE9zLHvhtx6JoOxnXzvxl5T
e9YFclEqCiuvZ4HhTJsxPlMBcsdVz8uJ9YJhZ11RMfcT5J48rfe9SdpnpZl1
TM0cczXu6YlNpIGh/W/e3kcTmDskpLz1sBrc/nRtGPFqx/xr6ps1jBXgxt8c
K74jFvNruqtSq6Xh5mXXGn7gIea/fzkvJ4jYRXVH8pyDkFc2Oy1VGAu3Fc3Z
XUNPIJ/qnNUdwYDbfM6XE4eOQyFqA2rn+cC1rpv9yN0cSjFrm2MXSsPV5sGP
DTc/Qeni/L6W1ky4mvas2zgEKD35RbvkKAJX/Vmbw6YaoTybLq4oTqzsyxMp
soVyus69geU6cJlUq93Bew2Vm/enDXhpcLltIBNeewkLZeaFu5P166LjX7Kr
0hALzd+VHfEQgYua8Mn1rX1Y6NfRay82DBf5GytTk4SwsNDjxBWmAlxmi3zR
XZwNNe3l0j3U/aB/fDtZUsmB2vOQeDHpLtBzpJ/rPEiBhlry75e+vaBrXP7l
+2EjNMzu00wGnoGudLXL3Jo8p/+53j2aBbrszeeJ1bbQ2PXs8l+5adAFq2tv
tapCoyVo7pGTXND65l4WUe6G5uHKzbPeZIGW4xA1nqeFRdKfpjPQAtoSqdN6
H7WxSPd7B0fEBzS1Zv1zC9ZjkYMsTZA5CJrC6Qvl6vuwKCq7TbmAWMR0SVcL
C4u+/rJMzjoO58+nFJMu1UK7boOm5OtNcL68IE7MVRY62fRcB14wnJcYzMi6
+RQ6j/dZ5Xt3w1k9ck787D/Q6amfNGGugLNimZXD93YsUSluvbhrEs6ivou2
XiPOuFknG50Mp6/VzNqPFCxN93meNW8+nG4E/7t2LAt6p9l18Wdd4WQ5eHfv
m53Qux9pntvwBk7GJiM14EPvTbaRi0EJnPT2iYqd74G+/OqGw1d3wmmhVrPK
E03on9gXND/dB05Cp/+IxE1g2cnZfww2VsCxkaJw7fdBGHgc3Z0emgzHDYfX
NWRchMG6yL+U5lQ4rmMZOUTXwmDbWu34pX1w9FsoEXp/FQwy+P4Xb2XA0b1i
JGXjHBh0tvGjvT7C0dI0i3lECIbrq673GAnDUaSvxuFxO4z2p5rGH18Ph2vc
SsEuARhl0oQvr1SAQ67+0Jud82BUMNf0fpcWHC4ISfz6GwWj5tornbGBcEgv
N+EXasBYs75xrs1uOOzeQu3QDIFxzSK3KG8TODhXV31yGILpXIlrnUdOw/77
CuPFsk0wXcK61PnnCOwHCjpiuLthanO5ZzLlIuw/aGW36VTBNGTr0iROOuzb
NS/6bCb30/KzY8LHv8G+kh9cqqIGs03Wf8W1SmGf2bA44NELmLcU/M1bYA57
h5MFNCVzmH+VSdF13Qh725rYYvshWMzY9+HbxCTsV/5e36VoBotlCQKh8y/A
3iRyo29eHCySlNubTd/CXj07ZKk0D5aIXiE2oQ676fE6n3mdWHFvYVVG8HHY
3d2s+SL9FlY0/A39EOIBuyIKL+9JLLnv9w+ZbDCH3Q3lUt3UrbCSf7dz7wMq
7PI6u2gGa2C1079ukYMM7E6eqn18wwrWVqeUnTjKsNshHlsp44OVL34+rHjJ
g51VXf7hY7VY+f7cdbcN4rCziBN8kC2LlVNus/9dZMLOdMXrzRsGYbOk8beA
2gDslt3vi/8QDpsk978Cnt2wUx86o+DwC6ucnXbJub2B3Rxdwwy9CKwKyIgb
O9oPO2Ht4fZxaazaPSxS9P0n7GYu1lwpNIZV1yoOzw5RB/WPSU/MxweA8PcG
q+OXQf1x4PLrv1eADWKpcb3ZoHb8nhxzVAe2J1T1fuwH9Y1N/jtGBBA/m3rg
kRSorw882eFUDJxV0HjIWQdqo/ry/FYmUL9ri4BoOKjVh7oiVlditYmV2AuG
JKi3zCpV55jDdmYFY8f7DaCm1PV7GzyFraygx0OF5aAmhXbUCIvCVs35hteS
JaAelG6tfx4IW+tvkUcTAWpc0IfnM4Zguz2O/ef9A1B3MbWj5c7C9ktXWVSC
K6jB806p/DKE7a/9vRcsSX/WC9k/PRcLiohxxGK7LFDXTvSIqhAvyn7/pe89
qPyhmgOG7qD4N2nMvaMGqs9cw+ZWAVDeBLr3ZF0B1ckp4NllNVA+R45ZSciA
6nAga33cJlB+piil7xsD1a7m4smxd6DOfTH5d2MEqLZefVURF0B1P7UotPsF
qFY3FcYb9EF9uTnefKAd1OW2JRuUckHtHJDrn30VVP3nzdqVO0D9Grzqcyrp
r55nfMk+BdiJ7g6/Vh8H6pLdx1S8KmHn+M1bVkIDVM3f4gdD3GH3dF6Sf+4B
UBWbvNxKfsDu9ReLBapk/BSKjQ03XoPdh6qyv4E6oMqf6XwVFAp7wRSXYvG9
oM6LjD+m2A17G7+rh9lGoMowmzjvrGDvErBkej75Xtrjdna/LOy5GxPj5zFA
lfKhhpXXw373kc+m5h9AlQjd1BweA/u7C52sDnwEdU5FFC4Iw77GvSfpSzeo
It2JOkZdsH+dzNvSNEosoMNuVob9mMRczdMkfoRdFQezxeBg6Jska5sO6sy5
vnMMkuBQKBVUKBIIyh/7T6wjwnAoyxo0/V4ByvTZPeWOPDi8tAjyHCoC5fd4
0Md2kpe+7qJe1BUBZeqW8fnF5nBcantrPa8PlEmGeuDvQ3BcISRQtScVlIny
8ROzEuHoVEtvzRcmNvorayoJx5CNbxtmN5F51DitOjYIx/yxsT/ZSaCMLY65
mn4Gjvc+WYsWWYIyenNHiYsdHJ+93V+85wuxdUz0dkM49ner/FAkcTHCu+a9
JheOk5/Ddp0ncfFjpLpLPxROIj8fp/59Q5z8dtaOs3Basni7uKoFKMOVQ/Xr
npF9w7HNsnyIeN3bsw1dcHLavDKmmkEsUhLmJASnkFdKGUnLQPnuKyV7vQZO
VzsXrMrxBuWbcn105GI4lXbEMqKOgTLU8vYT2V+cXvQUGs+IIU5LV3GcgtOX
30Hl23OJpV7LiY/B6bfMeKyCPCiDzb6vHnrDWWyZ66o4CvGpcN+FpnDW3el/
7KE0sb5FYO8xOFvlKc2wJuP/derdlXAunGnt5xec30BcO9toniucubKDlU/J
+1/PZdeaOsM5lDmrYrkWccRtC+8COO892d/xiIzXV2d902W9cD707sSrq8PE
WlLbzq6Cc2EiXV1aAZQv3WMhz+hwfviB9VzXgbh80G/tazjX2y8aPNdLnG2m
wB6Dc3dhufKvT8SJL7Ve7oPzd+WF3bZ6xJuvzFlC2vsv1eFmFanvC/spxToW
NOnZZsLjrcQO6k4GS8i54sAXZ0cynl9MbyVlnAHNUHRth0gCsXbExu1yoK0+
fknMTJNY0c/VgQIaUytHh7uCWDI8WUQAtIDSkC0bSX+/zMoKX0Web/X8oZyW
CMrA368Os3eBFj+xwl06n3jK2UPBDbTj56mGC0h8DkzcrWssAi2XJtFw6+R/
1v+ymjwv/nPSNGA/8WRei7kHaDXFXfyVncTTKjcdboLWtrXH5lwNqW9G0pmO
S6D1m5+7L3CWWORzofll0H7NmH+5h8TvF1mD0aM9oM9pdHyTUEasyt8xt4qc
03KNxfr/e740zOIHC3TdmOafOyWJLVnGG8+Abu2/dNXv/+ws6dt/HXQXe5P4
gOvE3BOZf+aA7mf4w/XCm//Gt691jzfo4Zp8jZ1/iRNGfsTfBz1WaW8E34n4
fNmTY6T8o/IOOZTLxPeslI8ngH5JsVx64wfi5qCn311Ar1p+rcj2HJl/ySId
PV/QX1NUWefJevy6rJo59A/0T1yTWasKiBmhjwYN4SJywbFWp5E4M0BIwQsu
is9tW0eOED/K1uitgcvSyfbu6/7En/wlbW/CxSW4Vec9idfBFcYntPbAxe+K
Wf9SEv+D61c67PwEl/DvumevjBIfyx+zug2X9JSnhurFxCOH9A/+hsub2TEp
f06Q9VL+IjGdnKu/fF+/c1sa8VS79bdsuPx5W71Y/CdZf+ZOk11z4apZ11Fg
XUt8Z3mYsR9cw6cmNM6S+r8/VDJJc4bbnAM691T9SH6Y2TVvqgEMtdNlF26S
/DKx+HDRTBYYS7ckF46S+JiImpKWjgPDhGYTok3ifaLlxlJbcg9ynO244gDJ
X5NxDT3fdoIRfnH3v11bQfnV+yPlXAwY5ezmh1OB/+XHob9qgnD3fxxpHaMF
6oxWzz6aGdw32ETcnyb7seDCQ7XbT8N968NIhthb4mAZ1aRAuCc8DjurkEn8
87NTuyncC3pv8OyvgyokJv0kMgnuJWErr5uQ/UjI5VeFwwy4l/++7GB2lvjI
7+tbv8K9WXXCfRnJ57NkDLqFmsm9fcdYvCyP5PfZN1NPniH3fNmnK3zJ/iVs
e7MWvWCK33AqYZP9U3hv5pKzbWAuHHJY6H+DeEjIbe5RMO33xq69MBvU2eWF
jOgRMBlay7z3thD/WO3p2Aembx23scKT7Cfqh4deC4IZpqWRkU36JxK94lrZ
CTCPvb8ofWEV2Y8WO2eIR4F57kS2kc1+Ylcx8fUaYF52Gul2m0+81TdgWyiY
pSX+NpsEie+nnBcdBbNq0+Z9f4SJOwIvT5L36xcXhcucIP51v2tWDZjvzhVX
Hif1iRo/7FwSBuZXdpDdnhhi13Vr/faDOa6wPHeE7K+iQRFpqfvA/Ns2u17w
G3F03+jWZniInOzPZAUSH79juN4aHrLeL15ZBRPn9wjl0+GhonjZ7DnZ30Uf
+FvfeQiPRV3bd3aWEr80fpRyFh7Lswwtl6cSd3ru/ycHD8t1jWJb9Ij7H18U
mA0PylLaNrcfxGORll/84UEfPvPt6B7ivyGHG3/Dw+vu/XeLPoEqJnzux3M7
ePjHnLti/YpYQqLJLAoeGxxXneAsIJYpLpq7Dx6RMhmftpD2is1NN7B1g0dU
5/mGURbxvAt/aofhcTCPvuP70/+ed/abiMLj6JbMiSUkPsRkbVvKPsHjzMq9
voZO/5X/6vHNKXjkzvl2Nua/72cfqLnaB4/rrZ9vHyHzI/qPO7erDR73cvgx
02S+RcfdJ7x3w+NJhEvXeQPigXXNjEXweImrx3KE/ut/us568rz1veqaPc3E
L8IjDE/B4138n9TCeuK74id8JuExqI3tF4yJL66vK9sPj5/POteOHSFO2hNl
4QHWjI2VaVUixOGOerONwBKX/Kb9rIyY+SJJSxUsdc/uDy0DxLKf642XgaX7
64h0qAWJh+/R7aa2YJmd8yx4Rr6f87yy3Q9g0T78OuF6iHiH+wPp+2B5JVZs
aLMids4UMvoB1hq9zVW++cTKB2XZoWBt3+q/vegRid8SrnzZHbD2zU/8RPvP
saj+qAdWyv2w2b3kXCniUHv5cAZYWX8tp5zJfM9uaKZ9rQXrWpbYjlBV4jTG
gjZTsEpWh/y7fZzYdau9jSFYtXEXZowWkvVVeT3T8jVYrRq8mgPTxLufmbrL
gtX7eLeeAGmP8PIU8RAOWON/zozqk3iYlS5jY/AHnmqhhp1nosh6t6IlFsXB
U3fWIX9XMl8ze9rTT66Ap+m5vtvxZL3PjFuoL34Dns613nna5HwrWN552z8H
ntvkf/NzE0g+Utt0uUgBnjGX+7QEn4MqUCSe8TgCnslm6ypCTYgpe7WCP8Hz
gtvMpBozUP7xei9VPoLn8zDG7iEqOQ/uWnm+ngvP5uF8Bx45t09PfTzyygee
3RGmcTH/nQ93H1CNZ8JzNPzh84QBcj7c+vhi/WV4qXpoPrYg/uX6puPFO3ht
vmnMcdUg57vCNeOp48T/chYL7SPOL8/RH4PXFre5fiEkv4/lqIweCiQeGpUa
qCI+3Rr5+Da8tupe2cOcIE60E8y9C69teVP+eyKJ10r7KhyH1+5zus+vbSNW
8Pf28CMeTOrdd5BY7vYKyy/w2mP12Z96gFhqZnlxI3FH1mlLcl4am5V7+4o0
vKIUxMa3kvPf6MjHFaqn4BWTXmPac4m4jtnlGEr8XunVsgjiZ+e/xxjAK9Zw
U8ucYOLKL3mW34kb50mL7SUujf27g7wfJ8H2awPx5SuckhvE3Ksmqt3El0YO
3XpGfO3XZtgQn7dac0URXvHOJ1UqjIiP1048I/2NP9V36Mcd4jS5+1IaxAMG
a/PIeWI0hbMgVQte+y32Zj0n/RtNuKTDavn//wXU////Alz/B9NjcHE=
      "]]}}, {
    CircleBox[{22, 59}, 58.5], 
    CircleBox[{22, 59}, NCache[Rational[9, 5], 1.8]], 
    CircleBox[{48.55844423476349, 111.12388166501952`}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{209.25695036926845`, 90.63022103207092}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{95.18085033551493, 105.17818999990479`}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{87.62900371931076, -42.0598034374236}, NCache[
     Rational[9, 5], 1.8]], 
    LineBox[{{22, 59}, {87.62900371931076, -42.0598034374236}}], 
    LineBox[{{22, 59}, {48.55844423476349, 111.12388166501952`}}], 
    LineBox[{{87.62900371931076, -42.0598034374236}, {209.25695036926845`, 
     90.63022103207092}}], 
    LineBox[{{48.55844423476349, 111.12388166501952`}, {209.25695036926845`, 
     90.63022103207092}, {95.18085033551493, 105.17818999990479`}, {
     48.55844423476349, 111.12388166501952`}}], InsetBox["A0", {28, 53}], 
    InsetBox["A", {54.55844423476349, 117.12388166501952`}], 
    InsetBox["B", {215.25695036926845`, 96.63022103207092}], 
    InsetBox["K", {101.18085033551493`, 111.17818999990479`}], 
    InsetBox["B0", {93.62900371931076, -48.0598034374236}]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 3)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.467463022695632*^9, 3.467466439507635*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt3Hc81d8fB3BJkj0qu6ykUPaI9Mq95r24rmvd4UoJRUraGVEyStKgrYxU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      "]]}}, {
    CircleBox[{22, 59}, 58.5], 
    CircleBox[{22, 59}, NCache[Rational[9, 5], 1.8]], 
    CircleBox[{18.93834655978778, 117.41982778314258`}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{180.8450699243537, 111.92319887535459`}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{65.91128481987789, 115.82512680372261`}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{87.62900371931076, -42.0598034374236}, NCache[
     Rational[9, 5], 1.8]], 
    LineBox[{{22, 59}, {87.62900371931076, -42.0598034374236}}], 
    LineBox[{{22, 59}, {18.93834655978778, 117.41982778314258`}}], 
    LineBox[{{87.62900371931076, -42.0598034374236}, {180.8450699243537, 
     111.92319887535459`}}], 
    LineBox[{{18.93834655978778, 117.41982778314258`}, {180.8450699243537, 
     111.92319887535459`}, {65.91128481987789, 115.82512680372261`}, {
     18.93834655978778, 117.41982778314258`}}], InsetBox["A0", {28, 53}], 
    InsetBox["A", {24.93834655978778, 123.41982778314258`}], 
    InsetBox["B", {186.8450699243537, 117.92319887535459`}], 
    InsetBox["K", {71.91128481987789, 121.82512680372261`}], 
    InsetBox["B0", {93.62900371931076, -48.0598034374236}]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 3)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.467463022695632*^9, 3.46746643962901*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt3Hc81d8fB3BJkj0qu6ykUPaI9Mq95r24rmvd4UoJRUraGVEyStKgrYxU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      "]]}}, {
    CircleBox[{22, 59}, 58.5], 
    CircleBox[{22, 59}, NCache[Rational[9, 5], 1.8]], 
    CircleBox[{-9.861383548379084, 108.06222822480731`}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{151.09983900726962`, 126.37847329280419`}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{36.83724274863012, 113.37620055934961`}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{87.62900371931076, -42.0598034374236}, NCache[
     Rational[9, 5], 1.8]], 
    LineBox[{{22, 59}, {87.62900371931076, -42.0598034374236}}], 
    LineBox[{{22, 59}, {-9.861383548379084, 108.06222822480731`}}], 
    LineBox[{{87.62900371931076, -42.0598034374236}, {151.09983900726962`, 
     126.37847329280419`}}], 
    LineBox[{{-9.861383548379084, 108.06222822480731`}, {151.09983900726962`, 
     126.37847329280419`}, {36.83724274863012, 
     113.37620055934961`}, {-9.861383548379084, 108.06222822480731`}}], 
    InsetBox["A0", {28, 53}], 
    InsetBox["A", {-3.8613835483790844`, 114.06222822480731`}], 
    InsetBox["B", {157.09983900726962`, 132.3784732928042}], 
    InsetBox["K", {42.83724274863012, 119.37620055934961`}], 
    InsetBox["B0", {93.62900371931076, -48.0598034374236}]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 3)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.467463022695632*^9, 3.467466439711854*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt3Hc81d8fB3BJkj0qu6ykUPaI9Mq95r24rmvd4UoJRUraGVEyStKgrYxU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      "]]}}, {
    CircleBox[{22, 59}, 58.5], 
    CircleBox[{22, 59}, NCache[Rational[9, 5], 1.8]], 
    CircleBox[{-30.123881665019518`, 85.5584442347635}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{124.42002347717053`, 134.1401422639777}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{14.7129303206776, 99.65313440373306}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{87.62900371931076, -42.0598034374236}, NCache[
     Rational[9, 5], 1.8]], 
    LineBox[{{22, 59}, {87.62900371931076, -42.0598034374236}}], 
    LineBox[{{22, 59}, {-30.123881665019518`, 85.5584442347635}}], 
    LineBox[{{87.62900371931076, -42.0598034374236}, {124.42002347717053`, 
     134.1401422639777}}], 
    LineBox[{{-30.123881665019518`, 85.5584442347635}, {124.42002347717053`, 
     134.1401422639777}, {14.7129303206776, 
     99.65313440373306}, {-30.123881665019518`, 85.5584442347635}}], 
    InsetBox["A0", {28, 53}], 
    InsetBox["A", {-24.123881665019518`, 91.5584442347635}], 
    InsetBox["B", {130.42002347717053`, 140.1401422639777}], 
    InsetBox["K", {20.7129303206776, 105.65313440373306`}], 
    InsetBox["B0", {93.62900371931076, -48.0598034374236}]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 3)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.467463022695632*^9, 3.467466439795192*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt3Hc81d8fB3BJkj0qu6ykUPaI9Mq95r24rmvd4UoJRUraGVEyStKgrYxU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      "]]}}, {
    CircleBox[{22, 59}, 58.5], 
    CircleBox[{22, 59}, NCache[Rational[9, 5], 1.8]], 
    CircleBox[{-36.41982778314257, 55.93834655978778}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{103.71321636454906`, 137.22013995720926`}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{4.2360553955087, 79.52010143434833}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{87.62900371931076, -42.0598034374236}, NCache[
     Rational[9, 5], 1.8]], 
    LineBox[{{22, 59}, {87.62900371931076, -42.0598034374236}}], 
    LineBox[{{22, 59}, {-36.41982778314257, 55.93834655978778}}], 
    LineBox[{{87.62900371931076, -42.0598034374236}, {103.71321636454906`, 
     137.22013995720926`}}], 
    LineBox[{{-36.41982778314257, 55.93834655978778}, {103.71321636454906`, 
     137.22013995720926`}, {4.2360553955087, 
     79.52010143434833}, {-36.41982778314257, 55.93834655978778}}], 
    InsetBox["A0", {28, 53}], 
    InsetBox["A", {-30.419827783142573`, 61.93834655978778}], 
    InsetBox["B", {109.71321636454906`, 143.22013995720926`}], 
    InsetBox["K", {10.2360553955087, 85.52010143434833}], 
    InsetBox["B0", {93.62900371931076, -48.0598034374236}]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 3)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.467463022695632*^9, 3.467466439879202*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt3Hc81d8fB3BJkj0qu6ykUPaI9Mq95r24rmvd4UoJRUraGVEyStKgrYxU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      "]]}}, {
    CircleBox[{22, 59}, 58.5], 
    CircleBox[{22, 59}, NCache[Rational[9, 5], 1.8]], 
    CircleBox[{-27.062228224807306`, 27.138616451620916`}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{91.1521969545891, 137.90571300788568`}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{7.234549450696598, 59.27474940312983}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{87.62900371931076, -42.0598034374236}, NCache[
     Rational[9, 5], 1.8]], 
    LineBox[{{22, 59}, {87.62900371931076, -42.0598034374236}}], 
    LineBox[{{22, 59}, {-27.062228224807306`, 27.138616451620916`}}], 
    LineBox[{{87.62900371931076, -42.0598034374236}, {91.1521969545891, 
     137.90571300788568`}}], 
    LineBox[{{-27.062228224807306`, 27.138616451620916`}, {91.1521969545891, 
     137.90571300788568`}, {7.234549450696598, 
     59.27474940312983}, {-27.062228224807306`, 27.138616451620916`}}], 
    InsetBox["A0", {28, 53}], 
    InsetBox["A", {-21.062228224807306`, 33.13861645162092}], 
    InsetBox["B", {97.1521969545891, 143.90571300788568`}], 
    InsetBox["K", {13.234549450696598`, 65.27474940312983}], 
    InsetBox["B0", {93.62900371931076, -48.0598034374236}]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 3)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.467463022695632*^9, 3.467466439995605*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt3Hc81d8fB3BJkj0qu6ykUPaI9Mq95r24rmvd4UoJRUraGVEyStKgrYxU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      "]]}}, {
    CircleBox[{22, 59}, 58.5], 
    CircleBox[{22, 59}, NCache[Rational[9, 5], 1.8]], 
    CircleBox[{-4.558444234763492, 6.876118334980482}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{90.69410382803736, 137.91409789641838`}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{23.076554277283666`, 44.893309936138394`}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{87.62900371931076, -42.0598034374236}, NCache[
     Rational[9, 5], 1.8]], 
    LineBox[{{22, 59}, {87.62900371931076, -42.0598034374236}}], 
    LineBox[{{22, 59}, {-4.558444234763492, 6.876118334980482}}], 
    LineBox[{{87.62900371931076, -42.0598034374236}, {90.69410382803736, 
     137.91409789641838`}}], 
    LineBox[{{-4.558444234763492, 6.876118334980482}, {90.69410382803736, 
     137.91409789641838`}, {23.076554277283666`, 
     44.893309936138394`}, {-4.558444234763492, 6.876118334980482}}], 
    InsetBox["A0", {28, 53}], 
    InsetBox["A", {1.441555765236508, 12.876118334980482`}], 
    InsetBox["B", {96.69410382803736, 143.91409789641838`}], 
    InsetBox["K", {29.076554277283666`, 50.893309936138394`}], 
    InsetBox["B0", {93.62900371931076, -48.0598034374236}]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 3)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.467463022695632*^9, 3.467466440094239*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt3Hc81d8fB3BJkj0qu6ykUPaI9Mq95r24rmvd4UoJRUraGVEyStKgrYxU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      "]]}}, {
    CircleBox[{22, 59}, 58.5], 
    CircleBox[{22, 59}, NCache[Rational[9, 5], 1.8]], 
    CircleBox[{25.06165344021222, 0.5801722168574273}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{113.97089567470142`, 136.00227766972995`}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{50.85631013787267, 39.869301576641426`}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{87.62900371931076, -42.0598034374236}, NCache[
     Rational[9, 5], 1.8]], 
    LineBox[{{22, 59}, {87.62900371931076, -42.0598034374236}}], 
    LineBox[{{22, 59}, {25.06165344021222, 0.5801722168574273}}], 
    LineBox[{{87.62900371931076, -42.0598034374236}, {113.97089567470142`, 
     136.00227766972995`}}], 
    LineBox[{{25.06165344021222, 0.5801722168574273}, {113.97089567470142`, 
     136.00227766972995`}, {50.85631013787267, 39.869301576641426`}, {
     25.06165344021222, 0.5801722168574273}}], InsetBox["A0", {28, 53}], 
    InsetBox["A", {31.06165344021222, 6.580172216857427}], 
    InsetBox["B", {119.97089567470142`, 142.00227766972995`}], 
    InsetBox["K", {56.85631013787267, 45.869301576641426`}], 
    InsetBox["B0", {93.62900371931076, -48.0598034374236}]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 3)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.467463022695632*^9, 3.467466440194631*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN03tIk1EUAPC5NC1hOsPkm0yZzqI0DBNNy2YpWD7xRQprhvlIRTMZpIHo
RHuoiwix0XwrlPlYummEmaZfCmY+0tRyj1xrTWdqkMo0XQV17j1wuPz+Oedy
DifqWiIrmUKhUP9k+N/3TOxi/6QuOZjyLziehCqbEWAKDiSkVaLaE+AYorpz
9l0IOIl40LuZdBHMJ4QBt90V4GKi9FaEbR24grh7WGohADf9WJPUx8eBJQ5B
XIHREiwrG9StRLqAX/wUcXzGboD7TEyUdJkdeOD0+GiAuhtMLsfbV6cPgIcz
26z8Dq2DR1zsrVsMVPBoe3T3ZaMXePzo0Jhn8Sh4YqXZoL/vCH5//INStakH
T92jjfQsNYGnNZrVx0waeIZdl9KVVg6eLbiqafHfAM8NHpSRHnzwJ9ZkGdmu
As/fPCKeTt8Gy3tSds3PuoKVdh2prIYgsIq74JTARPP6HDZrGbvshrxFWqxZ
HQAvVDlLxH1o/+qQfR97PDOQN17VJV5oAX+p1Foz9GiemsCKPUHRXchaWW3J
+QLw15LGuWAFC6z1ICqKvX2Rp0wM4w5c8DdBtlo4gurr2FF8nqkImaQ2dCnR
/xev+8QI8s3ASzZqCa+ZgjxgI5Q8ygHrs+gWd1x7wcu0IrecYDryy7ypiWNy
8Heehs2peYa8y6R7SS6BV57KBfUlheDVUJqYqWtD3ho+SaNHYpbbU81KMa/t
rBtI5G3GoELthTkrok3KQP5lmxoWo0beuVJZLuJjzs0rLMf67wi5/EIt5udO
3DR0f6u7+9vdfP0wd7x5K9+LeehJ3wQH83yZlMxFNppFiluXMMcpMvLHMGf2
J+SYYy5qjE7xx9yadiq8E/PrUPdzeswz7s7ebMx6GztXHmbjuqXjw//+DVMA
RmY=
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt3Hc81d8fB3BJkj0qu6ykUPaI9Mq95r24rmvd4UoJRUraGVEyStKgrYxU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      "]]}}, {
    CircleBox[{22, 59}, 58.5], 
    CircleBox[{22, 59}, NCache[Rational[9, 5], 1.8]], 
    CircleBox[{53.86138354837908, 9.937771775192694}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{178.66826523116958`, 113.22011433488649`}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{90.0707874933862, 39.902402023992735`}, NCache[
     Rational[9, 5], 1.8]], 
    CircleBox[{87.62900371931076, -42.0598034374236}, NCache[
     Rational[9, 5], 1.8]], 
    LineBox[{{22, 59}, {87.62900371931076, -42.0598034374236}}], 
    LineBox[{{22, 59}, {53.86138354837908, 9.937771775192694}}], 
    LineBox[{{87.62900371931076, -42.0598034374236}, {178.66826523116958`, 
     113.22011433488649`}}], 
    LineBox[{{53.86138354837908, 9.937771775192694}, {178.66826523116958`, 
     113.22011433488649`}, {90.0707874933862, 39.902402023992735`}, {
     53.86138354837908, 9.937771775192694}}], InsetBox["A0", {28, 53}], 
    InsetBox["A", {59.86138354837908, 15.937771775192694`}], 
    InsetBox["B", {184.66826523116958`, 119.22011433488649`}], 
    InsetBox["K", {96.0707874933862, 45.902402023992735`}], 
    InsetBox["B0", {93.62900371931076, -48.0598034374236}]}},
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotLabel->FormBox["\"Coupling Path par set 3)\"", TraditionalForm],
  PlotRange->{{-100, 300}, {-150, 200}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.467463022695632*^9, 3.467466440278201*^9}]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{967, 928},
WindowMargins->{{Automatic, 344}, {Automatic, 0}},
Magnification->1,
FrontEndVersion->"6.0 for Mac OS X PowerPC (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 166, 3, 46, "Subtitle"],
Cell[759, 28, 204, 5, 41, "Text"],
Cell[CellGroupData[{
Cell[988, 37, 63, 0, 34, "Subsection"],
Cell[1054, 39, 132, 3, 27, "Input"],
Cell[CellGroupData[{
Cell[1211, 46, 375, 9, 79, "Input"],
Cell[1589, 57, 360, 10, 48, "Output"],
Cell[1952, 69, 327, 9, 38, "Output"],
Cell[2282, 80, 680, 19, 59, "Output"],
Cell[2965, 101, 950, 27, 59, "Output"],
Cell[3918, 130, 948, 27, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4903, 162, 1126, 36, 73, "Input"],
Cell[6032, 200, 872, 29, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6941, 234, 1032, 34, 73, "Input"],
Cell[7976, 270, 713, 23, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8726, 298, 374, 12, 27, "Input"],
Cell[9103, 312, 394, 12, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9534, 329, 409, 13, 27, "Input"],
Cell[9946, 344, 404, 12, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10387, 361, 230, 6, 27, "Input"],
Cell[10620, 369, 289, 7, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10946, 381, 513, 16, 27, "Input"],
Cell[11462, 399, 515, 15, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12014, 419, 653, 18, 43, "Input"],
Cell[12670, 439, 359, 9, 27, "Output"],
Cell[13032, 450, 358, 9, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[13439, 465, 262, 5, 67, "Section"],
Cell[CellGroupData[{
Cell[13726, 474, 157, 4, 49, "Subsection"],
Cell[CellGroupData[{
Cell[13908, 482, 597, 15, 27, "Input"],
Cell[14508, 499, 589, 15, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15134, 519, 1554, 41, 73, "Input"],
Cell[16691, 562, 15570, 260, 362, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32298, 827, 94, 2, 25, "Subsubsection"],
Cell[CellGroupData[{
Cell[32417, 833, 52, 1, 27, "Input"],
Cell[32472, 836, 589, 15, 27, "Output"]
}, Open  ]],
Cell[33076, 854, 80, 2, 27, "Input"],
Cell[33159, 858, 3457, 107, 208, "Input"],
Cell[CellGroupData[{
Cell[36641, 969, 5437, 137, 119, "Input"],
Cell[CellGroupData[{
Cell[42103, 1110, 18286, 310, 326, "Print"],
Cell[60392, 1422, 18300, 310, 326, "Print"],
Cell[78695, 1734, 18305, 311, 326, "Print"],
Cell[97003, 2047, 18295, 310, 326, "Print"],
Cell[115301, 2359, 18776, 319, 326, "Print"],
Cell[134080, 2680, 18319, 311, 326, "Print"],
Cell[152402, 2993, 18307, 311, 326, "Print"],
Cell[170712, 3306, 18304, 311, 326, "Print"],
Cell[189019, 3619, 18307, 311, 326, "Print"],
Cell[207329, 3932, 18341, 311, 326, "Print"],
Cell[225673, 4245, 18307, 311, 326, "Print"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[244053, 4564, 247, 7, 64, "Subsection"],
Cell[CellGroupData[{
Cell[244325, 4575, 95, 1, 27, "Input"],
Cell[244423, 4578, 592, 15, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[245052, 4598, 636, 16, 27, "Input"],
Cell[245691, 4616, 667, 16, 27, "Output"]
}, Open  ]],
Cell[246373, 4635, 1416, 40, 73, "Input"],
Cell[CellGroupData[{
Cell[247814, 4679, 167, 4, 27, "Input"],
Cell[247984, 4685, 36308, 601, 362, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[284329, 5291, 186, 4, 25, "Subsubsection"],
Cell[CellGroupData[{
Cell[284540, 5299, 53, 1, 27, "Input"],
Cell[284596, 5302, 624, 16, 27, "Output"]
}, Open  ]],
Cell[285235, 5321, 81, 2, 27, "Input"],
Cell[285319, 5325, 3454, 107, 208, "Input"],
Cell[CellGroupData[{
Cell[288798, 5436, 5177, 132, 106, "Input"],
Cell[CellGroupData[{
Cell[294000, 5572, 24023, 407, 326, "Print"],
Cell[318026, 5981, 24023, 407, 326, "Print"],
Cell[342052, 6390, 24022, 407, 326, "Print"],
Cell[366077, 6799, 24023, 407, 326, "Print"],
Cell[390103, 7208, 24007, 407, 326, "Print"],
Cell[414113, 7617, 24001, 407, 326, "Print"],
Cell[438117, 8026, 24012, 407, 326, "Print"],
Cell[462132, 8435, 24007, 407, 326, "Print"],
Cell[486142, 8844, 24031, 407, 326, "Print"],
Cell[510176, 9253, 24007, 405, 326, "Print"],
Cell[534186, 9660, 24009, 405, 326, "Print"],
Cell[558198, 10067, 24007, 405, 326, "Print"],
Cell[582208, 10474, 24021, 407, 326, "Print"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[606302, 10889, 193, 5, 64, "Subsection"],
Cell[CellGroupData[{
Cell[606520, 10898, 690, 18, 27, "Input"],
Cell[607213, 10918, 568, 14, 27, "Output"]
}, Open  ]],
Cell[607796, 10935, 1415, 40, 73, "Input"],
Cell[CellGroupData[{
Cell[609236, 10979, 182, 4, 27, "Input"],
Cell[609421, 10985, 56931, 940, 362, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[666389, 11930, 165, 5, 25, "Subsubsection"],
Cell[CellGroupData[{
Cell[666579, 11939, 53, 1, 27, "Input"],
Cell[666635, 11942, 567, 14, 27, "Output"]
}, Open  ]],
Cell[667217, 11959, 80, 2, 27, "Input"],
Cell[667300, 11963, 3431, 106, 208, "Input"],
Cell[CellGroupData[{
Cell[670756, 12073, 5135, 131, 106, "Input"],
Cell[CellGroupData[{
Cell[675916, 12208, 23186, 388, 326, "Print"],
Cell[699105, 12598, 23185, 388, 326, "Print"],
Cell[722293, 12988, 23175, 388, 326, "Print"],
Cell[745471, 13378, 23168, 388, 326, "Print"],
Cell[768642, 13768, 23191, 388, 326, "Print"],
Cell[791836, 14158, 23188, 388, 326, "Print"],
Cell[815027, 14548, 23207, 389, 326, "Print"],
Cell[838237, 14939, 23187, 389, 326, "Print"],
Cell[861427, 15330, 23188, 389, 326, "Print"],
Cell[884618, 15721, 23199, 389, 326, "Print"],
Cell[907820, 16112, 23196, 389, 326, "Print"],
Cell[931019, 16503, 23191, 388, 326, "Print"],
Cell[954213, 16893, 23186, 388, 326, "Print"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
