(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     23113,        642]
NotebookOptionsPosition[     20728,        551]
NotebookOutlinePosition[     21121,        568]
CellTagsIndexPosition[     21078,        565]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["P3.03\tDead point construction via ALT", "Section"],

Cell["\<\
created 2009, Prof. Oskar Wallrapp, FK06, Munich University of Applied \
Sciences
updated 17.11.2009 - \
\>", "Text",
 CellChangeTimes->{{3.4674673047927027`*^9, 3.467467378523714*^9}}],

Cell[CellGroupData[{

Cell["\<\
1. Find r, l, e of an eccentric  sider-crank mechanism (VDI 2130)\
\>", "Subsection",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"phi0", ",", "s0", ",", "s", ",", "r", ",", "l", ",", "e"}], "]"}],
   ";"}]], "Input"],

Cell[CellGroupData[{

Cell["data = {phi0->130 Degree, s0->75, auxbeta->78 Degree}", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"phi0", "\[Rule]", 
    RowBox[{"130", " ", "\[Degree]"}]}], ",", 
   RowBox[{"s0", "\[Rule]", "75"}], ",", 
   RowBox[{"auxbeta", "\[Rule]", 
    RowBox[{"78", " ", "\[Degree]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.4668708199678717`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["gam = 1/2 phi0", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 FractionBox["phi0", "2"]], "Output",
 CellChangeTimes->{3.4668708200584583`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["rA  = s0 / (4 Sin[gam])", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", "s0", " ", 
  RowBox[{"Csc", "[", 
   FractionBox["phi0", "2"], "]"}]}]], "Output",
 CellChangeTimes->{3.46687082012939*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["rB  = rA / Cos[gam]", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", "s0", " ", 
  RowBox[{"Csc", "[", 
   FractionBox["phi0", "2"], "]"}], " ", 
  RowBox[{"Sec", "[", 
   FractionBox["phi0", "2"], "]"}]}]], "Output",
 CellChangeTimes->{3.4668708202139463`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["theta = 180 Degree - auxbeta - phi0/2", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "auxbeta"}], "+", 
  RowBox[{"180", " ", "\[Degree]"}], "-", 
  FractionBox["phi0", "2"]}]], "Output",
 CellChangeTimes->{3.466870820297175*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["r = 2 rA Cos[theta]", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "2"]}], " ", "s0", " ", 
  RowBox[{"Cos", "[", 
   RowBox[{"auxbeta", "+", 
    FractionBox["phi0", "2"]}], "]"}], " ", 
  RowBox[{"Csc", "[", 
   FractionBox["phi0", "2"], "]"}]}]], "Output",
 CellChangeTimes->{3.4668708203828287`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["l = 2 rB Cos[theta - gam] - r", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", "s0", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"auxbeta", "+", 
     FractionBox["phi0", "2"]}], "]"}], " ", 
   RowBox[{"Csc", "[", 
    FractionBox["phi0", "2"], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "s0", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"auxbeta", "+", "phi0"}], "]"}], " ", 
   RowBox[{"Csc", "[", 
    FractionBox["phi0", "2"], "]"}], " ", 
   RowBox[{"Sec", "[", 
    FractionBox["phi0", "2"], "]"}]}]}]], "Output",
 CellChangeTimes->{3.46687082046493*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["e  = (r+l) Cos[auxbeta]", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "2"]}], " ", "s0", " ", 
  RowBox[{"Cos", "[", "auxbeta", "]"}], " ", 
  RowBox[{"Cos", "[", 
   RowBox[{"auxbeta", "+", "phi0"}], "]"}], " ", 
  RowBox[{"Csc", "[", 
   FractionBox["phi0", "2"], "]"}], " ", 
  RowBox[{"Sec", "[", 
   FractionBox["phi0", "2"], "]"}]}]], "Output",
 CellChangeTimes->{3.466870820545741*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["data"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"phi0", "\[Rule]", 
    RowBox[{"130", " ", "\[Degree]"}]}], ",", 
   RowBox[{"s0", "\[Rule]", "75"}], ",", 
   RowBox[{"auxbeta", "\[Rule]", 
    RowBox[{"78", " ", "\[Degree]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.466870820616407*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
r = r/.data//N
l = l/.data//N
e = e/.data//N\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData["33.04487951570738`"], "Output",
 CellChangeTimes->{3.4668708206843147`*^9}],

Cell[BoxData["53.40058727052504`"], "Output",
 CellChangeTimes->{3.466870820693836*^9}],

Cell[BoxData["17.973023163056038`"], "Output",
 CellChangeTimes->{3.466870820697198*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["further results", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"r", "+", 
   RowBox[{"Abs", "[", "e", "]"}]}], "//", "N"}]], "Input"],

Cell[BoxData["51.01790267876342`"], "Output",
 CellChangeTimes->{3.4668708207668543`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"s0", "=", 
  RowBox[{
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"l", "+", "r"}], ")"}], "^", "2"}], " ", "-", 
     RowBox[{"e", "^", "2"}]}], "]"}], "-", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"l", "-", "r"}], ")"}], "^", "2"}], " ", "-", 
     RowBox[{"e", "^", "2"}]}], "]"}]}]}]], "Input"],

Cell[BoxData["75.`"], "Output",
 CellChangeTimes->{3.466870820833351*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"phi0", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"Pi", "-", 
      RowBox[{"ArcSin", "[", 
       RowBox[{"e", "/", 
        RowBox[{"(", 
         RowBox[{"l", "-", "r"}], ")"}]}], "]"}], "+", 
      RowBox[{"ArcSin", "[", 
       RowBox[{"e", "/", 
        RowBox[{"(", 
         RowBox[{"l", "+", "r"}], ")"}]}], "]"}]}], ")"}], "/", "Degree"}], "//",
    "N"}]}]], "Input"],

Cell[BoxData["130.00000000000003`"], "Output",
 CellChangeTimes->{3.466870820983568*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mymin", "=", 
  RowBox[{
   RowBox[{"ArcCos", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"e", "+", "r"}], ")"}], "/", "l"}], "]"}], "/", 
   "Degree"}]}]], "Input"],

Cell[BoxData["17.18011569608142`"], "Output",
 CellChangeTimes->{3.466870821067678*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"s", " ", "=", " ", 
  RowBox[{
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "phi", "]"}]}], " ", "+", " ", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"l", "^", "2"}], " ", "-", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"e", "+", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", "phi", "]"}]}]}], ")"}], "^", "2"}]}], 
    "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"33.04487951570738`", " ", 
   RowBox[{"Cos", "[", "phi", "]"}]}], "+", 
  SqrtBox[
   RowBox[{"2851.6227208369605`", "\[InvisibleSpace]", "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"17.973023163056038`", "\[InvisibleSpace]", "+", 
       RowBox[{"33.04487951570738`", " ", 
        RowBox[{"Sin", "[", "phi", "]"}]}]}], ")"}], "2"]}]]}]], "Output",
 CellChangeTimes->{3.4668708211329803`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"phi", "=", 
   RowBox[{"phiG", "*", "Degree"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{"s", ",", 
   RowBox[{"{", 
    RowBox[{"phiG", ",", 
     RowBox[{"-", "40"}], ",", "400"}], "}"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<phi(Degree)\>\"", ",", "None"}], "}"}]}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<s (phi)\>\""}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "40"}], ",", "400"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "100"}], "}"}]}], "}"}]}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "phi", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.466870811956603*^9, 3.466870815898432*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmQk0lF0YxxGyRSRbWTIzdsq+84gkaSzzTvY1ayliZpCSLURKRIVQVLKF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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"phi(Degree)\"", TraditionalForm], None},
  AxesOrigin->{0, 0},
  GridLines->Automatic,
  PlotLabel->FormBox["\"s (phi)\"", TraditionalForm],
  PlotRange->{{-40, 400}, {0, 100}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.466870821272291*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{878, 802},
WindowMargins->{{39, Automatic}, {-5, Automatic}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"6.0 for Mac OS X PowerPC (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 57, 0, 67, "Section"],
Cell[650, 25, 195, 5, 41, "Text"],
Cell[CellGroupData[{
Cell[870, 34, 127, 3, 34, "Subsection"],
Cell[1000, 39, 147, 4, 27, "Input"],
Cell[CellGroupData[{
Cell[1172, 47, 102, 1, 27, "Input"],
Cell[1277, 50, 297, 8, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1611, 63, 63, 1, 27, "Input"],
Cell[1677, 66, 95, 2, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1809, 73, 72, 1, 27, "Input"],
Cell[1884, 76, 178, 5, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2099, 86, 68, 1, 27, "Input"],
Cell[2170, 89, 246, 7, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2453, 101, 86, 1, 27, "Input"],
Cell[2542, 104, 183, 5, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2762, 114, 68, 1, 27, "Input"],
Cell[2833, 117, 296, 9, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3166, 131, 78, 1, 27, "Input"],
Cell[3247, 134, 558, 17, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3842, 156, 72, 1, 27, "Input"],
Cell[3917, 159, 382, 11, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4336, 175, 30, 0, 27, "Input"],
Cell[4369, 177, 295, 8, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4701, 190, 101, 5, 53, "Input"],
Cell[4805, 197, 89, 1, 27, "Output"],
Cell[4897, 200, 87, 1, 27, "Output"],
Cell[4987, 203, 88, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5112, 209, 40, 0, 25, "Subsubsection"],
Cell[CellGroupData[{
Cell[5177, 213, 104, 3, 27, "Input"],
Cell[5284, 218, 89, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5410, 224, 411, 14, 27, "Input"],
Cell[5824, 240, 73, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5934, 246, 419, 14, 27, "Input"],
Cell[6356, 262, 88, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6481, 268, 197, 7, 27, "Input"],
Cell[6681, 277, 87, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6805, 283, 397, 13, 27, "Input"],
Cell[7205, 298, 443, 11, 38, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7685, 314, 894, 25, 73, "Input"],
Cell[8582, 341, 12094, 204, 235, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
