(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     23188,        644]
NotebookOptionsPosition[     20803,        553]
NotebookOutlinePosition[     21196,        570]
CellTagsIndexPosition[     21153,        567]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["P3.04\tDead point construction via ALT", "Section"],

Cell["\<\
created 2009, Prof. Oskar Wallrapp, FK06, Munich University of Applied \
Sciences
updated 17.11.2009 - \
\>", "Text",
 CellChangeTimes->{{3.4674673047927027`*^9, 3.467467378523714*^9}}],

Cell[CellGroupData[{

Cell["\<\
1. Find r, l, e of an eccentric  sider-crank mechanism (VDI 2130)\
\>", "Subsection",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"phi0", ",", "s0", ",", "s", ",", "r", ",", "l", ",", "e"}], "]"}],
   ";"}]], "Input"],

Cell[CellGroupData[{

Cell["data = {phi0->158 Degree, s0->60, auxbeta->75 Degree}", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"phi0", "\[Rule]", 
    RowBox[{"158", " ", "\[Degree]"}]}], ",", 
   RowBox[{"s0", "\[Rule]", "60"}], ",", 
   RowBox[{"auxbeta", "\[Rule]", 
    RowBox[{"75", " ", "\[Degree]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.466870845745229*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["gam = 1/2 phi0", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 FractionBox["phi0", "2"]], "Output",
 CellChangeTimes->{3.4668708457921*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["rA  = s0 / (4 Sin[gam])", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", "s0", " ", 
  RowBox[{"Csc", "[", 
   FractionBox["phi0", "2"], "]"}]}]], "Output",
 CellChangeTimes->{3.466870845842054*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["rB  = rA / Cos[gam]", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", "s0", " ", 
  RowBox[{"Csc", "[", 
   FractionBox["phi0", "2"], "]"}], " ", 
  RowBox[{"Sec", "[", 
   FractionBox["phi0", "2"], "]"}]}]], "Output",
 CellChangeTimes->{3.466870845892612*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["theta = 180 Degree - auxbeta - phi0/2", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "auxbeta"}], "+", 
  RowBox[{"180", " ", "\[Degree]"}], "-", 
  FractionBox["phi0", "2"]}]], "Output",
 CellChangeTimes->{3.4668708459460907`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["r = 2 rA Cos[theta]", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "2"]}], " ", "s0", " ", 
  RowBox[{"Cos", "[", 
   RowBox[{"auxbeta", "+", 
    FractionBox["phi0", "2"]}], "]"}], " ", 
  RowBox[{"Csc", "[", 
   FractionBox["phi0", "2"], "]"}]}]], "Output",
 CellChangeTimes->{3.466870845994956*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["l = 2 rB Cos[theta - gam] - r", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", "s0", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"auxbeta", "+", 
     FractionBox["phi0", "2"]}], "]"}], " ", 
   RowBox[{"Csc", "[", 
    FractionBox["phi0", "2"], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "s0", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"auxbeta", "+", "phi0"}], "]"}], " ", 
   RowBox[{"Csc", "[", 
    FractionBox["phi0", "2"], "]"}], " ", 
   RowBox[{"Sec", "[", 
    FractionBox["phi0", "2"], "]"}]}]}]], "Output",
 CellChangeTimes->{3.466870846064262*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["e  = (r+l) Cos[auxbeta]", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "2"]}], " ", "s0", " ", 
  RowBox[{"Cos", "[", "auxbeta", "]"}], " ", 
  RowBox[{"Cos", "[", 
   RowBox[{"auxbeta", "+", "phi0"}], "]"}], " ", 
  RowBox[{"Csc", "[", 
   FractionBox["phi0", "2"], "]"}], " ", 
  RowBox[{"Sec", "[", 
   FractionBox["phi0", "2"], "]"}]}]], "Output",
 CellChangeTimes->{3.46687084613426*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["data"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"phi0", "\[Rule]", 
    RowBox[{"158", " ", "\[Degree]"}]}], ",", 
   RowBox[{"s0", "\[Rule]", "60"}], ",", 
   RowBox[{"auxbeta", "\[Rule]", 
    RowBox[{"75", " ", "\[Degree]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.466870846197444*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
r = r/.data//N
l = l/.data//N
e = e/.data//N\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData["27.46849500873934`"], "Output",
 CellChangeTimes->{3.466870846268251*^9}],

Cell[BoxData["68.92303152542526`"], "Output",
 CellChangeTimes->{3.466870846274137*^9}],

Cell[BoxData["24.947962853546766`"], "Output",
 CellChangeTimes->{3.466870846278573*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["further results", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"r", "+", 
   RowBox[{"Abs", "[", "e", "]"}]}], "//", "N"}]], "Input"],

Cell[BoxData["52.41645786228611`"], "Output",
 CellChangeTimes->{3.466870846350976*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"s0", "=", 
  RowBox[{
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"l", "+", "r"}], ")"}], "^", "2"}], " ", "-", 
     RowBox[{"e", "^", "2"}]}], "]"}], "-", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"l", "-", "r"}], ")"}], "^", "2"}], " ", "-", 
     RowBox[{"e", "^", "2"}]}], "]"}]}]}]], "Input"],

Cell[BoxData["60.00000000000001`"], "Output",
 CellChangeTimes->{3.4668708464191923`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"phi0", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"Pi", "-", 
      RowBox[{"ArcSin", "[", 
       RowBox[{"e", "/", 
        RowBox[{"(", 
         RowBox[{"l", "-", "r"}], ")"}]}], "]"}], "+", 
      RowBox[{"ArcSin", "[", 
       RowBox[{"e", "/", 
        RowBox[{"(", 
         RowBox[{"l", "+", "r"}], ")"}]}], "]"}]}], ")"}], "/", "Degree"}], "//",
    "N"}]}]], "Input"],

Cell[BoxData["158.`"], "Output",
 CellChangeTimes->{3.466870846478878*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mymin", "=", 
  RowBox[{
   RowBox[{"ArcCos", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"e", "+", "r"}], ")"}], "/", "l"}], "]"}], "/", 
   "Degree"}]}]], "Input"],

Cell[BoxData["40.49107299647172`"], "Output",
 CellChangeTimes->{3.4668708465464897`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"s", " ", "=", " ", 
  RowBox[{
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "phi", "]"}]}], " ", "+", " ", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"l", "^", "2"}], " ", "-", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"e", "+", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", "phi", "]"}]}]}], ")"}], "^", "2"}]}], 
    "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"27.46849500873934`", " ", 
   RowBox[{"Cos", "[", "phi", "]"}]}], "+", 
  SqrtBox[
   RowBox[{"4750.384274654764`", "\[InvisibleSpace]", "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"24.947962853546766`", "\[InvisibleSpace]", "+", 
       RowBox[{"27.46849500873934`", " ", 
        RowBox[{"Sin", "[", "phi", "]"}]}]}], ")"}], "2"]}]]}]], "Output",
 CellChangeTimes->{3.46687084661814*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"phi", "=", 
   RowBox[{"phiG", "*", "Degree"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{"s", ",", 
   RowBox[{"{", 
    RowBox[{"phiG", ",", 
     RowBox[{"-", "40"}], ",", "400"}], "}"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<phi(Degree)\>\"", ",", "None"}], "}"}]}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<s (phi)\>\""}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "40"}], ",", "400"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "100"}], "}"}]}], "}"}]}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "phi", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.4668708415888987`*^9, 3.4668708424023113`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV2gk0VF8YAHCyi0S2FCH7ln1L+WbsS3bz7Jmx72JmUCGiQrtIlESLCtmS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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"phi(Degree)\"", TraditionalForm], None},
  AxesOrigin->{0, 0},
  GridLines->Automatic,
  PlotLabel->FormBox["\"s (phi)\"", TraditionalForm],
  PlotRange->{{-40, 400}, {0, 100}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.466870846812533*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{878, 802},
WindowMargins->{{39, Automatic}, {-5, Automatic}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"6.0 for Mac OS X PowerPC (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 57, 0, 67, "Section"],
Cell[650, 25, 195, 5, 41, "Text"],
Cell[CellGroupData[{
Cell[870, 34, 127, 3, 34, "Subsection"],
Cell[1000, 39, 147, 4, 27, "Input"],
Cell[CellGroupData[{
Cell[1172, 47, 102, 1, 27, "Input"],
Cell[1277, 50, 295, 8, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1609, 63, 63, 1, 27, "Input"],
Cell[1675, 66, 91, 2, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1803, 73, 72, 1, 27, "Input"],
Cell[1878, 76, 179, 5, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2094, 86, 68, 1, 27, "Input"],
Cell[2165, 89, 244, 7, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2446, 101, 86, 1, 27, "Input"],
Cell[2535, 104, 185, 5, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2757, 114, 68, 1, 27, "Input"],
Cell[2828, 117, 294, 9, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3159, 131, 78, 1, 27, "Input"],
Cell[3240, 134, 559, 17, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3836, 156, 72, 1, 27, "Input"],
Cell[3911, 159, 381, 11, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4329, 175, 30, 0, 27, "Input"],
Cell[4362, 177, 295, 8, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4694, 190, 101, 5, 53, "Input"],
Cell[4798, 197, 87, 1, 27, "Output"],
Cell[4888, 200, 87, 1, 27, "Output"],
Cell[4978, 203, 88, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5103, 209, 40, 0, 25, "Subsubsection"],
Cell[CellGroupData[{
Cell[5168, 213, 104, 3, 27, "Input"],
Cell[5275, 218, 87, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5399, 224, 411, 14, 27, "Input"],
Cell[5813, 240, 89, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5939, 246, 419, 14, 27, "Input"],
Cell[6361, 262, 74, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6472, 268, 197, 7, 27, "Input"],
Cell[6672, 277, 89, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6798, 283, 397, 13, 27, "Input"],
Cell[7198, 298, 439, 11, 38, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7674, 314, 898, 25, 73, "Input"],
Cell[8575, 341, 12176, 206, 235, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
